#include <assert.h>

#include <aterm2.h>
#include <deprecated.h>
#include "ASFME.h"

/**
 * Converts a string to an ATermList of integers (ASCII values). 
 * \param[in] str An ASCII string
 * \return An ATermList containing the ASCII values of #arg as ATermInts
 */
ATerm ASF_stringToChars(const char *str) {
  int len = strlen(str);
  int i;
  ATermList result = ATempty;

  for (i = len - 1; i >= 0; i--) {
    result = ATinsert(result, (ATerm) ATmakeInt(str[i]));
  }

  return (ATerm) result;
}

/**
 * Converts an ASCII char to an ATermInt. 
 * \param[in] ch an ASCII character
 * \return An ATerm representing the ASCII value of #arg
 */
ATerm ASF_byteToChar(char ch) {
    return (ATerm) ATmakeInt(ch);
}

/**
 * Converts a list of integers (ASCII values) to a C string. 
 * \param[in] arg An ATermList with ATermInts, such as [32,32,10]
 * \return String containing the characters from #arg as characters
 */
char *ASF_charsToString(ATerm arg) {
  ATermList list = (ATermList) arg;
  int len = ATgetLength(list);
  int i;
  char *str;

  str = (char *) malloc(len+1);
  if (str == NULL) {
      return NULL;
  }

  for (i = 0; !ATisEmpty(list); list = ATgetNext(list), i++) {
    str[i] = (char) ATgetInt((ATermInt) ATgetFirst(list));
  }
  str[i] = '\0';

  return str;
}

char ASF_charToByte(ATerm arg) {
    return (char) ATgetInt((ATermInt) arg);
}


typedef struct ATerm _ASF_OptLayout;
typedef struct ATerm _ASF_Layout;
typedef struct ATerm _ASF_LexLayoutList;
typedef struct ATerm _ASF_Tree;
typedef struct ATerm _ASF_LexCHAR;
typedef struct ATerm _ASF_CHAR;
typedef struct ATerm _ASF_ASFCondition;
typedef struct ATerm _ASF_ASFConditions;
typedef struct ATerm _ASF_ASFConditionList;
typedef struct ATerm _ASF_TreeAmbs;
typedef struct ATerm _ASF_CHARList;
typedef struct ATerm _ASF_LexASFBarEnd;
typedef struct ATerm _ASF_ASFBarEnd;
typedef struct ATerm _ASF_LexASFImplies;
typedef struct ATerm _ASF_ASFImplies;
typedef struct ATerm _ASF_ASFConditionalEquation;
typedef struct ATerm _ASF_ASFEquation;
typedef struct ATerm _ASF_Start;
typedef struct ATerm _ASF_ASFModule;
typedef struct ATerm _ASF_ASFSection;
typedef struct ATerm _ASF_ASFSectionList;
typedef struct ATerm _ASF_ASFConditionalEquationList;
typedef struct ATerm _ASF_ASFTestEquationTestList;
typedef struct ATerm _ASF_LexASFTagId;
typedef struct ATerm _ASF_ASFTagId;
typedef struct ATerm _ASF_ASFTag;
typedef struct ATerm _ASF_ASFTestEquation;
typedef struct ATerm _ASF_LexLayout;
typedef struct ATerm _ASF_LexNumChar;
typedef struct ATerm _ASF_NumChar;
typedef struct ATerm _ASF_LexShortChar;
typedef struct ATerm _ASF_ShortChar;
typedef struct ATerm _ASF_Character;


/**
 * Initializes the full API. Forgetting to call this function before using the API will lead to strange behaviour. ATinit() needs to be called before this function.
 */
void _ASF_initASFMEApi(void) {
  init_ASFME_dict();

}

/**
 * Protect a ASF_OptLayout from the ATerm garbage collector. Every ASF_OptLayout that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_OptLayout
 */
void _ASF_protectOptLayout(ASF_OptLayout *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_OptLayout from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_OptLayout
 */
void _ASF_unprotectOptLayout(ASF_OptLayout *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_Layout from the ATerm garbage collector. Every ASF_Layout that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_Layout
 */
void _ASF_protectLayout(ASF_Layout *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_Layout from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_Layout
 */
void _ASF_unprotectLayout(ASF_Layout *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_LexLayoutList from the ATerm garbage collector. Every ASF_LexLayoutList that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_LexLayoutList
 */
void _ASF_protectLexLayoutList(ASF_LexLayoutList *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_LexLayoutList from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_LexLayoutList
 */
void _ASF_unprotectLexLayoutList(ASF_LexLayoutList *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_Tree from the ATerm garbage collector. Every ASF_Tree that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_Tree
 */
void _ASF_protectTree(ASF_Tree *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_Tree from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_Tree
 */
void _ASF_unprotectTree(ASF_Tree *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_LexCHAR from the ATerm garbage collector. Every ASF_LexCHAR that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_LexCHAR
 */
void _ASF_protectLexCHAR(ASF_LexCHAR *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_LexCHAR from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_LexCHAR
 */
void _ASF_unprotectLexCHAR(ASF_LexCHAR *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_CHAR from the ATerm garbage collector. Every ASF_CHAR that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_CHAR
 */
void _ASF_protectCHAR(ASF_CHAR *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_CHAR from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_CHAR
 */
void _ASF_unprotectCHAR(ASF_CHAR *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_ASFCondition from the ATerm garbage collector. Every ASF_ASFCondition that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_ASFCondition
 */
void _ASF_protectASFCondition(ASF_ASFCondition *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_ASFCondition from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_ASFCondition
 */
void _ASF_unprotectASFCondition(ASF_ASFCondition *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_ASFConditions from the ATerm garbage collector. Every ASF_ASFConditions that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_ASFConditions
 */
void _ASF_protectASFConditions(ASF_ASFConditions *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_ASFConditions from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_ASFConditions
 */
void _ASF_unprotectASFConditions(ASF_ASFConditions *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_ASFConditionList from the ATerm garbage collector. Every ASF_ASFConditionList that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_ASFConditionList
 */
void _ASF_protectASFConditionList(ASF_ASFConditionList *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_ASFConditionList from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_ASFConditionList
 */
void _ASF_unprotectASFConditionList(ASF_ASFConditionList *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_TreeAmbs from the ATerm garbage collector. Every ASF_TreeAmbs that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_TreeAmbs
 */
void _ASF_protectTreeAmbs(ASF_TreeAmbs *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_TreeAmbs from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_TreeAmbs
 */
void _ASF_unprotectTreeAmbs(ASF_TreeAmbs *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_CHARList from the ATerm garbage collector. Every ASF_CHARList that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_CHARList
 */
void _ASF_protectCHARList(ASF_CHARList *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_CHARList from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_CHARList
 */
void _ASF_unprotectCHARList(ASF_CHARList *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_LexASFBarEnd from the ATerm garbage collector. Every ASF_LexASFBarEnd that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_LexASFBarEnd
 */
void _ASF_protectLexASFBarEnd(ASF_LexASFBarEnd *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_LexASFBarEnd from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_LexASFBarEnd
 */
void _ASF_unprotectLexASFBarEnd(ASF_LexASFBarEnd *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_ASFBarEnd from the ATerm garbage collector. Every ASF_ASFBarEnd that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_ASFBarEnd
 */
void _ASF_protectASFBarEnd(ASF_ASFBarEnd *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_ASFBarEnd from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_ASFBarEnd
 */
void _ASF_unprotectASFBarEnd(ASF_ASFBarEnd *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_LexASFImplies from the ATerm garbage collector. Every ASF_LexASFImplies that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_LexASFImplies
 */
void _ASF_protectLexASFImplies(ASF_LexASFImplies *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_LexASFImplies from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_LexASFImplies
 */
void _ASF_unprotectLexASFImplies(ASF_LexASFImplies *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_ASFImplies from the ATerm garbage collector. Every ASF_ASFImplies that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_ASFImplies
 */
void _ASF_protectASFImplies(ASF_ASFImplies *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_ASFImplies from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_ASFImplies
 */
void _ASF_unprotectASFImplies(ASF_ASFImplies *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_ASFConditionalEquation from the ATerm garbage collector. Every ASF_ASFConditionalEquation that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_ASFConditionalEquation
 */
void _ASF_protectASFConditionalEquation(ASF_ASFConditionalEquation *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_ASFConditionalEquation from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_ASFConditionalEquation
 */
void _ASF_unprotectASFConditionalEquation(ASF_ASFConditionalEquation *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_ASFEquation from the ATerm garbage collector. Every ASF_ASFEquation that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_ASFEquation
 */
void _ASF_protectASFEquation(ASF_ASFEquation *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_ASFEquation from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_ASFEquation
 */
void _ASF_unprotectASFEquation(ASF_ASFEquation *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_Start from the ATerm garbage collector. Every ASF_Start that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_Start
 */
void _ASF_protectStart(ASF_Start *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_Start from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_Start
 */
void _ASF_unprotectStart(ASF_Start *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_ASFModule from the ATerm garbage collector. Every ASF_ASFModule that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_ASFModule
 */
void _ASF_protectASFModule(ASF_ASFModule *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_ASFModule from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_ASFModule
 */
void _ASF_unprotectASFModule(ASF_ASFModule *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_ASFSection from the ATerm garbage collector. Every ASF_ASFSection that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_ASFSection
 */
void _ASF_protectASFSection(ASF_ASFSection *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_ASFSection from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_ASFSection
 */
void _ASF_unprotectASFSection(ASF_ASFSection *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_ASFSectionList from the ATerm garbage collector. Every ASF_ASFSectionList that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_ASFSectionList
 */
void _ASF_protectASFSectionList(ASF_ASFSectionList *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_ASFSectionList from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_ASFSectionList
 */
void _ASF_unprotectASFSectionList(ASF_ASFSectionList *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_ASFConditionalEquationList from the ATerm garbage collector. Every ASF_ASFConditionalEquationList that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_ASFConditionalEquationList
 */
void _ASF_protectASFConditionalEquationList(ASF_ASFConditionalEquationList *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_ASFConditionalEquationList from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_ASFConditionalEquationList
 */
void _ASF_unprotectASFConditionalEquationList(ASF_ASFConditionalEquationList *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_ASFTestEquationTestList from the ATerm garbage collector. Every ASF_ASFTestEquationTestList that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_ASFTestEquationTestList
 */
void _ASF_protectASFTestEquationTestList(ASF_ASFTestEquationTestList *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_ASFTestEquationTestList from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_ASFTestEquationTestList
 */
void _ASF_unprotectASFTestEquationTestList(ASF_ASFTestEquationTestList *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_LexASFTagId from the ATerm garbage collector. Every ASF_LexASFTagId that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_LexASFTagId
 */
void _ASF_protectLexASFTagId(ASF_LexASFTagId *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_LexASFTagId from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_LexASFTagId
 */
void _ASF_unprotectLexASFTagId(ASF_LexASFTagId *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_ASFTagId from the ATerm garbage collector. Every ASF_ASFTagId that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_ASFTagId
 */
void _ASF_protectASFTagId(ASF_ASFTagId *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_ASFTagId from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_ASFTagId
 */
void _ASF_unprotectASFTagId(ASF_ASFTagId *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_ASFTag from the ATerm garbage collector. Every ASF_ASFTag that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_ASFTag
 */
void _ASF_protectASFTag(ASF_ASFTag *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_ASFTag from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_ASFTag
 */
void _ASF_unprotectASFTag(ASF_ASFTag *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_ASFTestEquation from the ATerm garbage collector. Every ASF_ASFTestEquation that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_ASFTestEquation
 */
void _ASF_protectASFTestEquation(ASF_ASFTestEquation *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_ASFTestEquation from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_ASFTestEquation
 */
void _ASF_unprotectASFTestEquation(ASF_ASFTestEquation *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_LexLayout from the ATerm garbage collector. Every ASF_LexLayout that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_LexLayout
 */
void _ASF_protectLexLayout(ASF_LexLayout *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_LexLayout from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_LexLayout
 */
void _ASF_unprotectLexLayout(ASF_LexLayout *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_LexNumChar from the ATerm garbage collector. Every ASF_LexNumChar that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_LexNumChar
 */
void _ASF_protectLexNumChar(ASF_LexNumChar *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_LexNumChar from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_LexNumChar
 */
void _ASF_unprotectLexNumChar(ASF_LexNumChar *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_NumChar from the ATerm garbage collector. Every ASF_NumChar that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_NumChar
 */
void _ASF_protectNumChar(ASF_NumChar *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_NumChar from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_NumChar
 */
void _ASF_unprotectNumChar(ASF_NumChar *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_LexShortChar from the ATerm garbage collector. Every ASF_LexShortChar that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_LexShortChar
 */
void _ASF_protectLexShortChar(ASF_LexShortChar *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_LexShortChar from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_LexShortChar
 */
void _ASF_unprotectLexShortChar(ASF_LexShortChar *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_ShortChar from the ATerm garbage collector. Every ASF_ShortChar that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_ShortChar
 */
void _ASF_protectShortChar(ASF_ShortChar *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_ShortChar from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_ShortChar
 */
void _ASF_unprotectShortChar(ASF_ShortChar *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a ASF_Character from the ATerm garbage collector. Every ASF_Character that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a ASF_Character
 */
void _ASF_protectCharacter(ASF_Character *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a ASF_Character from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a ASF_Character
 */
void _ASF_unprotectCharacter(ASF_Character *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Transforms an ATerm to a ASF_OptLayout. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_OptLayout that was encoded by \arg
 */
ASF_OptLayout _ASF_OptLayoutFromTerm(ATerm t) {
  return (ASF_OptLayout)t;
}

/**
 * Transforms a ASF_OptLayoutto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_OptLayout to be converted
 * \return ATerm that represents the ASF_OptLayout
 */
ATerm _ASF_OptLayoutToTerm(ASF_OptLayout arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_Layout. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_Layout that was encoded by \arg
 */
ASF_Layout _ASF_LayoutFromTerm(ATerm t) {
  return (ASF_Layout)t;
}

/**
 * Transforms a ASF_Layoutto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_Layout to be converted
 * \return ATerm that represents the ASF_Layout
 */
ATerm _ASF_LayoutToTerm(ASF_Layout arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_LexLayoutList. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_LexLayoutList that was encoded by \arg
 */
ASF_LexLayoutList _ASF_LexLayoutListFromTerm(ATerm t) {
  return (ASF_LexLayoutList)t;
}

/**
 * Transforms a ASF_LexLayoutListto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_LexLayoutList to be converted
 * \return ATerm that represents the ASF_LexLayoutList
 */
ATerm _ASF_LexLayoutListToTerm(ASF_LexLayoutList arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_Tree. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_Tree that was encoded by \arg
 */
ASF_Tree _ASF_TreeFromTerm(ATerm t) {
  return (ASF_Tree)t;
}

/**
 * Transforms a ASF_Treeto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_Tree to be converted
 * \return ATerm that represents the ASF_Tree
 */
ATerm _ASF_TreeToTerm(ASF_Tree arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_LexCHAR. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_LexCHAR that was encoded by \arg
 */
ASF_LexCHAR _ASF_LexCHARFromTerm(ATerm t) {
  return (ASF_LexCHAR)t;
}

/**
 * Transforms a ASF_LexCHARto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_LexCHAR to be converted
 * \return ATerm that represents the ASF_LexCHAR
 */
ATerm _ASF_LexCHARToTerm(ASF_LexCHAR arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_CHAR. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_CHAR that was encoded by \arg
 */
ASF_CHAR _ASF_CHARFromTerm(ATerm t) {
  return (ASF_CHAR)t;
}

/**
 * Transforms a ASF_CHARto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_CHAR to be converted
 * \return ATerm that represents the ASF_CHAR
 */
ATerm _ASF_CHARToTerm(ASF_CHAR arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_ASFCondition. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_ASFCondition that was encoded by \arg
 */
ASF_ASFCondition _ASF_ASFConditionFromTerm(ATerm t) {
  return (ASF_ASFCondition)t;
}

/**
 * Transforms a ASF_ASFConditionto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_ASFCondition to be converted
 * \return ATerm that represents the ASF_ASFCondition
 */
ATerm _ASF_ASFConditionToTerm(ASF_ASFCondition arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_ASFConditions. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_ASFConditions that was encoded by \arg
 */
ASF_ASFConditions _ASF_ASFConditionsFromTerm(ATerm t) {
  return (ASF_ASFConditions)t;
}

/**
 * Transforms a ASF_ASFConditionsto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_ASFConditions to be converted
 * \return ATerm that represents the ASF_ASFConditions
 */
ATerm _ASF_ASFConditionsToTerm(ASF_ASFConditions arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_ASFConditionList. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_ASFConditionList that was encoded by \arg
 */
ASF_ASFConditionList _ASF_ASFConditionListFromTerm(ATerm t) {
  return (ASF_ASFConditionList)t;
}

/**
 * Transforms a ASF_ASFConditionListto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_ASFConditionList to be converted
 * \return ATerm that represents the ASF_ASFConditionList
 */
ATerm _ASF_ASFConditionListToTerm(ASF_ASFConditionList arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_TreeAmbs. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_TreeAmbs that was encoded by \arg
 */
ASF_TreeAmbs _ASF_TreeAmbsFromTerm(ATerm t) {
  return (ASF_TreeAmbs)t;
}

/**
 * Transforms a ASF_TreeAmbsto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_TreeAmbs to be converted
 * \return ATerm that represents the ASF_TreeAmbs
 */
ATerm _ASF_TreeAmbsToTerm(ASF_TreeAmbs arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_CHARList. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_CHARList that was encoded by \arg
 */
ASF_CHARList _ASF_CHARListFromTerm(ATerm t) {
  return (ASF_CHARList)t;
}

/**
 * Transforms a ASF_CHARListto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_CHARList to be converted
 * \return ATerm that represents the ASF_CHARList
 */
ATerm _ASF_CHARListToTerm(ASF_CHARList arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_LexASFBarEnd. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_LexASFBarEnd that was encoded by \arg
 */
ASF_LexASFBarEnd _ASF_LexASFBarEndFromTerm(ATerm t) {
  return (ASF_LexASFBarEnd)t;
}

/**
 * Transforms a ASF_LexASFBarEndto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_LexASFBarEnd to be converted
 * \return ATerm that represents the ASF_LexASFBarEnd
 */
ATerm _ASF_LexASFBarEndToTerm(ASF_LexASFBarEnd arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_ASFBarEnd. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_ASFBarEnd that was encoded by \arg
 */
ASF_ASFBarEnd _ASF_ASFBarEndFromTerm(ATerm t) {
  return (ASF_ASFBarEnd)t;
}

/**
 * Transforms a ASF_ASFBarEndto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_ASFBarEnd to be converted
 * \return ATerm that represents the ASF_ASFBarEnd
 */
ATerm _ASF_ASFBarEndToTerm(ASF_ASFBarEnd arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_LexASFImplies. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_LexASFImplies that was encoded by \arg
 */
ASF_LexASFImplies _ASF_LexASFImpliesFromTerm(ATerm t) {
  return (ASF_LexASFImplies)t;
}

/**
 * Transforms a ASF_LexASFImpliesto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_LexASFImplies to be converted
 * \return ATerm that represents the ASF_LexASFImplies
 */
ATerm _ASF_LexASFImpliesToTerm(ASF_LexASFImplies arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_ASFImplies. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_ASFImplies that was encoded by \arg
 */
ASF_ASFImplies _ASF_ASFImpliesFromTerm(ATerm t) {
  return (ASF_ASFImplies)t;
}

/**
 * Transforms a ASF_ASFImpliesto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_ASFImplies to be converted
 * \return ATerm that represents the ASF_ASFImplies
 */
ATerm _ASF_ASFImpliesToTerm(ASF_ASFImplies arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_ASFConditionalEquation. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_ASFConditionalEquation that was encoded by \arg
 */
ASF_ASFConditionalEquation _ASF_ASFConditionalEquationFromTerm(ATerm t) {
  return (ASF_ASFConditionalEquation)t;
}

/**
 * Transforms a ASF_ASFConditionalEquationto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_ASFConditionalEquation to be converted
 * \return ATerm that represents the ASF_ASFConditionalEquation
 */
ATerm _ASF_ASFConditionalEquationToTerm(ASF_ASFConditionalEquation arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_ASFEquation. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_ASFEquation that was encoded by \arg
 */
ASF_ASFEquation _ASF_ASFEquationFromTerm(ATerm t) {
  return (ASF_ASFEquation)t;
}

/**
 * Transforms a ASF_ASFEquationto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_ASFEquation to be converted
 * \return ATerm that represents the ASF_ASFEquation
 */
ATerm _ASF_ASFEquationToTerm(ASF_ASFEquation arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_Start. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_Start that was encoded by \arg
 */
ASF_Start _ASF_StartFromTerm(ATerm t) {
  return (ASF_Start)t;
}

/**
 * Transforms a ASF_Startto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_Start to be converted
 * \return ATerm that represents the ASF_Start
 */
ATerm _ASF_StartToTerm(ASF_Start arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_ASFModule. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_ASFModule that was encoded by \arg
 */
ASF_ASFModule _ASF_ASFModuleFromTerm(ATerm t) {
  return (ASF_ASFModule)t;
}

/**
 * Transforms a ASF_ASFModuleto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_ASFModule to be converted
 * \return ATerm that represents the ASF_ASFModule
 */
ATerm _ASF_ASFModuleToTerm(ASF_ASFModule arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_ASFSection. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_ASFSection that was encoded by \arg
 */
ASF_ASFSection _ASF_ASFSectionFromTerm(ATerm t) {
  return (ASF_ASFSection)t;
}

/**
 * Transforms a ASF_ASFSectionto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_ASFSection to be converted
 * \return ATerm that represents the ASF_ASFSection
 */
ATerm _ASF_ASFSectionToTerm(ASF_ASFSection arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_ASFSectionList. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_ASFSectionList that was encoded by \arg
 */
ASF_ASFSectionList _ASF_ASFSectionListFromTerm(ATerm t) {
  return (ASF_ASFSectionList)t;
}

/**
 * Transforms a ASF_ASFSectionListto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_ASFSectionList to be converted
 * \return ATerm that represents the ASF_ASFSectionList
 */
ATerm _ASF_ASFSectionListToTerm(ASF_ASFSectionList arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_ASFConditionalEquationList. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_ASFConditionalEquationList that was encoded by \arg
 */
ASF_ASFConditionalEquationList _ASF_ASFConditionalEquationListFromTerm(ATerm t) {
  return (ASF_ASFConditionalEquationList)t;
}

/**
 * Transforms a ASF_ASFConditionalEquationListto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_ASFConditionalEquationList to be converted
 * \return ATerm that represents the ASF_ASFConditionalEquationList
 */
ATerm _ASF_ASFConditionalEquationListToTerm(ASF_ASFConditionalEquationList arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_ASFTestEquationTestList. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_ASFTestEquationTestList that was encoded by \arg
 */
ASF_ASFTestEquationTestList _ASF_ASFTestEquationTestListFromTerm(ATerm t) {
  return (ASF_ASFTestEquationTestList)t;
}

/**
 * Transforms a ASF_ASFTestEquationTestListto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_ASFTestEquationTestList to be converted
 * \return ATerm that represents the ASF_ASFTestEquationTestList
 */
ATerm _ASF_ASFTestEquationTestListToTerm(ASF_ASFTestEquationTestList arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_LexASFTagId. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_LexASFTagId that was encoded by \arg
 */
ASF_LexASFTagId _ASF_LexASFTagIdFromTerm(ATerm t) {
  return (ASF_LexASFTagId)t;
}

/**
 * Transforms a ASF_LexASFTagIdto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_LexASFTagId to be converted
 * \return ATerm that represents the ASF_LexASFTagId
 */
ATerm _ASF_LexASFTagIdToTerm(ASF_LexASFTagId arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_ASFTagId. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_ASFTagId that was encoded by \arg
 */
ASF_ASFTagId _ASF_ASFTagIdFromTerm(ATerm t) {
  return (ASF_ASFTagId)t;
}

/**
 * Transforms a ASF_ASFTagIdto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_ASFTagId to be converted
 * \return ATerm that represents the ASF_ASFTagId
 */
ATerm _ASF_ASFTagIdToTerm(ASF_ASFTagId arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_ASFTag. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_ASFTag that was encoded by \arg
 */
ASF_ASFTag _ASF_ASFTagFromTerm(ATerm t) {
  return (ASF_ASFTag)t;
}

/**
 * Transforms a ASF_ASFTagto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_ASFTag to be converted
 * \return ATerm that represents the ASF_ASFTag
 */
ATerm _ASF_ASFTagToTerm(ASF_ASFTag arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_ASFTestEquation. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_ASFTestEquation that was encoded by \arg
 */
ASF_ASFTestEquation _ASF_ASFTestEquationFromTerm(ATerm t) {
  return (ASF_ASFTestEquation)t;
}

/**
 * Transforms a ASF_ASFTestEquationto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_ASFTestEquation to be converted
 * \return ATerm that represents the ASF_ASFTestEquation
 */
ATerm _ASF_ASFTestEquationToTerm(ASF_ASFTestEquation arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_LexLayout. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_LexLayout that was encoded by \arg
 */
ASF_LexLayout _ASF_LexLayoutFromTerm(ATerm t) {
  return (ASF_LexLayout)t;
}

/**
 * Transforms a ASF_LexLayoutto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_LexLayout to be converted
 * \return ATerm that represents the ASF_LexLayout
 */
ATerm _ASF_LexLayoutToTerm(ASF_LexLayout arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_LexNumChar. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_LexNumChar that was encoded by \arg
 */
ASF_LexNumChar _ASF_LexNumCharFromTerm(ATerm t) {
  return (ASF_LexNumChar)t;
}

/**
 * Transforms a ASF_LexNumCharto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_LexNumChar to be converted
 * \return ATerm that represents the ASF_LexNumChar
 */
ATerm _ASF_LexNumCharToTerm(ASF_LexNumChar arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_NumChar. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_NumChar that was encoded by \arg
 */
ASF_NumChar _ASF_NumCharFromTerm(ATerm t) {
  return (ASF_NumChar)t;
}

/**
 * Transforms a ASF_NumCharto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_NumChar to be converted
 * \return ATerm that represents the ASF_NumChar
 */
ATerm _ASF_NumCharToTerm(ASF_NumChar arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_LexShortChar. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_LexShortChar that was encoded by \arg
 */
ASF_LexShortChar _ASF_LexShortCharFromTerm(ATerm t) {
  return (ASF_LexShortChar)t;
}

/**
 * Transforms a ASF_LexShortCharto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_LexShortChar to be converted
 * \return ATerm that represents the ASF_LexShortChar
 */
ATerm _ASF_LexShortCharToTerm(ASF_LexShortChar arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_ShortChar. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_ShortChar that was encoded by \arg
 */
ASF_ShortChar _ASF_ShortCharFromTerm(ATerm t) {
  return (ASF_ShortChar)t;
}

/**
 * Transforms a ASF_ShortCharto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_ShortChar to be converted
 * \return ATerm that represents the ASF_ShortChar
 */
ATerm _ASF_ShortCharToTerm(ASF_ShortChar arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a ASF_Character. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return ASF_Character that was encoded by \arg
 */
ASF_Character _ASF_CharacterFromTerm(ATerm t) {
  return (ASF_Character)t;
}

/**
 * Transforms a ASF_Characterto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg ASF_Character to be converted
 * \return ATerm that represents the ASF_Character
 */
ATerm _ASF_CharacterToTerm(ASF_Character arg) {
  return (ATerm)arg;
}

/**
 * Retrieve the length of a ASF_LexLayoutList. 
 * \param[in] arg input ASF_LexLayoutList
 * \return The number of elements in the ASF_LexLayoutList
 */
int _ASF_getLexLayoutListLength(ASF_LexLayoutList arg) {
  return ATgetLength((ATermList) arg);
}

/**
 * Reverse a ASF_LexLayoutList. 
 * \param[in] arg ASF_LexLayoutList to be reversed
 * \return a reversed #arg
 */
ASF_LexLayoutList _ASF_reverseLexLayoutList(ASF_LexLayoutList arg) {
  return (ASF_LexLayoutList) ATreverse((ATermList) arg);
}

/**
 * Append a ASF_LexLayout to the end of a ASF_LexLayoutList. 
 * \param[in] arg ASF_LexLayoutList to append the ASF_LexLayout to
 * \param[in] elem ASF_LexLayout to be appended
 * \return new ASF_LexLayoutList with #elem appended
 */
ASF_LexLayoutList _ASF_appendLexLayoutList(ASF_LexLayoutList arg, ASF_LexLayout elem) {
  return (ASF_LexLayoutList) ATappend((ATermList) arg, (ATerm) ((ATerm) elem));
}

/**
 * Concatenate two ASF_LexLayoutLists. 
 * \param[in] arg0 first ASF_LexLayoutList
 * \param[in] arg1 second ASF_LexLayoutList
 * \return ASF_LexLayoutList with the elements of #arg0 before the elements of #arg1
 */
ASF_LexLayoutList _ASF_concatLexLayoutList(ASF_LexLayoutList arg0, ASF_LexLayoutList arg1) {
  return (ASF_LexLayoutList) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a ASF_LexLayoutList. 
 * \param[in] arg ASF_LexLayoutList to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new ASF_LexLayoutList with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
ASF_LexLayoutList _ASF_sliceLexLayoutList(ASF_LexLayoutList arg, int start, int end) {
  return (ASF_LexLayoutList) ATgetSlice((ATermList) arg, start, end);
}

/**
 * Retrieve the ASF_LexLayout at #index from a ASF_LexLayoutList. 
 * \param[in] arg ASF_LexLayoutList to retrieve the ASF_LexLayout from
 * \param[in] index index to use to point in the ASF_LexLayoutList
 * \return ASF_LexLayout at position #index in #arg
 */
ASF_LexLayout _ASF_getLexLayoutListLexLayoutAt(ASF_LexLayoutList arg, int index) {
 return (ASF_LexLayout)ATelementAt((ATermList) arg,index);
}

/**
 * Replace the ASF_LexLayout at #index from a ASF_LexLayoutList by a new one. 
 * \param[in] arg ASF_LexLayoutList to retrieve the ASF_LexLayout from
 * \param[in] elem new ASF_LexLayout to replace another
 * \param[in] index index to use to point in the ASF_LexLayoutList
 * \return A new ASF_LexLayoutListwith #elem replaced in #arg at position #index
 */
ASF_LexLayoutList _ASF_replaceLexLayoutListLexLayoutAt(ASF_LexLayoutList arg, ASF_LexLayout elem, int index) {
 return (ASF_LexLayoutList) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index);
}

/**
 * Builds a ASF_LexLayoutList of 2 consecutive elements. 
 * \param[in] elem1 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \param[in] elem2 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \return A new ASF_LexLayoutList consisting of 2 ASF_LexLayouts
 */
ASF_LexLayoutList _ASF_makeLexLayoutList2(ASF_LexLayout elem1, ASF_LexLayout elem2) {
  return (ASF_LexLayoutList) ATmakeList2((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2));
}

/**
 * Builds a ASF_LexLayoutList of 3 consecutive elements. 
 * \param[in] elem1 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \param[in] elem2 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \param[in] elem3 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \return A new ASF_LexLayoutList consisting of 3 ASF_LexLayouts
 */
ASF_LexLayoutList _ASF_makeLexLayoutList3(ASF_LexLayout elem1, ASF_LexLayout elem2, ASF_LexLayout elem3) {
  return (ASF_LexLayoutList) ATmakeList3((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3));
}

/**
 * Builds a ASF_LexLayoutList of 4 consecutive elements. 
 * \param[in] elem1 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \param[in] elem2 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \param[in] elem3 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \param[in] elem4 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \return A new ASF_LexLayoutList consisting of 4 ASF_LexLayouts
 */
ASF_LexLayoutList _ASF_makeLexLayoutList4(ASF_LexLayout elem1, ASF_LexLayout elem2, ASF_LexLayout elem3, ASF_LexLayout elem4) {
  return (ASF_LexLayoutList) ATmakeList4((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3), (ATerm) ((ATerm) elem4));
}

/**
 * Builds a ASF_LexLayoutList of 5 consecutive elements. 
 * \param[in] elem1 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \param[in] elem2 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \param[in] elem3 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \param[in] elem4 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \param[in] elem5 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \return A new ASF_LexLayoutList consisting of 5 ASF_LexLayouts
 */
ASF_LexLayoutList _ASF_makeLexLayoutList5(ASF_LexLayout elem1, ASF_LexLayout elem2, ASF_LexLayout elem3, ASF_LexLayout elem4, ASF_LexLayout elem5) {
  return (ASF_LexLayoutList) ATmakeList5((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3), (ATerm) ((ATerm) elem4), (ATerm) ((ATerm) elem5));
}

/**
 * Builds a ASF_LexLayoutList of 6 consecutive elements. 
 * \param[in] elem1 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \param[in] elem2 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \param[in] elem3 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \param[in] elem4 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \param[in] elem5 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \param[in] elem6 One ASF_LexLayout element of the new ASF_LexLayoutList
 * \return A new ASF_LexLayoutList consisting of 6 ASF_LexLayouts
 */
ASF_LexLayoutList _ASF_makeLexLayoutList6(ASF_LexLayout elem1, ASF_LexLayout elem2, ASF_LexLayout elem3, ASF_LexLayout elem4, ASF_LexLayout elem5, ASF_LexLayout elem6) {
  return (ASF_LexLayoutList) ATmakeList6((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3), (ATerm) ((ATerm) elem4), (ATerm) ((ATerm) elem5), (ATerm) ((ATerm) elem6));
}

/**
 * Retrieve the number of elements in a ASF_ASFConditionList. 
 * \param[in] arg input ASF_ASFConditionList
 * \return The number of elements in #arg, excluding any separators
 */
int _ASF_getASFConditionListLength(ASF_ASFConditionList arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 4) + 1;
}

/**
 * Reverses the elements of a ASF_ASFConditionList. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg ASF_ASFConditionList to be reversed
 * \return #arg reversed
 */
ASF_ASFConditionList ASF_reverseASFConditionList(ASF_ASFConditionList arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATerm sep1;
  ATerm sep2;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep2);
    result = ATinsert(result, sep1);
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (ASF_ASFConditionList) result;
}

/**
 * Append a ASF_ASFCondition to the end of a ASF_ASFConditionList. 
 * \param[in] arg ASF_ASFConditionList to append the ASF_ASFCondition to
 * \param[in] elem ASF_ASFCondition to be appended
 * \return new ASF_ASFConditionList with #elem appended after the separators
 */
ASF_ASFConditionList ASF_appendASFConditionList(ASF_ASFConditionList arg0, ASF_OptLayout wsAfterHead, ASF_OptLayout wsAfterSep, ASF_ASFCondition arg1) {
  return ASF_concatASFConditionList(arg0, wsAfterHead, wsAfterSep, ASF_makeASFConditionListSingle(arg1));
}

/**
 * Concatenate two ASF_ASFConditionLists. 
 * \param[in] arg0 first ASF_ASFConditionList
 * \param[in] arg1 second ASF_ASFConditionList
 * \return ASF_ASFConditionList with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
ASF_ASFConditionList ASF_concatASFConditionList(ASF_ASFConditionList arg0, ASF_OptLayout wsAfterHead, ASF_OptLayout wsAfterSep, ASF_ASFConditionList arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = ASF_makeASFConditionListMany((ASF_ASFCondition)ATgetFirst((ATermList) arg0), wsAfterHead, wsAfterSep,  arg1);
  arg1 = (ASF_ASFConditionList) ATgetNext((ATermList) arg1);
  return (ASF_ASFConditionList) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a ASF_ASFConditionList. 
 * \param[in] arg ASF_ASFConditionList to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new ASF_ASFConditionList with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
ASF_ASFConditionList _ASF_sliceASFConditionList(ASF_ASFConditionList arg, int start, int end) {
  return (ASF_ASFConditionList) ATgetSlice((ATermList) arg, start * 4, end * 4);
}

/**
 * Retrieve the ASF_ASFCondition at #index from a ASF_ASFConditionList. 
 * \param[in] arg ASF_ASFConditionList to retrieve the ASF_ASFCondition from
 * \param[in] index index to use to point in the ASF_ASFConditionList
 * \return ASF_ASFCondition at position #index in #arg
 */
ASF_ASFCondition _ASF_getASFConditionListASFConditionAt(ASF_ASFConditionList arg, int index) {
 return (ASF_ASFCondition)ATelementAt((ATermList) arg,index * 4);
}

/**
 * Replace the ASF_ASFCondition at #index from a ASF_ASFConditionList by a new one. 
 * \param[in] arg ASF_ASFConditionList to retrieve the ASF_ASFCondition from
 * \param[in] elem new ASF_ASFCondition to replace another
 * \param[in] index index to use to point in the ASF_ASFConditionList
 * \return A new ASF_ASFConditionListwith #elem replaced in #arg at position #index
 */
ASF_ASFConditionList _ASF_replaceASFConditionListASFConditionAt(ASF_ASFConditionList arg, ASF_ASFCondition elem, int index) {
 return (ASF_ASFConditionList) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 4);
}

/**
 * Builds a ASF_ASFConditionList of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \param[in] elem2 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \return A new ASF_ASFConditionList consisting of 2 ASF_ASFConditions
 */
ASF_ASFConditionList ASF_makeASFConditionList2(ASF_OptLayout wsAfterHead, ASF_OptLayout wsAfterSep, ASF_ASFCondition elem1, ASF_ASFCondition elem2) {
  return ASF_makeASFConditionListMany(elem1, wsAfterHead, wsAfterSep, ASF_makeASFConditionListSingle(elem2));
}

/**
 * Builds a ASF_ASFConditionList of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \param[in] elem2 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \param[in] elem3 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \return A new ASF_ASFConditionList consisting of 3 ASF_ASFConditions
 */
ASF_ASFConditionList ASF_makeASFConditionList3(ASF_OptLayout wsAfterHead, ASF_OptLayout wsAfterSep, ASF_ASFCondition elem1, ASF_ASFCondition elem2, ASF_ASFCondition elem3) {
  return ASF_makeASFConditionListMany(elem1, wsAfterHead, wsAfterSep, ASF_makeASFConditionList2(wsAfterHead, wsAfterSep, elem2, elem3));
}

/**
 * Builds a ASF_ASFConditionList of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \param[in] elem2 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \param[in] elem3 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \param[in] elem4 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \return A new ASF_ASFConditionList consisting of 4 ASF_ASFConditions
 */
ASF_ASFConditionList ASF_makeASFConditionList4(ASF_OptLayout wsAfterHead, ASF_OptLayout wsAfterSep, ASF_ASFCondition elem1, ASF_ASFCondition elem2, ASF_ASFCondition elem3, ASF_ASFCondition elem4) {
  return ASF_makeASFConditionListMany(elem1, wsAfterHead, wsAfterSep, ASF_makeASFConditionList3(wsAfterHead, wsAfterSep, elem2, elem3, elem4));
}

/**
 * Builds a ASF_ASFConditionList of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \param[in] elem2 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \param[in] elem3 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \param[in] elem4 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \param[in] elem5 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \return A new ASF_ASFConditionList consisting of 5 ASF_ASFConditions
 */
ASF_ASFConditionList ASF_makeASFConditionList5(ASF_OptLayout wsAfterHead, ASF_OptLayout wsAfterSep, ASF_ASFCondition elem1, ASF_ASFCondition elem2, ASF_ASFCondition elem3, ASF_ASFCondition elem4, ASF_ASFCondition elem5) {
  return ASF_makeASFConditionListMany(elem1, wsAfterHead, wsAfterSep, ASF_makeASFConditionList4(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5));
}

/**
 * Builds a ASF_ASFConditionList of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \param[in] elem2 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \param[in] elem3 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \param[in] elem4 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \param[in] elem5 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \param[in] elem6 One ASF_ASFCondition element of the new ASF_ASFConditionList
 * \return A new ASF_ASFConditionList consisting of 6 ASF_ASFConditions
 */
ASF_ASFConditionList ASF_makeASFConditionList6(ASF_OptLayout wsAfterHead, ASF_OptLayout wsAfterSep, ASF_ASFCondition elem1, ASF_ASFCondition elem2, ASF_ASFCondition elem3, ASF_ASFCondition elem4, ASF_ASFCondition elem5, ASF_ASFCondition elem6) {
  return ASF_makeASFConditionListMany(elem1, wsAfterHead, wsAfterSep, ASF_makeASFConditionList5(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the number of elements in a ASF_TreeAmbs. 
 * \param[in] arg input ASF_TreeAmbs
 * \return The number of elements in #arg, excluding any separators
 */
int _ASF_getTreeAmbsLength(ASF_TreeAmbs arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 4) + 1;
}

/**
 * Reverses the elements of a ASF_TreeAmbs. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg ASF_TreeAmbs to be reversed
 * \return #arg reversed
 */
ASF_TreeAmbs ASF_reverseTreeAmbs(ASF_TreeAmbs arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATerm sep1;
  ATerm sep2;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep2);
    result = ATinsert(result, sep1);
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (ASF_TreeAmbs) result;
}

/**
 * Append a ASF_Tree to the end of a ASF_TreeAmbs. 
 * \param[in] arg ASF_TreeAmbs to append the ASF_Tree to
 * \param[in] elem ASF_Tree to be appended
 * \return new ASF_TreeAmbs with #elem appended after the separators
 */
ASF_TreeAmbs ASF_appendTreeAmbs(ASF_TreeAmbs arg0, ASF_OptLayout wsAfterHead, ASF_OptLayout wsAfterSep, ASF_Tree arg1) {
  return ASF_concatTreeAmbs(arg0, wsAfterHead, wsAfterSep, ASF_makeTreeAmbsSingle(arg1));
}

/**
 * Concatenate two ASF_TreeAmbss. 
 * \param[in] arg0 first ASF_TreeAmbs
 * \param[in] arg1 second ASF_TreeAmbs
 * \return ASF_TreeAmbs with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
ASF_TreeAmbs ASF_concatTreeAmbs(ASF_TreeAmbs arg0, ASF_OptLayout wsAfterHead, ASF_OptLayout wsAfterSep, ASF_TreeAmbs arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = ASF_makeTreeAmbsMany((ASF_Tree)ATgetFirst((ATermList) arg0), wsAfterHead, wsAfterSep,  arg1);
  arg1 = (ASF_TreeAmbs) ATgetNext((ATermList) arg1);
  return (ASF_TreeAmbs) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a ASF_TreeAmbs. 
 * \param[in] arg ASF_TreeAmbs to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new ASF_TreeAmbs with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
ASF_TreeAmbs _ASF_sliceTreeAmbs(ASF_TreeAmbs arg, int start, int end) {
  return (ASF_TreeAmbs) ATgetSlice((ATermList) arg, start * 4, end * 4);
}

/**
 * Retrieve the ASF_Tree at #index from a ASF_TreeAmbs. 
 * \param[in] arg ASF_TreeAmbs to retrieve the ASF_Tree from
 * \param[in] index index to use to point in the ASF_TreeAmbs
 * \return ASF_Tree at position #index in #arg
 */
ASF_Tree _ASF_getTreeAmbsTreeAt(ASF_TreeAmbs arg, int index) {
 return (ASF_Tree)ATelementAt((ATermList) arg,index * 4);
}

/**
 * Replace the ASF_Tree at #index from a ASF_TreeAmbs by a new one. 
 * \param[in] arg ASF_TreeAmbs to retrieve the ASF_Tree from
 * \param[in] elem new ASF_Tree to replace another
 * \param[in] index index to use to point in the ASF_TreeAmbs
 * \return A new ASF_TreeAmbswith #elem replaced in #arg at position #index
 */
ASF_TreeAmbs _ASF_replaceTreeAmbsTreeAt(ASF_TreeAmbs arg, ASF_Tree elem, int index) {
 return (ASF_TreeAmbs) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 4);
}

/**
 * Builds a ASF_TreeAmbs of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_Tree element of the new ASF_TreeAmbs
 * \param[in] elem2 One ASF_Tree element of the new ASF_TreeAmbs
 * \return A new ASF_TreeAmbs consisting of 2 ASF_Trees
 */
ASF_TreeAmbs ASF_makeTreeAmbs2(ASF_OptLayout wsAfterHead, ASF_OptLayout wsAfterSep, ASF_Tree elem1, ASF_Tree elem2) {
  return ASF_makeTreeAmbsMany(elem1, wsAfterHead, wsAfterSep, ASF_makeTreeAmbsSingle(elem2));
}

/**
 * Builds a ASF_TreeAmbs of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_Tree element of the new ASF_TreeAmbs
 * \param[in] elem2 One ASF_Tree element of the new ASF_TreeAmbs
 * \param[in] elem3 One ASF_Tree element of the new ASF_TreeAmbs
 * \return A new ASF_TreeAmbs consisting of 3 ASF_Trees
 */
ASF_TreeAmbs ASF_makeTreeAmbs3(ASF_OptLayout wsAfterHead, ASF_OptLayout wsAfterSep, ASF_Tree elem1, ASF_Tree elem2, ASF_Tree elem3) {
  return ASF_makeTreeAmbsMany(elem1, wsAfterHead, wsAfterSep, ASF_makeTreeAmbs2(wsAfterHead, wsAfterSep, elem2, elem3));
}

/**
 * Builds a ASF_TreeAmbs of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_Tree element of the new ASF_TreeAmbs
 * \param[in] elem2 One ASF_Tree element of the new ASF_TreeAmbs
 * \param[in] elem3 One ASF_Tree element of the new ASF_TreeAmbs
 * \param[in] elem4 One ASF_Tree element of the new ASF_TreeAmbs
 * \return A new ASF_TreeAmbs consisting of 4 ASF_Trees
 */
ASF_TreeAmbs ASF_makeTreeAmbs4(ASF_OptLayout wsAfterHead, ASF_OptLayout wsAfterSep, ASF_Tree elem1, ASF_Tree elem2, ASF_Tree elem3, ASF_Tree elem4) {
  return ASF_makeTreeAmbsMany(elem1, wsAfterHead, wsAfterSep, ASF_makeTreeAmbs3(wsAfterHead, wsAfterSep, elem2, elem3, elem4));
}

/**
 * Builds a ASF_TreeAmbs of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_Tree element of the new ASF_TreeAmbs
 * \param[in] elem2 One ASF_Tree element of the new ASF_TreeAmbs
 * \param[in] elem3 One ASF_Tree element of the new ASF_TreeAmbs
 * \param[in] elem4 One ASF_Tree element of the new ASF_TreeAmbs
 * \param[in] elem5 One ASF_Tree element of the new ASF_TreeAmbs
 * \return A new ASF_TreeAmbs consisting of 5 ASF_Trees
 */
ASF_TreeAmbs ASF_makeTreeAmbs5(ASF_OptLayout wsAfterHead, ASF_OptLayout wsAfterSep, ASF_Tree elem1, ASF_Tree elem2, ASF_Tree elem3, ASF_Tree elem4, ASF_Tree elem5) {
  return ASF_makeTreeAmbsMany(elem1, wsAfterHead, wsAfterSep, ASF_makeTreeAmbs4(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5));
}

/**
 * Builds a ASF_TreeAmbs of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_Tree element of the new ASF_TreeAmbs
 * \param[in] elem2 One ASF_Tree element of the new ASF_TreeAmbs
 * \param[in] elem3 One ASF_Tree element of the new ASF_TreeAmbs
 * \param[in] elem4 One ASF_Tree element of the new ASF_TreeAmbs
 * \param[in] elem5 One ASF_Tree element of the new ASF_TreeAmbs
 * \param[in] elem6 One ASF_Tree element of the new ASF_TreeAmbs
 * \return A new ASF_TreeAmbs consisting of 6 ASF_Trees
 */
ASF_TreeAmbs ASF_makeTreeAmbs6(ASF_OptLayout wsAfterHead, ASF_OptLayout wsAfterSep, ASF_Tree elem1, ASF_Tree elem2, ASF_Tree elem3, ASF_Tree elem4, ASF_Tree elem5, ASF_Tree elem6) {
  return ASF_makeTreeAmbsMany(elem1, wsAfterHead, wsAfterSep, ASF_makeTreeAmbs5(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the number of elements in a ASF_CHARList. 
 * \param[in] arg input ASF_CHARList
 * \return The number of elements in #arg, excluding any separators
 */
int _ASF_getCHARListLength(ASF_CHARList arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 2) + 1;
}

/**
 * Reverses the elements of a ASF_CHARList. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg ASF_CHARList to be reversed
 * \return #arg reversed
 */
ASF_CHARList ASF_reverseCHARList(ASF_CHARList arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (ASF_CHARList) result;
}

/**
 * Append a ASF_CHAR to the end of a ASF_CHARList. 
 * \param[in] arg ASF_CHARList to append the ASF_CHAR to
 * \param[in] elem ASF_CHAR to be appended
 * \return new ASF_CHARList with #elem appended after the separators
 */
ASF_CHARList ASF_appendCHARList(ASF_CHARList arg0, ASF_OptLayout wsAfterHead, ASF_CHAR arg1) {
  return ASF_concatCHARList(arg0, wsAfterHead, ASF_makeCHARListSingle(arg1));
}

/**
 * Concatenate two ASF_CHARLists. 
 * \param[in] arg0 first ASF_CHARList
 * \param[in] arg1 second ASF_CHARList
 * \return ASF_CHARList with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
ASF_CHARList ASF_concatCHARList(ASF_CHARList arg0, ASF_OptLayout wsAfterHead, ASF_CHARList arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = ASF_makeCHARListMany((ASF_CHAR)ATgetFirst((ATermList) arg0), wsAfterHead,  arg1);
  arg1 = (ASF_CHARList) ATgetNext((ATermList) arg1);
  return (ASF_CHARList) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a ASF_CHARList. 
 * \param[in] arg ASF_CHARList to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new ASF_CHARList with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
ASF_CHARList _ASF_sliceCHARList(ASF_CHARList arg, int start, int end) {
  return (ASF_CHARList) ATgetSlice((ATermList) arg, start * 2, end * 2);
}

/**
 * Retrieve the ASF_CHAR at #index from a ASF_CHARList. 
 * \param[in] arg ASF_CHARList to retrieve the ASF_CHAR from
 * \param[in] index index to use to point in the ASF_CHARList
 * \return ASF_CHAR at position #index in #arg
 */
ASF_CHAR _ASF_getCHARListCHARAt(ASF_CHARList arg, int index) {
 return (ASF_CHAR)ATelementAt((ATermList) arg,index * 2);
}

/**
 * Replace the ASF_CHAR at #index from a ASF_CHARList by a new one. 
 * \param[in] arg ASF_CHARList to retrieve the ASF_CHAR from
 * \param[in] elem new ASF_CHAR to replace another
 * \param[in] index index to use to point in the ASF_CHARList
 * \return A new ASF_CHARListwith #elem replaced in #arg at position #index
 */
ASF_CHARList _ASF_replaceCHARListCHARAt(ASF_CHARList arg, ASF_CHAR elem, int index) {
 return (ASF_CHARList) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 2);
}

/**
 * Builds a ASF_CHARList of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_CHAR element of the new ASF_CHARList
 * \param[in] elem2 One ASF_CHAR element of the new ASF_CHARList
 * \return A new ASF_CHARList consisting of 2 ASF_CHARs
 */
ASF_CHARList ASF_makeCHARList2(ASF_OptLayout wsAfterHead, ASF_CHAR elem1, ASF_CHAR elem2) {
  return ASF_makeCHARListMany(elem1, wsAfterHead, ASF_makeCHARListSingle(elem2));
}

/**
 * Builds a ASF_CHARList of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_CHAR element of the new ASF_CHARList
 * \param[in] elem2 One ASF_CHAR element of the new ASF_CHARList
 * \param[in] elem3 One ASF_CHAR element of the new ASF_CHARList
 * \return A new ASF_CHARList consisting of 3 ASF_CHARs
 */
ASF_CHARList ASF_makeCHARList3(ASF_OptLayout wsAfterHead, ASF_CHAR elem1, ASF_CHAR elem2, ASF_CHAR elem3) {
  return ASF_makeCHARListMany(elem1, wsAfterHead, ASF_makeCHARList2(wsAfterHead, elem2, elem3));
}

/**
 * Builds a ASF_CHARList of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_CHAR element of the new ASF_CHARList
 * \param[in] elem2 One ASF_CHAR element of the new ASF_CHARList
 * \param[in] elem3 One ASF_CHAR element of the new ASF_CHARList
 * \param[in] elem4 One ASF_CHAR element of the new ASF_CHARList
 * \return A new ASF_CHARList consisting of 4 ASF_CHARs
 */
ASF_CHARList ASF_makeCHARList4(ASF_OptLayout wsAfterHead, ASF_CHAR elem1, ASF_CHAR elem2, ASF_CHAR elem3, ASF_CHAR elem4) {
  return ASF_makeCHARListMany(elem1, wsAfterHead, ASF_makeCHARList3(wsAfterHead, elem2, elem3, elem4));
}

/**
 * Builds a ASF_CHARList of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_CHAR element of the new ASF_CHARList
 * \param[in] elem2 One ASF_CHAR element of the new ASF_CHARList
 * \param[in] elem3 One ASF_CHAR element of the new ASF_CHARList
 * \param[in] elem4 One ASF_CHAR element of the new ASF_CHARList
 * \param[in] elem5 One ASF_CHAR element of the new ASF_CHARList
 * \return A new ASF_CHARList consisting of 5 ASF_CHARs
 */
ASF_CHARList ASF_makeCHARList5(ASF_OptLayout wsAfterHead, ASF_CHAR elem1, ASF_CHAR elem2, ASF_CHAR elem3, ASF_CHAR elem4, ASF_CHAR elem5) {
  return ASF_makeCHARListMany(elem1, wsAfterHead, ASF_makeCHARList4(wsAfterHead, elem2, elem3, elem4, elem5));
}

/**
 * Builds a ASF_CHARList of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_CHAR element of the new ASF_CHARList
 * \param[in] elem2 One ASF_CHAR element of the new ASF_CHARList
 * \param[in] elem3 One ASF_CHAR element of the new ASF_CHARList
 * \param[in] elem4 One ASF_CHAR element of the new ASF_CHARList
 * \param[in] elem5 One ASF_CHAR element of the new ASF_CHARList
 * \param[in] elem6 One ASF_CHAR element of the new ASF_CHARList
 * \return A new ASF_CHARList consisting of 6 ASF_CHARs
 */
ASF_CHARList ASF_makeCHARList6(ASF_OptLayout wsAfterHead, ASF_CHAR elem1, ASF_CHAR elem2, ASF_CHAR elem3, ASF_CHAR elem4, ASF_CHAR elem5, ASF_CHAR elem6) {
  return ASF_makeCHARListMany(elem1, wsAfterHead, ASF_makeCHARList5(wsAfterHead, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the number of elements in a ASF_ASFSectionList. 
 * \param[in] arg input ASF_ASFSectionList
 * \return The number of elements in #arg, excluding any separators
 */
int _ASF_getASFSectionListLength(ASF_ASFSectionList arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 2) + 1;
}

/**
 * Reverses the elements of a ASF_ASFSectionList. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg ASF_ASFSectionList to be reversed
 * \return #arg reversed
 */
ASF_ASFSectionList ASF_reverseASFSectionList(ASF_ASFSectionList arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (ASF_ASFSectionList) result;
}

/**
 * Append a ASF_ASFSection to the end of a ASF_ASFSectionList. 
 * \param[in] arg ASF_ASFSectionList to append the ASF_ASFSection to
 * \param[in] elem ASF_ASFSection to be appended
 * \return new ASF_ASFSectionList with #elem appended after the separators
 */
ASF_ASFSectionList ASF_appendASFSectionList(ASF_ASFSectionList arg0, ASF_OptLayout wsAfterHead, ASF_ASFSection arg1) {
  return ASF_concatASFSectionList(arg0, wsAfterHead, ASF_makeASFSectionListSingle(arg1));
}

/**
 * Concatenate two ASF_ASFSectionLists. 
 * \param[in] arg0 first ASF_ASFSectionList
 * \param[in] arg1 second ASF_ASFSectionList
 * \return ASF_ASFSectionList with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
ASF_ASFSectionList ASF_concatASFSectionList(ASF_ASFSectionList arg0, ASF_OptLayout wsAfterHead, ASF_ASFSectionList arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = ASF_makeASFSectionListMany((ASF_ASFSection)ATgetFirst((ATermList) arg0), wsAfterHead,  arg1);
  arg1 = (ASF_ASFSectionList) ATgetNext((ATermList) arg1);
  return (ASF_ASFSectionList) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a ASF_ASFSectionList. 
 * \param[in] arg ASF_ASFSectionList to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new ASF_ASFSectionList with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
ASF_ASFSectionList _ASF_sliceASFSectionList(ASF_ASFSectionList arg, int start, int end) {
  return (ASF_ASFSectionList) ATgetSlice((ATermList) arg, start * 2, end * 2);
}

/**
 * Retrieve the ASF_ASFSection at #index from a ASF_ASFSectionList. 
 * \param[in] arg ASF_ASFSectionList to retrieve the ASF_ASFSection from
 * \param[in] index index to use to point in the ASF_ASFSectionList
 * \return ASF_ASFSection at position #index in #arg
 */
ASF_ASFSection _ASF_getASFSectionListASFSectionAt(ASF_ASFSectionList arg, int index) {
 return (ASF_ASFSection)ATelementAt((ATermList) arg,index * 2);
}

/**
 * Replace the ASF_ASFSection at #index from a ASF_ASFSectionList by a new one. 
 * \param[in] arg ASF_ASFSectionList to retrieve the ASF_ASFSection from
 * \param[in] elem new ASF_ASFSection to replace another
 * \param[in] index index to use to point in the ASF_ASFSectionList
 * \return A new ASF_ASFSectionListwith #elem replaced in #arg at position #index
 */
ASF_ASFSectionList _ASF_replaceASFSectionListASFSectionAt(ASF_ASFSectionList arg, ASF_ASFSection elem, int index) {
 return (ASF_ASFSectionList) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 2);
}

/**
 * Builds a ASF_ASFSectionList of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \param[in] elem2 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \return A new ASF_ASFSectionList consisting of 2 ASF_ASFSections
 */
ASF_ASFSectionList ASF_makeASFSectionList2(ASF_OptLayout wsAfterHead, ASF_ASFSection elem1, ASF_ASFSection elem2) {
  return ASF_makeASFSectionListMany(elem1, wsAfterHead, ASF_makeASFSectionListSingle(elem2));
}

/**
 * Builds a ASF_ASFSectionList of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \param[in] elem2 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \param[in] elem3 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \return A new ASF_ASFSectionList consisting of 3 ASF_ASFSections
 */
ASF_ASFSectionList ASF_makeASFSectionList3(ASF_OptLayout wsAfterHead, ASF_ASFSection elem1, ASF_ASFSection elem2, ASF_ASFSection elem3) {
  return ASF_makeASFSectionListMany(elem1, wsAfterHead, ASF_makeASFSectionList2(wsAfterHead, elem2, elem3));
}

/**
 * Builds a ASF_ASFSectionList of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \param[in] elem2 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \param[in] elem3 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \param[in] elem4 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \return A new ASF_ASFSectionList consisting of 4 ASF_ASFSections
 */
ASF_ASFSectionList ASF_makeASFSectionList4(ASF_OptLayout wsAfterHead, ASF_ASFSection elem1, ASF_ASFSection elem2, ASF_ASFSection elem3, ASF_ASFSection elem4) {
  return ASF_makeASFSectionListMany(elem1, wsAfterHead, ASF_makeASFSectionList3(wsAfterHead, elem2, elem3, elem4));
}

/**
 * Builds a ASF_ASFSectionList of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \param[in] elem2 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \param[in] elem3 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \param[in] elem4 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \param[in] elem5 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \return A new ASF_ASFSectionList consisting of 5 ASF_ASFSections
 */
ASF_ASFSectionList ASF_makeASFSectionList5(ASF_OptLayout wsAfterHead, ASF_ASFSection elem1, ASF_ASFSection elem2, ASF_ASFSection elem3, ASF_ASFSection elem4, ASF_ASFSection elem5) {
  return ASF_makeASFSectionListMany(elem1, wsAfterHead, ASF_makeASFSectionList4(wsAfterHead, elem2, elem3, elem4, elem5));
}

/**
 * Builds a ASF_ASFSectionList of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \param[in] elem2 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \param[in] elem3 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \param[in] elem4 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \param[in] elem5 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \param[in] elem6 One ASF_ASFSection element of the new ASF_ASFSectionList
 * \return A new ASF_ASFSectionList consisting of 6 ASF_ASFSections
 */
ASF_ASFSectionList ASF_makeASFSectionList6(ASF_OptLayout wsAfterHead, ASF_ASFSection elem1, ASF_ASFSection elem2, ASF_ASFSection elem3, ASF_ASFSection elem4, ASF_ASFSection elem5, ASF_ASFSection elem6) {
  return ASF_makeASFSectionListMany(elem1, wsAfterHead, ASF_makeASFSectionList5(wsAfterHead, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the number of elements in a ASF_ASFConditionalEquationList. 
 * \param[in] arg input ASF_ASFConditionalEquationList
 * \return The number of elements in #arg, excluding any separators
 */
int _ASF_getASFConditionalEquationListLength(ASF_ASFConditionalEquationList arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 2) + 1;
}

/**
 * Reverses the elements of a ASF_ASFConditionalEquationList. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg ASF_ASFConditionalEquationList to be reversed
 * \return #arg reversed
 */
ASF_ASFConditionalEquationList ASF_reverseASFConditionalEquationList(ASF_ASFConditionalEquationList arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (ASF_ASFConditionalEquationList) result;
}

/**
 * Append a ASF_ASFConditionalEquation to the end of a ASF_ASFConditionalEquationList. 
 * \param[in] arg ASF_ASFConditionalEquationList to append the ASF_ASFConditionalEquation to
 * \param[in] elem ASF_ASFConditionalEquation to be appended
 * \return new ASF_ASFConditionalEquationList with #elem appended after the separators
 */
ASF_ASFConditionalEquationList ASF_appendASFConditionalEquationList(ASF_ASFConditionalEquationList arg0, ASF_OptLayout wsAfterHead, ASF_ASFConditionalEquation arg1) {
  return ASF_concatASFConditionalEquationList(arg0, wsAfterHead, ASF_makeASFConditionalEquationListSingle(arg1));
}

/**
 * Concatenate two ASF_ASFConditionalEquationLists. 
 * \param[in] arg0 first ASF_ASFConditionalEquationList
 * \param[in] arg1 second ASF_ASFConditionalEquationList
 * \return ASF_ASFConditionalEquationList with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
ASF_ASFConditionalEquationList ASF_concatASFConditionalEquationList(ASF_ASFConditionalEquationList arg0, ASF_OptLayout wsAfterHead, ASF_ASFConditionalEquationList arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = ASF_makeASFConditionalEquationListMany((ASF_ASFConditionalEquation)ATgetFirst((ATermList) arg0), wsAfterHead,  arg1);
  arg1 = (ASF_ASFConditionalEquationList) ATgetNext((ATermList) arg1);
  return (ASF_ASFConditionalEquationList) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a ASF_ASFConditionalEquationList. 
 * \param[in] arg ASF_ASFConditionalEquationList to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new ASF_ASFConditionalEquationList with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
ASF_ASFConditionalEquationList _ASF_sliceASFConditionalEquationList(ASF_ASFConditionalEquationList arg, int start, int end) {
  return (ASF_ASFConditionalEquationList) ATgetSlice((ATermList) arg, start * 2, end * 2);
}

/**
 * Retrieve the ASF_ASFConditionalEquation at #index from a ASF_ASFConditionalEquationList. 
 * \param[in] arg ASF_ASFConditionalEquationList to retrieve the ASF_ASFConditionalEquation from
 * \param[in] index index to use to point in the ASF_ASFConditionalEquationList
 * \return ASF_ASFConditionalEquation at position #index in #arg
 */
ASF_ASFConditionalEquation _ASF_getASFConditionalEquationListASFConditionalEquationAt(ASF_ASFConditionalEquationList arg, int index) {
 return (ASF_ASFConditionalEquation)ATelementAt((ATermList) arg,index * 2);
}

/**
 * Replace the ASF_ASFConditionalEquation at #index from a ASF_ASFConditionalEquationList by a new one. 
 * \param[in] arg ASF_ASFConditionalEquationList to retrieve the ASF_ASFConditionalEquation from
 * \param[in] elem new ASF_ASFConditionalEquation to replace another
 * \param[in] index index to use to point in the ASF_ASFConditionalEquationList
 * \return A new ASF_ASFConditionalEquationListwith #elem replaced in #arg at position #index
 */
ASF_ASFConditionalEquationList _ASF_replaceASFConditionalEquationListASFConditionalEquationAt(ASF_ASFConditionalEquationList arg, ASF_ASFConditionalEquation elem, int index) {
 return (ASF_ASFConditionalEquationList) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 2);
}

/**
 * Builds a ASF_ASFConditionalEquationList of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \param[in] elem2 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \return A new ASF_ASFConditionalEquationList consisting of 2 ASF_ASFConditionalEquations
 */
ASF_ASFConditionalEquationList ASF_makeASFConditionalEquationList2(ASF_OptLayout wsAfterHead, ASF_ASFConditionalEquation elem1, ASF_ASFConditionalEquation elem2) {
  return ASF_makeASFConditionalEquationListMany(elem1, wsAfterHead, ASF_makeASFConditionalEquationListSingle(elem2));
}

/**
 * Builds a ASF_ASFConditionalEquationList of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \param[in] elem2 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \param[in] elem3 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \return A new ASF_ASFConditionalEquationList consisting of 3 ASF_ASFConditionalEquations
 */
ASF_ASFConditionalEquationList ASF_makeASFConditionalEquationList3(ASF_OptLayout wsAfterHead, ASF_ASFConditionalEquation elem1, ASF_ASFConditionalEquation elem2, ASF_ASFConditionalEquation elem3) {
  return ASF_makeASFConditionalEquationListMany(elem1, wsAfterHead, ASF_makeASFConditionalEquationList2(wsAfterHead, elem2, elem3));
}

/**
 * Builds a ASF_ASFConditionalEquationList of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \param[in] elem2 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \param[in] elem3 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \param[in] elem4 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \return A new ASF_ASFConditionalEquationList consisting of 4 ASF_ASFConditionalEquations
 */
ASF_ASFConditionalEquationList ASF_makeASFConditionalEquationList4(ASF_OptLayout wsAfterHead, ASF_ASFConditionalEquation elem1, ASF_ASFConditionalEquation elem2, ASF_ASFConditionalEquation elem3, ASF_ASFConditionalEquation elem4) {
  return ASF_makeASFConditionalEquationListMany(elem1, wsAfterHead, ASF_makeASFConditionalEquationList3(wsAfterHead, elem2, elem3, elem4));
}

/**
 * Builds a ASF_ASFConditionalEquationList of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \param[in] elem2 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \param[in] elem3 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \param[in] elem4 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \param[in] elem5 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \return A new ASF_ASFConditionalEquationList consisting of 5 ASF_ASFConditionalEquations
 */
ASF_ASFConditionalEquationList ASF_makeASFConditionalEquationList5(ASF_OptLayout wsAfterHead, ASF_ASFConditionalEquation elem1, ASF_ASFConditionalEquation elem2, ASF_ASFConditionalEquation elem3, ASF_ASFConditionalEquation elem4, ASF_ASFConditionalEquation elem5) {
  return ASF_makeASFConditionalEquationListMany(elem1, wsAfterHead, ASF_makeASFConditionalEquationList4(wsAfterHead, elem2, elem3, elem4, elem5));
}

/**
 * Builds a ASF_ASFConditionalEquationList of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \param[in] elem2 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \param[in] elem3 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \param[in] elem4 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \param[in] elem5 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \param[in] elem6 One ASF_ASFConditionalEquation element of the new ASF_ASFConditionalEquationList
 * \return A new ASF_ASFConditionalEquationList consisting of 6 ASF_ASFConditionalEquations
 */
ASF_ASFConditionalEquationList ASF_makeASFConditionalEquationList6(ASF_OptLayout wsAfterHead, ASF_ASFConditionalEquation elem1, ASF_ASFConditionalEquation elem2, ASF_ASFConditionalEquation elem3, ASF_ASFConditionalEquation elem4, ASF_ASFConditionalEquation elem5, ASF_ASFConditionalEquation elem6) {
  return ASF_makeASFConditionalEquationListMany(elem1, wsAfterHead, ASF_makeASFConditionalEquationList5(wsAfterHead, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the number of elements in a ASF_ASFTestEquationTestList. 
 * \param[in] arg input ASF_ASFTestEquationTestList
 * \return The number of elements in #arg, excluding any separators
 */
int _ASF_getASFTestEquationTestListLength(ASF_ASFTestEquationTestList arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 2) + 1;
}

/**
 * Reverses the elements of a ASF_ASFTestEquationTestList. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg ASF_ASFTestEquationTestList to be reversed
 * \return #arg reversed
 */
ASF_ASFTestEquationTestList ASF_reverseASFTestEquationTestList(ASF_ASFTestEquationTestList arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (ASF_ASFTestEquationTestList) result;
}

/**
 * Append a ASF_ASFTestEquation to the end of a ASF_ASFTestEquationTestList. 
 * \param[in] arg ASF_ASFTestEquationTestList to append the ASF_ASFTestEquation to
 * \param[in] elem ASF_ASFTestEquation to be appended
 * \return new ASF_ASFTestEquationTestList with #elem appended after the separators
 */
ASF_ASFTestEquationTestList ASF_appendASFTestEquationTestList(ASF_ASFTestEquationTestList arg0, ASF_OptLayout wsAfterHead, ASF_ASFTestEquation arg1) {
  return ASF_concatASFTestEquationTestList(arg0, wsAfterHead, ASF_makeASFTestEquationTestListSingle(arg1));
}

/**
 * Concatenate two ASF_ASFTestEquationTestLists. 
 * \param[in] arg0 first ASF_ASFTestEquationTestList
 * \param[in] arg1 second ASF_ASFTestEquationTestList
 * \return ASF_ASFTestEquationTestList with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
ASF_ASFTestEquationTestList ASF_concatASFTestEquationTestList(ASF_ASFTestEquationTestList arg0, ASF_OptLayout wsAfterHead, ASF_ASFTestEquationTestList arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = ASF_makeASFTestEquationTestListMany((ASF_ASFTestEquation)ATgetFirst((ATermList) arg0), wsAfterHead,  arg1);
  arg1 = (ASF_ASFTestEquationTestList) ATgetNext((ATermList) arg1);
  return (ASF_ASFTestEquationTestList) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a ASF_ASFTestEquationTestList. 
 * \param[in] arg ASF_ASFTestEquationTestList to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new ASF_ASFTestEquationTestList with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
ASF_ASFTestEquationTestList _ASF_sliceASFTestEquationTestList(ASF_ASFTestEquationTestList arg, int start, int end) {
  return (ASF_ASFTestEquationTestList) ATgetSlice((ATermList) arg, start * 2, end * 2);
}

/**
 * Retrieve the ASF_ASFTestEquation at #index from a ASF_ASFTestEquationTestList. 
 * \param[in] arg ASF_ASFTestEquationTestList to retrieve the ASF_ASFTestEquation from
 * \param[in] index index to use to point in the ASF_ASFTestEquationTestList
 * \return ASF_ASFTestEquation at position #index in #arg
 */
ASF_ASFTestEquation _ASF_getASFTestEquationTestListASFTestEquationAt(ASF_ASFTestEquationTestList arg, int index) {
 return (ASF_ASFTestEquation)ATelementAt((ATermList) arg,index * 2);
}

/**
 * Replace the ASF_ASFTestEquation at #index from a ASF_ASFTestEquationTestList by a new one. 
 * \param[in] arg ASF_ASFTestEquationTestList to retrieve the ASF_ASFTestEquation from
 * \param[in] elem new ASF_ASFTestEquation to replace another
 * \param[in] index index to use to point in the ASF_ASFTestEquationTestList
 * \return A new ASF_ASFTestEquationTestListwith #elem replaced in #arg at position #index
 */
ASF_ASFTestEquationTestList _ASF_replaceASFTestEquationTestListASFTestEquationAt(ASF_ASFTestEquationTestList arg, ASF_ASFTestEquation elem, int index) {
 return (ASF_ASFTestEquationTestList) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 2);
}

/**
 * Builds a ASF_ASFTestEquationTestList of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \param[in] elem2 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \return A new ASF_ASFTestEquationTestList consisting of 2 ASF_ASFTestEquations
 */
ASF_ASFTestEquationTestList ASF_makeASFTestEquationTestList2(ASF_OptLayout wsAfterHead, ASF_ASFTestEquation elem1, ASF_ASFTestEquation elem2) {
  return ASF_makeASFTestEquationTestListMany(elem1, wsAfterHead, ASF_makeASFTestEquationTestListSingle(elem2));
}

/**
 * Builds a ASF_ASFTestEquationTestList of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \param[in] elem2 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \param[in] elem3 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \return A new ASF_ASFTestEquationTestList consisting of 3 ASF_ASFTestEquations
 */
ASF_ASFTestEquationTestList ASF_makeASFTestEquationTestList3(ASF_OptLayout wsAfterHead, ASF_ASFTestEquation elem1, ASF_ASFTestEquation elem2, ASF_ASFTestEquation elem3) {
  return ASF_makeASFTestEquationTestListMany(elem1, wsAfterHead, ASF_makeASFTestEquationTestList2(wsAfterHead, elem2, elem3));
}

/**
 * Builds a ASF_ASFTestEquationTestList of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \param[in] elem2 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \param[in] elem3 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \param[in] elem4 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \return A new ASF_ASFTestEquationTestList consisting of 4 ASF_ASFTestEquations
 */
ASF_ASFTestEquationTestList ASF_makeASFTestEquationTestList4(ASF_OptLayout wsAfterHead, ASF_ASFTestEquation elem1, ASF_ASFTestEquation elem2, ASF_ASFTestEquation elem3, ASF_ASFTestEquation elem4) {
  return ASF_makeASFTestEquationTestListMany(elem1, wsAfterHead, ASF_makeASFTestEquationTestList3(wsAfterHead, elem2, elem3, elem4));
}

/**
 * Builds a ASF_ASFTestEquationTestList of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \param[in] elem2 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \param[in] elem3 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \param[in] elem4 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \param[in] elem5 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \return A new ASF_ASFTestEquationTestList consisting of 5 ASF_ASFTestEquations
 */
ASF_ASFTestEquationTestList ASF_makeASFTestEquationTestList5(ASF_OptLayout wsAfterHead, ASF_ASFTestEquation elem1, ASF_ASFTestEquation elem2, ASF_ASFTestEquation elem3, ASF_ASFTestEquation elem4, ASF_ASFTestEquation elem5) {
  return ASF_makeASFTestEquationTestListMany(elem1, wsAfterHead, ASF_makeASFTestEquationTestList4(wsAfterHead, elem2, elem3, elem4, elem5));
}

/**
 * Builds a ASF_ASFTestEquationTestList of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \param[in] elem2 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \param[in] elem3 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \param[in] elem4 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \param[in] elem5 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \param[in] elem6 One ASF_ASFTestEquation element of the new ASF_ASFTestEquationTestList
 * \return A new ASF_ASFTestEquationTestList consisting of 6 ASF_ASFTestEquations
 */
ASF_ASFTestEquationTestList ASF_makeASFTestEquationTestList6(ASF_OptLayout wsAfterHead, ASF_ASFTestEquation elem1, ASF_ASFTestEquation elem2, ASF_ASFTestEquation elem3, ASF_ASFTestEquation elem4, ASF_ASFTestEquation elem5, ASF_ASFTestEquation elem6) {
  return ASF_makeASFTestEquationTestListMany(elem1, wsAfterHead, ASF_makeASFTestEquationTestList5(wsAfterHead, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Constructs a Absent of type ASF_OptLayout. Like all ATerm types, ASF_OptLayouts are maximally shared.
 * \return A pointer to a Absent, either newly constructed or shared
 */
ASF_OptLayout ASF_makeOptLayoutAbsent(void) {
  return (ASF_OptLayout)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATempty, (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4))), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATempty);
}
/**
 * Constructs a Present of type ASF_OptLayout. Like all ATerm types, ASF_OptLayouts are maximally shared.
 * \param[in] layout a child of the new Present
 * \return A pointer to a Present, either newly constructed or shared
 */
ASF_OptLayout ASF_makeOptLayoutPresent(ASF_Layout layout) {
  return (ASF_OptLayout)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl0(ASF_afun4))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4))), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm) layout));
}
/**
 * Constructs a Lex-to-cf of type ASF_Layout. Like all ATerm types, ASF_Layouts are maximally shared.
 * \param[in] list a child of the new Lex-to-cf
 * \return A pointer to a Lex-to-cf, either newly constructed or shared
 */
ASF_Layout ASF_makeLayoutLexToCf(ASF_LexLayoutList list) {
  return (ASF_Layout)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun7, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl0(ASF_afun4)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl1(ASF_afun8, (ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun7, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm) list)));
}
/**
 * Constructs a empty of type ASF_LexLayoutList. Like all ATerm types, ASF_LexLayoutLists are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
ASF_LexLayoutList ASF_makeLexLayoutListEmpty(void) {
  return (ASF_LexLayoutList)(ATerm)ATempty;
}
/**
 * Constructs a single of type ASF_LexLayoutList. Like all ATerm types, ASF_LexLayoutLists are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
ASF_LexLayoutList ASF_makeLexLayoutListSingle(ASF_LexLayout head) {
  return (ASF_LexLayoutList)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type ASF_LexLayoutList. Like all ATerm types, ASF_LexLayoutLists are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
ASF_LexLayoutList ASF_makeLexLayoutListMany(ASF_LexLayout head, ASF_LexLayoutList tail) {
  return (ASF_LexLayoutList)(ATerm)ATinsert((ATermList)tail, (ATerm) head);
}
/**
 * Constructs a cast of type ASF_Tree. Like all ATerm types, ASF_Trees are maximally shared.
 * \param[in] Tree a child of the new cast
 * \return A pointer to a cast, either newly constructed or shared
 */
ASF_Tree ASF_makeTreeCast(ATerm Tree) {
  return (ASF_Tree)(ATerm) Tree;
}
/**
 * Constructs a ambiguity-constructor of type ASF_Tree. Like all ATerm types, ASF_Trees are maximally shared.
 * \param[in] wsAfterAmb a child of the new ambiguity-constructor
 * \param[in] wsAfterParenOpen a child of the new ambiguity-constructor
 * \param[in] ambs a child of the new ambiguity-constructor
 * \param[in] wsAfterAmbs a child of the new ambiguity-constructor
 * \return A pointer to a ambiguity-constructor, either newly constructed or shared
 */
ASF_Tree ASF_makeTreeAmbiguityConstructor(ASF_OptLayout wsAfterAmb, ASF_OptLayout wsAfterParenOpen, ASF_TreeAmbs ambs, ASF_OptLayout wsAfterAmbs) {
  return (ASF_Tree)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun10))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl2(ASF_afun11, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun13)), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun14))))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun15))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun16))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun13))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun20)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun10)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterAmbs), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl1(ASF_afun8, (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl2(ASF_afun11, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun13)), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun14))))), (ATerm) ambs)), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun15)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterAmb), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(98)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(109)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun16)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(98)), (ATerm)ATmakeInt(109)), (ATerm)ATmakeInt(97)))));
}
/**
 * Constructs a lexical-constructor of type ASF_Tree. Like all ATerm types, ASF_Trees are maximally shared.
 * \param[in] name a child of the new lexical-constructor
 * \param[in] wsAfterName a child of the new lexical-constructor
 * \param[in] wsAfterParenOpen a child of the new lexical-constructor
 * \param[in] list a child of the new lexical-constructor
 * \param[in] wsAfterList a child of the new lexical-constructor
 * \return A pointer to a lexical-constructor, either newly constructed or shared
 */
ASF_Tree ASF_makeTreeLexicalConstructor(ASF_Tree name, ASF_OptLayout wsAfterName, ASF_OptLayout wsAfterParenOpen, ASF_CHARList list, ASF_OptLayout wsAfterList) {
  return (ASF_Tree)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun10))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun22, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun23))))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun15))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun13)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun13))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun24)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun10)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterList), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl1(ASF_afun8, (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun22, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun23))))), (ATerm) list)), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun15)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterName), (ATerm) name));
}
/**
 * Constructs a default of type ASF_LexCHAR. Like all ATerm types, ASF_LexCHARs are maximally shared.
 * \param[in] value a child of the new default
 * \return A pointer to a default, either newly constructed or shared
 */
ASF_LexCHAR ASF_makeLexCHARDefault(char value) {
  return (ASF_LexCHAR)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(34)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(0), (ATerm)ATmakeInt(255))))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(34)))), (ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun23))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun26)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(34)), (ATerm) ((ATerm) ASF_byteToChar(value))), (ATerm)ATmakeInt(34)));
}
/**
 * Constructs a Lex-to-cf of type ASF_CHAR. Like all ATerm types, ASF_CHARs are maximally shared.
 * \param[in] CHAR a child of the new Lex-to-cf
 * \return A pointer to a Lex-to-cf, either newly constructed or shared
 */
ASF_CHAR ASF_makeCHARLexToCf(ASF_LexCHAR CHAR) {
  return (ASF_CHAR)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun23)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun23))), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm) CHAR));
}
/**
 * Constructs a negative of type ASF_ASFCondition. Like all ATerm types, ASF_ASFConditions are maximally shared.
 * \param[in] typeOfLhs a child of the new negative
 * \param[in] typeOfRhs a child of the new negative
 * \param[in] lhs a child of the new negative
 * \param[in] wsAfterLhs a child of the new negative
 * \param[in] wsAfterUnequal a child of the new negative
 * \param[in] rhs a child of the new negative
 * \return A pointer to a negative, either newly constructed or shared
 */
ASF_ASFCondition ASF_makeASFConditionNegative(ATerm typeOfLhs, ATerm typeOfRhs, ASF_Tree lhs, ASF_OptLayout wsAfterLhs, ASF_OptLayout wsAfterUnequal, ASF_Tree rhs) {
  return (ASF_ASFCondition)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) typeOfRhs), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun27))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm) typeOfLhs), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun28))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun29)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) rhs), (ATerm) wsAfterUnequal), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(33)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun27)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(61)), (ATerm)ATmakeInt(33)))), (ATerm) wsAfterLhs), (ATerm) lhs));
}
/**
 * Constructs a equality of type ASF_ASFCondition. Like all ATerm types, ASF_ASFConditions are maximally shared.
 * \param[in] typeOfLhs a child of the new equality
 * \param[in] typeOfRhs a child of the new equality
 * \param[in] lhs a child of the new equality
 * \param[in] wsAfterLhs a child of the new equality
 * \param[in] wsAfterEquality a child of the new equality
 * \param[in] rhs a child of the new equality
 * \return A pointer to a equality, either newly constructed or shared
 */
ASF_ASFCondition ASF_makeASFConditionEquality(ATerm typeOfLhs, ATerm typeOfRhs, ASF_Tree lhs, ASF_OptLayout wsAfterLhs, ASF_OptLayout wsAfterEquality, ASF_Tree rhs) {
  return (ASF_ASFCondition)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) typeOfRhs), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun30))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm) typeOfLhs), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun28))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun31)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) rhs), (ATerm) wsAfterEquality), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun30)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(61)), (ATerm)ATmakeInt(61)))), (ATerm) wsAfterLhs), (ATerm) lhs));
}
/**
 * Constructs a match of type ASF_ASFCondition. Like all ATerm types, ASF_ASFConditions are maximally shared.
 * \param[in] typeOfLhs a child of the new match
 * \param[in] typeOfRhs a child of the new match
 * \param[in] lhs a child of the new match
 * \param[in] wsAfterLhs a child of the new match
 * \param[in] wsAfterMatch a child of the new match
 * \param[in] rhs a child of the new match
 * \return A pointer to a match, either newly constructed or shared
 */
ASF_ASFCondition ASF_makeASFConditionMatch(ATerm typeOfLhs, ATerm typeOfRhs, ASF_Tree lhs, ASF_OptLayout wsAfterLhs, ASF_OptLayout wsAfterMatch, ASF_Tree rhs) {
  return (ASF_ASFCondition)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) typeOfRhs), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun32))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm) typeOfLhs), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun28))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun33)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) rhs), (ATerm) wsAfterMatch), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(58)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun32)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(61)), (ATerm)ATmakeInt(58)))), (ATerm) wsAfterLhs), (ATerm) lhs));
}
/**
 * Constructs a no-match of type ASF_ASFCondition. Like all ATerm types, ASF_ASFConditions are maximally shared.
 * \param[in] typeOfLhs a child of the new no-match
 * \param[in] typeOfRhs a child of the new no-match
 * \param[in] lhs a child of the new no-match
 * \param[in] wsAfterLhs a child of the new no-match
 * \param[in] wsAfterMatch a child of the new no-match
 * \param[in] rhs a child of the new no-match
 * \return A pointer to a no-match, either newly constructed or shared
 */
ASF_ASFCondition ASF_makeASFConditionNoMatch(ATerm typeOfLhs, ATerm typeOfRhs, ASF_Tree lhs, ASF_OptLayout wsAfterLhs, ASF_OptLayout wsAfterMatch, ASF_Tree rhs) {
  return (ASF_ASFCondition)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) typeOfRhs), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun34))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm) typeOfLhs), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun28))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun35)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) rhs), (ATerm) wsAfterMatch), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(58)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(33)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun34)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(61)), (ATerm)ATmakeInt(58)), (ATerm)ATmakeInt(33)))), (ATerm) wsAfterLhs), (ATerm) lhs));
}
/**
 * Constructs a Default of type ASF_ASFConditions. Like all ATerm types, ASF_ASFConditionss are maximally shared.
 * \param[in] list a child of the new Default
 * \return A pointer to a Default, either newly constructed or shared
 */
ASF_ASFConditions ASF_makeASFConditionsDefault(ASF_ASFConditionList list) {
  return (ASF_ASFConditions)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl2(ASF_afun36, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun28)), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun14))))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun37))), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl1(ASF_afun8, (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl2(ASF_afun36, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun28)), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun14))))), (ATerm) list)));
}
/**
 * Constructs a empty of type ASF_ASFConditionList. Like all ATerm types, ASF_ASFConditionLists are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
ASF_ASFConditionList ASF_makeASFConditionListEmpty(void) {
  return (ASF_ASFConditionList)(ATerm)ATempty;
}
/**
 * Constructs a single of type ASF_ASFConditionList. Like all ATerm types, ASF_ASFConditionLists are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
ASF_ASFConditionList ASF_makeASFConditionListSingle(ASF_ASFCondition head) {
  return (ASF_ASFConditionList)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type ASF_ASFConditionList. Like all ATerm types, ASF_ASFConditionLists are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] wsAfterSep a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
ASF_ASFConditionList ASF_makeASFConditionListMany(ASF_ASFCondition head, ASF_OptLayout wsAfterHead, ASF_OptLayout wsAfterSep, ASF_ASFConditionList tail) {
  if (ASF_isASFConditionListEmpty(tail)) {
    return ASF_makeASFConditionListSingle(head);
  }
  return (ASF_ASFConditionList)(ATerm)ATinsert(ATinsert(ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterSep), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun14)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a empty of type ASF_TreeAmbs. Like all ATerm types, ASF_TreeAmbss are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
ASF_TreeAmbs ASF_makeTreeAmbsEmpty(void) {
  return (ASF_TreeAmbs)(ATerm)ATempty;
}
/**
 * Constructs a single of type ASF_TreeAmbs. Like all ATerm types, ASF_TreeAmbss are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
ASF_TreeAmbs ASF_makeTreeAmbsSingle(ASF_Tree head) {
  return (ASF_TreeAmbs)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type ASF_TreeAmbs. Like all ATerm types, ASF_TreeAmbss are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] wsAfterSep a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
ASF_TreeAmbs ASF_makeTreeAmbsMany(ASF_Tree head, ASF_OptLayout wsAfterHead, ASF_OptLayout wsAfterSep, ASF_TreeAmbs tail) {
  if (ASF_isTreeAmbsEmpty(tail)) {
    return ASF_makeTreeAmbsSingle(head);
  }
  return (ASF_TreeAmbs)(ATerm)ATinsert(ATinsert(ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterSep), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun14)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a empty of type ASF_CHARList. Like all ATerm types, ASF_CHARLists are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
ASF_CHARList ASF_makeCHARListEmpty(void) {
  return (ASF_CHARList)(ATerm)ATempty;
}
/**
 * Constructs a single of type ASF_CHARList. Like all ATerm types, ASF_CHARLists are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
ASF_CHARList ASF_makeCHARListSingle(ASF_CHAR head) {
  return (ASF_CHARList)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type ASF_CHARList. Like all ATerm types, ASF_CHARLists are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
ASF_CHARList ASF_makeCHARListMany(ASF_CHAR head, ASF_OptLayout wsAfterHead, ASF_CHARList tail) {
  if (ASF_isCHARListEmpty(tail)) {
    return ASF_makeCHARListSingle(head);
  }
  return (ASF_CHARList)(ATerm)ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a Absent of type ASF_LexASFBarEnd. Like all ATerm types, ASF_LexASFBarEnds are maximally shared.
 * \return A pointer to a Absent, either newly constructed or shared
 */
ASF_LexASFBarEnd ASF_makeLexASFBarEndAbsent(void) {
  return (ASF_LexASFBarEnd)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATempty, (ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun38))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun39)))))), (ATerm)ATempty);
}
/**
 * Constructs a Present of type ASF_LexASFBarEnd. Like all ATerm types, ASF_LexASFBarEnds are maximally shared.
 * \return A pointer to a Present, either newly constructed or shared
 */
ASF_LexASFBarEnd ASF_makeLexASFBarEndPresent(void) {
  return (ASF_LexASFBarEnd)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(62)))), (ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun38))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun40)))))), (ATerm)ATmakeList1((ATerm)ATmakeInt(62)));
}
/**
 * Constructs a Lex-to-cf of type ASF_ASFBarEnd. Like all ATerm types, ASF_ASFBarEnds are maximally shared.
 * \param[in] ASFBarEnd a child of the new Lex-to-cf
 * \return A pointer to a Lex-to-cf, either newly constructed or shared
 */
ASF_ASFBarEnd ASF_makeASFBarEndLexToCf(ASF_LexASFBarEnd ASFBarEnd) {
  return (ASF_ASFBarEnd)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun38)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun38))), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm) ASFBarEnd));
}
/**
 * Constructs a default of type ASF_LexASFImplies. Like all ATerm types, ASF_LexASFImpliess are maximally shared.
 * \param[in] bar a child of the new default
 * \param[in] end a child of the new default
 * \return A pointer to a default, either newly constructed or shared
 */
ASF_LexASFImplies ASF_makeLexASFImpliesDefault(const char* bar, ASF_LexASFBarEnd end) {
  return (ASF_LexASFImplies)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun38)))), (ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun22, (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun41))), (ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun42))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun26)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) end), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl1(ASF_afun8, (ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun22, (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))))), (ATerm) ((ATerm) ASF_stringToChars(bar)))), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun41)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(61)), (ATerm)ATmakeInt(61)), (ATerm)ATmakeInt(61)))));
}
/**
 * Constructs a Lex-to-cf of type ASF_ASFImplies. Like all ATerm types, ASF_ASFImpliess are maximally shared.
 * \param[in] ASFImplies a child of the new Lex-to-cf
 * \return A pointer to a Lex-to-cf, either newly constructed or shared
 */
ASF_ASFImplies ASF_makeASFImpliesLexToCf(ASF_LexASFImplies ASFImplies) {
  return (ASF_ASFImplies)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun42)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun42))), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm) ASFImplies));
}
/**
 * Constructs a simple of type ASF_ASFConditionalEquation. Like all ATerm types, ASF_ASFConditionalEquations are maximally shared.
 * \param[in] ASFTag a child of the new simple
 * \param[in] wsAfterASFTag a child of the new simple
 * \param[in] ASFEquation a child of the new simple
 * \return A pointer to a simple, either newly constructed or shared
 */
ASF_ASFConditionalEquation ASF_makeASFConditionalEquationSimple(ASF_ASFTag ASFTag, ASF_OptLayout wsAfterASFTag, ASF_ASFEquation ASFEquation) {
  return (ASF_ASFConditionalEquation)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun43)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun44)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun45))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun46)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) ASFEquation), (ATerm) wsAfterASFTag), (ATerm) ASFTag));
}
/**
 * Constructs a implies of type ASF_ASFConditionalEquation. Like all ATerm types, ASF_ASFConditionalEquations are maximally shared.
 * \param[in] ASFTag a child of the new implies
 * \param[in] wsAfterASFTag a child of the new implies
 * \param[in] ASFConditions a child of the new implies
 * \param[in] wsAfterASFConditions a child of the new implies
 * \param[in] ASFImplies a child of the new implies
 * \param[in] wsAfterASFImplies a child of the new implies
 * \param[in] ASFEquation a child of the new implies
 * \return A pointer to a implies, either newly constructed or shared
 */
ASF_ASFConditionalEquation ASF_makeASFConditionalEquationImplies(ASF_ASFTag ASFTag, ASF_OptLayout wsAfterASFTag, ASF_ASFConditions ASFConditions, ASF_OptLayout wsAfterASFConditions, ASF_ASFImplies ASFImplies, ASF_OptLayout wsAfterASFImplies, ASF_ASFEquation ASFEquation) {
  return (ASF_ASFConditionalEquation)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun43)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun42)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun37)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun44)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun45))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun47)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) ASFEquation), (ATerm) wsAfterASFImplies), (ATerm) ASFImplies), (ATerm) wsAfterASFConditions), (ATerm) ASFConditions), (ATerm) wsAfterASFTag), (ATerm) ASFTag));
}
/**
 * Constructs a when of type ASF_ASFConditionalEquation. Like all ATerm types, ASF_ASFConditionalEquations are maximally shared.
 * \param[in] ASFTag a child of the new when
 * \param[in] wsAfterASFTag a child of the new when
 * \param[in] ASFEquation a child of the new when
 * \param[in] wsAfterASFEquation a child of the new when
 * \param[in] wsAfterWhen a child of the new when
 * \param[in] ASFConditions a child of the new when
 * \return A pointer to a when, either newly constructed or shared
 */
ASF_ASFConditionalEquation ASF_makeASFConditionalEquationWhen(ASF_ASFTag ASFTag, ASF_OptLayout wsAfterASFTag, ASF_ASFEquation ASFEquation, ASF_OptLayout wsAfterASFEquation, ASF_OptLayout wsAfterWhen, ASF_ASFConditions ASFConditions) {
  return (ASF_ASFConditionalEquation)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun37)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun48))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun43)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun44)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun45))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun48)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) ASFConditions), (ATerm) wsAfterWhen), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(110)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(104)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(119)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun48)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(110)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(104)), (ATerm)ATmakeInt(119)))), (ATerm) wsAfterASFEquation), (ATerm) ASFEquation), (ATerm) wsAfterASFTag), (ATerm) ASFTag));
}
/**
 * Constructs a Default of type ASF_ASFEquation. Like all ATerm types, ASF_ASFEquations are maximally shared.
 * \param[in] typeOfLhs a child of the new Default
 * \param[in] typeOfRhs a child of the new Default
 * \param[in] lhs a child of the new Default
 * \param[in] wsAfterLhs a child of the new Default
 * \param[in] wsAfterEquals a child of the new Default
 * \param[in] rhs a child of the new Default
 * \return A pointer to a Default, either newly constructed or shared
 */
ASF_ASFEquation ASF_makeASFEquationDefault(ATerm typeOfLhs, ATerm typeOfRhs, ASF_Tree lhs, ASF_OptLayout wsAfterLhs, ASF_OptLayout wsAfterEquals, ASF_Tree rhs) {
  return (ASF_ASFEquation)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) typeOfRhs), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun49))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm) typeOfLhs), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun43))), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) rhs), (ATerm) wsAfterEquals), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun49)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm) wsAfterLhs), (ATerm) lhs));
}
/**
 * Constructs a ASF-Module of type ASF_Start. Like all ATerm types, ASF_Starts are maximally shared.
 * \param[in] wsBefore a child of the new ASF-Module
 * \param[in] topASFModule a child of the new ASF-Module
 * \param[in] wsAfter a child of the new ASF-Module
 * \param[in] ambCnt a child of the new ASF-Module
 * \return A pointer to a ASF-Module, either newly constructed or shared
 */
ASF_Start ASF_makeStartASFModule(ASF_OptLayout wsBefore, ASF_ASFModule topASFModule, ASF_OptLayout wsAfter, int ambCnt) {
  return (ASF_Start)(ATerm)ATmakeAppl2(ASF_afun50, (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun51)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun52)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) wsAfter), (ATerm) topASFModule), (ATerm) wsBefore)), (ATerm) (ATerm) ATmakeInt(ambCnt));
}
/**
 * Constructs a ASF-Section of type ASF_Start. Like all ATerm types, ASF_Starts are maximally shared.
 * \param[in] wsBefore a child of the new ASF-Section
 * \param[in] topASFSection a child of the new ASF-Section
 * \param[in] wsAfter a child of the new ASF-Section
 * \param[in] ambCnt a child of the new ASF-Section
 * \return A pointer to a ASF-Section, either newly constructed or shared
 */
ASF_Start ASF_makeStartASFSection(ASF_OptLayout wsBefore, ASF_ASFSection topASFSection, ASF_OptLayout wsAfter, int ambCnt) {
  return (ASF_Start)(ATerm)ATmakeAppl2(ASF_afun50, (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun53)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun52)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) wsAfter), (ATerm) topASFSection), (ATerm) wsBefore)), (ATerm) (ATerm) ATmakeInt(ambCnt));
}
/**
 * Constructs a default of type ASF_ASFModule. Like all ATerm types, ASF_ASFModules are maximally shared.
 * \param[in] list a child of the new default
 * \return A pointer to a default, either newly constructed or shared
 */
ASF_ASFModule ASF_makeASFModuleDefault(ASF_ASFSectionList list) {
  return (ASF_ASFModule)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun22, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun53))))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun51))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun26)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl1(ASF_afun8, (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun22, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun53))))), (ATerm) list)));
}
/**
 * Constructs a equations of type ASF_ASFSection. Like all ATerm types, ASF_ASFSections are maximally shared.
 * \param[in] wsAfterEquations a child of the new equations
 * \param[in] list a child of the new equations
 * \return A pointer to a equations, either newly constructed or shared
 */
ASF_ASFSection ASF_makeASFSectionEquations(ASF_OptLayout wsAfterEquations, ASF_ASFConditionalEquationList list) {
  return (ASF_ASFSection)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun22, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun45))))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun54))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun53))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun54)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl1(ASF_afun8, (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun22, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun45))))), (ATerm) list)), (ATerm) wsAfterEquations), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(110)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(105)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(117)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(113)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun54)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(110)), (ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(105)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(117)), (ATerm)ATmakeInt(113)), (ATerm)ATmakeInt(101)))));
}
/**
 * Constructs a tests of type ASF_ASFSection. Like all ATerm types, ASF_ASFSections are maximally shared.
 * \param[in] wsAfterTests a child of the new tests
 * \param[in] testList a child of the new tests
 * \return A pointer to a tests, either newly constructed or shared
 */
ASF_ASFSection ASF_makeASFSectionTests(ASF_OptLayout wsAfterTests, ASF_ASFTestEquationTestList testList) {
  return (ASF_ASFSection)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun22, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun55))))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun56))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun53))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun56)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl1(ASF_afun8, (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun22, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun55))))), (ATerm) testList)), (ATerm) wsAfterTests), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun56)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(116)))));
}
/**
 * Constructs a empty of type ASF_ASFSectionList. Like all ATerm types, ASF_ASFSectionLists are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
ASF_ASFSectionList ASF_makeASFSectionListEmpty(void) {
  return (ASF_ASFSectionList)(ATerm)ATempty;
}
/**
 * Constructs a single of type ASF_ASFSectionList. Like all ATerm types, ASF_ASFSectionLists are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
ASF_ASFSectionList ASF_makeASFSectionListSingle(ASF_ASFSection head) {
  return (ASF_ASFSectionList)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type ASF_ASFSectionList. Like all ATerm types, ASF_ASFSectionLists are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
ASF_ASFSectionList ASF_makeASFSectionListMany(ASF_ASFSection head, ASF_OptLayout wsAfterHead, ASF_ASFSectionList tail) {
  if (ASF_isASFSectionListEmpty(tail)) {
    return ASF_makeASFSectionListSingle(head);
  }
  return (ASF_ASFSectionList)(ATerm)ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a empty of type ASF_ASFConditionalEquationList. Like all ATerm types, ASF_ASFConditionalEquationLists are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
ASF_ASFConditionalEquationList ASF_makeASFConditionalEquationListEmpty(void) {
  return (ASF_ASFConditionalEquationList)(ATerm)ATempty;
}
/**
 * Constructs a single of type ASF_ASFConditionalEquationList. Like all ATerm types, ASF_ASFConditionalEquationLists are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
ASF_ASFConditionalEquationList ASF_makeASFConditionalEquationListSingle(ASF_ASFConditionalEquation head) {
  return (ASF_ASFConditionalEquationList)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type ASF_ASFConditionalEquationList. Like all ATerm types, ASF_ASFConditionalEquationLists are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
ASF_ASFConditionalEquationList ASF_makeASFConditionalEquationListMany(ASF_ASFConditionalEquation head, ASF_OptLayout wsAfterHead, ASF_ASFConditionalEquationList tail) {
  if (ASF_isASFConditionalEquationListEmpty(tail)) {
    return ASF_makeASFConditionalEquationListSingle(head);
  }
  return (ASF_ASFConditionalEquationList)(ATerm)ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a empty of type ASF_ASFTestEquationTestList. Like all ATerm types, ASF_ASFTestEquationTestLists are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
ASF_ASFTestEquationTestList ASF_makeASFTestEquationTestListEmpty(void) {
  return (ASF_ASFTestEquationTestList)(ATerm)ATempty;
}
/**
 * Constructs a single of type ASF_ASFTestEquationTestList. Like all ATerm types, ASF_ASFTestEquationTestLists are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
ASF_ASFTestEquationTestList ASF_makeASFTestEquationTestListSingle(ASF_ASFTestEquation head) {
  return (ASF_ASFTestEquationTestList)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type ASF_ASFTestEquationTestList. Like all ATerm types, ASF_ASFTestEquationTestLists are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
ASF_ASFTestEquationTestList ASF_makeASFTestEquationTestListMany(ASF_ASFTestEquation head, ASF_OptLayout wsAfterHead, ASF_ASFTestEquationTestList tail) {
  if (ASF_isASFTestEquationTestListEmpty(tail)) {
    return ASF_makeASFTestEquationTestListSingle(head);
  }
  return (ASF_ASFTestEquationTestList)(ATerm)ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a one-char of type ASF_LexASFTagId. Like all ATerm types, ASF_LexASFTagIds are maximally shared.
 * \param[in] head a child of the new one-char
 * \return A pointer to a one-char, either newly constructed or shared
 */
ASF_LexASFTagId ASF_makeLexASFTagIdOneChar(char head) {
  return (ASF_LexASFTagId)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(97), (ATerm)ATmakeInt(122))), (ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(65), (ATerm)ATmakeInt(90))), (ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))), (ATerm)ATmakeInt(39)), (ATerm)ATmakeInt(34)))), (ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun57))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun58)))), (ATerm)ATmakeAppl0(ASF_afun59)))), (ATerm)ATmakeList1((ATerm) ((ATerm) ASF_byteToChar(head))));
}
/**
 * Constructs a many-chars of type ASF_LexASFTagId. Like all ATerm types, ASF_LexASFTagIds are maximally shared.
 * \param[in] head a child of the new many-chars
 * \param[in] middle a child of the new many-chars
 * \param[in] last a child of the new many-chars
 * \return A pointer to a many-chars, either newly constructed or shared
 */
ASF_LexASFTagId ASF_makeLexASFTagIdManyChars(char head, const char* middle, char last) {
  return (ASF_LexASFTagId)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(97), (ATerm)ATmakeInt(122))), (ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(65), (ATerm)ATmakeInt(90))), (ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))), (ATerm)ATmakeInt(39)), (ATerm)ATmakeInt(34)))), (ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun22, (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(97), (ATerm)ATmakeInt(122))), (ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(65), (ATerm)ATmakeInt(90))), (ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))), (ATerm)ATmakeInt(45)), (ATerm)ATmakeInt(39)), (ATerm)ATmakeInt(34)))))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(97), (ATerm)ATmakeInt(122))), (ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(65), (ATerm)ATmakeInt(90))), (ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))), (ATerm)ATmakeInt(39)), (ATerm)ATmakeInt(34)))), (ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun57))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun60)))), (ATerm)ATmakeAppl0(ASF_afun59)))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) ((ATerm) ASF_byteToChar(last))), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl1(ASF_afun8, (ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun22, (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(97), (ATerm)ATmakeInt(122))), (ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(65), (ATerm)ATmakeInt(90))), (ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))), (ATerm)ATmakeInt(45)), (ATerm)ATmakeInt(39)), (ATerm)ATmakeInt(34)))))), (ATerm) ((ATerm) ASF_stringToChars(middle)))), (ATerm) ((ATerm) ASF_byteToChar(head))));
}
/**
 * Constructs a Lex-to-cf of type ASF_ASFTagId. Like all ATerm types, ASF_ASFTagIds are maximally shared.
 * \param[in] ASFTagId a child of the new Lex-to-cf
 * \return A pointer to a Lex-to-cf, either newly constructed or shared
 */
ASF_ASFTagId ASF_makeASFTagIdLexToCf(ASF_LexASFTagId ASFTagId) {
  return (ASF_ASFTagId)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun57)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun57))), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm) ASFTagId));
}
/**
 * Constructs a empty of type ASF_ASFTag. Like all ATerm types, ASF_ASFTags are maximally shared.
 * \param[in] wsAfterBracketOpen a child of the new empty
 * \return A pointer to a empty, either newly constructed or shared
 */
ASF_ASFTag ASF_makeASFTagEmpty(ASF_OptLayout wsAfterBracketOpen) {
  return (ASF_ASFTag)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun61))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun62))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun44))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun63)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun61)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm) wsAfterBracketOpen), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun62)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))));
}
/**
 * Constructs a not-empty of type ASF_ASFTag. Like all ATerm types, ASF_ASFTags are maximally shared.
 * \param[in] wsAfterBracketOpen a child of the new not-empty
 * \param[in] ASFTagId a child of the new not-empty
 * \param[in] wsAfterASFTagId a child of the new not-empty
 * \return A pointer to a not-empty, either newly constructed or shared
 */
ASF_ASFTag ASF_makeASFTagNotEmpty(ASF_OptLayout wsAfterBracketOpen, ASF_ASFTagId ASFTagId, ASF_OptLayout wsAfterASFTagId) {
  return (ASF_ASFTag)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun61))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun57)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun62))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun44))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun64)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun61)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm) wsAfterASFTagId), (ATerm) ASFTagId), (ATerm) wsAfterBracketOpen), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun62)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))));
}
/**
 * Constructs a simple of type ASF_ASFTestEquation. Like all ATerm types, ASF_ASFTestEquations are maximally shared.
 * \param[in] ASFTag a child of the new simple
 * \param[in] wsAfterASFTag a child of the new simple
 * \param[in] ASFCondition a child of the new simple
 * \return A pointer to a simple, either newly constructed or shared
 */
ASF_ASFTestEquation ASF_makeASFTestEquationSimple(ASF_ASFTag ASFTag, ASF_OptLayout wsAfterASFTag, ASF_ASFCondition ASFCondition) {
  return (ASF_ASFTestEquation)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun28)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun44)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun55))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun46)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) ASFCondition), (ATerm) wsAfterASFTag), (ATerm) ASFTag));
}
/**
 * Constructs a implies of type ASF_ASFTestEquation. Like all ATerm types, ASF_ASFTestEquations are maximally shared.
 * \param[in] ASFTag a child of the new implies
 * \param[in] wsAfterASFTag a child of the new implies
 * \param[in] ASFConditions a child of the new implies
 * \param[in] wsAfterASFConditions a child of the new implies
 * \param[in] ASFImplies a child of the new implies
 * \param[in] wsAfterASFImplies a child of the new implies
 * \param[in] ASFCondition a child of the new implies
 * \return A pointer to a implies, either newly constructed or shared
 */
ASF_ASFTestEquation ASF_makeASFTestEquationImplies(ASF_ASFTag ASFTag, ASF_OptLayout wsAfterASFTag, ASF_ASFConditions ASFConditions, ASF_OptLayout wsAfterASFConditions, ASF_ASFImplies ASFImplies, ASF_OptLayout wsAfterASFImplies, ASF_ASFCondition ASFCondition) {
  return (ASF_ASFTestEquation)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun28)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun42)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun37)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun44)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun55))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun47)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) ASFCondition), (ATerm) wsAfterASFImplies), (ATerm) ASFImplies), (ATerm) wsAfterASFConditions), (ATerm) ASFConditions), (ATerm) wsAfterASFTag), (ATerm) ASFTag));
}
/**
 * Constructs a when of type ASF_ASFTestEquation. Like all ATerm types, ASF_ASFTestEquations are maximally shared.
 * \param[in] ASFTag a child of the new when
 * \param[in] wsAfterASFTag a child of the new when
 * \param[in] ASFCondition a child of the new when
 * \param[in] wsAfterASFCondition a child of the new when
 * \param[in] wsAfterWhen a child of the new when
 * \param[in] ASFConditions a child of the new when
 * \return A pointer to a when, either newly constructed or shared
 */
ASF_ASFTestEquation ASF_makeASFTestEquationWhen(ASF_ASFTag ASFTag, ASF_OptLayout wsAfterASFTag, ASF_ASFCondition ASFCondition, ASF_OptLayout wsAfterASFCondition, ASF_OptLayout wsAfterWhen, ASF_ASFConditions ASFConditions) {
  return (ASF_ASFTestEquation)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun37)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun48))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun28)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun3, (ATerm)ATmakeAppl0(ASF_afun4)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun44)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun55))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun48)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) ASFConditions), (ATerm) wsAfterWhen), (ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(110)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(104)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(119)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun48)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(110)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(104)), (ATerm)ATmakeInt(119)))), (ATerm) wsAfterASFCondition), (ATerm) ASFCondition), (ATerm) wsAfterASFTag), (ATerm) ASFTag));
}
/**
 * Constructs a whitespace of type ASF_LexLayout. Like all ATerm types, ASF_LexLayouts are maximally shared.
 * \param[in] ch a child of the new whitespace
 * \return A pointer to a whitespace, either newly constructed or shared
 */
ASF_LexLayout ASF_makeLexLayoutWhitespace(char ch) {
  return (ASF_LexLayout)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(32)), (ATerm)ATmakeInt(13)), (ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(9), (ATerm)ATmakeInt(10))))), (ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl0(ASF_afun4)), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun65)))))), (ATerm)ATmakeList1((ATerm) ((ATerm) ASF_byteToChar(ch))));
}
/**
 * Constructs a digits of type ASF_LexNumChar. Like all ATerm types, ASF_LexNumChars are maximally shared.
 * \param[in] number a child of the new digits
 * \return A pointer to a digits, either newly constructed or shared
 */
ASF_LexNumChar ASF_makeLexNumCharDigits(const char* number) {
  return (ASF_LexNumChar)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun7, (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))))))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun66))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun67)))))), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl1(ASF_afun8, (ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun7, (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))))))), (ATerm) ((ATerm) ASF_stringToChars(number)))), (ATerm)ATmakeInt(92)));
}
/**
 * Constructs a Lex-to-cf of type ASF_NumChar. Like all ATerm types, ASF_NumChars are maximally shared.
 * \param[in] NumChar a child of the new Lex-to-cf
 * \return A pointer to a Lex-to-cf, either newly constructed or shared
 */
ASF_NumChar ASF_makeNumCharLexToCf(ASF_LexNumChar NumChar) {
  return (ASF_NumChar)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun66)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun66))), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm) NumChar));
}
/**
 * Constructs a regular of type ASF_LexShortChar. Like all ATerm types, ASF_LexShortChars are maximally shared.
 * \param[in] character a child of the new regular
 * \return A pointer to a regular, either newly constructed or shared
 */
ASF_LexShortChar ASF_makeLexShortCharRegular(char character) {
  return (ASF_LexShortChar)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(97), (ATerm)ATmakeInt(122))), (ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(65), (ATerm)ATmakeInt(90))), (ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))))), (ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun68))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun69)))))), (ATerm)ATmakeList1((ATerm) ((ATerm) ASF_byteToChar(character))));
}
/**
 * Constructs a escaped of type ASF_LexShortChar. Like all ATerm types, ASF_LexShortChars are maximally shared.
 * \param[in] escape a child of the new escaped
 * \return A pointer to a escaped, either newly constructed or shared
 */
ASF_LexShortChar ASF_makeLexShortCharEscaped(char escape) {
  return (ASF_LexShortChar)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(123), (ATerm)ATmakeInt(255))), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(110)), (ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(91), (ATerm)ATmakeInt(96))), (ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(58), (ATerm)ATmakeInt(64))), (ATerm)ATmakeAppl2(ASF_afun25, (ATerm)ATmakeInt(32), (ATerm)ATmakeInt(47))))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun68))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun70)))))), (ATerm)ATinsert(ATmakeList1((ATerm) ((ATerm) ASF_byteToChar(escape))), (ATerm)ATmakeInt(92)));
}
/**
 * Constructs a Lex-to-cf of type ASF_ShortChar. Like all ATerm types, ASF_ShortChars are maximally shared.
 * \param[in] ShortChar a child of the new Lex-to-cf
 * \return A pointer to a Lex-to-cf, either newly constructed or shared
 */
ASF_ShortChar ASF_makeShortCharLexToCf(ASF_LexShortChar ShortChar) {
  return (ASF_ShortChar)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun6, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun68)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun68))), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATmakeList1((ATerm) ShortChar));
}
/**
 * Constructs a numeric of type ASF_Character. Like all ATerm types, ASF_Characters are maximally shared.
 * \param[in] NumChar a child of the new numeric
 * \return A pointer to a numeric, either newly constructed or shared
 */
ASF_Character ASF_makeCharacterNumeric(ASF_NumChar NumChar) {
  return (ASF_Character)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun66)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun71))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun72)))))), (ATerm)ATmakeList1((ATerm) NumChar));
}
/**
 * Constructs a short of type ASF_Character. Like all ATerm types, ASF_Characters are maximally shared.
 * \param[in] ShortChar a child of the new short
 * \return A pointer to a short, either newly constructed or shared
 */
ASF_Character ASF_makeCharacterShort(ASF_ShortChar ShortChar) {
  return (ASF_Character)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun68)))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun71))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun73)))))), (ATerm)ATmakeList1((ATerm) ShortChar));
}
/**
 * Constructs a top of type ASF_Character. Like all ATerm types, ASF_Characters are maximally shared.
 * \return A pointer to a top, either newly constructed or shared
 */
ASF_Character ASF_makeCharacterTop(void) {
  return (ASF_Character)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun74))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun71))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun75)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(80)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(79)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(84)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun74)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(80)), (ATerm)ATmakeInt(79)), (ATerm)ATmakeInt(84)), (ATerm)ATmakeInt(92)))));
}
/**
 * Constructs a eof of type ASF_Character. Like all ATerm types, ASF_Characters are maximally shared.
 * \return A pointer to a eof, either newly constructed or shared
 */
ASF_Character ASF_makeCharacterEof(void) {
  return (ASF_Character)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun76))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun71))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun77)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(70)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(79)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(69)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun76)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(70)), (ATerm)ATmakeInt(79)), (ATerm)ATmakeInt(69)), (ATerm)ATmakeInt(92)))));
}
/**
 * Constructs a bot of type ASF_Character. Like all ATerm types, ASF_Characters are maximally shared.
 * \return A pointer to a bot, either newly constructed or shared
 */
ASF_Character ASF_makeCharacterBot(void) {
  return (ASF_Character)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun78))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun71))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun79)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(84)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(79)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(66)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun78)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(84)), (ATerm)ATmakeInt(79)), (ATerm)ATmakeInt(66)), (ATerm)ATmakeInt(92)))));
}
/**
 * Constructs a label_start of type ASF_Character. Like all ATerm types, ASF_Characters are maximally shared.
 * \return A pointer to a label_start, either newly constructed or shared
 */
ASF_Character ASF_makeCharacterLabelUnderscoreStart(void) {
  return (ASF_Character)(ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun80))), (ATerm)ATmakeAppl1(ASF_afun2, (ATerm)ATmakeAppl1(ASF_afun12, (ATerm)ATmakeAppl0(ASF_afun71))), (ATerm)ATmakeAppl1(ASF_afun17, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(ASF_afun18, (ATerm)ATmakeAppl1(ASF_afun19, (ATerm)ATmakeAppl0(ASF_afun81)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(ASF_afun0, (ATerm)ATmakeAppl3(ASF_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(84)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(82)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(65)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(84)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(83)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(95)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(76)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(69)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(66)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(65)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(76)))), (ATerm)ATmakeAppl1(ASF_afun21, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(ASF_afun9, (ATerm)ATmakeAppl0(ASF_afun80)), (ATerm)ATmakeAppl0(ASF_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(84)), (ATerm)ATmakeInt(82)), (ATerm)ATmakeInt(65)), (ATerm)ATmakeInt(84)), (ATerm)ATmakeInt(83)), (ATerm)ATmakeInt(95)), (ATerm)ATmakeInt(76)), (ATerm)ATmakeInt(69)), (ATerm)ATmakeInt(66)), (ATerm)ATmakeInt(65)), (ATerm)ATmakeInt(76)), (ATerm)ATmakeInt(92)))));
}

/**
 * Tests equality of two ASF_OptLayouts. A constant time operation.
 * \param[in] arg0 first ASF_OptLayout to be compared
 * \param[in] arg1 second ASF_OptLayout to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualOptLayout(ASF_OptLayout arg0, ASF_OptLayout arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_Layouts. A constant time operation.
 * \param[in] arg0 first ASF_Layout to be compared
 * \param[in] arg1 second ASF_Layout to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualLayout(ASF_Layout arg0, ASF_Layout arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_LexLayoutLists. A constant time operation.
 * \param[in] arg0 first ASF_LexLayoutList to be compared
 * \param[in] arg1 second ASF_LexLayoutList to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualLexLayoutList(ASF_LexLayoutList arg0, ASF_LexLayoutList arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_Trees. A constant time operation.
 * \param[in] arg0 first ASF_Tree to be compared
 * \param[in] arg1 second ASF_Tree to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualTree(ASF_Tree arg0, ASF_Tree arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_LexCHARs. A constant time operation.
 * \param[in] arg0 first ASF_LexCHAR to be compared
 * \param[in] arg1 second ASF_LexCHAR to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualLexCHAR(ASF_LexCHAR arg0, ASF_LexCHAR arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_CHARs. A constant time operation.
 * \param[in] arg0 first ASF_CHAR to be compared
 * \param[in] arg1 second ASF_CHAR to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualCHAR(ASF_CHAR arg0, ASF_CHAR arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_ASFConditions. A constant time operation.
 * \param[in] arg0 first ASF_ASFCondition to be compared
 * \param[in] arg1 second ASF_ASFCondition to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualASFCondition(ASF_ASFCondition arg0, ASF_ASFCondition arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_ASFConditionss. A constant time operation.
 * \param[in] arg0 first ASF_ASFConditions to be compared
 * \param[in] arg1 second ASF_ASFConditions to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualASFConditions(ASF_ASFConditions arg0, ASF_ASFConditions arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_ASFConditionLists. A constant time operation.
 * \param[in] arg0 first ASF_ASFConditionList to be compared
 * \param[in] arg1 second ASF_ASFConditionList to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualASFConditionList(ASF_ASFConditionList arg0, ASF_ASFConditionList arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_TreeAmbss. A constant time operation.
 * \param[in] arg0 first ASF_TreeAmbs to be compared
 * \param[in] arg1 second ASF_TreeAmbs to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualTreeAmbs(ASF_TreeAmbs arg0, ASF_TreeAmbs arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_CHARLists. A constant time operation.
 * \param[in] arg0 first ASF_CHARList to be compared
 * \param[in] arg1 second ASF_CHARList to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualCHARList(ASF_CHARList arg0, ASF_CHARList arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_LexASFBarEnds. A constant time operation.
 * \param[in] arg0 first ASF_LexASFBarEnd to be compared
 * \param[in] arg1 second ASF_LexASFBarEnd to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualLexASFBarEnd(ASF_LexASFBarEnd arg0, ASF_LexASFBarEnd arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_ASFBarEnds. A constant time operation.
 * \param[in] arg0 first ASF_ASFBarEnd to be compared
 * \param[in] arg1 second ASF_ASFBarEnd to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualASFBarEnd(ASF_ASFBarEnd arg0, ASF_ASFBarEnd arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_LexASFImpliess. A constant time operation.
 * \param[in] arg0 first ASF_LexASFImplies to be compared
 * \param[in] arg1 second ASF_LexASFImplies to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualLexASFImplies(ASF_LexASFImplies arg0, ASF_LexASFImplies arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_ASFImpliess. A constant time operation.
 * \param[in] arg0 first ASF_ASFImplies to be compared
 * \param[in] arg1 second ASF_ASFImplies to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualASFImplies(ASF_ASFImplies arg0, ASF_ASFImplies arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_ASFConditionalEquations. A constant time operation.
 * \param[in] arg0 first ASF_ASFConditionalEquation to be compared
 * \param[in] arg1 second ASF_ASFConditionalEquation to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualASFConditionalEquation(ASF_ASFConditionalEquation arg0, ASF_ASFConditionalEquation arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_ASFEquations. A constant time operation.
 * \param[in] arg0 first ASF_ASFEquation to be compared
 * \param[in] arg1 second ASF_ASFEquation to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualASFEquation(ASF_ASFEquation arg0, ASF_ASFEquation arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_Starts. A constant time operation.
 * \param[in] arg0 first ASF_Start to be compared
 * \param[in] arg1 second ASF_Start to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualStart(ASF_Start arg0, ASF_Start arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_ASFModules. A constant time operation.
 * \param[in] arg0 first ASF_ASFModule to be compared
 * \param[in] arg1 second ASF_ASFModule to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualASFModule(ASF_ASFModule arg0, ASF_ASFModule arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_ASFSections. A constant time operation.
 * \param[in] arg0 first ASF_ASFSection to be compared
 * \param[in] arg1 second ASF_ASFSection to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualASFSection(ASF_ASFSection arg0, ASF_ASFSection arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_ASFSectionLists. A constant time operation.
 * \param[in] arg0 first ASF_ASFSectionList to be compared
 * \param[in] arg1 second ASF_ASFSectionList to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualASFSectionList(ASF_ASFSectionList arg0, ASF_ASFSectionList arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_ASFConditionalEquationLists. A constant time operation.
 * \param[in] arg0 first ASF_ASFConditionalEquationList to be compared
 * \param[in] arg1 second ASF_ASFConditionalEquationList to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualASFConditionalEquationList(ASF_ASFConditionalEquationList arg0, ASF_ASFConditionalEquationList arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_ASFTestEquationTestLists. A constant time operation.
 * \param[in] arg0 first ASF_ASFTestEquationTestList to be compared
 * \param[in] arg1 second ASF_ASFTestEquationTestList to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualASFTestEquationTestList(ASF_ASFTestEquationTestList arg0, ASF_ASFTestEquationTestList arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_LexASFTagIds. A constant time operation.
 * \param[in] arg0 first ASF_LexASFTagId to be compared
 * \param[in] arg1 second ASF_LexASFTagId to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualLexASFTagId(ASF_LexASFTagId arg0, ASF_LexASFTagId arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_ASFTagIds. A constant time operation.
 * \param[in] arg0 first ASF_ASFTagId to be compared
 * \param[in] arg1 second ASF_ASFTagId to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualASFTagId(ASF_ASFTagId arg0, ASF_ASFTagId arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_ASFTags. A constant time operation.
 * \param[in] arg0 first ASF_ASFTag to be compared
 * \param[in] arg1 second ASF_ASFTag to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualASFTag(ASF_ASFTag arg0, ASF_ASFTag arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_ASFTestEquations. A constant time operation.
 * \param[in] arg0 first ASF_ASFTestEquation to be compared
 * \param[in] arg1 second ASF_ASFTestEquation to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualASFTestEquation(ASF_ASFTestEquation arg0, ASF_ASFTestEquation arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_LexLayouts. A constant time operation.
 * \param[in] arg0 first ASF_LexLayout to be compared
 * \param[in] arg1 second ASF_LexLayout to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualLexLayout(ASF_LexLayout arg0, ASF_LexLayout arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_LexNumChars. A constant time operation.
 * \param[in] arg0 first ASF_LexNumChar to be compared
 * \param[in] arg1 second ASF_LexNumChar to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualLexNumChar(ASF_LexNumChar arg0, ASF_LexNumChar arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_NumChars. A constant time operation.
 * \param[in] arg0 first ASF_NumChar to be compared
 * \param[in] arg1 second ASF_NumChar to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualNumChar(ASF_NumChar arg0, ASF_NumChar arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_LexShortChars. A constant time operation.
 * \param[in] arg0 first ASF_LexShortChar to be compared
 * \param[in] arg1 second ASF_LexShortChar to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualLexShortChar(ASF_LexShortChar arg0, ASF_LexShortChar arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_ShortChars. A constant time operation.
 * \param[in] arg0 first ASF_ShortChar to be compared
 * \param[in] arg1 second ASF_ShortChar to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualShortChar(ASF_ShortChar arg0, ASF_ShortChar arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two ASF_Characters. A constant time operation.
 * \param[in] arg0 first ASF_Character to be compared
 * \param[in] arg1 second ASF_Character to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _ASF_isEqualCharacter(ASF_Character arg0, ASF_Character arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Assert whether a ASF_OptLayout is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_OptLayout
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidOptLayout(ASF_OptLayout arg) {
  if (ASF_isOptLayoutAbsent(arg)) {
    return ATtrue;
  }
  else if (ASF_isOptLayoutPresent(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_OptLayout is a Absent by checking against the following ATerm pattern: appl(prod([],cf(opt(layout)),no-attrs),[]). May not be used to assert correctness of the ASF_OptLayout
 * \param[in] arg input ASF_OptLayout
 * \return ATtrue if #arg corresponds to the signature of a Absent, or ATfalse otherwise
 */
inline ATbool ASF_isOptLayoutAbsent(ASF_OptLayout arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATisEmpty((ATermList)arg_arg0_arg0)) {
        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
          /* checking for: opt */
          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun3) {
            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
            /* checking for: layout */
            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun4) {
              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
              /* checking for: no-attrs */
              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun5) {
                ATerm arg_arg1 = ATgetArgument(arg, 1);
                if (ATisEmpty((ATermList)arg_arg1)) {
                  return ATtrue;
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_OptLayout is a Present by checking against the following ATerm pattern: appl(prod([cf(layout)],cf(opt(layout)),no-attrs),[<"layout"("Layout")>]). May not be used to assert correctness of the ASF_OptLayout
 * \param[in] arg input ASF_OptLayout
 * \return ATtrue if #arg corresponds to the signature of a Present, or ATfalse otherwise
 */
inline ATbool ASF_isOptLayoutPresent(ASF_OptLayout arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: layout */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun4) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun3) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun4) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: no-attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun5) {
                      ATerm arg_arg1 = ATgetArgument(arg, 1);
                      if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                        ATermList arg_arg1_list = (ATermList)arg_arg1;
                        arg_arg1_list = ATgetNext(arg_arg1_list);
                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                          return ATtrue;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_OptLayout has a layout. 
 * \param[in] arg input ASF_OptLayout
 * \return ATtrue if the ASF_OptLayout had a layout, or ATfalse otherwise
 */
ATbool ASF_hasOptLayoutLayout(ASF_OptLayout arg) {
  if (ASF_isOptLayoutPresent(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the layout ASF_Layout of a ASF_OptLayout. Note that the precondition is that this ASF_OptLayout actually has a layout
 * \param[in] arg input ASF_OptLayout
 * \return the layout of #arg, if it exist or an undefined value if it does not
 */
ASF_Layout ASF_getOptLayoutLayout(ASF_OptLayout arg) {
  
    return (ASF_Layout)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the layout of a ASF_OptLayout. The precondition being that this ASF_OptLayout actually has a layout
 * \param[in] arg input ASF_OptLayout
 * \param[in] layout new ASF_Layout to set in #arg
 * \return A new ASF_OptLayout with layout at the right place, or a core dump if #arg did not have a layout
 */
ASF_OptLayout ASF_setOptLayoutLayout(ASF_OptLayout arg, ASF_Layout layout) {
  if (ASF_isOptLayoutPresent(arg)) {
    return (ASF_OptLayout)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) layout), 0), 1);
  }

  ATabort("OptLayout has no Layout: %t\n", arg);
  return (ASF_OptLayout)NULL;
}

/**
 * Assert whether a ASF_Layout is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_Layout
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidLayout(ASF_Layout arg) {
  if (ASF_isLayoutLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Layout is a Lex-to-cf by checking against the following ATerm pattern: appl(prod([lex(iter(layout))],cf(layout),no-attrs),[appl(list(lex(iter(layout))),<"list"("Lex-Layout-list")>)]). Always returns ATtrue
 * \param[in] arg input ASF_Layout
 * \return ATtrue if #arg corresponds to the signature of a Lex-to-cf, or ATfalse otherwise
 */
inline ATbool ASF_isLayoutLexToCf(ASF_Layout arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun7) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: layout */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun4) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: no-attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun5) {
                      ATerm arg_arg1 = ATgetArgument(arg, 1);
                      if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                        ATerm arg_arg1_head;
                        ATermList arg_arg1_list = (ATermList)arg_arg1;
                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                        arg_arg1_list = ATgetNext(arg_arg1_list);
                        /* checking for: appl */
                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                          /* checking for: list */
                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun8) {
                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                            /* checking for: lex */
                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == ASF_afun6) {
                              ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                              /* checking for: iter */
                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == ASF_afun7) {
                                ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == ASF_afun4) {
                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                    return ATtrue;
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Layout has a list. 
 * \param[in] arg input ASF_Layout
 * \return ATtrue if the ASF_Layout had a list, or ATfalse otherwise
 */
ATbool ASF_hasLayoutList(ASF_Layout arg) {
  if (ASF_isLayoutLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the list ASF_LexLayoutList of a ASF_Layout. Note that the precondition is that this ASF_Layout actually has a list
 * \param[in] arg input ASF_Layout
 * \return the list of #arg, if it exist or an undefined value if it does not
 */
ASF_LexLayoutList ASF_getLayoutList(ASF_Layout arg) {
  
    return (ASF_LexLayoutList)ATgetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), 1);
}

/**
 * Set the list of a ASF_Layout. The precondition being that this ASF_Layout actually has a list
 * \param[in] arg input ASF_Layout
 * \param[in] list new ASF_LexLayoutList to set in #arg
 * \return A new ASF_Layout with list at the right place, or a core dump if #arg did not have a list
 */
ASF_Layout ASF_setLayoutList(ASF_Layout arg, ASF_LexLayoutList list) {
  if (ASF_isLayoutLexToCf(arg)) {
    return (ASF_Layout)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), (ATerm)((ATerm) list), 1), 0), 1);
  }

  ATabort("Layout has no List: %t\n", arg);
  return (ASF_Layout)NULL;
}

/**
 * Assert whether a ASF_LexLayoutList is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_LexLayoutList
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidLexLayoutList(ASF_LexLayoutList arg) {
  if (ASF_isLexLayoutListEmpty(arg)) {
    return ATtrue;
  }
  else if (ASF_isLexLayoutListSingle(arg)) {
    return ATtrue;
  }
  else if (ASF_isLexLayoutListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexLayoutList is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the ASF_LexLayoutList
 * \param[in] arg input ASF_LexLayoutList
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool ASF_isLexLayoutListEmpty(ASF_LexLayoutList arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexLayoutList is a single by checking against the following ATerm pattern: [<head(Lex-Layout)>]. May not be used to assert correctness of the ASF_LexLayoutList
 * \param[in] arg input ASF_LexLayoutList
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool ASF_isLexLayoutListSingle(ASF_LexLayoutList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexLayoutList is a many by checking against the following ATerm pattern: [<head(Lex-Layout)>,<[tail(Lex-Layout-list)]>]. May not be used to assert correctness of the ASF_LexLayoutList
 * \param[in] arg input ASF_LexLayoutList
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool ASF_isLexLayoutListMany(ASF_LexLayoutList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexLayoutList has a head. 
 * \param[in] arg input ASF_LexLayoutList
 * \return ATtrue if the ASF_LexLayoutList had a head, or ATfalse otherwise
 */
ATbool ASF_hasLexLayoutListHead(ASF_LexLayoutList arg) {
  if (ASF_isLexLayoutListSingle(arg)) {
    return ATtrue;
  }
  else if (ASF_isLexLayoutListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexLayoutList has a tail. 
 * \param[in] arg input ASF_LexLayoutList
 * \return ATtrue if the ASF_LexLayoutList had a tail, or ATfalse otherwise
 */
ATbool ASF_hasLexLayoutListTail(ASF_LexLayoutList arg) {
  if (ASF_isLexLayoutListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the head ASF_LexLayout of a ASF_LexLayoutList. Note that the precondition is that this ASF_LexLayoutList actually has a head
 * \param[in] arg input ASF_LexLayoutList
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
ASF_LexLayout ASF_getLexLayoutListHead(ASF_LexLayoutList arg) {
  if (ASF_isLexLayoutListSingle(arg)) {
    return (ASF_LexLayout)ATgetFirst((ATermList)arg);
  }
  else 
    return (ASF_LexLayout)ATgetFirst((ATermList)arg);
}

/**
 * Get the tail ASF_LexLayoutList of a ASF_LexLayoutList. Note that the precondition is that this ASF_LexLayoutList actually has a tail
 * \param[in] arg input ASF_LexLayoutList
 * \return the tail of #arg, if it exist or an undefined value if it does not
 */
ASF_LexLayoutList ASF_getLexLayoutListTail(ASF_LexLayoutList arg) {
  
    return (ASF_LexLayoutList)ATgetNext((ATermList)arg);
}

/**
 * Set the head of a ASF_LexLayoutList. The precondition being that this ASF_LexLayoutList actually has a head
 * \param[in] arg input ASF_LexLayoutList
 * \param[in] head new ASF_LexLayout to set in #arg
 * \return A new ASF_LexLayoutList with head at the right place, or a core dump if #arg did not have a head
 */
ASF_LexLayoutList ASF_setLexLayoutListHead(ASF_LexLayoutList arg, ASF_LexLayout head) {
  if (ASF_isLexLayoutListSingle(arg)) {
    return (ASF_LexLayoutList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (ASF_isLexLayoutListMany(arg)) {
    return (ASF_LexLayoutList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("LexLayoutList has no Head: %t\n", arg);
  return (ASF_LexLayoutList)NULL;
}

/**
 * Set the tail of a ASF_LexLayoutList. The precondition being that this ASF_LexLayoutList actually has a tail
 * \param[in] arg input ASF_LexLayoutList
 * \param[in] tail new ASF_LexLayoutList to set in #arg
 * \return A new ASF_LexLayoutList with tail at the right place, or a core dump if #arg did not have a tail
 */
ASF_LexLayoutList ASF_setLexLayoutListTail(ASF_LexLayoutList arg, ASF_LexLayoutList tail) {
  if (ASF_isLexLayoutListMany(arg)) {
    return (ASF_LexLayoutList)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 1);
  }

  ATabort("LexLayoutList has no Tail: %t\n", arg);
  return (ASF_LexLayoutList)NULL;
}

/**
 * Assert whether a ASF_Tree is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_Tree
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidTree(ASF_Tree arg) {
  if (ASF_isTreeCast(arg)) {
    return ATtrue;
  }
  else if (ASF_isTreeAmbiguityConstructor(arg)) {
    return ATtrue;
  }
  else if (ASF_isTreeLexicalConstructor(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Tree is a cast by checking against the following ATerm pattern: <"Tree"(term)>. May not be used to assert correctness of the ASF_Tree
 * \param[in] arg input ASF_Tree
 * \return ATtrue if #arg corresponds to the signature of a cast, or ATfalse otherwise
 */
inline ATbool ASF_isTreeCast(ASF_Tree arg){
  if (arg != NULL) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Tree is a ambiguity-constructor by checking against the following ATerm pattern: appl(prod([lit("amb"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(iter-star-sep(sort("Tree"),lit(","))),cf(opt(layout)),lit(")")],cf(sort("Tree")),attrs([term(cons("ambiguity-constructor"))])),[appl(prod([char-class([97]),char-class([109]),char-class([98])],lit("amb"),no-attrs),[97,109,98]),<"ws-after-amb"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,appl(list(cf(iter-star-sep(sort("Tree"),lit(",")))),<"ambs"("Tree-ambs")>),<"ws-after-ambs"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the ASF_Tree
 * \param[in] arg input ASF_Tree
 * \return ATtrue if #arg corresponds to the signature of a ambiguity-constructor, or ATfalse otherwise
 */
inline ATbool ASF_isTreeAmbiguityConstructor(ASF_Tree arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: amb */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun16) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun15) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: iter-star-sep */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun11) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun12) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                                          /* checking for: Tree */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == ASF_afun13) {
                                            ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                                            /* checking for: lit */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == ASF_afun9) {
                                              ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                                              /* checking for: , */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == ASF_afun14) {
                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                  /* checking for: cf */
                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                    /* checking for: opt */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                                                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                      /* checking for: layout */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                          /* checking for: lit */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                            /* checking for: ) */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun10) {
                                                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                /* checking for: cf */
                                                                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                                                                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                  /* checking for: sort */
                                                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                                                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                    /* checking for: Tree */
                                                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun13) {
                                                                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                      /* checking for: attrs */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                                                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                          ATerm arg_arg0_arg2_arg0_head;
                                                                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                          /* checking for: term */
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                            /* checking for: cons */
                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                              /* checking for: ambiguity-constructor */
                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun20) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                    ATerm arg_arg1_head;
                                                                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                    /* checking for: appl */
                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                      /* checking for: prod */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                          /* checking for: char-class */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                    /* checking for: char-class */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 109) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                              /* checking for: char-class */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 98) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                        /* checking for: lit */
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                          /* checking for: amb */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun16) {
                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                            /* checking for: no-attrs */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 109) {

                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 98) {

                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                /* checking for: appl */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                                                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                  /* checking for: prod */
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                      /* checking for: char-class */
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                /* checking for: lit */
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                  /* checking for: ( */
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun15) {
                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                    /* checking for: no-attrs */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                /* checking for: appl */
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                  /* checking for: list */
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun8) {
                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                    /* checking for: cf */
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == ASF_afun2) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                                                                                                      /* checking for: iter-star-sep */
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == ASF_afun11) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                                                                                                        /* checking for: sort */
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == ASF_afun12) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                                                                                                          /* checking for: Tree */
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == ASF_afun13) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                                                                                                                                                                            /* checking for: lit */
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == ASF_afun9) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                                                                                                                                                                              /* checking for: , */
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == ASF_afun14) {
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                    /* checking for: appl */
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                      /* checking for: prod */
                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                      /* checking for: ) */
                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun10) {
                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                  return ATtrue;
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Tree is a lexical-constructor by checking against the following ATerm pattern: appl(prod([cf(sort("Tree")),cf(opt(layout)),lit("("),cf(opt(layout)),cf(iter-star(sort("CHAR"))),cf(opt(layout)),lit(")")],cf(sort("Tree")),attrs([term(cons("lexical-constructor"))])),[<"name"("Tree")>,<"ws-after-name"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,appl(list(cf(iter-star(sort("CHAR")))),<"list"("CHAR-list")>),<"ws-after-list"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the ASF_Tree
 * \param[in] arg input ASF_Tree
 * \return ATtrue if #arg corresponds to the signature of a lexical-constructor, or ATfalse otherwise
 */
inline ATbool ASF_isTreeLexicalConstructor(ASF_Tree arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: Tree */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun13) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: ( */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun15) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: iter-star */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun22) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: sort */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun12) {
                                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                                            /* checking for: CHAR */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == ASF_afun23) {
                                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                /* checking for: cf */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                  /* checking for: opt */
                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                                                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                    /* checking for: layout */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                        /* checking for: lit */
                                                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
                                                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                          /* checking for: ) */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun10) {
                                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                              /* checking for: cf */
                                                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                                                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                /* checking for: sort */
                                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                  /* checking for: Tree */
                                                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun13) {
                                                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                    /* checking for: attrs */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                        ATerm arg_arg0_arg2_arg0_head;
                                                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                        /* checking for: term */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                          /* checking for: cons */
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                            /* checking for: lexical-constructor */
                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun24) {
                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                  ATerm arg_arg1_head;
                                                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                      /* checking for: appl */
                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                        /* checking for: prod */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                            /* checking for: char-class */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                      /* checking for: lit */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                        /* checking for: ( */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun15) {
                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                          /* checking for: no-attrs */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                      /* checking for: appl */
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                        /* checking for: list */
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun8) {
                                                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                          /* checking for: cf */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == ASF_afun2) {
                                                                                                                            ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                                            /* checking for: iter-star */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == ASF_afun22) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                                              /* checking for: sort */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == ASF_afun12) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                                                /* checking for: CHAR */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == ASF_afun23) {
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                      /* checking for: appl */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                        /* checking for: prod */
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                            /* checking for: char-class */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                      /* checking for: lit */
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                        /* checking for: ) */
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun10) {
                                                                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                          /* checking for: no-attrs */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                    return ATtrue;
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Tree has a Tree. 
 * \param[in] arg input ASF_Tree
 * \return ATtrue if the ASF_Tree had a Tree, or ATfalse otherwise
 */
ATbool ASF_hasTreeTree(ASF_Tree arg) {
  if (ASF_isTreeCast(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Tree has a ws-after-amb. 
 * \param[in] arg input ASF_Tree
 * \return ATtrue if the ASF_Tree had a ws-after-amb, or ATfalse otherwise
 */
ATbool ASF_hasTreeWsAfterAmb(ASF_Tree arg) {
  if (ASF_isTreeAmbiguityConstructor(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Tree has a ws-after-(. 
 * \param[in] arg input ASF_Tree
 * \return ATtrue if the ASF_Tree had a ws-after-(, or ATfalse otherwise
 */
ATbool ASF_hasTreeWsAfterParenOpen(ASF_Tree arg) {
  if (ASF_isTreeAmbiguityConstructor(arg)) {
    return ATtrue;
  }
  else if (ASF_isTreeLexicalConstructor(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Tree has a ambs. 
 * \param[in] arg input ASF_Tree
 * \return ATtrue if the ASF_Tree had a ambs, or ATfalse otherwise
 */
ATbool ASF_hasTreeAmbs(ASF_Tree arg) {
  if (ASF_isTreeAmbiguityConstructor(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Tree has a ws-after-ambs. 
 * \param[in] arg input ASF_Tree
 * \return ATtrue if the ASF_Tree had a ws-after-ambs, or ATfalse otherwise
 */
ATbool ASF_hasTreeWsAfterAmbs(ASF_Tree arg) {
  if (ASF_isTreeAmbiguityConstructor(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Tree has a name. 
 * \param[in] arg input ASF_Tree
 * \return ATtrue if the ASF_Tree had a name, or ATfalse otherwise
 */
ATbool ASF_hasTreeName(ASF_Tree arg) {
  if (ASF_isTreeLexicalConstructor(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Tree has a ws-after-name. 
 * \param[in] arg input ASF_Tree
 * \return ATtrue if the ASF_Tree had a ws-after-name, or ATfalse otherwise
 */
ATbool ASF_hasTreeWsAfterName(ASF_Tree arg) {
  if (ASF_isTreeLexicalConstructor(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Tree has a list. 
 * \param[in] arg input ASF_Tree
 * \return ATtrue if the ASF_Tree had a list, or ATfalse otherwise
 */
ATbool ASF_hasTreeList(ASF_Tree arg) {
  if (ASF_isTreeLexicalConstructor(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Tree has a ws-after-list. 
 * \param[in] arg input ASF_Tree
 * \return ATtrue if the ASF_Tree had a ws-after-list, or ATfalse otherwise
 */
ATbool ASF_hasTreeWsAfterList(ASF_Tree arg) {
  if (ASF_isTreeLexicalConstructor(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the Tree ATerm of a ASF_Tree. Note that the precondition is that this ASF_Tree actually has a Tree
 * \param[in] arg input ASF_Tree
 * \return the Tree of #arg, if it exist or an undefined value if it does not
 */
ATerm ASF_getTreeTree(ASF_Tree arg) {
  
    return (ATerm)arg;
}

/**
 * Get the ws-after-amb ASF_OptLayout of a ASF_Tree. Note that the precondition is that this ASF_Tree actually has a ws-after-amb
 * \param[in] arg input ASF_Tree
 * \return the ws-after-amb of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getTreeWsAfterAmb(ASF_Tree arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-( ASF_OptLayout of a ASF_Tree. Note that the precondition is that this ASF_Tree actually has a ws-after-(
 * \param[in] arg input ASF_Tree
 * \return the ws-after-( of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getTreeWsAfterParenOpen(ASF_Tree arg) {
  if (ASF_isTreeAmbiguityConstructor(arg)) {
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else 
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the ambs ASF_TreeAmbs of a ASF_Tree. Note that the precondition is that this ASF_Tree actually has a ambs
 * \param[in] arg input ASF_Tree
 * \return the ambs of #arg, if it exist or an undefined value if it does not
 */
ASF_TreeAmbs ASF_getTreeAmbs(ASF_Tree arg) {
  
    return (ASF_TreeAmbs)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4), 1);
}

/**
 * Get the ws-after-ambs ASF_OptLayout of a ASF_Tree. Note that the precondition is that this ASF_Tree actually has a ws-after-ambs
 * \param[in] arg input ASF_Tree
 * \return the ws-after-ambs of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getTreeWsAfterAmbs(ASF_Tree arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the name ASF_Tree of a ASF_Tree. Note that the precondition is that this ASF_Tree actually has a name
 * \param[in] arg input ASF_Tree
 * \return the name of #arg, if it exist or an undefined value if it does not
 */
ASF_Tree ASF_getTreeName(ASF_Tree arg) {
  
    return (ASF_Tree)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the ws-after-name ASF_OptLayout of a ASF_Tree. Note that the precondition is that this ASF_Tree actually has a ws-after-name
 * \param[in] arg input ASF_Tree
 * \return the ws-after-name of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getTreeWsAfterName(ASF_Tree arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the list ASF_CHARList of a ASF_Tree. Note that the precondition is that this ASF_Tree actually has a list
 * \param[in] arg input ASF_Tree
 * \return the list of #arg, if it exist or an undefined value if it does not
 */
ASF_CHARList ASF_getTreeList(ASF_Tree arg) {
  
    return (ASF_CHARList)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4), 1);
}

/**
 * Get the ws-after-list ASF_OptLayout of a ASF_Tree. Note that the precondition is that this ASF_Tree actually has a ws-after-list
 * \param[in] arg input ASF_Tree
 * \return the ws-after-list of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getTreeWsAfterList(ASF_Tree arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Set the Tree of a ASF_Tree. The precondition being that this ASF_Tree actually has a Tree
 * \param[in] arg input ASF_Tree
 * \param[in] Tree new ATerm to set in #arg
 * \return A new ASF_Tree with Tree at the right place, or a core dump if #arg did not have a Tree
 */
ASF_Tree ASF_setTreeTree(ASF_Tree arg, ATerm Tree) {
  if (ASF_isTreeCast(arg)) {
    return (ASF_Tree)((ATerm) Tree);
  }

  ATabort("Tree has no Tree: %t\n", arg);
  return (ASF_Tree)NULL;
}

/**
 * Set the ws-after-amb of a ASF_Tree. The precondition being that this ASF_Tree actually has a ws-after-amb
 * \param[in] arg input ASF_Tree
 * \param[in] wsAfterAmb new ASF_OptLayout to set in #arg
 * \return A new ASF_Tree with wsAfterAmb at the right place, or a core dump if #arg did not have a wsAfterAmb
 */
ASF_Tree ASF_setTreeWsAfterAmb(ASF_Tree arg, ASF_OptLayout wsAfterAmb) {
  if (ASF_isTreeAmbiguityConstructor(arg)) {
    return (ASF_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterAmb), 1), 1);
  }

  ATabort("Tree has no WsAfterAmb: %t\n", arg);
  return (ASF_Tree)NULL;
}

/**
 * Set the ws-after-( of a ASF_Tree. The precondition being that this ASF_Tree actually has a ws-after-(
 * \param[in] arg input ASF_Tree
 * \param[in] wsAfterParenOpen new ASF_OptLayout to set in #arg
 * \return A new ASF_Tree with wsAfterParenOpen at the right place, or a core dump if #arg did not have a wsAfterParenOpen
 */
ASF_Tree ASF_setTreeWsAfterParenOpen(ASF_Tree arg, ASF_OptLayout wsAfterParenOpen) {
  if (ASF_isTreeAmbiguityConstructor(arg)) {
    return (ASF_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (ASF_isTreeLexicalConstructor(arg)) {
    return (ASF_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }

  ATabort("Tree has no WsAfterParenOpen: %t\n", arg);
  return (ASF_Tree)NULL;
}

/**
 * Set the ambs of a ASF_Tree. The precondition being that this ASF_Tree actually has a ambs
 * \param[in] arg input ASF_Tree
 * \param[in] ambs new ASF_TreeAmbs to set in #arg
 * \return A new ASF_Tree with ambs at the right place, or a core dump if #arg did not have a ambs
 */
ASF_Tree ASF_setTreeAmbs(ASF_Tree arg, ASF_TreeAmbs ambs) {
  if (ASF_isTreeAmbiguityConstructor(arg)) {
    return (ASF_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4), (ATerm)((ATerm) ambs), 1), 4), 1);
  }

  ATabort("Tree has no Ambs: %t\n", arg);
  return (ASF_Tree)NULL;
}

/**
 * Set the ws-after-ambs of a ASF_Tree. The precondition being that this ASF_Tree actually has a ws-after-ambs
 * \param[in] arg input ASF_Tree
 * \param[in] wsAfterAmbs new ASF_OptLayout to set in #arg
 * \return A new ASF_Tree with wsAfterAmbs at the right place, or a core dump if #arg did not have a wsAfterAmbs
 */
ASF_Tree ASF_setTreeWsAfterAmbs(ASF_Tree arg, ASF_OptLayout wsAfterAmbs) {
  if (ASF_isTreeAmbiguityConstructor(arg)) {
    return (ASF_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterAmbs), 5), 1);
  }

  ATabort("Tree has no WsAfterAmbs: %t\n", arg);
  return (ASF_Tree)NULL;
}

/**
 * Set the name of a ASF_Tree. The precondition being that this ASF_Tree actually has a name
 * \param[in] arg input ASF_Tree
 * \param[in] name new ASF_Tree to set in #arg
 * \return A new ASF_Tree with name at the right place, or a core dump if #arg did not have a name
 */
ASF_Tree ASF_setTreeName(ASF_Tree arg, ASF_Tree name) {
  if (ASF_isTreeLexicalConstructor(arg)) {
    return (ASF_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) name), 0), 1);
  }

  ATabort("Tree has no Name: %t\n", arg);
  return (ASF_Tree)NULL;
}

/**
 * Set the ws-after-name of a ASF_Tree. The precondition being that this ASF_Tree actually has a ws-after-name
 * \param[in] arg input ASF_Tree
 * \param[in] wsAfterName new ASF_OptLayout to set in #arg
 * \return A new ASF_Tree with wsAfterName at the right place, or a core dump if #arg did not have a wsAfterName
 */
ASF_Tree ASF_setTreeWsAfterName(ASF_Tree arg, ASF_OptLayout wsAfterName) {
  if (ASF_isTreeLexicalConstructor(arg)) {
    return (ASF_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterName), 1), 1);
  }

  ATabort("Tree has no WsAfterName: %t\n", arg);
  return (ASF_Tree)NULL;
}

/**
 * Set the list of a ASF_Tree. The precondition being that this ASF_Tree actually has a list
 * \param[in] arg input ASF_Tree
 * \param[in] list new ASF_CHARList to set in #arg
 * \return A new ASF_Tree with list at the right place, or a core dump if #arg did not have a list
 */
ASF_Tree ASF_setTreeList(ASF_Tree arg, ASF_CHARList list) {
  if (ASF_isTreeLexicalConstructor(arg)) {
    return (ASF_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4), (ATerm)((ATerm) list), 1), 4), 1);
  }

  ATabort("Tree has no List: %t\n", arg);
  return (ASF_Tree)NULL;
}

/**
 * Set the ws-after-list of a ASF_Tree. The precondition being that this ASF_Tree actually has a ws-after-list
 * \param[in] arg input ASF_Tree
 * \param[in] wsAfterList new ASF_OptLayout to set in #arg
 * \return A new ASF_Tree with wsAfterList at the right place, or a core dump if #arg did not have a wsAfterList
 */
ASF_Tree ASF_setTreeWsAfterList(ASF_Tree arg, ASF_OptLayout wsAfterList) {
  if (ASF_isTreeLexicalConstructor(arg)) {
    return (ASF_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterList), 5), 1);
  }

  ATabort("Tree has no WsAfterList: %t\n", arg);
  return (ASF_Tree)NULL;
}

/**
 * Assert whether a ASF_LexCHAR is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_LexCHAR
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidLexCHAR(ASF_LexCHAR arg) {
  if (ASF_isLexCHARDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexCHAR is a default by checking against the following ATerm pattern: appl(prod([char-class([34]),char-class([range(0,255)]),char-class([34])],lex(sort("CHAR")),attrs([term(cons("default"))])),[34,<"value"(char)>,34]). Always returns ATtrue
 * \param[in] arg input ASF_LexCHAR
 * \return ATtrue if #arg corresponds to the signature of a default, or ATfalse otherwise
 */
inline ATbool ASF_isLexCHARDefault(ASF_LexCHAR arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: char-class */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun21) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
            ATerm arg_arg0_arg0_head_arg0_head;
            ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
            if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 34) {

              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                  /* checking for: char-class */
                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun21) {
                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
                      ATerm arg_arg0_arg0_head_arg0_head;
                      ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
                      arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                      arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                      /* checking for: range */
                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
                        ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                        if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 0) {

                          ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                          if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 255) {

                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                /* checking for: char-class */
                                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun21) {
                                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
                                    ATerm arg_arg0_arg0_head_arg0_head;
                                    ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
                                    arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                    arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                    if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 34) {

                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                          /* checking for: lex */
                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun6) {
                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                            /* checking for: sort */
                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                              /* checking for: CHAR */
                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun23) {
                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                /* checking for: attrs */
                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                    ATerm arg_arg0_arg2_arg0_head;
                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                    /* checking for: term */
                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                      /* checking for: cons */
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                        /* checking for: default */
                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun26) {
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                              ATerm arg_arg1_head;
                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                              if (ATgetInt((ATermInt)arg_arg1_head) == 34) {

                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                      if (ATgetInt((ATermInt)arg_arg1_head) == 34) {

                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                          return ATtrue;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexCHAR has a value. 
 * \param[in] arg input ASF_LexCHAR
 * \return ATtrue if the ASF_LexCHAR had a value, or ATfalse otherwise
 */
ATbool ASF_hasLexCHARValue(ASF_LexCHAR arg) {
  if (ASF_isLexCHARDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the value char of a ASF_LexCHAR. Note that the precondition is that this ASF_LexCHAR actually has a value
 * \param[in] arg input ASF_LexCHAR
 * \return the value of #arg, if it exist or an undefined value if it does not
 */
char ASF_getLexCHARValue(ASF_LexCHAR arg) {
  
    return (char)ASF_charToByte((ATerm)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1));
}

/**
 * Set the value of a ASF_LexCHAR. The precondition being that this ASF_LexCHAR actually has a value
 * \param[in] arg input ASF_LexCHAR
 * \param[in] value new char to set in #arg
 * \return A new ASF_LexCHAR with value at the right place, or a core dump if #arg did not have a value
 */
ASF_LexCHAR ASF_setLexCHARValue(ASF_LexCHAR arg, char value) {
  if (ASF_isLexCHARDefault(arg)) {
    return (ASF_LexCHAR)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) ASF_byteToChar(value))), 1), 1);
  }

  ATabort("LexCHAR has no Value: %t\n", arg);
  return (ASF_LexCHAR)NULL;
}

/**
 * Assert whether a ASF_CHAR is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_CHAR
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidCHAR(ASF_CHAR arg) {
  if (ASF_isCHARLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_CHAR is a Lex-to-cf by checking against the following ATerm pattern: appl(prod([lex(sort("CHAR"))],cf(sort("CHAR")),no-attrs),[<"CHAR"("Lex-CHAR")>]). Always returns ATtrue
 * \param[in] arg input ASF_CHAR
 * \return ATtrue if #arg corresponds to the signature of a Lex-to-cf, or ATfalse otherwise
 */
inline ATbool ASF_isCHARLexToCf(ASF_CHAR arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: CHAR */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun23) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: CHAR */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun23) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: no-attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun5) {
                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                          arg_arg1_list = ATgetNext(arg_arg1_list);
                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_CHAR has a CHAR. 
 * \param[in] arg input ASF_CHAR
 * \return ATtrue if the ASF_CHAR had a CHAR, or ATfalse otherwise
 */
ATbool ASF_hasCHARCHAR(ASF_CHAR arg) {
  if (ASF_isCHARLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the CHAR ASF_LexCHAR of a ASF_CHAR. Note that the precondition is that this ASF_CHAR actually has a CHAR
 * \param[in] arg input ASF_CHAR
 * \return the CHAR of #arg, if it exist or an undefined value if it does not
 */
ASF_LexCHAR ASF_getCHARCHAR(ASF_CHAR arg) {
  
    return (ASF_LexCHAR)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the CHAR of a ASF_CHAR. The precondition being that this ASF_CHAR actually has a CHAR
 * \param[in] arg input ASF_CHAR
 * \param[in] CHAR new ASF_LexCHAR to set in #arg
 * \return A new ASF_CHAR with CHAR at the right place, or a core dump if #arg did not have a CHAR
 */
ASF_CHAR ASF_setCHARCHAR(ASF_CHAR arg, ASF_LexCHAR CHAR) {
  if (ASF_isCHARLexToCf(arg)) {
    return (ASF_CHAR)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) CHAR), 0), 1);
  }

  ATabort("CHAR has no CHAR: %t\n", arg);
  return (ASF_CHAR)NULL;
}

/**
 * Assert whether a ASF_ASFCondition is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_ASFCondition
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidASFCondition(ASF_ASFCondition arg) {
  if (ASF_isASFConditionNegative(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionEquality(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionMatch(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionNoMatch(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFCondition is a negative by checking against the following ATerm pattern: appl(prod([<"type-of-lhs"(term)>,cf(opt(layout)),lit("!="),cf(opt(layout)),<"type-of-rhs"(term)>],cf(sort("ASF-Condition")),attrs([term(cons("negative"))])),[<"lhs"("Tree")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([33]),char-class([61])],lit("!="),no-attrs),[33,61]),<"ws-after-unequal"("OptLayout")>,<"rhs"("Tree")>]). May not be used to assert correctness of the ASF_ASFCondition
 * \param[in] arg input ASF_ASFCondition
 * \return ATtrue if #arg corresponds to the signature of a negative, or ATfalse otherwise
 */
inline ATbool ASF_isASFConditionNegative(ASF_ASFCondition arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        if (arg_arg0_arg0_head != NULL) {
          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
            /* checking for: cf */
            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
              /* checking for: opt */
              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                /* checking for: layout */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                    /* checking for: lit */
                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                      /* checking for: != */
                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun27) {
                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                          /* checking for: cf */
                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                            /* checking for: opt */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                              /* checking for: layout */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                  if (arg_arg0_arg0_head != NULL) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                          /* checking for: ASF-Condition */
                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun28) {
                                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                            /* checking for: attrs */
                                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                              ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                ATerm arg_arg0_arg2_arg0_head;
                                                ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                /* checking for: term */
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                  ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                  /* checking for: cons */
                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                    ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                    /* checking for: negative */
                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun29) {
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                          ATerm arg_arg1_head;
                                                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                              /* checking for: appl */
                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                /* checking for: prod */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                    /* checking for: char-class */
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 33) {

                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                              /* checking for: char-class */
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                        /* checking for: lit */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                          /* checking for: != */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun27) {
                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                            /* checking for: no-attrs */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 33) {

                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                              return ATtrue;
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFCondition is a equality by checking against the following ATerm pattern: appl(prod([<"type-of-lhs"(term)>,cf(opt(layout)),lit("=="),cf(opt(layout)),<"type-of-rhs"(term)>],cf(sort("ASF-Condition")),attrs([term(cons("equality"))])),[<"lhs"("Tree")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([61]),char-class([61])],lit("=="),no-attrs),[61,61]),<"ws-after-equality"("OptLayout")>,<"rhs"("Tree")>]). May not be used to assert correctness of the ASF_ASFCondition
 * \param[in] arg input ASF_ASFCondition
 * \return ATtrue if #arg corresponds to the signature of a equality, or ATfalse otherwise
 */
inline ATbool ASF_isASFConditionEquality(ASF_ASFCondition arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        if (arg_arg0_arg0_head != NULL) {
          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
            /* checking for: cf */
            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
              /* checking for: opt */
              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                /* checking for: layout */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                    /* checking for: lit */
                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                      /* checking for: == */
                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun30) {
                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                          /* checking for: cf */
                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                            /* checking for: opt */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                              /* checking for: layout */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                  if (arg_arg0_arg0_head != NULL) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                          /* checking for: ASF-Condition */
                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun28) {
                                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                            /* checking for: attrs */
                                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                              ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                ATerm arg_arg0_arg2_arg0_head;
                                                ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                /* checking for: term */
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                  ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                  /* checking for: cons */
                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                    ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                    /* checking for: equality */
                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun31) {
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                          ATerm arg_arg1_head;
                                                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                              /* checking for: appl */
                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                /* checking for: prod */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                    /* checking for: char-class */
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                              /* checking for: char-class */
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                        /* checking for: lit */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                          /* checking for: == */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun30) {
                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                            /* checking for: no-attrs */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                              return ATtrue;
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFCondition is a match by checking against the following ATerm pattern: appl(prod([<"type-of-lhs"(term)>,cf(opt(layout)),lit(":="),cf(opt(layout)),<"type-of-rhs"(term)>],cf(sort("ASF-Condition")),attrs([term(cons("match"))])),[<"lhs"("Tree")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([58]),char-class([61])],lit(":="),no-attrs),[58,61]),<"ws-after-match"("OptLayout")>,<"rhs"("Tree")>]). May not be used to assert correctness of the ASF_ASFCondition
 * \param[in] arg input ASF_ASFCondition
 * \return ATtrue if #arg corresponds to the signature of a match, or ATfalse otherwise
 */
inline ATbool ASF_isASFConditionMatch(ASF_ASFCondition arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        if (arg_arg0_arg0_head != NULL) {
          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
            /* checking for: cf */
            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
              /* checking for: opt */
              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                /* checking for: layout */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                    /* checking for: lit */
                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                      /* checking for: := */
                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun32) {
                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                          /* checking for: cf */
                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                            /* checking for: opt */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                              /* checking for: layout */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                  if (arg_arg0_arg0_head != NULL) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                          /* checking for: ASF-Condition */
                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun28) {
                                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                            /* checking for: attrs */
                                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                              ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                ATerm arg_arg0_arg2_arg0_head;
                                                ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                /* checking for: term */
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                  ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                  /* checking for: cons */
                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                    ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                    /* checking for: match */
                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun33) {
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                          ATerm arg_arg1_head;
                                                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                              /* checking for: appl */
                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                /* checking for: prod */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                    /* checking for: char-class */
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 58) {

                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                              /* checking for: char-class */
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                        /* checking for: lit */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                          /* checking for: := */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun32) {
                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                            /* checking for: no-attrs */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 58) {

                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                              return ATtrue;
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFCondition is a no-match by checking against the following ATerm pattern: appl(prod([<"type-of-lhs"(term)>,cf(opt(layout)),lit("!:="),cf(opt(layout)),<"type-of-rhs"(term)>],cf(sort("ASF-Condition")),attrs([term(cons("no-match"))])),[<"lhs"("Tree")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([33]),char-class([58]),char-class([61])],lit("!:="),no-attrs),[33,58,61]),<"ws-after-match"("OptLayout")>,<"rhs"("Tree")>]). May not be used to assert correctness of the ASF_ASFCondition
 * \param[in] arg input ASF_ASFCondition
 * \return ATtrue if #arg corresponds to the signature of a no-match, or ATfalse otherwise
 */
inline ATbool ASF_isASFConditionNoMatch(ASF_ASFCondition arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        if (arg_arg0_arg0_head != NULL) {
          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
            /* checking for: cf */
            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
              /* checking for: opt */
              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                /* checking for: layout */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                    /* checking for: lit */
                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                      /* checking for: !:= */
                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun34) {
                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                          /* checking for: cf */
                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                            /* checking for: opt */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                              /* checking for: layout */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                  if (arg_arg0_arg0_head != NULL) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                          /* checking for: ASF-Condition */
                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun28) {
                                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                            /* checking for: attrs */
                                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                              ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                ATerm arg_arg0_arg2_arg0_head;
                                                ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                /* checking for: term */
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                  ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                  /* checking for: cons */
                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                    ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                    /* checking for: no-match */
                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun35) {
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                          ATerm arg_arg1_head;
                                                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                              /* checking for: appl */
                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                /* checking for: prod */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                    /* checking for: char-class */
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 33) {

                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                              /* checking for: char-class */
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 58) {

                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                        /* checking for: char-class */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                  /* checking for: lit */
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                    /* checking for: !:= */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun34) {
                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                      /* checking for: no-attrs */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 33) {

                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 58) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                            return ATtrue;
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFCondition has a type-of-lhs. 
 * \param[in] arg input ASF_ASFCondition
 * \return ATtrue if the ASF_ASFCondition had a type-of-lhs, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionTypeOfLhs(ASF_ASFCondition arg) {
  if (ASF_isASFConditionNegative(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionEquality(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionMatch(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionNoMatch(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFCondition has a type-of-rhs. 
 * \param[in] arg input ASF_ASFCondition
 * \return ATtrue if the ASF_ASFCondition had a type-of-rhs, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionTypeOfRhs(ASF_ASFCondition arg) {
  if (ASF_isASFConditionNegative(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionEquality(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionMatch(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionNoMatch(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFCondition has a lhs. 
 * \param[in] arg input ASF_ASFCondition
 * \return ATtrue if the ASF_ASFCondition had a lhs, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionLhs(ASF_ASFCondition arg) {
  if (ASF_isASFConditionNegative(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionEquality(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionMatch(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionNoMatch(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFCondition has a ws-after-lhs. 
 * \param[in] arg input ASF_ASFCondition
 * \return ATtrue if the ASF_ASFCondition had a ws-after-lhs, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionWsAfterLhs(ASF_ASFCondition arg) {
  if (ASF_isASFConditionNegative(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionEquality(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionMatch(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionNoMatch(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFCondition has a ws-after-unequal. 
 * \param[in] arg input ASF_ASFCondition
 * \return ATtrue if the ASF_ASFCondition had a ws-after-unequal, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionWsAfterUnequal(ASF_ASFCondition arg) {
  if (ASF_isASFConditionNegative(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFCondition has a rhs. 
 * \param[in] arg input ASF_ASFCondition
 * \return ATtrue if the ASF_ASFCondition had a rhs, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionRhs(ASF_ASFCondition arg) {
  if (ASF_isASFConditionNegative(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionEquality(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionMatch(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionNoMatch(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFCondition has a ws-after-equality. 
 * \param[in] arg input ASF_ASFCondition
 * \return ATtrue if the ASF_ASFCondition had a ws-after-equality, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionWsAfterEquality(ASF_ASFCondition arg) {
  if (ASF_isASFConditionEquality(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFCondition has a ws-after-match. 
 * \param[in] arg input ASF_ASFCondition
 * \return ATtrue if the ASF_ASFCondition had a ws-after-match, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionWsAfterMatch(ASF_ASFCondition arg) {
  if (ASF_isASFConditionMatch(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionNoMatch(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the type-of-lhs ATerm of a ASF_ASFCondition. Note that the precondition is that this ASF_ASFCondition actually has a type-of-lhs
 * \param[in] arg input ASF_ASFCondition
 * \return the type-of-lhs of #arg, if it exist or an undefined value if it does not
 */
ATerm ASF_getASFConditionTypeOfLhs(ASF_ASFCondition arg) {
  if (ASF_isASFConditionNegative(arg)) {
    return (ATerm)ATgetFirst((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0));
  }
  else if (ASF_isASFConditionEquality(arg)) {
    return (ATerm)ATgetFirst((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0));
  }
  else if (ASF_isASFConditionMatch(arg)) {
    return (ATerm)ATgetFirst((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0));
  }
  else 
    return (ATerm)ATgetFirst((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0));
}

/**
 * Get the type-of-rhs ATerm of a ASF_ASFCondition. Note that the precondition is that this ASF_ASFCondition actually has a type-of-rhs
 * \param[in] arg input ASF_ASFCondition
 * \return the type-of-rhs of #arg, if it exist or an undefined value if it does not
 */
ATerm ASF_getASFConditionTypeOfRhs(ASF_ASFCondition arg) {
  if (ASF_isASFConditionNegative(arg)) {
    return (ATerm)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0), 4);
  }
  else if (ASF_isASFConditionEquality(arg)) {
    return (ATerm)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0), 4);
  }
  else if (ASF_isASFConditionMatch(arg)) {
    return (ATerm)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0), 4);
  }
  else 
    return (ATerm)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0), 4);
}

/**
 * Get the lhs ASF_Tree of a ASF_ASFCondition. Note that the precondition is that this ASF_ASFCondition actually has a lhs
 * \param[in] arg input ASF_ASFCondition
 * \return the lhs of #arg, if it exist or an undefined value if it does not
 */
ASF_Tree ASF_getASFConditionLhs(ASF_ASFCondition arg) {
  if (ASF_isASFConditionNegative(arg)) {
    return (ASF_Tree)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else if (ASF_isASFConditionEquality(arg)) {
    return (ASF_Tree)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else if (ASF_isASFConditionMatch(arg)) {
    return (ASF_Tree)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else 
    return (ASF_Tree)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the ws-after-lhs ASF_OptLayout of a ASF_ASFCondition. Note that the precondition is that this ASF_ASFCondition actually has a ws-after-lhs
 * \param[in] arg input ASF_ASFCondition
 * \return the ws-after-lhs of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFConditionWsAfterLhs(ASF_ASFCondition arg) {
  if (ASF_isASFConditionNegative(arg)) {
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else if (ASF_isASFConditionEquality(arg)) {
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else if (ASF_isASFConditionMatch(arg)) {
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else 
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-unequal ASF_OptLayout of a ASF_ASFCondition. Note that the precondition is that this ASF_ASFCondition actually has a ws-after-unequal
 * \param[in] arg input ASF_ASFCondition
 * \return the ws-after-unequal of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFConditionWsAfterUnequal(ASF_ASFCondition arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the rhs ASF_Tree of a ASF_ASFCondition. Note that the precondition is that this ASF_ASFCondition actually has a rhs
 * \param[in] arg input ASF_ASFCondition
 * \return the rhs of #arg, if it exist or an undefined value if it does not
 */
ASF_Tree ASF_getASFConditionRhs(ASF_ASFCondition arg) {
  if (ASF_isASFConditionNegative(arg)) {
    return (ASF_Tree)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else if (ASF_isASFConditionEquality(arg)) {
    return (ASF_Tree)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else if (ASF_isASFConditionMatch(arg)) {
    return (ASF_Tree)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else 
    return (ASF_Tree)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-equality ASF_OptLayout of a ASF_ASFCondition. Note that the precondition is that this ASF_ASFCondition actually has a ws-after-equality
 * \param[in] arg input ASF_ASFCondition
 * \return the ws-after-equality of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFConditionWsAfterEquality(ASF_ASFCondition arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the ws-after-match ASF_OptLayout of a ASF_ASFCondition. Note that the precondition is that this ASF_ASFCondition actually has a ws-after-match
 * \param[in] arg input ASF_ASFCondition
 * \return the ws-after-match of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFConditionWsAfterMatch(ASF_ASFCondition arg) {
  if (ASF_isASFConditionMatch(arg)) {
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else 
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Set the type-of-lhs of a ASF_ASFCondition. The precondition being that this ASF_ASFCondition actually has a type-of-lhs
 * \param[in] arg input ASF_ASFCondition
 * \param[in] typeOfLhs new ATerm to set in #arg
 * \return A new ASF_ASFCondition with typeOfLhs at the right place, or a core dump if #arg did not have a typeOfLhs
 */
ASF_ASFCondition ASF_setASFConditionTypeOfLhs(ASF_ASFCondition arg, ATerm typeOfLhs) {
  if (ASF_isASFConditionNegative(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0), (ATerm)((ATerm) typeOfLhs), 0), 0), 0);
  }
  else if (ASF_isASFConditionEquality(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0), (ATerm)((ATerm) typeOfLhs), 0), 0), 0);
  }
  else if (ASF_isASFConditionMatch(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0), (ATerm)((ATerm) typeOfLhs), 0), 0), 0);
  }
  else if (ASF_isASFConditionNoMatch(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0), (ATerm)((ATerm) typeOfLhs), 0), 0), 0);
  }

  ATabort("ASFCondition has no TypeOfLhs: %t\n", arg);
  return (ASF_ASFCondition)NULL;
}

/**
 * Set the type-of-rhs of a ASF_ASFCondition. The precondition being that this ASF_ASFCondition actually has a type-of-rhs
 * \param[in] arg input ASF_ASFCondition
 * \param[in] typeOfRhs new ATerm to set in #arg
 * \return A new ASF_ASFCondition with typeOfRhs at the right place, or a core dump if #arg did not have a typeOfRhs
 */
ASF_ASFCondition ASF_setASFConditionTypeOfRhs(ASF_ASFCondition arg, ATerm typeOfRhs) {
  if (ASF_isASFConditionNegative(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0), (ATerm)((ATerm) typeOfRhs), 4), 0), 0);
  }
  else if (ASF_isASFConditionEquality(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0), (ATerm)((ATerm) typeOfRhs), 4), 0), 0);
  }
  else if (ASF_isASFConditionMatch(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0), (ATerm)((ATerm) typeOfRhs), 4), 0), 0);
  }
  else if (ASF_isASFConditionNoMatch(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0), (ATerm)((ATerm) typeOfRhs), 4), 0), 0);
  }

  ATabort("ASFCondition has no TypeOfRhs: %t\n", arg);
  return (ASF_ASFCondition)NULL;
}

/**
 * Set the lhs of a ASF_ASFCondition. The precondition being that this ASF_ASFCondition actually has a lhs
 * \param[in] arg input ASF_ASFCondition
 * \param[in] lhs new ASF_Tree to set in #arg
 * \return A new ASF_ASFCondition with lhs at the right place, or a core dump if #arg did not have a lhs
 */
ASF_ASFCondition ASF_setASFConditionLhs(ASF_ASFCondition arg, ASF_Tree lhs) {
  if (ASF_isASFConditionNegative(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 0), 1);
  }
  else if (ASF_isASFConditionEquality(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 0), 1);
  }
  else if (ASF_isASFConditionMatch(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 0), 1);
  }
  else if (ASF_isASFConditionNoMatch(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 0), 1);
  }

  ATabort("ASFCondition has no Lhs: %t\n", arg);
  return (ASF_ASFCondition)NULL;
}

/**
 * Set the ws-after-lhs of a ASF_ASFCondition. The precondition being that this ASF_ASFCondition actually has a ws-after-lhs
 * \param[in] arg input ASF_ASFCondition
 * \param[in] wsAfterLhs new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFCondition with wsAfterLhs at the right place, or a core dump if #arg did not have a wsAfterLhs
 */
ASF_ASFCondition ASF_setASFConditionWsAfterLhs(ASF_ASFCondition arg, ASF_OptLayout wsAfterLhs) {
  if (ASF_isASFConditionNegative(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 1), 1);
  }
  else if (ASF_isASFConditionEquality(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 1), 1);
  }
  else if (ASF_isASFConditionMatch(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 1), 1);
  }
  else if (ASF_isASFConditionNoMatch(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 1), 1);
  }

  ATabort("ASFCondition has no WsAfterLhs: %t\n", arg);
  return (ASF_ASFCondition)NULL;
}

/**
 * Set the ws-after-unequal of a ASF_ASFCondition. The precondition being that this ASF_ASFCondition actually has a ws-after-unequal
 * \param[in] arg input ASF_ASFCondition
 * \param[in] wsAfterUnequal new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFCondition with wsAfterUnequal at the right place, or a core dump if #arg did not have a wsAfterUnequal
 */
ASF_ASFCondition ASF_setASFConditionWsAfterUnequal(ASF_ASFCondition arg, ASF_OptLayout wsAfterUnequal) {
  if (ASF_isASFConditionNegative(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterUnequal), 3), 1);
  }

  ATabort("ASFCondition has no WsAfterUnequal: %t\n", arg);
  return (ASF_ASFCondition)NULL;
}

/**
 * Set the rhs of a ASF_ASFCondition. The precondition being that this ASF_ASFCondition actually has a rhs
 * \param[in] arg input ASF_ASFCondition
 * \param[in] rhs new ASF_Tree to set in #arg
 * \return A new ASF_ASFCondition with rhs at the right place, or a core dump if #arg did not have a rhs
 */
ASF_ASFCondition ASF_setASFConditionRhs(ASF_ASFCondition arg, ASF_Tree rhs) {
  if (ASF_isASFConditionNegative(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 4), 1);
  }
  else if (ASF_isASFConditionEquality(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 4), 1);
  }
  else if (ASF_isASFConditionMatch(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 4), 1);
  }
  else if (ASF_isASFConditionNoMatch(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 4), 1);
  }

  ATabort("ASFCondition has no Rhs: %t\n", arg);
  return (ASF_ASFCondition)NULL;
}

/**
 * Set the ws-after-equality of a ASF_ASFCondition. The precondition being that this ASF_ASFCondition actually has a ws-after-equality
 * \param[in] arg input ASF_ASFCondition
 * \param[in] wsAfterEquality new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFCondition with wsAfterEquality at the right place, or a core dump if #arg did not have a wsAfterEquality
 */
ASF_ASFCondition ASF_setASFConditionWsAfterEquality(ASF_ASFCondition arg, ASF_OptLayout wsAfterEquality) {
  if (ASF_isASFConditionEquality(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterEquality), 3), 1);
  }

  ATabort("ASFCondition has no WsAfterEquality: %t\n", arg);
  return (ASF_ASFCondition)NULL;
}

/**
 * Set the ws-after-match of a ASF_ASFCondition. The precondition being that this ASF_ASFCondition actually has a ws-after-match
 * \param[in] arg input ASF_ASFCondition
 * \param[in] wsAfterMatch new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFCondition with wsAfterMatch at the right place, or a core dump if #arg did not have a wsAfterMatch
 */
ASF_ASFCondition ASF_setASFConditionWsAfterMatch(ASF_ASFCondition arg, ASF_OptLayout wsAfterMatch) {
  if (ASF_isASFConditionMatch(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterMatch), 3), 1);
  }
  else if (ASF_isASFConditionNoMatch(arg)) {
    return (ASF_ASFCondition)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterMatch), 3), 1);
  }

  ATabort("ASFCondition has no WsAfterMatch: %t\n", arg);
  return (ASF_ASFCondition)NULL;
}

/**
 * Assert whether a ASF_ASFConditions is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_ASFConditions
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidASFConditions(ASF_ASFConditions arg) {
  if (ASF_isASFConditionsDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditions is a Default by checking against the following ATerm pattern: appl(prod([cf(iter-sep(sort("ASF-Condition"),lit(",")))],cf(sort("ASF-Conditions")),no-attrs),[appl(list(cf(iter-sep(sort("ASF-Condition"),lit(",")))),<"list"("ASF-Condition-list")>)]). Always returns ATtrue
 * \param[in] arg input ASF_ASFConditions
 * \return ATtrue if #arg corresponds to the signature of a Default, or ATfalse otherwise
 */
inline ATbool ASF_isASFConditionsDefault(ASF_ASFConditions arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter-sep */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun36) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: sort */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun12) {
              ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
              /* checking for: ASF-Condition */
              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == ASF_afun28) {
                ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                /* checking for: lit */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == ASF_afun9) {
                  ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                  /* checking for: , */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == ASF_afun14) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                          /* checking for: ASF-Conditions */
                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun37) {
                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun5) {
                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                ATerm arg_arg1_head;
                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                /* checking for: appl */
                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                  /* checking for: list */
                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun8) {
                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == ASF_afun2) {
                                      ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                      /* checking for: iter-sep */
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == ASF_afun36) {
                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == ASF_afun12) {
                                          ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                          /* checking for: ASF-Condition */
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == ASF_afun28) {
                                            ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                            /* checking for: lit */
                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == ASF_afun9) {
                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                              /* checking for: , */
                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == ASF_afun14) {
                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                  return ATtrue;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditions has a list. 
 * \param[in] arg input ASF_ASFConditions
 * \return ATtrue if the ASF_ASFConditions had a list, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionsList(ASF_ASFConditions arg) {
  if (ASF_isASFConditionsDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the list ASF_ASFConditionList of a ASF_ASFConditions. Note that the precondition is that this ASF_ASFConditions actually has a list
 * \param[in] arg input ASF_ASFConditions
 * \return the list of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFConditionList ASF_getASFConditionsList(ASF_ASFConditions arg) {
  
    return (ASF_ASFConditionList)ATgetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), 1);
}

/**
 * Set the list of a ASF_ASFConditions. The precondition being that this ASF_ASFConditions actually has a list
 * \param[in] arg input ASF_ASFConditions
 * \param[in] list new ASF_ASFConditionList to set in #arg
 * \return A new ASF_ASFConditions with list at the right place, or a core dump if #arg did not have a list
 */
ASF_ASFConditions ASF_setASFConditionsList(ASF_ASFConditions arg, ASF_ASFConditionList list) {
  if (ASF_isASFConditionsDefault(arg)) {
    return (ASF_ASFConditions)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), (ATerm)((ATerm) list), 1), 0), 1);
  }

  ATabort("ASFConditions has no List: %t\n", arg);
  return (ASF_ASFConditions)NULL;
}

/**
 * Assert whether a ASF_ASFConditionList is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_ASFConditionList
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidASFConditionList(ASF_ASFConditionList arg) {
  if (ASF_isASFConditionListEmpty(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionListSingle(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionList is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the ASF_ASFConditionList
 * \param[in] arg input ASF_ASFConditionList
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool ASF_isASFConditionListEmpty(ASF_ASFConditionList arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionList is a single by checking against the following ATerm pattern: [<head(ASF-Condition)>]. May not be used to assert correctness of the ASF_ASFConditionList
 * \param[in] arg input ASF_ASFConditionList
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool ASF_isASFConditionListSingle(ASF_ASFConditionList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionList is a many by checking against the following ATerm pattern: [<head(ASF-Condition)>,<ws-after-head("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<ws-after-sep("OptLayout")>,<[tail(ASF-Condition-list)]>]. May not be used to assert correctness of the ASF_ASFConditionList
 * \param[in] arg input ASF_ASFConditionList
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool ASF_isASFConditionListMany(ASF_ASFConditionList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATerm arg_head;
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      arg_list = ATgetNext(arg_list);
      if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
        arg_head = ATgetFirst(arg_list);
        arg_list = ATgetNext(arg_list);
        /* checking for: appl */
        if (ATgetType((ATerm)arg_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head) == ASF_afun0) {
          ATerm arg_head_arg0 = ATgetArgument(arg_head, 0);
          /* checking for: prod */
          if (ATgetType((ATerm)arg_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0) == ASF_afun1) {
            ATerm arg_head_arg0_arg0 = ATgetArgument(arg_head_arg0, 0);
            if (ATgetType((ATerm)arg_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0) == ATfalse) {
              ATerm arg_head_arg0_arg0_head;
              ATermList arg_head_arg0_arg0_list = (ATermList)arg_head_arg0_arg0;
              arg_head_arg0_arg0_head = ATgetFirst(arg_head_arg0_arg0_list);
              arg_head_arg0_arg0_list = ATgetNext(arg_head_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg0_head) == ASF_afun21) {
                ATerm arg_head_arg0_arg0_head_arg0 = ATgetArgument(arg_head_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_head_arg0_arg0_head_arg0_head;
                  ATermList arg_head_arg0_arg0_head_arg0_list = (ATermList)arg_head_arg0_arg0_head_arg0;
                  arg_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_head_arg0_arg0_head_arg0_list);
                  arg_head_arg0_arg0_head_arg0_list = ATgetNext(arg_head_arg0_arg0_head_arg0_list);
                  if (ATgetInt((ATermInt)arg_head_arg0_arg0_head_arg0_head) == 44) {

                    if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0_list) == ATtrue) {
                      if (ATgetType((ATerm)arg_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_list) == ATtrue) {
                        ATerm arg_head_arg0_arg1 = ATgetArgument(arg_head_arg0, 1);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1) == ASF_afun9) {
                          ATerm arg_head_arg0_arg1_arg0 = ATgetArgument(arg_head_arg0_arg1, 0);
                          /* checking for: , */
                          if (ATgetType((ATerm)arg_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1_arg0) == ASF_afun14) {
                            ATerm arg_head_arg0_arg2 = ATgetArgument(arg_head_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg2) == ASF_afun5) {
                              ATerm arg_head_arg1 = ATgetArgument(arg_head, 1);
                              if (ATgetType((ATerm)arg_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1) == ATfalse) {
                                ATerm arg_head_arg1_head;
                                ATermList arg_head_arg1_list = (ATermList)arg_head_arg1;
                                arg_head_arg1_head = ATgetFirst(arg_head_arg1_list);
                                arg_head_arg1_list = ATgetNext(arg_head_arg1_list);
                                if (ATgetInt((ATermInt)arg_head_arg1_head) == 44) {

                                  if (ATgetType((ATerm)arg_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionList has a head. 
 * \param[in] arg input ASF_ASFConditionList
 * \return ATtrue if the ASF_ASFConditionList had a head, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionListHead(ASF_ASFConditionList arg) {
  if (ASF_isASFConditionListSingle(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionList has a ws-after-head. 
 * \param[in] arg input ASF_ASFConditionList
 * \return ATtrue if the ASF_ASFConditionList had a ws-after-head, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionListWsAfterHead(ASF_ASFConditionList arg) {
  if (ASF_isASFConditionListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionList has a ws-after-sep. 
 * \param[in] arg input ASF_ASFConditionList
 * \return ATtrue if the ASF_ASFConditionList had a ws-after-sep, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionListWsAfterSep(ASF_ASFConditionList arg) {
  if (ASF_isASFConditionListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionList has a tail. 
 * \param[in] arg input ASF_ASFConditionList
 * \return ATtrue if the ASF_ASFConditionList had a tail, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionListTail(ASF_ASFConditionList arg) {
  if (ASF_isASFConditionListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a ASF_ASFConditionList. 
 * \param[in] arg input ASF_ASFConditionList
 * \return A new ASF_ASFConditionList, without the first element and the separator(s) just after it.)
 */
ASF_ASFConditionList ASF_getASFConditionListTail(ASF_ASFConditionList arg) {
  assert(!ASF_isASFConditionListEmpty(arg) && "getTail on an empty list");
  if (ASF_isASFConditionListSingle(arg)) {
    return (ASF_ASFConditionList) ASF_makeASFConditionListEmpty();
  }
  else {
  
    return (ASF_ASFConditionList)ATgetTail((ATermList)arg, 4);
  }
}

/**
 * Get the head ASF_ASFCondition of a ASF_ASFConditionList. Note that the precondition is that this ASF_ASFConditionList actually has a head
 * \param[in] arg input ASF_ASFConditionList
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFCondition ASF_getASFConditionListHead(ASF_ASFConditionList arg) {
  if (ASF_isASFConditionListSingle(arg)) {
    return (ASF_ASFCondition)ATgetFirst((ATermList)arg);
  }
  else 
    return (ASF_ASFCondition)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head ASF_OptLayout of a ASF_ASFConditionList. Note that the precondition is that this ASF_ASFConditionList actually has a ws-after-head
 * \param[in] arg input ASF_ASFConditionList
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFConditionListWsAfterHead(ASF_ASFConditionList arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Get the ws-after-sep ASF_OptLayout of a ASF_ASFConditionList. Note that the precondition is that this ASF_ASFConditionList actually has a ws-after-sep
 * \param[in] arg input ASF_ASFConditionList
 * \return the ws-after-sep of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFConditionListWsAfterSep(ASF_ASFConditionList arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)arg, 3);
}

/**
 * Set the head of a ASF_ASFConditionList. The precondition being that this ASF_ASFConditionList actually has a head
 * \param[in] arg input ASF_ASFConditionList
 * \param[in] head new ASF_ASFCondition to set in #arg
 * \return A new ASF_ASFConditionList with head at the right place, or a core dump if #arg did not have a head
 */
ASF_ASFConditionList ASF_setASFConditionListHead(ASF_ASFConditionList arg, ASF_ASFCondition head) {
  if (ASF_isASFConditionListSingle(arg)) {
    return (ASF_ASFConditionList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (ASF_isASFConditionListMany(arg)) {
    return (ASF_ASFConditionList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("ASFConditionList has no Head: %t\n", arg);
  return (ASF_ASFConditionList)NULL;
}

/**
 * Set the ws-after-head of a ASF_ASFConditionList. The precondition being that this ASF_ASFConditionList actually has a ws-after-head
 * \param[in] arg input ASF_ASFConditionList
 * \param[in] wsAfterHead new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFConditionList with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
ASF_ASFConditionList ASF_setASFConditionListWsAfterHead(ASF_ASFConditionList arg, ASF_OptLayout wsAfterHead) {
  if (ASF_isASFConditionListMany(arg)) {
    return (ASF_ASFConditionList)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("ASFConditionList has no WsAfterHead: %t\n", arg);
  return (ASF_ASFConditionList)NULL;
}

/**
 * Set the ws-after-sep of a ASF_ASFConditionList. The precondition being that this ASF_ASFConditionList actually has a ws-after-sep
 * \param[in] arg input ASF_ASFConditionList
 * \param[in] wsAfterSep new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFConditionList with wsAfterSep at the right place, or a core dump if #arg did not have a wsAfterSep
 */
ASF_ASFConditionList ASF_setASFConditionListWsAfterSep(ASF_ASFConditionList arg, ASF_OptLayout wsAfterSep) {
  if (ASF_isASFConditionListMany(arg)) {
    return (ASF_ASFConditionList)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterSep), 3);
  }

  ATabort("ASFConditionList has no WsAfterSep: %t\n", arg);
  return (ASF_ASFConditionList)NULL;
}

/**
 * Set the tail of a ASF_ASFConditionList. The precondition being that this ASF_ASFConditionList actually has a tail
 * \param[in] arg input ASF_ASFConditionList
 * \param[in] tail new ASF_ASFConditionList to set in #arg
 * \return A new ASF_ASFConditionList with tail at the right place, or a core dump if #arg did not have a tail
 */
ASF_ASFConditionList ASF_setASFConditionListTail(ASF_ASFConditionList arg, ASF_ASFConditionList tail) {
  if (ASF_isASFConditionListMany(arg)) {
    return (ASF_ASFConditionList)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 4);
  }

  ATabort("ASFConditionList has no Tail: %t\n", arg);
  return (ASF_ASFConditionList)NULL;
}

/**
 * Assert whether a ASF_TreeAmbs is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_TreeAmbs
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidTreeAmbs(ASF_TreeAmbs arg) {
  if (ASF_isTreeAmbsEmpty(arg)) {
    return ATtrue;
  }
  else if (ASF_isTreeAmbsSingle(arg)) {
    return ATtrue;
  }
  else if (ASF_isTreeAmbsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_TreeAmbs is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the ASF_TreeAmbs
 * \param[in] arg input ASF_TreeAmbs
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool ASF_isTreeAmbsEmpty(ASF_TreeAmbs arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_TreeAmbs is a single by checking against the following ATerm pattern: [<head(Tree)>]. May not be used to assert correctness of the ASF_TreeAmbs
 * \param[in] arg input ASF_TreeAmbs
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool ASF_isTreeAmbsSingle(ASF_TreeAmbs arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_TreeAmbs is a many by checking against the following ATerm pattern: [<head(Tree)>,<ws-after-head("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<ws-after-sep("OptLayout")>,<[tail(Tree-ambs)]>]. May not be used to assert correctness of the ASF_TreeAmbs
 * \param[in] arg input ASF_TreeAmbs
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool ASF_isTreeAmbsMany(ASF_TreeAmbs arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATerm arg_head;
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      arg_list = ATgetNext(arg_list);
      if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
        arg_head = ATgetFirst(arg_list);
        arg_list = ATgetNext(arg_list);
        /* checking for: appl */
        if (ATgetType((ATerm)arg_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head) == ASF_afun0) {
          ATerm arg_head_arg0 = ATgetArgument(arg_head, 0);
          /* checking for: prod */
          if (ATgetType((ATerm)arg_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0) == ASF_afun1) {
            ATerm arg_head_arg0_arg0 = ATgetArgument(arg_head_arg0, 0);
            if (ATgetType((ATerm)arg_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0) == ATfalse) {
              ATerm arg_head_arg0_arg0_head;
              ATermList arg_head_arg0_arg0_list = (ATermList)arg_head_arg0_arg0;
              arg_head_arg0_arg0_head = ATgetFirst(arg_head_arg0_arg0_list);
              arg_head_arg0_arg0_list = ATgetNext(arg_head_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg0_head) == ASF_afun21) {
                ATerm arg_head_arg0_arg0_head_arg0 = ATgetArgument(arg_head_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_head_arg0_arg0_head_arg0_head;
                  ATermList arg_head_arg0_arg0_head_arg0_list = (ATermList)arg_head_arg0_arg0_head_arg0;
                  arg_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_head_arg0_arg0_head_arg0_list);
                  arg_head_arg0_arg0_head_arg0_list = ATgetNext(arg_head_arg0_arg0_head_arg0_list);
                  if (ATgetInt((ATermInt)arg_head_arg0_arg0_head_arg0_head) == 44) {

                    if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0_list) == ATtrue) {
                      if (ATgetType((ATerm)arg_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_list) == ATtrue) {
                        ATerm arg_head_arg0_arg1 = ATgetArgument(arg_head_arg0, 1);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1) == ASF_afun9) {
                          ATerm arg_head_arg0_arg1_arg0 = ATgetArgument(arg_head_arg0_arg1, 0);
                          /* checking for: , */
                          if (ATgetType((ATerm)arg_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1_arg0) == ASF_afun14) {
                            ATerm arg_head_arg0_arg2 = ATgetArgument(arg_head_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg2) == ASF_afun5) {
                              ATerm arg_head_arg1 = ATgetArgument(arg_head, 1);
                              if (ATgetType((ATerm)arg_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1) == ATfalse) {
                                ATerm arg_head_arg1_head;
                                ATermList arg_head_arg1_list = (ATermList)arg_head_arg1;
                                arg_head_arg1_head = ATgetFirst(arg_head_arg1_list);
                                arg_head_arg1_list = ATgetNext(arg_head_arg1_list);
                                if (ATgetInt((ATermInt)arg_head_arg1_head) == 44) {

                                  if (ATgetType((ATerm)arg_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_TreeAmbs has a head. 
 * \param[in] arg input ASF_TreeAmbs
 * \return ATtrue if the ASF_TreeAmbs had a head, or ATfalse otherwise
 */
ATbool ASF_hasTreeAmbsHead(ASF_TreeAmbs arg) {
  if (ASF_isTreeAmbsSingle(arg)) {
    return ATtrue;
  }
  else if (ASF_isTreeAmbsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_TreeAmbs has a ws-after-head. 
 * \param[in] arg input ASF_TreeAmbs
 * \return ATtrue if the ASF_TreeAmbs had a ws-after-head, or ATfalse otherwise
 */
ATbool ASF_hasTreeAmbsWsAfterHead(ASF_TreeAmbs arg) {
  if (ASF_isTreeAmbsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_TreeAmbs has a ws-after-sep. 
 * \param[in] arg input ASF_TreeAmbs
 * \return ATtrue if the ASF_TreeAmbs had a ws-after-sep, or ATfalse otherwise
 */
ATbool ASF_hasTreeAmbsWsAfterSep(ASF_TreeAmbs arg) {
  if (ASF_isTreeAmbsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_TreeAmbs has a tail. 
 * \param[in] arg input ASF_TreeAmbs
 * \return ATtrue if the ASF_TreeAmbs had a tail, or ATfalse otherwise
 */
ATbool ASF_hasTreeAmbsTail(ASF_TreeAmbs arg) {
  if (ASF_isTreeAmbsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a ASF_TreeAmbs. 
 * \param[in] arg input ASF_TreeAmbs
 * \return A new ASF_TreeAmbs, without the first element and the separator(s) just after it.)
 */
ASF_TreeAmbs ASF_getTreeAmbsTail(ASF_TreeAmbs arg) {
  assert(!ASF_isTreeAmbsEmpty(arg) && "getTail on an empty list");
  if (ASF_isTreeAmbsSingle(arg)) {
    return (ASF_TreeAmbs) ASF_makeTreeAmbsEmpty();
  }
  else {
  
    return (ASF_TreeAmbs)ATgetTail((ATermList)arg, 4);
  }
}

/**
 * Get the head ASF_Tree of a ASF_TreeAmbs. Note that the precondition is that this ASF_TreeAmbs actually has a head
 * \param[in] arg input ASF_TreeAmbs
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
ASF_Tree ASF_getTreeAmbsHead(ASF_TreeAmbs arg) {
  if (ASF_isTreeAmbsSingle(arg)) {
    return (ASF_Tree)ATgetFirst((ATermList)arg);
  }
  else 
    return (ASF_Tree)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head ASF_OptLayout of a ASF_TreeAmbs. Note that the precondition is that this ASF_TreeAmbs actually has a ws-after-head
 * \param[in] arg input ASF_TreeAmbs
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getTreeAmbsWsAfterHead(ASF_TreeAmbs arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Get the ws-after-sep ASF_OptLayout of a ASF_TreeAmbs. Note that the precondition is that this ASF_TreeAmbs actually has a ws-after-sep
 * \param[in] arg input ASF_TreeAmbs
 * \return the ws-after-sep of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getTreeAmbsWsAfterSep(ASF_TreeAmbs arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)arg, 3);
}

/**
 * Set the head of a ASF_TreeAmbs. The precondition being that this ASF_TreeAmbs actually has a head
 * \param[in] arg input ASF_TreeAmbs
 * \param[in] head new ASF_Tree to set in #arg
 * \return A new ASF_TreeAmbs with head at the right place, or a core dump if #arg did not have a head
 */
ASF_TreeAmbs ASF_setTreeAmbsHead(ASF_TreeAmbs arg, ASF_Tree head) {
  if (ASF_isTreeAmbsSingle(arg)) {
    return (ASF_TreeAmbs)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (ASF_isTreeAmbsMany(arg)) {
    return (ASF_TreeAmbs)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("TreeAmbs has no Head: %t\n", arg);
  return (ASF_TreeAmbs)NULL;
}

/**
 * Set the ws-after-head of a ASF_TreeAmbs. The precondition being that this ASF_TreeAmbs actually has a ws-after-head
 * \param[in] arg input ASF_TreeAmbs
 * \param[in] wsAfterHead new ASF_OptLayout to set in #arg
 * \return A new ASF_TreeAmbs with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
ASF_TreeAmbs ASF_setTreeAmbsWsAfterHead(ASF_TreeAmbs arg, ASF_OptLayout wsAfterHead) {
  if (ASF_isTreeAmbsMany(arg)) {
    return (ASF_TreeAmbs)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("TreeAmbs has no WsAfterHead: %t\n", arg);
  return (ASF_TreeAmbs)NULL;
}

/**
 * Set the ws-after-sep of a ASF_TreeAmbs. The precondition being that this ASF_TreeAmbs actually has a ws-after-sep
 * \param[in] arg input ASF_TreeAmbs
 * \param[in] wsAfterSep new ASF_OptLayout to set in #arg
 * \return A new ASF_TreeAmbs with wsAfterSep at the right place, or a core dump if #arg did not have a wsAfterSep
 */
ASF_TreeAmbs ASF_setTreeAmbsWsAfterSep(ASF_TreeAmbs arg, ASF_OptLayout wsAfterSep) {
  if (ASF_isTreeAmbsMany(arg)) {
    return (ASF_TreeAmbs)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterSep), 3);
  }

  ATabort("TreeAmbs has no WsAfterSep: %t\n", arg);
  return (ASF_TreeAmbs)NULL;
}

/**
 * Set the tail of a ASF_TreeAmbs. The precondition being that this ASF_TreeAmbs actually has a tail
 * \param[in] arg input ASF_TreeAmbs
 * \param[in] tail new ASF_TreeAmbs to set in #arg
 * \return A new ASF_TreeAmbs with tail at the right place, or a core dump if #arg did not have a tail
 */
ASF_TreeAmbs ASF_setTreeAmbsTail(ASF_TreeAmbs arg, ASF_TreeAmbs tail) {
  if (ASF_isTreeAmbsMany(arg)) {
    return (ASF_TreeAmbs)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 4);
  }

  ATabort("TreeAmbs has no Tail: %t\n", arg);
  return (ASF_TreeAmbs)NULL;
}

/**
 * Assert whether a ASF_CHARList is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_CHARList
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidCHARList(ASF_CHARList arg) {
  if (ASF_isCHARListEmpty(arg)) {
    return ATtrue;
  }
  else if (ASF_isCHARListSingle(arg)) {
    return ATtrue;
  }
  else if (ASF_isCHARListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_CHARList is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the ASF_CHARList
 * \param[in] arg input ASF_CHARList
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool ASF_isCHARListEmpty(ASF_CHARList arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_CHARList is a single by checking against the following ATerm pattern: [<head(CHAR)>]. May not be used to assert correctness of the ASF_CHARList
 * \param[in] arg input ASF_CHARList
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool ASF_isCHARListSingle(ASF_CHARList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_CHARList is a many by checking against the following ATerm pattern: [<head(CHAR)>,<ws-after-head("OptLayout")>,<[tail(CHAR-list)]>]. May not be used to assert correctness of the ASF_CHARList
 * \param[in] arg input ASF_CHARList
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool ASF_isCHARListMany(ASF_CHARList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_CHARList has a head. 
 * \param[in] arg input ASF_CHARList
 * \return ATtrue if the ASF_CHARList had a head, or ATfalse otherwise
 */
ATbool ASF_hasCHARListHead(ASF_CHARList arg) {
  if (ASF_isCHARListSingle(arg)) {
    return ATtrue;
  }
  else if (ASF_isCHARListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_CHARList has a ws-after-head. 
 * \param[in] arg input ASF_CHARList
 * \return ATtrue if the ASF_CHARList had a ws-after-head, or ATfalse otherwise
 */
ATbool ASF_hasCHARListWsAfterHead(ASF_CHARList arg) {
  if (ASF_isCHARListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_CHARList has a tail. 
 * \param[in] arg input ASF_CHARList
 * \return ATtrue if the ASF_CHARList had a tail, or ATfalse otherwise
 */
ATbool ASF_hasCHARListTail(ASF_CHARList arg) {
  if (ASF_isCHARListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a ASF_CHARList. 
 * \param[in] arg input ASF_CHARList
 * \return A new ASF_CHARList, without the first element and the separator(s) just after it.)
 */
ASF_CHARList ASF_getCHARListTail(ASF_CHARList arg) {
  assert(!ASF_isCHARListEmpty(arg) && "getTail on an empty list");
  if (ASF_isCHARListSingle(arg)) {
    return (ASF_CHARList) ASF_makeCHARListEmpty();
  }
  else {
  
    return (ASF_CHARList)ATgetTail((ATermList)arg, 2);
  }
}

/**
 * Get the head ASF_CHAR of a ASF_CHARList. Note that the precondition is that this ASF_CHARList actually has a head
 * \param[in] arg input ASF_CHARList
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
ASF_CHAR ASF_getCHARListHead(ASF_CHARList arg) {
  if (ASF_isCHARListSingle(arg)) {
    return (ASF_CHAR)ATgetFirst((ATermList)arg);
  }
  else 
    return (ASF_CHAR)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head ASF_OptLayout of a ASF_CHARList. Note that the precondition is that this ASF_CHARList actually has a ws-after-head
 * \param[in] arg input ASF_CHARList
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getCHARListWsAfterHead(ASF_CHARList arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Set the head of a ASF_CHARList. The precondition being that this ASF_CHARList actually has a head
 * \param[in] arg input ASF_CHARList
 * \param[in] head new ASF_CHAR to set in #arg
 * \return A new ASF_CHARList with head at the right place, or a core dump if #arg did not have a head
 */
ASF_CHARList ASF_setCHARListHead(ASF_CHARList arg, ASF_CHAR head) {
  if (ASF_isCHARListSingle(arg)) {
    return (ASF_CHARList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (ASF_isCHARListMany(arg)) {
    return (ASF_CHARList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("CHARList has no Head: %t\n", arg);
  return (ASF_CHARList)NULL;
}

/**
 * Set the ws-after-head of a ASF_CHARList. The precondition being that this ASF_CHARList actually has a ws-after-head
 * \param[in] arg input ASF_CHARList
 * \param[in] wsAfterHead new ASF_OptLayout to set in #arg
 * \return A new ASF_CHARList with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
ASF_CHARList ASF_setCHARListWsAfterHead(ASF_CHARList arg, ASF_OptLayout wsAfterHead) {
  if (ASF_isCHARListMany(arg)) {
    return (ASF_CHARList)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("CHARList has no WsAfterHead: %t\n", arg);
  return (ASF_CHARList)NULL;
}

/**
 * Set the tail of a ASF_CHARList. The precondition being that this ASF_CHARList actually has a tail
 * \param[in] arg input ASF_CHARList
 * \param[in] tail new ASF_CHARList to set in #arg
 * \return A new ASF_CHARList with tail at the right place, or a core dump if #arg did not have a tail
 */
ASF_CHARList ASF_setCHARListTail(ASF_CHARList arg, ASF_CHARList tail) {
  if (ASF_isCHARListMany(arg)) {
    return (ASF_CHARList)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 2);
  }

  ATabort("CHARList has no Tail: %t\n", arg);
  return (ASF_CHARList)NULL;
}

/**
 * Assert whether a ASF_LexASFBarEnd is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_LexASFBarEnd
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidLexASFBarEnd(ASF_LexASFBarEnd arg) {
  if (ASF_isLexASFBarEndAbsent(arg)) {
    return ATtrue;
  }
  else if (ASF_isLexASFBarEndPresent(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexASFBarEnd is a Absent by checking against the following ATerm pattern: appl(prod([],lex(sort("ASF-BarEnd")),attrs([term(cons("Absent"))])),[]). May not be used to assert correctness of the ASF_LexASFBarEnd
 * \param[in] arg input ASF_LexASFBarEnd
 * \return ATtrue if #arg corresponds to the signature of a Absent, or ATfalse otherwise
 */
inline ATbool ASF_isLexASFBarEndAbsent(ASF_LexASFBarEnd arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATisEmpty((ATermList)arg_arg0_arg0)) {
        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun6) {
          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
            /* checking for: ASF-BarEnd */
            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun38) {
              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
              /* checking for: attrs */
              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                  ATerm arg_arg0_arg2_arg0_head;
                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                  /* checking for: term */
                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                    /* checking for: cons */
                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                      /* checking for: Absent */
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun39) {
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                          if (ATisEmpty((ATermList)arg_arg1)) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexASFBarEnd is a Present by checking against the following ATerm pattern: appl(prod([char-class([62])],lex(sort("ASF-BarEnd")),attrs([term(cons("Present"))])),[62]). May not be used to assert correctness of the ASF_LexASFBarEnd
 * \param[in] arg input ASF_LexASFBarEnd
 * \return ATtrue if #arg corresponds to the signature of a Present, or ATfalse otherwise
 */
inline ATbool ASF_isLexASFBarEndPresent(ASF_LexASFBarEnd arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: char-class */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun21) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
            ATerm arg_arg0_arg0_head_arg0_head;
            ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
            if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 62) {

              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                  ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                  /* checking for: lex */
                  if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun6) {
                    ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                    /* checking for: sort */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                      ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                      /* checking for: ASF-BarEnd */
                      if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun38) {
                        ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                        /* checking for: attrs */
                        if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                          ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                            ATerm arg_arg0_arg2_arg0_head;
                            ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                            arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                            arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                            /* checking for: term */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                              ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                              /* checking for: cons */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                /* checking for: Present */
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun40) {
                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                    ATerm arg_arg1 = ATgetArgument(arg, 1);
                                    if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                      ATerm arg_arg1_head;
                                      ATermList arg_arg1_list = (ATermList)arg_arg1;
                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                      if (ATgetInt((ATermInt)arg_arg1_head) == 62) {

                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                          return ATtrue;
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFBarEnd is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_ASFBarEnd
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidASFBarEnd(ASF_ASFBarEnd arg) {
  if (ASF_isASFBarEndLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFBarEnd is a Lex-to-cf by checking against the following ATerm pattern: appl(prod([lex(sort("ASF-BarEnd"))],cf(sort("ASF-BarEnd")),no-attrs),[<"ASF-BarEnd"("Lex-ASF-BarEnd")>]). Always returns ATtrue
 * \param[in] arg input ASF_ASFBarEnd
 * \return ATtrue if #arg corresponds to the signature of a Lex-to-cf, or ATfalse otherwise
 */
inline ATbool ASF_isASFBarEndLexToCf(ASF_ASFBarEnd arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: ASF-BarEnd */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun38) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: ASF-BarEnd */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun38) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: no-attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun5) {
                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                          arg_arg1_list = ATgetNext(arg_arg1_list);
                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFBarEnd has a ASF-BarEnd. 
 * \param[in] arg input ASF_ASFBarEnd
 * \return ATtrue if the ASF_ASFBarEnd had a ASF-BarEnd, or ATfalse otherwise
 */
ATbool ASF_hasASFBarEndASFBarEnd(ASF_ASFBarEnd arg) {
  if (ASF_isASFBarEndLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ASF-BarEnd ASF_LexASFBarEnd of a ASF_ASFBarEnd. Note that the precondition is that this ASF_ASFBarEnd actually has a ASF-BarEnd
 * \param[in] arg input ASF_ASFBarEnd
 * \return the ASF-BarEnd of #arg, if it exist or an undefined value if it does not
 */
ASF_LexASFBarEnd ASF_getASFBarEndASFBarEnd(ASF_ASFBarEnd arg) {
  
    return (ASF_LexASFBarEnd)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the ASF-BarEnd of a ASF_ASFBarEnd. The precondition being that this ASF_ASFBarEnd actually has a ASF-BarEnd
 * \param[in] arg input ASF_ASFBarEnd
 * \param[in] ASFBarEnd new ASF_LexASFBarEnd to set in #arg
 * \return A new ASF_ASFBarEnd with ASFBarEnd at the right place, or a core dump if #arg did not have a ASFBarEnd
 */
ASF_ASFBarEnd ASF_setASFBarEndASFBarEnd(ASF_ASFBarEnd arg, ASF_LexASFBarEnd ASFBarEnd) {
  if (ASF_isASFBarEndLexToCf(arg)) {
    return (ASF_ASFBarEnd)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFBarEnd), 0), 1);
  }

  ATabort("ASFBarEnd has no ASFBarEnd: %t\n", arg);
  return (ASF_ASFBarEnd)NULL;
}

/**
 * Assert whether a ASF_LexASFImplies is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_LexASFImplies
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidLexASFImplies(ASF_LexASFImplies arg) {
  if (ASF_isLexASFImpliesDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexASFImplies is a default by checking against the following ATerm pattern: appl(prod([lit("==="),lex(iter-star(char-class([61]))),lex(sort("ASF-BarEnd"))],lex(sort("ASF-Implies")),attrs([term(cons("default"))])),[appl(prod([char-class([61]),char-class([61]),char-class([61])],lit("==="),no-attrs),[61,61,61]),appl(list(lex(iter-star(char-class([61])))),<"bar"(chars)>),<"end"("Lex-ASF-BarEnd")>]). Always returns ATtrue
 * \param[in] arg input ASF_LexASFImplies
 * \return ATtrue if #arg corresponds to the signature of a default, or ATfalse otherwise
 */
inline ATbool ASF_isLexASFImpliesDefault(ASF_LexASFImplies arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: === */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun41) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: lex */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun6) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: iter-star */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun22) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: char-class */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun21) {
                    ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0) == ATfalse) {
                      ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head;
                      ATermList arg_arg0_arg0_head_arg0_arg0_arg0_list = (ATermList)arg_arg0_arg0_head_arg0_arg0_arg0;
                      arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                      arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head) == 61) {

                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATtrue) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: lex */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun6) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: sort */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: ASF-BarEnd */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun38) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                    ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                    /* checking for: lex */
                                    if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun6) {
                                      ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                        ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                        /* checking for: ASF-Implies */
                                        if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun42) {
                                          ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                          /* checking for: attrs */
                                          if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                            ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                              ATerm arg_arg0_arg2_arg0_head;
                                              ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                              arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                              arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                              /* checking for: term */
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                /* checking for: cons */
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                  ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                  /* checking for: default */
                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun26) {
                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                      ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                      if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                        ATerm arg_arg1_head;
                                                        ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                        /* checking for: appl */
                                                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                          /* checking for: prod */
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                              ATerm arg_arg1_head_arg0_arg0_head;
                                                              ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                              /* checking for: char-class */
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                        /* checking for: char-class */
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                  /* checking for: char-class */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                            /* checking for: lit */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                              /* checking for: === */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun41) {
                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                /* checking for: no-attrs */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                  /* checking for: appl */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                    /* checking for: list */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun8) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                      /* checking for: lex */
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == ASF_afun6) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                                        /* checking for: iter-star */
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == ASF_afun22) {
                                                                                                                          ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                                          /* checking for: char-class */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == ASF_afun21) {
                                                                                                                            ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == ATfalse) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head;
                                                                                                                              ATermList arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0;
                                                                                                                              arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                              arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == 61) {

                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATtrue) {
                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                        return ATtrue;
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexASFImplies has a bar. 
 * \param[in] arg input ASF_LexASFImplies
 * \return ATtrue if the ASF_LexASFImplies had a bar, or ATfalse otherwise
 */
ATbool ASF_hasLexASFImpliesBar(ASF_LexASFImplies arg) {
  if (ASF_isLexASFImpliesDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexASFImplies has a end. 
 * \param[in] arg input ASF_LexASFImplies
 * \return ATtrue if the ASF_LexASFImplies had a end, or ATfalse otherwise
 */
ATbool ASF_hasLexASFImpliesEnd(ASF_LexASFImplies arg) {
  if (ASF_isLexASFImpliesDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the bar char* of a ASF_LexASFImplies. Note that the precondition is that this ASF_LexASFImplies actually has a bar
 * \param[in] arg input ASF_LexASFImplies
 * \return the bar of #arg, if it exist or an undefined value if it does not
 */
char* ASF_getLexASFImpliesBar(ASF_LexASFImplies arg) {
  
    return (char*)ASF_charsToString((ATerm)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1), 1));
}

/**
 * Get the end ASF_LexASFBarEnd of a ASF_LexASFImplies. Note that the precondition is that this ASF_LexASFImplies actually has a end
 * \param[in] arg input ASF_LexASFImplies
 * \return the end of #arg, if it exist or an undefined value if it does not
 */
ASF_LexASFBarEnd ASF_getLexASFImpliesEnd(ASF_LexASFImplies arg) {
  
    return (ASF_LexASFBarEnd)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
}

/**
 * Set the bar of a ASF_LexASFImplies. The precondition being that this ASF_LexASFImplies actually has a bar
 * \param[in] arg input ASF_LexASFImplies
 * \param[in] bar new const char* to set in #arg
 * \return A new ASF_LexASFImplies with bar at the right place, or a core dump if #arg did not have a bar
 */
ASF_LexASFImplies ASF_setLexASFImpliesBar(ASF_LexASFImplies arg, const char* bar) {
  if (ASF_isLexASFImpliesDefault(arg)) {
    return (ASF_LexASFImplies)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1), (ATerm)((ATerm) ((ATerm) ASF_stringToChars(bar))), 1), 1), 1);
  }

  ATabort("LexASFImplies has no Bar: %t\n", arg);
  return (ASF_LexASFImplies)NULL;
}

/**
 * Set the end of a ASF_LexASFImplies. The precondition being that this ASF_LexASFImplies actually has a end
 * \param[in] arg input ASF_LexASFImplies
 * \param[in] end new ASF_LexASFBarEnd to set in #arg
 * \return A new ASF_LexASFImplies with end at the right place, or a core dump if #arg did not have a end
 */
ASF_LexASFImplies ASF_setLexASFImpliesEnd(ASF_LexASFImplies arg, ASF_LexASFBarEnd end) {
  if (ASF_isLexASFImpliesDefault(arg)) {
    return (ASF_LexASFImplies)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) end), 2), 1);
  }

  ATabort("LexASFImplies has no End: %t\n", arg);
  return (ASF_LexASFImplies)NULL;
}

/**
 * Assert whether a ASF_ASFImplies is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_ASFImplies
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidASFImplies(ASF_ASFImplies arg) {
  if (ASF_isASFImpliesLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFImplies is a Lex-to-cf by checking against the following ATerm pattern: appl(prod([lex(sort("ASF-Implies"))],cf(sort("ASF-Implies")),no-attrs),[<"ASF-Implies"("Lex-ASF-Implies")>]). Always returns ATtrue
 * \param[in] arg input ASF_ASFImplies
 * \return ATtrue if #arg corresponds to the signature of a Lex-to-cf, or ATfalse otherwise
 */
inline ATbool ASF_isASFImpliesLexToCf(ASF_ASFImplies arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: ASF-Implies */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun42) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: ASF-Implies */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun42) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: no-attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun5) {
                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                          arg_arg1_list = ATgetNext(arg_arg1_list);
                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFImplies has a ASF-Implies. 
 * \param[in] arg input ASF_ASFImplies
 * \return ATtrue if the ASF_ASFImplies had a ASF-Implies, or ATfalse otherwise
 */
ATbool ASF_hasASFImpliesASFImplies(ASF_ASFImplies arg) {
  if (ASF_isASFImpliesLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ASF-Implies ASF_LexASFImplies of a ASF_ASFImplies. Note that the precondition is that this ASF_ASFImplies actually has a ASF-Implies
 * \param[in] arg input ASF_ASFImplies
 * \return the ASF-Implies of #arg, if it exist or an undefined value if it does not
 */
ASF_LexASFImplies ASF_getASFImpliesASFImplies(ASF_ASFImplies arg) {
  
    return (ASF_LexASFImplies)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the ASF-Implies of a ASF_ASFImplies. The precondition being that this ASF_ASFImplies actually has a ASF-Implies
 * \param[in] arg input ASF_ASFImplies
 * \param[in] ASFImplies new ASF_LexASFImplies to set in #arg
 * \return A new ASF_ASFImplies with ASFImplies at the right place, or a core dump if #arg did not have a ASFImplies
 */
ASF_ASFImplies ASF_setASFImpliesASFImplies(ASF_ASFImplies arg, ASF_LexASFImplies ASFImplies) {
  if (ASF_isASFImpliesLexToCf(arg)) {
    return (ASF_ASFImplies)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFImplies), 0), 1);
  }

  ATabort("ASFImplies has no ASFImplies: %t\n", arg);
  return (ASF_ASFImplies)NULL;
}

/**
 * Assert whether a ASF_ASFConditionalEquation is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidASFConditionalEquation(ASF_ASFConditionalEquation arg) {
  if (ASF_isASFConditionalEquationSimple(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionalEquationImplies(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionalEquationWhen(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquation is a simple by checking against the following ATerm pattern: appl(prod([cf(sort("ASF-Tag")),cf(opt(layout)),cf(sort("ASF-Equation"))],cf(sort("ASF-ConditionalEquation")),attrs([term(cons("simple"))])),[<"ASF-Tag"("ASF-Tag")>,<"ws-after-ASF-Tag"("OptLayout")>,<"ASF-Equation"("ASF-Equation")>]). May not be used to assert correctness of the ASF_ASFConditionalEquation
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return ATtrue if #arg corresponds to the signature of a simple, or ATfalse otherwise
 */
inline ATbool ASF_isASFConditionalEquationSimple(ASF_ASFConditionalEquation arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: ASF-Tag */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun44) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: cf */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
                            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                            /* checking for: ASF-Equation */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun43) {
                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                /* checking for: cf */
                                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                  /* checking for: sort */
                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                    /* checking for: ASF-ConditionalEquation */
                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun45) {
                                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                      /* checking for: attrs */
                                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                          ATerm arg_arg0_arg2_arg0_head;
                                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                          /* checking for: term */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                            /* checking for: cons */
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                              /* checking for: simple */
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun46) {
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                          return ATtrue;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquation is a implies by checking against the following ATerm pattern: appl(prod([cf(sort("ASF-Tag")),cf(opt(layout)),cf(sort("ASF-Conditions")),cf(opt(layout)),cf(sort("ASF-Implies")),cf(opt(layout)),cf(sort("ASF-Equation"))],cf(sort("ASF-ConditionalEquation")),attrs([term(cons("implies"))])),[<"ASF-Tag"("ASF-Tag")>,<"ws-after-ASF-Tag"("OptLayout")>,<"ASF-Conditions"("ASF-Conditions")>,<"ws-after-ASF-Conditions"("OptLayout")>,<"ASF-Implies"("ASF-Implies")>,<"ws-after-ASF-Implies"("OptLayout")>,<"ASF-Equation"("ASF-Equation")>]). May not be used to assert correctness of the ASF_ASFConditionalEquation
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return ATtrue if #arg corresponds to the signature of a implies, or ATfalse otherwise
 */
inline ATbool ASF_isASFConditionalEquationImplies(ASF_ASFConditionalEquation arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: ASF-Tag */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun44) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: cf */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
                            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                            /* checking for: ASF-Conditions */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun37) {
                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                /* checking for: cf */
                                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                  /* checking for: opt */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                    /* checking for: layout */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                        /* checking for: cf */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                          /* checking for: sort */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
                                            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                            /* checking for: ASF-Implies */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun42) {
                                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                /* checking for: cf */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                  /* checking for: opt */
                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                                                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                    /* checking for: layout */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                        /* checking for: cf */
                                                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                          /* checking for: sort */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
                                                            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                            /* checking for: ASF-Equation */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun43) {
                                                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                /* checking for: cf */
                                                                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                                                                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                  /* checking for: sort */
                                                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                                                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                    /* checking for: ASF-ConditionalEquation */
                                                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun45) {
                                                                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                      /* checking for: attrs */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                                                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                          ATerm arg_arg0_arg2_arg0_head;
                                                                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                          /* checking for: term */
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                            /* checking for: cons */
                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                              /* checking for: implies */
                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun47) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                  return ATtrue;
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquation is a when by checking against the following ATerm pattern: appl(prod([cf(sort("ASF-Tag")),cf(opt(layout)),cf(sort("ASF-Equation")),cf(opt(layout)),lit("when"),cf(opt(layout)),cf(sort("ASF-Conditions"))],cf(sort("ASF-ConditionalEquation")),attrs([term(cons("when"))])),[<"ASF-Tag"("ASF-Tag")>,<"ws-after-ASF-Tag"("OptLayout")>,<"ASF-Equation"("ASF-Equation")>,<"ws-after-ASF-Equation"("OptLayout")>,appl(prod([char-class([119]),char-class([104]),char-class([101]),char-class([110])],lit("when"),no-attrs),[119,104,101,110]),<"ws-after-when"("OptLayout")>,<"ASF-Conditions"("ASF-Conditions")>]). May not be used to assert correctness of the ASF_ASFConditionalEquation
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return ATtrue if #arg corresponds to the signature of a when, or ATfalse otherwise
 */
inline ATbool ASF_isASFConditionalEquationWhen(ASF_ASFConditionalEquation arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: ASF-Tag */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun44) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: cf */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
                            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                            /* checking for: ASF-Equation */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun43) {
                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                /* checking for: cf */
                                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                  /* checking for: opt */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                    /* checking for: layout */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                        /* checking for: lit */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
                                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                          /* checking for: when */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun48) {
                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                              /* checking for: cf */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                /* checking for: opt */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                  /* checking for: layout */
                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                      /* checking for: cf */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                        /* checking for: sort */
                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
                                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                          /* checking for: ASF-Conditions */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun37) {
                                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                              /* checking for: cf */
                                                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                                                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                /* checking for: sort */
                                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                  /* checking for: ASF-ConditionalEquation */
                                                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun45) {
                                                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                    /* checking for: attrs */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                        ATerm arg_arg0_arg2_arg0_head;
                                                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                        /* checking for: term */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                          /* checking for: cons */
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                            /* checking for: when */
                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun48) {
                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                  ATerm arg_arg1_head;
                                                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                          /* checking for: appl */
                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                            /* checking for: prod */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                /* checking for: char-class */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 119) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                          /* checking for: char-class */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 104) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                    /* checking for: char-class */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                              /* checking for: char-class */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 110) {

                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                        /* checking for: lit */
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                          /* checking for: when */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun48) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 119) {

                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 104) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 110) {

                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                      return ATtrue;
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquation has a ASF-Tag. 
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return ATtrue if the ASF_ASFConditionalEquation had a ASF-Tag, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionalEquationASFTag(ASF_ASFConditionalEquation arg) {
  if (ASF_isASFConditionalEquationSimple(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionalEquationImplies(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionalEquationWhen(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquation has a ws-after-ASF-Tag. 
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return ATtrue if the ASF_ASFConditionalEquation had a ws-after-ASF-Tag, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionalEquationWsAfterASFTag(ASF_ASFConditionalEquation arg) {
  if (ASF_isASFConditionalEquationSimple(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionalEquationImplies(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionalEquationWhen(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquation has a ASF-Equation. 
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return ATtrue if the ASF_ASFConditionalEquation had a ASF-Equation, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionalEquationASFEquation(ASF_ASFConditionalEquation arg) {
  if (ASF_isASFConditionalEquationSimple(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionalEquationImplies(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionalEquationWhen(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquation has a ASF-Conditions. 
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return ATtrue if the ASF_ASFConditionalEquation had a ASF-Conditions, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionalEquationASFConditions(ASF_ASFConditionalEquation arg) {
  if (ASF_isASFConditionalEquationImplies(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionalEquationWhen(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquation has a ws-after-ASF-Conditions. 
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return ATtrue if the ASF_ASFConditionalEquation had a ws-after-ASF-Conditions, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionalEquationWsAfterASFConditions(ASF_ASFConditionalEquation arg) {
  if (ASF_isASFConditionalEquationImplies(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquation has a ASF-Implies. 
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return ATtrue if the ASF_ASFConditionalEquation had a ASF-Implies, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionalEquationASFImplies(ASF_ASFConditionalEquation arg) {
  if (ASF_isASFConditionalEquationImplies(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquation has a ws-after-ASF-Implies. 
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return ATtrue if the ASF_ASFConditionalEquation had a ws-after-ASF-Implies, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionalEquationWsAfterASFImplies(ASF_ASFConditionalEquation arg) {
  if (ASF_isASFConditionalEquationImplies(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquation has a ws-after-ASF-Equation. 
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return ATtrue if the ASF_ASFConditionalEquation had a ws-after-ASF-Equation, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionalEquationWsAfterASFEquation(ASF_ASFConditionalEquation arg) {
  if (ASF_isASFConditionalEquationWhen(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquation has a ws-after-when. 
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return ATtrue if the ASF_ASFConditionalEquation had a ws-after-when, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionalEquationWsAfterWhen(ASF_ASFConditionalEquation arg) {
  if (ASF_isASFConditionalEquationWhen(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ASF-Tag ASF_ASFTag of a ASF_ASFConditionalEquation. Note that the precondition is that this ASF_ASFConditionalEquation actually has a ASF-Tag
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return the ASF-Tag of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFTag ASF_getASFConditionalEquationASFTag(ASF_ASFConditionalEquation arg) {
  if (ASF_isASFConditionalEquationSimple(arg)) {
    return (ASF_ASFTag)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else if (ASF_isASFConditionalEquationImplies(arg)) {
    return (ASF_ASFTag)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else 
    return (ASF_ASFTag)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the ws-after-ASF-Tag ASF_OptLayout of a ASF_ASFConditionalEquation. Note that the precondition is that this ASF_ASFConditionalEquation actually has a ws-after-ASF-Tag
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return the ws-after-ASF-Tag of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFConditionalEquationWsAfterASFTag(ASF_ASFConditionalEquation arg) {
  if (ASF_isASFConditionalEquationSimple(arg)) {
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else if (ASF_isASFConditionalEquationImplies(arg)) {
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else 
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ASF-Equation ASF_ASFEquation of a ASF_ASFConditionalEquation. Note that the precondition is that this ASF_ASFConditionalEquation actually has a ASF-Equation
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return the ASF-Equation of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFEquation ASF_getASFConditionalEquationASFEquation(ASF_ASFConditionalEquation arg) {
  if (ASF_isASFConditionalEquationSimple(arg)) {
    return (ASF_ASFEquation)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
  }
  else if (ASF_isASFConditionalEquationImplies(arg)) {
    return (ASF_ASFEquation)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 6);
  }
  else 
    return (ASF_ASFEquation)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
}

/**
 * Get the ASF-Conditions ASF_ASFConditions of a ASF_ASFConditionalEquation. Note that the precondition is that this ASF_ASFConditionalEquation actually has a ASF-Conditions
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return the ASF-Conditions of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFConditions ASF_getASFConditionalEquationASFConditions(ASF_ASFConditionalEquation arg) {
  if (ASF_isASFConditionalEquationImplies(arg)) {
    return (ASF_ASFConditions)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
  }
  else 
    return (ASF_ASFConditions)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 6);
}

/**
 * Get the ws-after-ASF-Conditions ASF_OptLayout of a ASF_ASFConditionalEquation. Note that the precondition is that this ASF_ASFConditionalEquation actually has a ws-after-ASF-Conditions
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return the ws-after-ASF-Conditions of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFConditionalEquationWsAfterASFConditions(ASF_ASFConditionalEquation arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the ASF-Implies ASF_ASFImplies of a ASF_ASFConditionalEquation. Note that the precondition is that this ASF_ASFConditionalEquation actually has a ASF-Implies
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return the ASF-Implies of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFImplies ASF_getASFConditionalEquationASFImplies(ASF_ASFConditionalEquation arg) {
  
    return (ASF_ASFImplies)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-ASF-Implies ASF_OptLayout of a ASF_ASFConditionalEquation. Note that the precondition is that this ASF_ASFConditionalEquation actually has a ws-after-ASF-Implies
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return the ws-after-ASF-Implies of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFConditionalEquationWsAfterASFImplies(ASF_ASFConditionalEquation arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-ASF-Equation ASF_OptLayout of a ASF_ASFConditionalEquation. Note that the precondition is that this ASF_ASFConditionalEquation actually has a ws-after-ASF-Equation
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return the ws-after-ASF-Equation of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFConditionalEquationWsAfterASFEquation(ASF_ASFConditionalEquation arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the ws-after-when ASF_OptLayout of a ASF_ASFConditionalEquation. Note that the precondition is that this ASF_ASFConditionalEquation actually has a ws-after-when
 * \param[in] arg input ASF_ASFConditionalEquation
 * \return the ws-after-when of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFConditionalEquationWsAfterWhen(ASF_ASFConditionalEquation arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Set the ASF-Tag of a ASF_ASFConditionalEquation. The precondition being that this ASF_ASFConditionalEquation actually has a ASF-Tag
 * \param[in] arg input ASF_ASFConditionalEquation
 * \param[in] ASFTag new ASF_ASFTag to set in #arg
 * \return A new ASF_ASFConditionalEquation with ASFTag at the right place, or a core dump if #arg did not have a ASFTag
 */
ASF_ASFConditionalEquation ASF_setASFConditionalEquationASFTag(ASF_ASFConditionalEquation arg, ASF_ASFTag ASFTag) {
  if (ASF_isASFConditionalEquationSimple(arg)) {
    return (ASF_ASFConditionalEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFTag), 0), 1);
  }
  else if (ASF_isASFConditionalEquationImplies(arg)) {
    return (ASF_ASFConditionalEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFTag), 0), 1);
  }
  else if (ASF_isASFConditionalEquationWhen(arg)) {
    return (ASF_ASFConditionalEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFTag), 0), 1);
  }

  ATabort("ASFConditionalEquation has no ASFTag: %t\n", arg);
  return (ASF_ASFConditionalEquation)NULL;
}

/**
 * Set the ws-after-ASF-Tag of a ASF_ASFConditionalEquation. The precondition being that this ASF_ASFConditionalEquation actually has a ws-after-ASF-Tag
 * \param[in] arg input ASF_ASFConditionalEquation
 * \param[in] wsAfterASFTag new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFConditionalEquation with wsAfterASFTag at the right place, or a core dump if #arg did not have a wsAfterASFTag
 */
ASF_ASFConditionalEquation ASF_setASFConditionalEquationWsAfterASFTag(ASF_ASFConditionalEquation arg, ASF_OptLayout wsAfterASFTag) {
  if (ASF_isASFConditionalEquationSimple(arg)) {
    return (ASF_ASFConditionalEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterASFTag), 1), 1);
  }
  else if (ASF_isASFConditionalEquationImplies(arg)) {
    return (ASF_ASFConditionalEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterASFTag), 1), 1);
  }
  else if (ASF_isASFConditionalEquationWhen(arg)) {
    return (ASF_ASFConditionalEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterASFTag), 1), 1);
  }

  ATabort("ASFConditionalEquation has no WsAfterASFTag: %t\n", arg);
  return (ASF_ASFConditionalEquation)NULL;
}

/**
 * Set the ASF-Equation of a ASF_ASFConditionalEquation. The precondition being that this ASF_ASFConditionalEquation actually has a ASF-Equation
 * \param[in] arg input ASF_ASFConditionalEquation
 * \param[in] ASFEquation new ASF_ASFEquation to set in #arg
 * \return A new ASF_ASFConditionalEquation with ASFEquation at the right place, or a core dump if #arg did not have a ASFEquation
 */
ASF_ASFConditionalEquation ASF_setASFConditionalEquationASFEquation(ASF_ASFConditionalEquation arg, ASF_ASFEquation ASFEquation) {
  if (ASF_isASFConditionalEquationSimple(arg)) {
    return (ASF_ASFConditionalEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFEquation), 2), 1);
  }
  else if (ASF_isASFConditionalEquationImplies(arg)) {
    return (ASF_ASFConditionalEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFEquation), 6), 1);
  }
  else if (ASF_isASFConditionalEquationWhen(arg)) {
    return (ASF_ASFConditionalEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFEquation), 2), 1);
  }

  ATabort("ASFConditionalEquation has no ASFEquation: %t\n", arg);
  return (ASF_ASFConditionalEquation)NULL;
}

/**
 * Set the ASF-Conditions of a ASF_ASFConditionalEquation. The precondition being that this ASF_ASFConditionalEquation actually has a ASF-Conditions
 * \param[in] arg input ASF_ASFConditionalEquation
 * \param[in] ASFConditions new ASF_ASFConditions to set in #arg
 * \return A new ASF_ASFConditionalEquation with ASFConditions at the right place, or a core dump if #arg did not have a ASFConditions
 */
ASF_ASFConditionalEquation ASF_setASFConditionalEquationASFConditions(ASF_ASFConditionalEquation arg, ASF_ASFConditions ASFConditions) {
  if (ASF_isASFConditionalEquationImplies(arg)) {
    return (ASF_ASFConditionalEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFConditions), 2), 1);
  }
  else if (ASF_isASFConditionalEquationWhen(arg)) {
    return (ASF_ASFConditionalEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFConditions), 6), 1);
  }

  ATabort("ASFConditionalEquation has no ASFConditions: %t\n", arg);
  return (ASF_ASFConditionalEquation)NULL;
}

/**
 * Set the ws-after-ASF-Conditions of a ASF_ASFConditionalEquation. The precondition being that this ASF_ASFConditionalEquation actually has a ws-after-ASF-Conditions
 * \param[in] arg input ASF_ASFConditionalEquation
 * \param[in] wsAfterASFConditions new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFConditionalEquation with wsAfterASFConditions at the right place, or a core dump if #arg did not have a wsAfterASFConditions
 */
ASF_ASFConditionalEquation ASF_setASFConditionalEquationWsAfterASFConditions(ASF_ASFConditionalEquation arg, ASF_OptLayout wsAfterASFConditions) {
  if (ASF_isASFConditionalEquationImplies(arg)) {
    return (ASF_ASFConditionalEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterASFConditions), 3), 1);
  }

  ATabort("ASFConditionalEquation has no WsAfterASFConditions: %t\n", arg);
  return (ASF_ASFConditionalEquation)NULL;
}

/**
 * Set the ASF-Implies of a ASF_ASFConditionalEquation. The precondition being that this ASF_ASFConditionalEquation actually has a ASF-Implies
 * \param[in] arg input ASF_ASFConditionalEquation
 * \param[in] ASFImplies new ASF_ASFImplies to set in #arg
 * \return A new ASF_ASFConditionalEquation with ASFImplies at the right place, or a core dump if #arg did not have a ASFImplies
 */
ASF_ASFConditionalEquation ASF_setASFConditionalEquationASFImplies(ASF_ASFConditionalEquation arg, ASF_ASFImplies ASFImplies) {
  if (ASF_isASFConditionalEquationImplies(arg)) {
    return (ASF_ASFConditionalEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFImplies), 4), 1);
  }

  ATabort("ASFConditionalEquation has no ASFImplies: %t\n", arg);
  return (ASF_ASFConditionalEquation)NULL;
}

/**
 * Set the ws-after-ASF-Implies of a ASF_ASFConditionalEquation. The precondition being that this ASF_ASFConditionalEquation actually has a ws-after-ASF-Implies
 * \param[in] arg input ASF_ASFConditionalEquation
 * \param[in] wsAfterASFImplies new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFConditionalEquation with wsAfterASFImplies at the right place, or a core dump if #arg did not have a wsAfterASFImplies
 */
ASF_ASFConditionalEquation ASF_setASFConditionalEquationWsAfterASFImplies(ASF_ASFConditionalEquation arg, ASF_OptLayout wsAfterASFImplies) {
  if (ASF_isASFConditionalEquationImplies(arg)) {
    return (ASF_ASFConditionalEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterASFImplies), 5), 1);
  }

  ATabort("ASFConditionalEquation has no WsAfterASFImplies: %t\n", arg);
  return (ASF_ASFConditionalEquation)NULL;
}

/**
 * Set the ws-after-ASF-Equation of a ASF_ASFConditionalEquation. The precondition being that this ASF_ASFConditionalEquation actually has a ws-after-ASF-Equation
 * \param[in] arg input ASF_ASFConditionalEquation
 * \param[in] wsAfterASFEquation new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFConditionalEquation with wsAfterASFEquation at the right place, or a core dump if #arg did not have a wsAfterASFEquation
 */
ASF_ASFConditionalEquation ASF_setASFConditionalEquationWsAfterASFEquation(ASF_ASFConditionalEquation arg, ASF_OptLayout wsAfterASFEquation) {
  if (ASF_isASFConditionalEquationWhen(arg)) {
    return (ASF_ASFConditionalEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterASFEquation), 3), 1);
  }

  ATabort("ASFConditionalEquation has no WsAfterASFEquation: %t\n", arg);
  return (ASF_ASFConditionalEquation)NULL;
}

/**
 * Set the ws-after-when of a ASF_ASFConditionalEquation. The precondition being that this ASF_ASFConditionalEquation actually has a ws-after-when
 * \param[in] arg input ASF_ASFConditionalEquation
 * \param[in] wsAfterWhen new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFConditionalEquation with wsAfterWhen at the right place, or a core dump if #arg did not have a wsAfterWhen
 */
ASF_ASFConditionalEquation ASF_setASFConditionalEquationWsAfterWhen(ASF_ASFConditionalEquation arg, ASF_OptLayout wsAfterWhen) {
  if (ASF_isASFConditionalEquationWhen(arg)) {
    return (ASF_ASFConditionalEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterWhen), 5), 1);
  }

  ATabort("ASFConditionalEquation has no WsAfterWhen: %t\n", arg);
  return (ASF_ASFConditionalEquation)NULL;
}

/**
 * Assert whether a ASF_ASFEquation is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_ASFEquation
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidASFEquation(ASF_ASFEquation arg) {
  if (ASF_isASFEquationDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFEquation is a Default by checking against the following ATerm pattern: appl(prod([<"type-of-lhs"(term)>,cf(opt(layout)),lit("="),cf(opt(layout)),<"type-of-rhs"(term)>],cf(sort("ASF-Equation")),no-attrs),[<"lhs"("Tree")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([61])],lit("="),no-attrs),[61]),<"ws-after-="("OptLayout")>,<"rhs"("Tree")>]). Always returns ATtrue
 * \param[in] arg input ASF_ASFEquation
 * \return ATtrue if #arg corresponds to the signature of a Default, or ATfalse otherwise
 */
inline ATbool ASF_isASFEquationDefault(ASF_ASFEquation arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        if (arg_arg0_arg0_head != NULL) {
          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
            /* checking for: cf */
            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
              /* checking for: opt */
              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                /* checking for: layout */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                    /* checking for: lit */
                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                      /* checking for: = */
                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun49) {
                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                          /* checking for: cf */
                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                            /* checking for: opt */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                              /* checking for: layout */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                  if (arg_arg0_arg0_head != NULL) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                          /* checking for: ASF-Equation */
                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun43) {
                                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                            /* checking for: no-attrs */
                                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun5) {
                                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                ATerm arg_arg1_head;
                                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                    /* checking for: appl */
                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                      /* checking for: prod */
                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                          /* checking for: char-class */
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                    /* checking for: lit */
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                      /* checking for: = */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun49) {
                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                        /* checking for: no-attrs */
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                            ATerm arg_arg1_head_arg1_head;
                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                      return ATtrue;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFEquation has a type-of-lhs. 
 * \param[in] arg input ASF_ASFEquation
 * \return ATtrue if the ASF_ASFEquation had a type-of-lhs, or ATfalse otherwise
 */
ATbool ASF_hasASFEquationTypeOfLhs(ASF_ASFEquation arg) {
  if (ASF_isASFEquationDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFEquation has a type-of-rhs. 
 * \param[in] arg input ASF_ASFEquation
 * \return ATtrue if the ASF_ASFEquation had a type-of-rhs, or ATfalse otherwise
 */
ATbool ASF_hasASFEquationTypeOfRhs(ASF_ASFEquation arg) {
  if (ASF_isASFEquationDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFEquation has a lhs. 
 * \param[in] arg input ASF_ASFEquation
 * \return ATtrue if the ASF_ASFEquation had a lhs, or ATfalse otherwise
 */
ATbool ASF_hasASFEquationLhs(ASF_ASFEquation arg) {
  if (ASF_isASFEquationDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFEquation has a ws-after-lhs. 
 * \param[in] arg input ASF_ASFEquation
 * \return ATtrue if the ASF_ASFEquation had a ws-after-lhs, or ATfalse otherwise
 */
ATbool ASF_hasASFEquationWsAfterLhs(ASF_ASFEquation arg) {
  if (ASF_isASFEquationDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFEquation has a ws-after-=. 
 * \param[in] arg input ASF_ASFEquation
 * \return ATtrue if the ASF_ASFEquation had a ws-after-=, or ATfalse otherwise
 */
ATbool ASF_hasASFEquationWsAfterEquals(ASF_ASFEquation arg) {
  if (ASF_isASFEquationDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFEquation has a rhs. 
 * \param[in] arg input ASF_ASFEquation
 * \return ATtrue if the ASF_ASFEquation had a rhs, or ATfalse otherwise
 */
ATbool ASF_hasASFEquationRhs(ASF_ASFEquation arg) {
  if (ASF_isASFEquationDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the type-of-lhs ATerm of a ASF_ASFEquation. Note that the precondition is that this ASF_ASFEquation actually has a type-of-lhs
 * \param[in] arg input ASF_ASFEquation
 * \return the type-of-lhs of #arg, if it exist or an undefined value if it does not
 */
ATerm ASF_getASFEquationTypeOfLhs(ASF_ASFEquation arg) {
  
    return (ATerm)ATgetFirst((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0));
}

/**
 * Get the type-of-rhs ATerm of a ASF_ASFEquation. Note that the precondition is that this ASF_ASFEquation actually has a type-of-rhs
 * \param[in] arg input ASF_ASFEquation
 * \return the type-of-rhs of #arg, if it exist or an undefined value if it does not
 */
ATerm ASF_getASFEquationTypeOfRhs(ASF_ASFEquation arg) {
  
    return (ATerm)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0), 4);
}

/**
 * Get the lhs ASF_Tree of a ASF_ASFEquation. Note that the precondition is that this ASF_ASFEquation actually has a lhs
 * \param[in] arg input ASF_ASFEquation
 * \return the lhs of #arg, if it exist or an undefined value if it does not
 */
ASF_Tree ASF_getASFEquationLhs(ASF_ASFEquation arg) {
  
    return (ASF_Tree)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the ws-after-lhs ASF_OptLayout of a ASF_ASFEquation. Note that the precondition is that this ASF_ASFEquation actually has a ws-after-lhs
 * \param[in] arg input ASF_ASFEquation
 * \return the ws-after-lhs of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFEquationWsAfterLhs(ASF_ASFEquation arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-= ASF_OptLayout of a ASF_ASFEquation. Note that the precondition is that this ASF_ASFEquation actually has a ws-after-=
 * \param[in] arg input ASF_ASFEquation
 * \return the ws-after-= of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFEquationWsAfterEquals(ASF_ASFEquation arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the rhs ASF_Tree of a ASF_ASFEquation. Note that the precondition is that this ASF_ASFEquation actually has a rhs
 * \param[in] arg input ASF_ASFEquation
 * \return the rhs of #arg, if it exist or an undefined value if it does not
 */
ASF_Tree ASF_getASFEquationRhs(ASF_ASFEquation arg) {
  
    return (ASF_Tree)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Set the type-of-lhs of a ASF_ASFEquation. The precondition being that this ASF_ASFEquation actually has a type-of-lhs
 * \param[in] arg input ASF_ASFEquation
 * \param[in] typeOfLhs new ATerm to set in #arg
 * \return A new ASF_ASFEquation with typeOfLhs at the right place, or a core dump if #arg did not have a typeOfLhs
 */
ASF_ASFEquation ASF_setASFEquationTypeOfLhs(ASF_ASFEquation arg, ATerm typeOfLhs) {
  if (ASF_isASFEquationDefault(arg)) {
    return (ASF_ASFEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0), (ATerm)((ATerm) typeOfLhs), 0), 0), 0);
  }

  ATabort("ASFEquation has no TypeOfLhs: %t\n", arg);
  return (ASF_ASFEquation)NULL;
}

/**
 * Set the type-of-rhs of a ASF_ASFEquation. The precondition being that this ASF_ASFEquation actually has a type-of-rhs
 * \param[in] arg input ASF_ASFEquation
 * \param[in] typeOfRhs new ATerm to set in #arg
 * \return A new ASF_ASFEquation with typeOfRhs at the right place, or a core dump if #arg did not have a typeOfRhs
 */
ASF_ASFEquation ASF_setASFEquationTypeOfRhs(ASF_ASFEquation arg, ATerm typeOfRhs) {
  if (ASF_isASFEquationDefault(arg)) {
    return (ASF_ASFEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 0), (ATerm)((ATerm) typeOfRhs), 4), 0), 0);
  }

  ATabort("ASFEquation has no TypeOfRhs: %t\n", arg);
  return (ASF_ASFEquation)NULL;
}

/**
 * Set the lhs of a ASF_ASFEquation. The precondition being that this ASF_ASFEquation actually has a lhs
 * \param[in] arg input ASF_ASFEquation
 * \param[in] lhs new ASF_Tree to set in #arg
 * \return A new ASF_ASFEquation with lhs at the right place, or a core dump if #arg did not have a lhs
 */
ASF_ASFEquation ASF_setASFEquationLhs(ASF_ASFEquation arg, ASF_Tree lhs) {
  if (ASF_isASFEquationDefault(arg)) {
    return (ASF_ASFEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 0), 1);
  }

  ATabort("ASFEquation has no Lhs: %t\n", arg);
  return (ASF_ASFEquation)NULL;
}

/**
 * Set the ws-after-lhs of a ASF_ASFEquation. The precondition being that this ASF_ASFEquation actually has a ws-after-lhs
 * \param[in] arg input ASF_ASFEquation
 * \param[in] wsAfterLhs new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFEquation with wsAfterLhs at the right place, or a core dump if #arg did not have a wsAfterLhs
 */
ASF_ASFEquation ASF_setASFEquationWsAfterLhs(ASF_ASFEquation arg, ASF_OptLayout wsAfterLhs) {
  if (ASF_isASFEquationDefault(arg)) {
    return (ASF_ASFEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 1), 1);
  }

  ATabort("ASFEquation has no WsAfterLhs: %t\n", arg);
  return (ASF_ASFEquation)NULL;
}

/**
 * Set the ws-after-= of a ASF_ASFEquation. The precondition being that this ASF_ASFEquation actually has a ws-after-=
 * \param[in] arg input ASF_ASFEquation
 * \param[in] wsAfterEquals new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFEquation with wsAfterEquals at the right place, or a core dump if #arg did not have a wsAfterEquals
 */
ASF_ASFEquation ASF_setASFEquationWsAfterEquals(ASF_ASFEquation arg, ASF_OptLayout wsAfterEquals) {
  if (ASF_isASFEquationDefault(arg)) {
    return (ASF_ASFEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterEquals), 3), 1);
  }

  ATabort("ASFEquation has no WsAfterEquals: %t\n", arg);
  return (ASF_ASFEquation)NULL;
}

/**
 * Set the rhs of a ASF_ASFEquation. The precondition being that this ASF_ASFEquation actually has a rhs
 * \param[in] arg input ASF_ASFEquation
 * \param[in] rhs new ASF_Tree to set in #arg
 * \return A new ASF_ASFEquation with rhs at the right place, or a core dump if #arg did not have a rhs
 */
ASF_ASFEquation ASF_setASFEquationRhs(ASF_ASFEquation arg, ASF_Tree rhs) {
  if (ASF_isASFEquationDefault(arg)) {
    return (ASF_ASFEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 4), 1);
  }

  ATabort("ASFEquation has no Rhs: %t\n", arg);
  return (ASF_ASFEquation)NULL;
}

/**
 * Assert whether a ASF_Start is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_Start
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidStart(ASF_Start arg) {
  if (ASF_isStartASFModule(arg)) {
    return ATtrue;
  }
  else if (ASF_isStartASFSection(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Start is a ASF-Module by checking against the following ATerm pattern: parsetree(appl(prod([cf(opt(layout)),cf(sort("ASF-Module")),cf(opt(layout))],sort("<START>"),no-attrs),[<"ws-before"("OptLayout")>,<"top-ASF-Module"("ASF-Module")>,<"ws-after"("OptLayout")>]),<amb-cnt(int)>). May not be used to assert correctness of the ASF_Start
 * \param[in] arg input ASF_Start
 * \return ATtrue if #arg corresponds to the signature of a ASF-Module, or ATfalse otherwise
 */
inline ATbool ASF_isStartASFModule(ASF_Start arg){
  /* checking for: parsetree */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun50) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: appl */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun0) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      /* checking for: prod */
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0) == ASF_afun1) {
        ATerm arg_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0, 0);
        if (ATgetType((ATerm)arg_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0) == ATfalse) {
          ATerm arg_arg0_arg0_arg0_head;
          ATermList arg_arg0_arg0_arg0_list = (ATermList)arg_arg0_arg0_arg0;
          arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
          arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
          /* checking for: cf */
          if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == ASF_afun2) {
            ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
            /* checking for: opt */
            if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == ASF_afun3) {
              ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
              /* checking for: layout */
              if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATfalse) {
                  arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
                  arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
                  /* checking for: cf */
                  if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == ASF_afun2) {
                    ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
                    /* checking for: sort */
                    if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == ASF_afun12) {
                      ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
                      /* checking for: ASF-Module */
                      if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == ASF_afun51) {
                        if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATfalse) {
                          arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
                          arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
                          /* checking for: cf */
                          if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == ASF_afun2) {
                            ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
                            /* checking for: opt */
                            if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == ASF_afun3) {
                              ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
                              /* checking for: layout */
                              if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATtrue) {
                                  ATerm arg_arg0_arg0_arg1 = ATgetArgument(arg_arg0_arg0, 1);
                                  /* checking for: sort */
                                  if (ATgetType((ATerm)arg_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg1) == ASF_afun12) {
                                    ATerm arg_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_arg1, 0);
                                    /* checking for: <START> */
                                    if (ATgetType((ATerm)arg_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg1_arg0) == ASF_afun52) {
                                      ATerm arg_arg0_arg0_arg2 = ATgetArgument(arg_arg0_arg0, 2);
                                      /* checking for: no-attrs */
                                      if (ATgetType((ATerm)arg_arg0_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg2) == ASF_afun5) {
                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1) == ATfalse) {
                                          ATermList arg_arg0_arg1_list = (ATermList)arg_arg0_arg1;
                                          arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                          if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATfalse) {
                                            arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                            if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATfalse) {
                                              arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                              if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATtrue) {
                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                if (ATgetType((ATerm)arg_arg1) == AT_INT) {
                                                  return ATtrue;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Start is a ASF-Section by checking against the following ATerm pattern: parsetree(appl(prod([cf(opt(layout)),cf(sort("ASF-Section")),cf(opt(layout))],sort("<START>"),no-attrs),[<"ws-before"("OptLayout")>,<"top-ASF-Section"("ASF-Section")>,<"ws-after"("OptLayout")>]),<amb-cnt(int)>). May not be used to assert correctness of the ASF_Start
 * \param[in] arg input ASF_Start
 * \return ATtrue if #arg corresponds to the signature of a ASF-Section, or ATfalse otherwise
 */
inline ATbool ASF_isStartASFSection(ASF_Start arg){
  /* checking for: parsetree */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun50) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: appl */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun0) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      /* checking for: prod */
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0) == ASF_afun1) {
        ATerm arg_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0, 0);
        if (ATgetType((ATerm)arg_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0) == ATfalse) {
          ATerm arg_arg0_arg0_arg0_head;
          ATermList arg_arg0_arg0_arg0_list = (ATermList)arg_arg0_arg0_arg0;
          arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
          arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
          /* checking for: cf */
          if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == ASF_afun2) {
            ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
            /* checking for: opt */
            if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == ASF_afun3) {
              ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
              /* checking for: layout */
              if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATfalse) {
                  arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
                  arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
                  /* checking for: cf */
                  if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == ASF_afun2) {
                    ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
                    /* checking for: sort */
                    if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == ASF_afun12) {
                      ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
                      /* checking for: ASF-Section */
                      if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == ASF_afun53) {
                        if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATfalse) {
                          arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
                          arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
                          /* checking for: cf */
                          if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == ASF_afun2) {
                            ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
                            /* checking for: opt */
                            if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == ASF_afun3) {
                              ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
                              /* checking for: layout */
                              if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATtrue) {
                                  ATerm arg_arg0_arg0_arg1 = ATgetArgument(arg_arg0_arg0, 1);
                                  /* checking for: sort */
                                  if (ATgetType((ATerm)arg_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg1) == ASF_afun12) {
                                    ATerm arg_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_arg1, 0);
                                    /* checking for: <START> */
                                    if (ATgetType((ATerm)arg_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg1_arg0) == ASF_afun52) {
                                      ATerm arg_arg0_arg0_arg2 = ATgetArgument(arg_arg0_arg0, 2);
                                      /* checking for: no-attrs */
                                      if (ATgetType((ATerm)arg_arg0_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg2) == ASF_afun5) {
                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1) == ATfalse) {
                                          ATermList arg_arg0_arg1_list = (ATermList)arg_arg0_arg1;
                                          arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                          if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATfalse) {
                                            arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                            if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATfalse) {
                                              arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                              if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATtrue) {
                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                if (ATgetType((ATerm)arg_arg1) == AT_INT) {
                                                  return ATtrue;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Start has a ws-before. 
 * \param[in] arg input ASF_Start
 * \return ATtrue if the ASF_Start had a ws-before, or ATfalse otherwise
 */
ATbool ASF_hasStartWsBefore(ASF_Start arg) {
  if (ASF_isStartASFModule(arg)) {
    return ATtrue;
  }
  else if (ASF_isStartASFSection(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Start has a top-ASF-Module. 
 * \param[in] arg input ASF_Start
 * \return ATtrue if the ASF_Start had a top-ASF-Module, or ATfalse otherwise
 */
ATbool ASF_hasStartTopASFModule(ASF_Start arg) {
  if (ASF_isStartASFModule(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Start has a ws-after. 
 * \param[in] arg input ASF_Start
 * \return ATtrue if the ASF_Start had a ws-after, or ATfalse otherwise
 */
ATbool ASF_hasStartWsAfter(ASF_Start arg) {
  if (ASF_isStartASFModule(arg)) {
    return ATtrue;
  }
  else if (ASF_isStartASFSection(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Start has a amb-cnt. 
 * \param[in] arg input ASF_Start
 * \return ATtrue if the ASF_Start had a amb-cnt, or ATfalse otherwise
 */
ATbool ASF_hasStartAmbCnt(ASF_Start arg) {
  if (ASF_isStartASFModule(arg)) {
    return ATtrue;
  }
  else if (ASF_isStartASFSection(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Start has a top-ASF-Section. 
 * \param[in] arg input ASF_Start
 * \return ATtrue if the ASF_Start had a top-ASF-Section, or ATfalse otherwise
 */
ATbool ASF_hasStartTopASFSection(ASF_Start arg) {
  if (ASF_isStartASFSection(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-before ASF_OptLayout of a ASF_Start. Note that the precondition is that this ASF_Start actually has a ws-before
 * \param[in] arg input ASF_Start
 * \return the ws-before of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getStartWsBefore(ASF_Start arg) {
  if (ASF_isStartASFModule(arg)) {
    return (ASF_OptLayout)ATgetFirst((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1));
  }
  else 
    return (ASF_OptLayout)ATgetFirst((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1));
}

/**
 * Get the top-ASF-Module ASF_ASFModule of a ASF_Start. Note that the precondition is that this ASF_Start actually has a top-ASF-Module
 * \param[in] arg input ASF_Start
 * \return the top-ASF-Module of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFModule ASF_getStartTopASFModule(ASF_Start arg) {
  
    return (ASF_ASFModule)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), 1);
}

/**
 * Get the ws-after ASF_OptLayout of a ASF_Start. Note that the precondition is that this ASF_Start actually has a ws-after
 * \param[in] arg input ASF_Start
 * \return the ws-after of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getStartWsAfter(ASF_Start arg) {
  if (ASF_isStartASFModule(arg)) {
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), 2);
  }
  else 
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), 2);
}

/**
 * Get the amb-cnt int of a ASF_Start. Note that the precondition is that this ASF_Start actually has a amb-cnt
 * \param[in] arg input ASF_Start
 * \return the amb-cnt of #arg, if it exist or an undefined value if it does not
 */
int ASF_getStartAmbCnt(ASF_Start arg) {
  if (ASF_isStartASFModule(arg)) {
    return (int)ATgetInt((ATermInt) ATgetArgument((ATermAppl)arg, 1));
  }
  else 
    return (int)ATgetInt((ATermInt) ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the top-ASF-Section ASF_ASFSection of a ASF_Start. Note that the precondition is that this ASF_Start actually has a top-ASF-Section
 * \param[in] arg input ASF_Start
 * \return the top-ASF-Section of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFSection ASF_getStartTopASFSection(ASF_Start arg) {
  
    return (ASF_ASFSection)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), 1);
}

/**
 * Set the ws-before of a ASF_Start. The precondition being that this ASF_Start actually has a ws-before
 * \param[in] arg input ASF_Start
 * \param[in] wsBefore new ASF_OptLayout to set in #arg
 * \return A new ASF_Start with wsBefore at the right place, or a core dump if #arg did not have a wsBefore
 */
ASF_Start ASF_setStartWsBefore(ASF_Start arg, ASF_OptLayout wsBefore) {
  if (ASF_isStartASFModule(arg)) {
    return (ASF_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) wsBefore), 0), 1), 0);
  }
  else if (ASF_isStartASFSection(arg)) {
    return (ASF_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) wsBefore), 0), 1), 0);
  }

  ATabort("Start has no WsBefore: %t\n", arg);
  return (ASF_Start)NULL;
}

/**
 * Set the top-ASF-Module of a ASF_Start. The precondition being that this ASF_Start actually has a top-ASF-Module
 * \param[in] arg input ASF_Start
 * \param[in] topASFModule new ASF_ASFModule to set in #arg
 * \return A new ASF_Start with topASFModule at the right place, or a core dump if #arg did not have a topASFModule
 */
ASF_Start ASF_setStartTopASFModule(ASF_Start arg, ASF_ASFModule topASFModule) {
  if (ASF_isStartASFModule(arg)) {
    return (ASF_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) topASFModule), 1), 1), 0);
  }

  ATabort("Start has no TopASFModule: %t\n", arg);
  return (ASF_Start)NULL;
}

/**
 * Set the ws-after of a ASF_Start. The precondition being that this ASF_Start actually has a ws-after
 * \param[in] arg input ASF_Start
 * \param[in] wsAfter new ASF_OptLayout to set in #arg
 * \return A new ASF_Start with wsAfter at the right place, or a core dump if #arg did not have a wsAfter
 */
ASF_Start ASF_setStartWsAfter(ASF_Start arg, ASF_OptLayout wsAfter) {
  if (ASF_isStartASFModule(arg)) {
    return (ASF_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) wsAfter), 2), 1), 0);
  }
  else if (ASF_isStartASFSection(arg)) {
    return (ASF_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) wsAfter), 2), 1), 0);
  }

  ATabort("Start has no WsAfter: %t\n", arg);
  return (ASF_Start)NULL;
}

/**
 * Set the amb-cnt of a ASF_Start. The precondition being that this ASF_Start actually has a amb-cnt
 * \param[in] arg input ASF_Start
 * \param[in] ambCnt new int to set in #arg
 * \return A new ASF_Start with ambCnt at the right place, or a core dump if #arg did not have a ambCnt
 */
ASF_Start ASF_setStartAmbCnt(ASF_Start arg, int ambCnt) {
  if (ASF_isStartASFModule(arg)) {
    return (ASF_Start)ATsetArgument((ATermAppl)arg, (ATerm)((ATerm) (ATerm) ATmakeInt(ambCnt)), 1);
  }
  else if (ASF_isStartASFSection(arg)) {
    return (ASF_Start)ATsetArgument((ATermAppl)arg, (ATerm)((ATerm) (ATerm) ATmakeInt(ambCnt)), 1);
  }

  ATabort("Start has no AmbCnt: %t\n", arg);
  return (ASF_Start)NULL;
}

/**
 * Set the top-ASF-Section of a ASF_Start. The precondition being that this ASF_Start actually has a top-ASF-Section
 * \param[in] arg input ASF_Start
 * \param[in] topASFSection new ASF_ASFSection to set in #arg
 * \return A new ASF_Start with topASFSection at the right place, or a core dump if #arg did not have a topASFSection
 */
ASF_Start ASF_setStartTopASFSection(ASF_Start arg, ASF_ASFSection topASFSection) {
  if (ASF_isStartASFSection(arg)) {
    return (ASF_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) topASFSection), 1), 1), 0);
  }

  ATabort("Start has no TopASFSection: %t\n", arg);
  return (ASF_Start)NULL;
}

/**
 * Assert whether a ASF_ASFModule is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_ASFModule
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidASFModule(ASF_ASFModule arg) {
  if (ASF_isASFModuleDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFModule is a default by checking against the following ATerm pattern: appl(prod([cf(iter-star(sort("ASF-Section")))],cf(sort("ASF-Module")),attrs([term(cons("default"))])),[appl(list(cf(iter-star(sort("ASF-Section")))),<"list"("ASF-Section-list")>)]). Always returns ATtrue
 * \param[in] arg input ASF_ASFModule
 * \return ATtrue if #arg corresponds to the signature of a default, or ATfalse otherwise
 */
inline ATbool ASF_isASFModuleDefault(ASF_ASFModule arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter-star */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun22) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: sort */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun12) {
              ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
              /* checking for: ASF-Section */
              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == ASF_afun53) {
                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                  ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                  /* checking for: cf */
                  if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                    ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                    /* checking for: sort */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                      ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                      /* checking for: ASF-Module */
                      if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun51) {
                        ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                        /* checking for: attrs */
                        if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                          ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                            ATerm arg_arg0_arg2_arg0_head;
                            ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                            arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                            arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                            /* checking for: term */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                              ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                              /* checking for: cons */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                /* checking for: default */
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun26) {
                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                    ATerm arg_arg1 = ATgetArgument(arg, 1);
                                    if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                      ATerm arg_arg1_head;
                                      ATermList arg_arg1_list = (ATermList)arg_arg1;
                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                      /* checking for: appl */
                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                        /* checking for: list */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun8) {
                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                          /* checking for: cf */
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == ASF_afun2) {
                                            ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                            /* checking for: iter-star */
                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == ASF_afun22) {
                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                              /* checking for: sort */
                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == ASF_afun12) {
                                                ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                /* checking for: ASF-Section */
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == ASF_afun53) {
                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                    return ATtrue;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFModule has a list. 
 * \param[in] arg input ASF_ASFModule
 * \return ATtrue if the ASF_ASFModule had a list, or ATfalse otherwise
 */
ATbool ASF_hasASFModuleList(ASF_ASFModule arg) {
  if (ASF_isASFModuleDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the list ASF_ASFSectionList of a ASF_ASFModule. Note that the precondition is that this ASF_ASFModule actually has a list
 * \param[in] arg input ASF_ASFModule
 * \return the list of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFSectionList ASF_getASFModuleList(ASF_ASFModule arg) {
  
    return (ASF_ASFSectionList)ATgetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), 1);
}

/**
 * Set the list of a ASF_ASFModule. The precondition being that this ASF_ASFModule actually has a list
 * \param[in] arg input ASF_ASFModule
 * \param[in] list new ASF_ASFSectionList to set in #arg
 * \return A new ASF_ASFModule with list at the right place, or a core dump if #arg did not have a list
 */
ASF_ASFModule ASF_setASFModuleList(ASF_ASFModule arg, ASF_ASFSectionList list) {
  if (ASF_isASFModuleDefault(arg)) {
    return (ASF_ASFModule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), (ATerm)((ATerm) list), 1), 0), 1);
  }

  ATabort("ASFModule has no List: %t\n", arg);
  return (ASF_ASFModule)NULL;
}

/**
 * Assert whether a ASF_ASFSection is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_ASFSection
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidASFSection(ASF_ASFSection arg) {
  if (ASF_isASFSectionEquations(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFSectionTests(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFSection is a equations by checking against the following ATerm pattern: appl(prod([lit("equations"),cf(opt(layout)),cf(iter-star(sort("ASF-ConditionalEquation")))],cf(sort("ASF-Section")),attrs([term(cons("equations"))])),[appl(prod([char-class([101]),char-class([113]),char-class([117]),char-class([97]),char-class([116]),char-class([105]),char-class([111]),char-class([110]),char-class([115])],lit("equations"),no-attrs),[101,113,117,97,116,105,111,110,115]),<"ws-after-equations"("OptLayout")>,appl(list(cf(iter-star(sort("ASF-ConditionalEquation")))),<"list"("ASF-ConditionalEquation-list")>)]). May not be used to assert correctness of the ASF_ASFSection
 * \param[in] arg input ASF_ASFSection
 * \return ATtrue if #arg corresponds to the signature of a equations, or ATfalse otherwise
 */
inline ATbool ASF_isASFSectionEquations(ASF_ASFSection arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: equations */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun54) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: iter-star */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun22) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun12) {
                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                            /* checking for: ASF-ConditionalEquation */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == ASF_afun45) {
                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                /* checking for: cf */
                                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                  /* checking for: sort */
                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                    /* checking for: ASF-Section */
                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun53) {
                                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                      /* checking for: attrs */
                                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                          ATerm arg_arg0_arg2_arg0_head;
                                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                          /* checking for: term */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                            /* checking for: cons */
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                              /* checking for: equations */
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun54) {
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                    ATerm arg_arg1_head;
                                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                    /* checking for: appl */
                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                      /* checking for: prod */
                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                          /* checking for: char-class */
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                    /* checking for: char-class */
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 113) {

                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                              /* checking for: char-class */
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 117) {

                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                        /* checking for: char-class */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                  /* checking for: char-class */
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                            /* checking for: char-class */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 105) {

                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                      /* checking for: char-class */
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                /* checking for: char-class */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 110) {

                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                          /* checking for: char-class */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                    /* checking for: lit */
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                      /* checking for: equations */
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun54) {
                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 113) {

                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 117) {

                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 105) {

                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 110) {

                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                    /* checking for: appl */
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                      /* checking for: list */
                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun8) {
                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                        /* checking for: cf */
                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == ASF_afun2) {
                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                                                                                                                          /* checking for: iter-star */
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == ASF_afun22) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                                                                                                                            /* checking for: sort */
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == ASF_afun12) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                                                                                                                              /* checking for: ASF-ConditionalEquation */
                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == ASF_afun45) {
                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                  return ATtrue;
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFSection is a tests by checking against the following ATerm pattern: appl(prod([lit("tests"),cf(opt(layout)),cf(iter-star(sort("ASF-TestEquation")))],cf(sort("ASF-Section")),attrs([term(cons("tests"))])),[appl(prod([char-class([116]),char-class([101]),char-class([115]),char-class([116]),char-class([115])],lit("tests"),no-attrs),[116,101,115,116,115]),<"ws-after-tests"("OptLayout")>,appl(list(cf(iter-star(sort("ASF-TestEquation")))),<"test-list"("ASF-TestEquation-test-list")>)]). May not be used to assert correctness of the ASF_ASFSection
 * \param[in] arg input ASF_ASFSection
 * \return ATtrue if #arg corresponds to the signature of a tests, or ATfalse otherwise
 */
inline ATbool ASF_isASFSectionTests(ASF_ASFSection arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: tests */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun56) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: iter-star */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun22) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun12) {
                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                            /* checking for: ASF-TestEquation */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == ASF_afun55) {
                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                /* checking for: cf */
                                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                  /* checking for: sort */
                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                    /* checking for: ASF-Section */
                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun53) {
                                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                      /* checking for: attrs */
                                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                          ATerm arg_arg0_arg2_arg0_head;
                                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                          /* checking for: term */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                            /* checking for: cons */
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                              /* checking for: tests */
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun56) {
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                    ATerm arg_arg1_head;
                                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                    /* checking for: appl */
                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                      /* checking for: prod */
                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                          /* checking for: char-class */
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                    /* checking for: char-class */
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                              /* checking for: char-class */
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                        /* checking for: char-class */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                  /* checking for: char-class */
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                            /* checking for: lit */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                              /* checking for: tests */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun56) {
                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                /* checking for: no-attrs */
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                            /* checking for: appl */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                              /* checking for: list */
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun8) {
                                                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                /* checking for: cf */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == ASF_afun2) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                                                                  /* checking for: iter-star */
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == ASF_afun22) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                                                                    /* checking for: sort */
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == ASF_afun12) {
                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                                                                      /* checking for: ASF-TestEquation */
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == ASF_afun55) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                          return ATtrue;
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFSection has a ws-after-equations. 
 * \param[in] arg input ASF_ASFSection
 * \return ATtrue if the ASF_ASFSection had a ws-after-equations, or ATfalse otherwise
 */
ATbool ASF_hasASFSectionWsAfterEquations(ASF_ASFSection arg) {
  if (ASF_isASFSectionEquations(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFSection has a list. 
 * \param[in] arg input ASF_ASFSection
 * \return ATtrue if the ASF_ASFSection had a list, or ATfalse otherwise
 */
ATbool ASF_hasASFSectionList(ASF_ASFSection arg) {
  if (ASF_isASFSectionEquations(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFSection has a ws-after-tests. 
 * \param[in] arg input ASF_ASFSection
 * \return ATtrue if the ASF_ASFSection had a ws-after-tests, or ATfalse otherwise
 */
ATbool ASF_hasASFSectionWsAfterTests(ASF_ASFSection arg) {
  if (ASF_isASFSectionTests(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFSection has a test-list. 
 * \param[in] arg input ASF_ASFSection
 * \return ATtrue if the ASF_ASFSection had a test-list, or ATfalse otherwise
 */
ATbool ASF_hasASFSectionTestList(ASF_ASFSection arg) {
  if (ASF_isASFSectionTests(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-equations ASF_OptLayout of a ASF_ASFSection. Note that the precondition is that this ASF_ASFSection actually has a ws-after-equations
 * \param[in] arg input ASF_ASFSection
 * \return the ws-after-equations of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFSectionWsAfterEquations(ASF_ASFSection arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the list ASF_ASFConditionalEquationList of a ASF_ASFSection. Note that the precondition is that this ASF_ASFSection actually has a list
 * \param[in] arg input ASF_ASFSection
 * \return the list of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFConditionalEquationList ASF_getASFSectionList(ASF_ASFSection arg) {
  
    return (ASF_ASFConditionalEquationList)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), 1);
}

/**
 * Get the ws-after-tests ASF_OptLayout of a ASF_ASFSection. Note that the precondition is that this ASF_ASFSection actually has a ws-after-tests
 * \param[in] arg input ASF_ASFSection
 * \return the ws-after-tests of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFSectionWsAfterTests(ASF_ASFSection arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the test-list ASF_ASFTestEquationTestList of a ASF_ASFSection. Note that the precondition is that this ASF_ASFSection actually has a test-list
 * \param[in] arg input ASF_ASFSection
 * \return the test-list of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFTestEquationTestList ASF_getASFSectionTestList(ASF_ASFSection arg) {
  
    return (ASF_ASFTestEquationTestList)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), 1);
}

/**
 * Set the ws-after-equations of a ASF_ASFSection. The precondition being that this ASF_ASFSection actually has a ws-after-equations
 * \param[in] arg input ASF_ASFSection
 * \param[in] wsAfterEquations new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFSection with wsAfterEquations at the right place, or a core dump if #arg did not have a wsAfterEquations
 */
ASF_ASFSection ASF_setASFSectionWsAfterEquations(ASF_ASFSection arg, ASF_OptLayout wsAfterEquations) {
  if (ASF_isASFSectionEquations(arg)) {
    return (ASF_ASFSection)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterEquations), 1), 1);
  }

  ATabort("ASFSection has no WsAfterEquations: %t\n", arg);
  return (ASF_ASFSection)NULL;
}

/**
 * Set the list of a ASF_ASFSection. The precondition being that this ASF_ASFSection actually has a list
 * \param[in] arg input ASF_ASFSection
 * \param[in] list new ASF_ASFConditionalEquationList to set in #arg
 * \return A new ASF_ASFSection with list at the right place, or a core dump if #arg did not have a list
 */
ASF_ASFSection ASF_setASFSectionList(ASF_ASFSection arg, ASF_ASFConditionalEquationList list) {
  if (ASF_isASFSectionEquations(arg)) {
    return (ASF_ASFSection)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), (ATerm)((ATerm) list), 1), 2), 1);
  }

  ATabort("ASFSection has no List: %t\n", arg);
  return (ASF_ASFSection)NULL;
}

/**
 * Set the ws-after-tests of a ASF_ASFSection. The precondition being that this ASF_ASFSection actually has a ws-after-tests
 * \param[in] arg input ASF_ASFSection
 * \param[in] wsAfterTests new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFSection with wsAfterTests at the right place, or a core dump if #arg did not have a wsAfterTests
 */
ASF_ASFSection ASF_setASFSectionWsAfterTests(ASF_ASFSection arg, ASF_OptLayout wsAfterTests) {
  if (ASF_isASFSectionTests(arg)) {
    return (ASF_ASFSection)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterTests), 1), 1);
  }

  ATabort("ASFSection has no WsAfterTests: %t\n", arg);
  return (ASF_ASFSection)NULL;
}

/**
 * Set the test-list of a ASF_ASFSection. The precondition being that this ASF_ASFSection actually has a test-list
 * \param[in] arg input ASF_ASFSection
 * \param[in] testList new ASF_ASFTestEquationTestList to set in #arg
 * \return A new ASF_ASFSection with testList at the right place, or a core dump if #arg did not have a testList
 */
ASF_ASFSection ASF_setASFSectionTestList(ASF_ASFSection arg, ASF_ASFTestEquationTestList testList) {
  if (ASF_isASFSectionTests(arg)) {
    return (ASF_ASFSection)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), (ATerm)((ATerm) testList), 1), 2), 1);
  }

  ATabort("ASFSection has no TestList: %t\n", arg);
  return (ASF_ASFSection)NULL;
}

/**
 * Assert whether a ASF_ASFSectionList is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_ASFSectionList
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidASFSectionList(ASF_ASFSectionList arg) {
  if (ASF_isASFSectionListEmpty(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFSectionListSingle(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFSectionListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFSectionList is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the ASF_ASFSectionList
 * \param[in] arg input ASF_ASFSectionList
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool ASF_isASFSectionListEmpty(ASF_ASFSectionList arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFSectionList is a single by checking against the following ATerm pattern: [<head(ASF-Section)>]. May not be used to assert correctness of the ASF_ASFSectionList
 * \param[in] arg input ASF_ASFSectionList
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool ASF_isASFSectionListSingle(ASF_ASFSectionList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFSectionList is a many by checking against the following ATerm pattern: [<head(ASF-Section)>,<ws-after-head("OptLayout")>,<[tail(ASF-Section-list)]>]. May not be used to assert correctness of the ASF_ASFSectionList
 * \param[in] arg input ASF_ASFSectionList
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool ASF_isASFSectionListMany(ASF_ASFSectionList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFSectionList has a head. 
 * \param[in] arg input ASF_ASFSectionList
 * \return ATtrue if the ASF_ASFSectionList had a head, or ATfalse otherwise
 */
ATbool ASF_hasASFSectionListHead(ASF_ASFSectionList arg) {
  if (ASF_isASFSectionListSingle(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFSectionListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFSectionList has a ws-after-head. 
 * \param[in] arg input ASF_ASFSectionList
 * \return ATtrue if the ASF_ASFSectionList had a ws-after-head, or ATfalse otherwise
 */
ATbool ASF_hasASFSectionListWsAfterHead(ASF_ASFSectionList arg) {
  if (ASF_isASFSectionListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFSectionList has a tail. 
 * \param[in] arg input ASF_ASFSectionList
 * \return ATtrue if the ASF_ASFSectionList had a tail, or ATfalse otherwise
 */
ATbool ASF_hasASFSectionListTail(ASF_ASFSectionList arg) {
  if (ASF_isASFSectionListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a ASF_ASFSectionList. 
 * \param[in] arg input ASF_ASFSectionList
 * \return A new ASF_ASFSectionList, without the first element and the separator(s) just after it.)
 */
ASF_ASFSectionList ASF_getASFSectionListTail(ASF_ASFSectionList arg) {
  assert(!ASF_isASFSectionListEmpty(arg) && "getTail on an empty list");
  if (ASF_isASFSectionListSingle(arg)) {
    return (ASF_ASFSectionList) ASF_makeASFSectionListEmpty();
  }
  else {
  
    return (ASF_ASFSectionList)ATgetTail((ATermList)arg, 2);
  }
}

/**
 * Get the head ASF_ASFSection of a ASF_ASFSectionList. Note that the precondition is that this ASF_ASFSectionList actually has a head
 * \param[in] arg input ASF_ASFSectionList
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFSection ASF_getASFSectionListHead(ASF_ASFSectionList arg) {
  if (ASF_isASFSectionListSingle(arg)) {
    return (ASF_ASFSection)ATgetFirst((ATermList)arg);
  }
  else 
    return (ASF_ASFSection)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head ASF_OptLayout of a ASF_ASFSectionList. Note that the precondition is that this ASF_ASFSectionList actually has a ws-after-head
 * \param[in] arg input ASF_ASFSectionList
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFSectionListWsAfterHead(ASF_ASFSectionList arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Set the head of a ASF_ASFSectionList. The precondition being that this ASF_ASFSectionList actually has a head
 * \param[in] arg input ASF_ASFSectionList
 * \param[in] head new ASF_ASFSection to set in #arg
 * \return A new ASF_ASFSectionList with head at the right place, or a core dump if #arg did not have a head
 */
ASF_ASFSectionList ASF_setASFSectionListHead(ASF_ASFSectionList arg, ASF_ASFSection head) {
  if (ASF_isASFSectionListSingle(arg)) {
    return (ASF_ASFSectionList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (ASF_isASFSectionListMany(arg)) {
    return (ASF_ASFSectionList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("ASFSectionList has no Head: %t\n", arg);
  return (ASF_ASFSectionList)NULL;
}

/**
 * Set the ws-after-head of a ASF_ASFSectionList. The precondition being that this ASF_ASFSectionList actually has a ws-after-head
 * \param[in] arg input ASF_ASFSectionList
 * \param[in] wsAfterHead new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFSectionList with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
ASF_ASFSectionList ASF_setASFSectionListWsAfterHead(ASF_ASFSectionList arg, ASF_OptLayout wsAfterHead) {
  if (ASF_isASFSectionListMany(arg)) {
    return (ASF_ASFSectionList)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("ASFSectionList has no WsAfterHead: %t\n", arg);
  return (ASF_ASFSectionList)NULL;
}

/**
 * Set the tail of a ASF_ASFSectionList. The precondition being that this ASF_ASFSectionList actually has a tail
 * \param[in] arg input ASF_ASFSectionList
 * \param[in] tail new ASF_ASFSectionList to set in #arg
 * \return A new ASF_ASFSectionList with tail at the right place, or a core dump if #arg did not have a tail
 */
ASF_ASFSectionList ASF_setASFSectionListTail(ASF_ASFSectionList arg, ASF_ASFSectionList tail) {
  if (ASF_isASFSectionListMany(arg)) {
    return (ASF_ASFSectionList)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 2);
  }

  ATabort("ASFSectionList has no Tail: %t\n", arg);
  return (ASF_ASFSectionList)NULL;
}

/**
 * Assert whether a ASF_ASFConditionalEquationList is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_ASFConditionalEquationList
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidASFConditionalEquationList(ASF_ASFConditionalEquationList arg) {
  if (ASF_isASFConditionalEquationListEmpty(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionalEquationListSingle(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionalEquationListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquationList is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the ASF_ASFConditionalEquationList
 * \param[in] arg input ASF_ASFConditionalEquationList
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool ASF_isASFConditionalEquationListEmpty(ASF_ASFConditionalEquationList arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquationList is a single by checking against the following ATerm pattern: [<head(ASF-ConditionalEquation)>]. May not be used to assert correctness of the ASF_ASFConditionalEquationList
 * \param[in] arg input ASF_ASFConditionalEquationList
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool ASF_isASFConditionalEquationListSingle(ASF_ASFConditionalEquationList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquationList is a many by checking against the following ATerm pattern: [<head(ASF-ConditionalEquation)>,<ws-after-head("OptLayout")>,<[tail(ASF-ConditionalEquation-list)]>]. May not be used to assert correctness of the ASF_ASFConditionalEquationList
 * \param[in] arg input ASF_ASFConditionalEquationList
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool ASF_isASFConditionalEquationListMany(ASF_ASFConditionalEquationList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquationList has a head. 
 * \param[in] arg input ASF_ASFConditionalEquationList
 * \return ATtrue if the ASF_ASFConditionalEquationList had a head, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionalEquationListHead(ASF_ASFConditionalEquationList arg) {
  if (ASF_isASFConditionalEquationListSingle(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFConditionalEquationListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquationList has a ws-after-head. 
 * \param[in] arg input ASF_ASFConditionalEquationList
 * \return ATtrue if the ASF_ASFConditionalEquationList had a ws-after-head, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionalEquationListWsAfterHead(ASF_ASFConditionalEquationList arg) {
  if (ASF_isASFConditionalEquationListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFConditionalEquationList has a tail. 
 * \param[in] arg input ASF_ASFConditionalEquationList
 * \return ATtrue if the ASF_ASFConditionalEquationList had a tail, or ATfalse otherwise
 */
ATbool ASF_hasASFConditionalEquationListTail(ASF_ASFConditionalEquationList arg) {
  if (ASF_isASFConditionalEquationListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a ASF_ASFConditionalEquationList. 
 * \param[in] arg input ASF_ASFConditionalEquationList
 * \return A new ASF_ASFConditionalEquationList, without the first element and the separator(s) just after it.)
 */
ASF_ASFConditionalEquationList ASF_getASFConditionalEquationListTail(ASF_ASFConditionalEquationList arg) {
  assert(!ASF_isASFConditionalEquationListEmpty(arg) && "getTail on an empty list");
  if (ASF_isASFConditionalEquationListSingle(arg)) {
    return (ASF_ASFConditionalEquationList) ASF_makeASFConditionalEquationListEmpty();
  }
  else {
  
    return (ASF_ASFConditionalEquationList)ATgetTail((ATermList)arg, 2);
  }
}

/**
 * Get the head ASF_ASFConditionalEquation of a ASF_ASFConditionalEquationList. Note that the precondition is that this ASF_ASFConditionalEquationList actually has a head
 * \param[in] arg input ASF_ASFConditionalEquationList
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFConditionalEquation ASF_getASFConditionalEquationListHead(ASF_ASFConditionalEquationList arg) {
  if (ASF_isASFConditionalEquationListSingle(arg)) {
    return (ASF_ASFConditionalEquation)ATgetFirst((ATermList)arg);
  }
  else 
    return (ASF_ASFConditionalEquation)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head ASF_OptLayout of a ASF_ASFConditionalEquationList. Note that the precondition is that this ASF_ASFConditionalEquationList actually has a ws-after-head
 * \param[in] arg input ASF_ASFConditionalEquationList
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFConditionalEquationListWsAfterHead(ASF_ASFConditionalEquationList arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Set the head of a ASF_ASFConditionalEquationList. The precondition being that this ASF_ASFConditionalEquationList actually has a head
 * \param[in] arg input ASF_ASFConditionalEquationList
 * \param[in] head new ASF_ASFConditionalEquation to set in #arg
 * \return A new ASF_ASFConditionalEquationList with head at the right place, or a core dump if #arg did not have a head
 */
ASF_ASFConditionalEquationList ASF_setASFConditionalEquationListHead(ASF_ASFConditionalEquationList arg, ASF_ASFConditionalEquation head) {
  if (ASF_isASFConditionalEquationListSingle(arg)) {
    return (ASF_ASFConditionalEquationList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (ASF_isASFConditionalEquationListMany(arg)) {
    return (ASF_ASFConditionalEquationList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("ASFConditionalEquationList has no Head: %t\n", arg);
  return (ASF_ASFConditionalEquationList)NULL;
}

/**
 * Set the ws-after-head of a ASF_ASFConditionalEquationList. The precondition being that this ASF_ASFConditionalEquationList actually has a ws-after-head
 * \param[in] arg input ASF_ASFConditionalEquationList
 * \param[in] wsAfterHead new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFConditionalEquationList with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
ASF_ASFConditionalEquationList ASF_setASFConditionalEquationListWsAfterHead(ASF_ASFConditionalEquationList arg, ASF_OptLayout wsAfterHead) {
  if (ASF_isASFConditionalEquationListMany(arg)) {
    return (ASF_ASFConditionalEquationList)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("ASFConditionalEquationList has no WsAfterHead: %t\n", arg);
  return (ASF_ASFConditionalEquationList)NULL;
}

/**
 * Set the tail of a ASF_ASFConditionalEquationList. The precondition being that this ASF_ASFConditionalEquationList actually has a tail
 * \param[in] arg input ASF_ASFConditionalEquationList
 * \param[in] tail new ASF_ASFConditionalEquationList to set in #arg
 * \return A new ASF_ASFConditionalEquationList with tail at the right place, or a core dump if #arg did not have a tail
 */
ASF_ASFConditionalEquationList ASF_setASFConditionalEquationListTail(ASF_ASFConditionalEquationList arg, ASF_ASFConditionalEquationList tail) {
  if (ASF_isASFConditionalEquationListMany(arg)) {
    return (ASF_ASFConditionalEquationList)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 2);
  }

  ATabort("ASFConditionalEquationList has no Tail: %t\n", arg);
  return (ASF_ASFConditionalEquationList)NULL;
}

/**
 * Assert whether a ASF_ASFTestEquationTestList is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_ASFTestEquationTestList
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidASFTestEquationTestList(ASF_ASFTestEquationTestList arg) {
  if (ASF_isASFTestEquationTestListEmpty(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFTestEquationTestListSingle(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFTestEquationTestListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquationTestList is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the ASF_ASFTestEquationTestList
 * \param[in] arg input ASF_ASFTestEquationTestList
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool ASF_isASFTestEquationTestListEmpty(ASF_ASFTestEquationTestList arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquationTestList is a single by checking against the following ATerm pattern: [<head(ASF-TestEquation)>]. May not be used to assert correctness of the ASF_ASFTestEquationTestList
 * \param[in] arg input ASF_ASFTestEquationTestList
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool ASF_isASFTestEquationTestListSingle(ASF_ASFTestEquationTestList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquationTestList is a many by checking against the following ATerm pattern: [<head(ASF-TestEquation)>,<ws-after-head("OptLayout")>,<[tail(ASF-TestEquation-test-list)]>]. May not be used to assert correctness of the ASF_ASFTestEquationTestList
 * \param[in] arg input ASF_ASFTestEquationTestList
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool ASF_isASFTestEquationTestListMany(ASF_ASFTestEquationTestList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquationTestList has a head. 
 * \param[in] arg input ASF_ASFTestEquationTestList
 * \return ATtrue if the ASF_ASFTestEquationTestList had a head, or ATfalse otherwise
 */
ATbool ASF_hasASFTestEquationTestListHead(ASF_ASFTestEquationTestList arg) {
  if (ASF_isASFTestEquationTestListSingle(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFTestEquationTestListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquationTestList has a ws-after-head. 
 * \param[in] arg input ASF_ASFTestEquationTestList
 * \return ATtrue if the ASF_ASFTestEquationTestList had a ws-after-head, or ATfalse otherwise
 */
ATbool ASF_hasASFTestEquationTestListWsAfterHead(ASF_ASFTestEquationTestList arg) {
  if (ASF_isASFTestEquationTestListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquationTestList has a tail. 
 * \param[in] arg input ASF_ASFTestEquationTestList
 * \return ATtrue if the ASF_ASFTestEquationTestList had a tail, or ATfalse otherwise
 */
ATbool ASF_hasASFTestEquationTestListTail(ASF_ASFTestEquationTestList arg) {
  if (ASF_isASFTestEquationTestListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a ASF_ASFTestEquationTestList. 
 * \param[in] arg input ASF_ASFTestEquationTestList
 * \return A new ASF_ASFTestEquationTestList, without the first element and the separator(s) just after it.)
 */
ASF_ASFTestEquationTestList ASF_getASFTestEquationTestListTail(ASF_ASFTestEquationTestList arg) {
  assert(!ASF_isASFTestEquationTestListEmpty(arg) && "getTail on an empty list");
  if (ASF_isASFTestEquationTestListSingle(arg)) {
    return (ASF_ASFTestEquationTestList) ASF_makeASFTestEquationTestListEmpty();
  }
  else {
  
    return (ASF_ASFTestEquationTestList)ATgetTail((ATermList)arg, 2);
  }
}

/**
 * Get the head ASF_ASFTestEquation of a ASF_ASFTestEquationTestList. Note that the precondition is that this ASF_ASFTestEquationTestList actually has a head
 * \param[in] arg input ASF_ASFTestEquationTestList
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFTestEquation ASF_getASFTestEquationTestListHead(ASF_ASFTestEquationTestList arg) {
  if (ASF_isASFTestEquationTestListSingle(arg)) {
    return (ASF_ASFTestEquation)ATgetFirst((ATermList)arg);
  }
  else 
    return (ASF_ASFTestEquation)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head ASF_OptLayout of a ASF_ASFTestEquationTestList. Note that the precondition is that this ASF_ASFTestEquationTestList actually has a ws-after-head
 * \param[in] arg input ASF_ASFTestEquationTestList
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFTestEquationTestListWsAfterHead(ASF_ASFTestEquationTestList arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Set the head of a ASF_ASFTestEquationTestList. The precondition being that this ASF_ASFTestEquationTestList actually has a head
 * \param[in] arg input ASF_ASFTestEquationTestList
 * \param[in] head new ASF_ASFTestEquation to set in #arg
 * \return A new ASF_ASFTestEquationTestList with head at the right place, or a core dump if #arg did not have a head
 */
ASF_ASFTestEquationTestList ASF_setASFTestEquationTestListHead(ASF_ASFTestEquationTestList arg, ASF_ASFTestEquation head) {
  if (ASF_isASFTestEquationTestListSingle(arg)) {
    return (ASF_ASFTestEquationTestList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (ASF_isASFTestEquationTestListMany(arg)) {
    return (ASF_ASFTestEquationTestList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("ASFTestEquationTestList has no Head: %t\n", arg);
  return (ASF_ASFTestEquationTestList)NULL;
}

/**
 * Set the ws-after-head of a ASF_ASFTestEquationTestList. The precondition being that this ASF_ASFTestEquationTestList actually has a ws-after-head
 * \param[in] arg input ASF_ASFTestEquationTestList
 * \param[in] wsAfterHead new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFTestEquationTestList with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
ASF_ASFTestEquationTestList ASF_setASFTestEquationTestListWsAfterHead(ASF_ASFTestEquationTestList arg, ASF_OptLayout wsAfterHead) {
  if (ASF_isASFTestEquationTestListMany(arg)) {
    return (ASF_ASFTestEquationTestList)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("ASFTestEquationTestList has no WsAfterHead: %t\n", arg);
  return (ASF_ASFTestEquationTestList)NULL;
}

/**
 * Set the tail of a ASF_ASFTestEquationTestList. The precondition being that this ASF_ASFTestEquationTestList actually has a tail
 * \param[in] arg input ASF_ASFTestEquationTestList
 * \param[in] tail new ASF_ASFTestEquationTestList to set in #arg
 * \return A new ASF_ASFTestEquationTestList with tail at the right place, or a core dump if #arg did not have a tail
 */
ASF_ASFTestEquationTestList ASF_setASFTestEquationTestListTail(ASF_ASFTestEquationTestList arg, ASF_ASFTestEquationTestList tail) {
  if (ASF_isASFTestEquationTestListMany(arg)) {
    return (ASF_ASFTestEquationTestList)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 2);
  }

  ATabort("ASFTestEquationTestList has no Tail: %t\n", arg);
  return (ASF_ASFTestEquationTestList)NULL;
}

/**
 * Assert whether a ASF_LexASFTagId is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_LexASFTagId
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidLexASFTagId(ASF_LexASFTagId arg) {
  if (ASF_isLexASFTagIdOneChar(arg)) {
    return ATtrue;
  }
  else if (ASF_isLexASFTagIdManyChars(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexASFTagId is a one-char by checking against the following ATerm pattern: appl(prod([char-class([34,39,range(48,57),range(65,90),range(97,122)])],lex(sort("ASF-TagId")),attrs([avoid,term(cons("one-char"))])),[<"head"(char)>]). May not be used to assert correctness of the ASF_LexASFTagId
 * \param[in] arg input ASF_LexASFTagId
 * \return ATtrue if #arg corresponds to the signature of a one-char, or ATfalse otherwise
 */
inline ATbool ASF_isLexASFTagIdOneChar(ASF_LexASFTagId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: char-class */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun21) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
            ATerm arg_arg0_arg0_head_arg0_head;
            ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
            if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 34) {

              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 39) {

                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                    arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                    arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                    /* checking for: range */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
                      ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 48) {

                        ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                        if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 57) {

                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                            /* checking for: range */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
                              ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 65) {

                                ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 90) {

                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                    arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                    /* checking for: range */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
                                      ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 97) {

                                        ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                                        if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 122) {

                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                              /* checking for: lex */
                                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun6) {
                                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                /* checking for: sort */
                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                  /* checking for: ASF-TagId */
                                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun57) {
                                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                    /* checking for: attrs */
                                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                        ATerm arg_arg0_arg2_arg0_head;
                                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                        /* checking for: avoid */
                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun59) {
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATfalse) {
                                                            arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                            arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                            /* checking for: term */
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                              ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                              /* checking for: cons */
                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                                ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                /* checking for: one-char */
                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun58) {
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                    ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                    if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                      ATerm arg_arg1_head;
                                                                      ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                          return ATtrue;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexASFTagId is a many-chars by checking against the following ATerm pattern: appl(prod([char-class([34,39,range(48,57),range(65,90),range(97,122)]),lex(iter-star(char-class([34,39,45,range(48,57),range(65,90),range(97,122)]))),char-class([34,39,range(48,57),range(65,90),range(97,122)])],lex(sort("ASF-TagId")),attrs([avoid,term(cons("many-chars"))])),[<"head"(char)>,appl(list(lex(iter-star(char-class([34,39,45,range(48,57),range(65,90),range(97,122)])))),<"middle"(chars)>),<"last"(char)>]). May not be used to assert correctness of the ASF_LexASFTagId
 * \param[in] arg input ASF_LexASFTagId
 * \return ATtrue if #arg corresponds to the signature of a many-chars, or ATfalse otherwise
 */
inline ATbool ASF_isLexASFTagIdManyChars(ASF_LexASFTagId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: char-class */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun21) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
            ATerm arg_arg0_arg0_head_arg0_head;
            ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
            if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 34) {

              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 39) {

                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                    arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                    arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                    /* checking for: range */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
                      ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 48) {

                        ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                        if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 57) {

                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                            /* checking for: range */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
                              ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 65) {

                                ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 90) {

                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                    arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                    /* checking for: range */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
                                      ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 97) {

                                        ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                                        if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 122) {

                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                              /* checking for: lex */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun6) {
                                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                /* checking for: iter-star */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun22) {
                                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun21) {
                                                    ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0) == ATfalse) {
                                                      ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head;
                                                      ATermList arg_arg0_arg0_head_arg0_arg0_arg0_list = (ATermList)arg_arg0_arg0_head_arg0_arg0_arg0;
                                                      arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                      arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head) == 34) {

                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                          arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                          if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head) == 39) {

                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATfalse) {
                                                              arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                              arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head) == 45) {

                                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                                  arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                                  /* checking for: range */
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0_head) == ASF_afun25) {
                                                                    ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 0);
                                                                    if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0) == 48) {

                                                                      ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 1);
                                                                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1) == 57) {

                                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATfalse) {
                                                                          arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                                          arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                                          /* checking for: range */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0_head) == ASF_afun25) {
                                                                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 0);
                                                                            if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0) == 65) {

                                                                              ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 1);
                                                                              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1) == 90) {

                                                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATfalse) {
                                                                                  arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                                                  arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                                                  /* checking for: range */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0_head) == ASF_afun25) {
                                                                                    ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 0);
                                                                                    if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0) == 97) {

                                                                                      ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 1);
                                                                                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1) == 122) {

                                                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATtrue) {
                                                                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                            /* checking for: char-class */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun21) {
                                                                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                ATerm arg_arg0_arg0_head_arg0_head;
                                                                                                ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
                                                                                                arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                                                                                arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                                                                                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 34) {

                                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                                                                                                    arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                                                                                    arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 39) {

                                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                                                                                                        arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                                                                                        arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                                                                                        /* checking for: range */
                                                                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
                                                                                                          ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                                                                                                          if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 48) {

                                                                                                            ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                                                                                                            if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 57) {

                                                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                                                                                                                arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                                                                                                arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                                                                                                /* checking for: range */
                                                                                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
                                                                                                                  ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 65) {

                                                                                                                    ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                                                                                                                    if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 90) {

                                                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                                                                                                                        arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                                                                                                        arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                                                                                                        /* checking for: range */
                                                                                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
                                                                                                                          ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                                                                                                                          if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 97) {

                                                                                                                            ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                                                                                                                            if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 122) {

                                                                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                                                                  ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                                                                  /* checking for: lex */
                                                                                                                                  if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun6) {
                                                                                                                                    ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                                                                    /* checking for: sort */
                                                                                                                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                                                                                                                      ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                                                                      /* checking for: ASF-TagId */
                                                                                                                                      if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun57) {
                                                                                                                                        ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                                                                        /* checking for: attrs */
                                                                                                                                        if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                                                                                                                          ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                                                                            ATerm arg_arg0_arg2_arg0_head;
                                                                                                                                            ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                                                                            arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                                                            arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                                                            /* checking for: avoid */
                                                                                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun59) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATfalse) {
                                                                                                                                                arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                                                                arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                                                                /* checking for: term */
                                                                                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                                                                                                                  ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                                                                                  /* checking for: cons */
                                                                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                                                                                                                    ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                                                                    /* checking for: many-chars */
                                                                                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun60) {
                                                                                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                                                                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                                                                          ATerm arg_arg1_head;
                                                                                                                                                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                              /* checking for: appl */
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                /* checking for: list */
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun8) {
                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                  /* checking for: lex */
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == ASF_afun6) {
                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                                                                                    /* checking for: iter-star */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == ASF_afun22) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                                                                                      /* checking for: char-class */
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == ASF_afun21) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == ATfalse) {
                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head;
                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0;
                                                                                                                                                                          arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                                                                          arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == 34) {

                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                                                                              arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == 39) {

                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == 45) {

                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                      arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                                                                                      arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                                                                                      /* checking for: range */
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == ASF_afun25) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 0);
                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0) == 48) {

                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 1);
                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1) == 57) {

                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                              arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                                                                                              arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                                                                                              /* checking for: range */
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == ASF_afun25) {
                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 0);
                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0) == 65) {

                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 1);
                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1) == 90) {

                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                                                                                                      /* checking for: range */
                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == ASF_afun25) {
                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 0);
                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0) == 97) {

                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 1);
                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1) == 122) {

                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST) {
                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                      return ATtrue;
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexASFTagId has a head. 
 * \param[in] arg input ASF_LexASFTagId
 * \return ATtrue if the ASF_LexASFTagId had a head, or ATfalse otherwise
 */
ATbool ASF_hasLexASFTagIdHead(ASF_LexASFTagId arg) {
  if (ASF_isLexASFTagIdOneChar(arg)) {
    return ATtrue;
  }
  else if (ASF_isLexASFTagIdManyChars(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexASFTagId has a middle. 
 * \param[in] arg input ASF_LexASFTagId
 * \return ATtrue if the ASF_LexASFTagId had a middle, or ATfalse otherwise
 */
ATbool ASF_hasLexASFTagIdMiddle(ASF_LexASFTagId arg) {
  if (ASF_isLexASFTagIdManyChars(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexASFTagId has a last. 
 * \param[in] arg input ASF_LexASFTagId
 * \return ATtrue if the ASF_LexASFTagId had a last, or ATfalse otherwise
 */
ATbool ASF_hasLexASFTagIdLast(ASF_LexASFTagId arg) {
  if (ASF_isLexASFTagIdManyChars(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the head char of a ASF_LexASFTagId. Note that the precondition is that this ASF_LexASFTagId actually has a head
 * \param[in] arg input ASF_LexASFTagId
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
char ASF_getLexASFTagIdHead(ASF_LexASFTagId arg) {
  if (ASF_isLexASFTagIdOneChar(arg)) {
    return (char)ASF_charToByte((ATerm)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)));
  }
  else 
    return (char)ASF_charToByte((ATerm)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)));
}

/**
 * Get the middle char* of a ASF_LexASFTagId. Note that the precondition is that this ASF_LexASFTagId actually has a middle
 * \param[in] arg input ASF_LexASFTagId
 * \return the middle of #arg, if it exist or an undefined value if it does not
 */
char* ASF_getLexASFTagIdMiddle(ASF_LexASFTagId arg) {
  
    return (char*)ASF_charsToString((ATerm)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1), 1));
}

/**
 * Get the last char of a ASF_LexASFTagId. Note that the precondition is that this ASF_LexASFTagId actually has a last
 * \param[in] arg input ASF_LexASFTagId
 * \return the last of #arg, if it exist or an undefined value if it does not
 */
char ASF_getLexASFTagIdLast(ASF_LexASFTagId arg) {
  
    return (char)ASF_charToByte((ATerm)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2));
}

/**
 * Set the head of a ASF_LexASFTagId. The precondition being that this ASF_LexASFTagId actually has a head
 * \param[in] arg input ASF_LexASFTagId
 * \param[in] head new char to set in #arg
 * \return A new ASF_LexASFTagId with head at the right place, or a core dump if #arg did not have a head
 */
ASF_LexASFTagId ASF_setLexASFTagIdHead(ASF_LexASFTagId arg, char head) {
  if (ASF_isLexASFTagIdOneChar(arg)) {
    return (ASF_LexASFTagId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) ASF_byteToChar(head))), 0), 1);
  }
  else if (ASF_isLexASFTagIdManyChars(arg)) {
    return (ASF_LexASFTagId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) ASF_byteToChar(head))), 0), 1);
  }

  ATabort("LexASFTagId has no Head: %t\n", arg);
  return (ASF_LexASFTagId)NULL;
}

/**
 * Set the middle of a ASF_LexASFTagId. The precondition being that this ASF_LexASFTagId actually has a middle
 * \param[in] arg input ASF_LexASFTagId
 * \param[in] middle new const char* to set in #arg
 * \return A new ASF_LexASFTagId with middle at the right place, or a core dump if #arg did not have a middle
 */
ASF_LexASFTagId ASF_setLexASFTagIdMiddle(ASF_LexASFTagId arg, const char* middle) {
  if (ASF_isLexASFTagIdManyChars(arg)) {
    return (ASF_LexASFTagId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1), (ATerm)((ATerm) ((ATerm) ASF_stringToChars(middle))), 1), 1), 1);
  }

  ATabort("LexASFTagId has no Middle: %t\n", arg);
  return (ASF_LexASFTagId)NULL;
}

/**
 * Set the last of a ASF_LexASFTagId. The precondition being that this ASF_LexASFTagId actually has a last
 * \param[in] arg input ASF_LexASFTagId
 * \param[in] last new char to set in #arg
 * \return A new ASF_LexASFTagId with last at the right place, or a core dump if #arg did not have a last
 */
ASF_LexASFTagId ASF_setLexASFTagIdLast(ASF_LexASFTagId arg, char last) {
  if (ASF_isLexASFTagIdManyChars(arg)) {
    return (ASF_LexASFTagId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) ASF_byteToChar(last))), 2), 1);
  }

  ATabort("LexASFTagId has no Last: %t\n", arg);
  return (ASF_LexASFTagId)NULL;
}

/**
 * Assert whether a ASF_ASFTagId is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_ASFTagId
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidASFTagId(ASF_ASFTagId arg) {
  if (ASF_isASFTagIdLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTagId is a Lex-to-cf by checking against the following ATerm pattern: appl(prod([lex(sort("ASF-TagId"))],cf(sort("ASF-TagId")),no-attrs),[<"ASF-TagId"("Lex-ASF-TagId")>]). Always returns ATtrue
 * \param[in] arg input ASF_ASFTagId
 * \return ATtrue if #arg corresponds to the signature of a Lex-to-cf, or ATfalse otherwise
 */
inline ATbool ASF_isASFTagIdLexToCf(ASF_ASFTagId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: ASF-TagId */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun57) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: ASF-TagId */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun57) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: no-attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun5) {
                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                          arg_arg1_list = ATgetNext(arg_arg1_list);
                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTagId has a ASF-TagId. 
 * \param[in] arg input ASF_ASFTagId
 * \return ATtrue if the ASF_ASFTagId had a ASF-TagId, or ATfalse otherwise
 */
ATbool ASF_hasASFTagIdASFTagId(ASF_ASFTagId arg) {
  if (ASF_isASFTagIdLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ASF-TagId ASF_LexASFTagId of a ASF_ASFTagId. Note that the precondition is that this ASF_ASFTagId actually has a ASF-TagId
 * \param[in] arg input ASF_ASFTagId
 * \return the ASF-TagId of #arg, if it exist or an undefined value if it does not
 */
ASF_LexASFTagId ASF_getASFTagIdASFTagId(ASF_ASFTagId arg) {
  
    return (ASF_LexASFTagId)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the ASF-TagId of a ASF_ASFTagId. The precondition being that this ASF_ASFTagId actually has a ASF-TagId
 * \param[in] arg input ASF_ASFTagId
 * \param[in] ASFTagId new ASF_LexASFTagId to set in #arg
 * \return A new ASF_ASFTagId with ASFTagId at the right place, or a core dump if #arg did not have a ASFTagId
 */
ASF_ASFTagId ASF_setASFTagIdASFTagId(ASF_ASFTagId arg, ASF_LexASFTagId ASFTagId) {
  if (ASF_isASFTagIdLexToCf(arg)) {
    return (ASF_ASFTagId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFTagId), 0), 1);
  }

  ATabort("ASFTagId has no ASFTagId: %t\n", arg);
  return (ASF_ASFTagId)NULL;
}

/**
 * Assert whether a ASF_ASFTag is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_ASFTag
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidASFTag(ASF_ASFTag arg) {
  if (ASF_isASFTagEmpty(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFTagNotEmpty(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTag is a empty by checking against the following ATerm pattern: appl(prod([lit("["),cf(opt(layout)),lit("]")],cf(sort("ASF-Tag")),attrs([term(cons("empty"))])),[appl(prod([char-class([91])],lit("["),no-attrs),[91]),<"ws-after-["("OptLayout")>,appl(prod([char-class([93])],lit("]"),no-attrs),[93])]). May not be used to assert correctness of the ASF_ASFTag
 * \param[in] arg input ASF_ASFTag
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool ASF_isASFTagEmpty(ASF_ASFTag arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: [ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun62) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ] */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun61) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                            ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                              ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                              /* checking for: sort */
                              if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                /* checking for: ASF-Tag */
                                if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun44) {
                                  ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                  /* checking for: attrs */
                                  if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                    ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                      ATerm arg_arg0_arg2_arg0_head;
                                      ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                      arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                      arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                      /* checking for: term */
                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                        ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                        /* checking for: cons */
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                          ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                          /* checking for: empty */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun63) {
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                ATerm arg_arg1_head;
                                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                /* checking for: appl */
                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                  /* checking for: prod */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                      /* checking for: char-class */
                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 91) {

                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                /* checking for: lit */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                  /* checking for: [ */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun62) {
                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                    /* checking for: no-attrs */
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                        ATerm arg_arg1_head_arg1_head;
                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 91) {

                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                /* checking for: appl */
                                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                  /* checking for: prod */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                      /* checking for: char-class */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 93) {

                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                /* checking for: lit */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                  /* checking for: ] */
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun61) {
                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                    /* checking for: no-attrs */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 93) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                              return ATtrue;
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTag is a not-empty by checking against the following ATerm pattern: appl(prod([lit("["),cf(opt(layout)),cf(sort("ASF-TagId")),cf(opt(layout)),lit("]")],cf(sort("ASF-Tag")),attrs([term(cons("not-empty"))])),[appl(prod([char-class([91])],lit("["),no-attrs),[91]),<"ws-after-["("OptLayout")>,<"ASF-TagId"("ASF-TagId")>,<"ws-after-ASF-TagId"("OptLayout")>,appl(prod([char-class([93])],lit("]"),no-attrs),[93])]). May not be used to assert correctness of the ASF_ASFTag
 * \param[in] arg input ASF_ASFTag
 * \return ATtrue if #arg corresponds to the signature of a not-empty, or ATfalse otherwise
 */
inline ATbool ASF_isASFTagNotEmpty(ASF_ASFTag arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: [ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun62) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: ASF-TagId */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun57) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: lit */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: ] */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun61) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                            ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                                              ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                              /* checking for: sort */
                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                                ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                /* checking for: ASF-Tag */
                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun44) {
                                                  ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                  /* checking for: attrs */
                                                  if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                                    ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                      ATerm arg_arg0_arg2_arg0_head;
                                                      ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                      arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                      arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                      /* checking for: term */
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                        ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                        /* checking for: cons */
                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                          ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                          /* checking for: not-empty */
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun64) {
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                ATerm arg_arg1_head;
                                                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                /* checking for: appl */
                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                  /* checking for: prod */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 91) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                /* checking for: lit */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                  /* checking for: [ */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun62) {
                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                    /* checking for: no-attrs */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 91) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                    /* checking for: appl */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                      /* checking for: prod */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                          /* checking for: char-class */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 93) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                    /* checking for: lit */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                      /* checking for: ] */
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun61) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                        /* checking for: no-attrs */
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 93) {

                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                  return ATtrue;
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTag has a ws-after-[. 
 * \param[in] arg input ASF_ASFTag
 * \return ATtrue if the ASF_ASFTag had a ws-after-[, or ATfalse otherwise
 */
ATbool ASF_hasASFTagWsAfterBracketOpen(ASF_ASFTag arg) {
  if (ASF_isASFTagEmpty(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFTagNotEmpty(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTag has a ASF-TagId. 
 * \param[in] arg input ASF_ASFTag
 * \return ATtrue if the ASF_ASFTag had a ASF-TagId, or ATfalse otherwise
 */
ATbool ASF_hasASFTagASFTagId(ASF_ASFTag arg) {
  if (ASF_isASFTagNotEmpty(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTag has a ws-after-ASF-TagId. 
 * \param[in] arg input ASF_ASFTag
 * \return ATtrue if the ASF_ASFTag had a ws-after-ASF-TagId, or ATfalse otherwise
 */
ATbool ASF_hasASFTagWsAfterASFTagId(ASF_ASFTag arg) {
  if (ASF_isASFTagNotEmpty(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-[ ASF_OptLayout of a ASF_ASFTag. Note that the precondition is that this ASF_ASFTag actually has a ws-after-[
 * \param[in] arg input ASF_ASFTag
 * \return the ws-after-[ of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFTagWsAfterBracketOpen(ASF_ASFTag arg) {
  if (ASF_isASFTagEmpty(arg)) {
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else 
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ASF-TagId ASF_ASFTagId of a ASF_ASFTag. Note that the precondition is that this ASF_ASFTag actually has a ASF-TagId
 * \param[in] arg input ASF_ASFTag
 * \return the ASF-TagId of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFTagId ASF_getASFTagASFTagId(ASF_ASFTag arg) {
  
    return (ASF_ASFTagId)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
}

/**
 * Get the ws-after-ASF-TagId ASF_OptLayout of a ASF_ASFTag. Note that the precondition is that this ASF_ASFTag actually has a ws-after-ASF-TagId
 * \param[in] arg input ASF_ASFTag
 * \return the ws-after-ASF-TagId of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFTagWsAfterASFTagId(ASF_ASFTag arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Set the ws-after-[ of a ASF_ASFTag. The precondition being that this ASF_ASFTag actually has a ws-after-[
 * \param[in] arg input ASF_ASFTag
 * \param[in] wsAfterBracketOpen new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFTag with wsAfterBracketOpen at the right place, or a core dump if #arg did not have a wsAfterBracketOpen
 */
ASF_ASFTag ASF_setASFTagWsAfterBracketOpen(ASF_ASFTag arg, ASF_OptLayout wsAfterBracketOpen) {
  if (ASF_isASFTagEmpty(arg)) {
    return (ASF_ASFTag)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBracketOpen), 1), 1);
  }
  else if (ASF_isASFTagNotEmpty(arg)) {
    return (ASF_ASFTag)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBracketOpen), 1), 1);
  }

  ATabort("ASFTag has no WsAfterBracketOpen: %t\n", arg);
  return (ASF_ASFTag)NULL;
}

/**
 * Set the ASF-TagId of a ASF_ASFTag. The precondition being that this ASF_ASFTag actually has a ASF-TagId
 * \param[in] arg input ASF_ASFTag
 * \param[in] ASFTagId new ASF_ASFTagId to set in #arg
 * \return A new ASF_ASFTag with ASFTagId at the right place, or a core dump if #arg did not have a ASFTagId
 */
ASF_ASFTag ASF_setASFTagASFTagId(ASF_ASFTag arg, ASF_ASFTagId ASFTagId) {
  if (ASF_isASFTagNotEmpty(arg)) {
    return (ASF_ASFTag)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFTagId), 2), 1);
  }

  ATabort("ASFTag has no ASFTagId: %t\n", arg);
  return (ASF_ASFTag)NULL;
}

/**
 * Set the ws-after-ASF-TagId of a ASF_ASFTag. The precondition being that this ASF_ASFTag actually has a ws-after-ASF-TagId
 * \param[in] arg input ASF_ASFTag
 * \param[in] wsAfterASFTagId new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFTag with wsAfterASFTagId at the right place, or a core dump if #arg did not have a wsAfterASFTagId
 */
ASF_ASFTag ASF_setASFTagWsAfterASFTagId(ASF_ASFTag arg, ASF_OptLayout wsAfterASFTagId) {
  if (ASF_isASFTagNotEmpty(arg)) {
    return (ASF_ASFTag)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterASFTagId), 3), 1);
  }

  ATabort("ASFTag has no WsAfterASFTagId: %t\n", arg);
  return (ASF_ASFTag)NULL;
}

/**
 * Assert whether a ASF_ASFTestEquation is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_ASFTestEquation
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidASFTestEquation(ASF_ASFTestEquation arg) {
  if (ASF_isASFTestEquationSimple(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFTestEquationImplies(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFTestEquationWhen(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquation is a simple by checking against the following ATerm pattern: appl(prod([cf(sort("ASF-Tag")),cf(opt(layout)),cf(sort("ASF-Condition"))],cf(sort("ASF-TestEquation")),attrs([term(cons("simple"))])),[<"ASF-Tag"("ASF-Tag")>,<"ws-after-ASF-Tag"("OptLayout")>,<"ASF-Condition"("ASF-Condition")>]). May not be used to assert correctness of the ASF_ASFTestEquation
 * \param[in] arg input ASF_ASFTestEquation
 * \return ATtrue if #arg corresponds to the signature of a simple, or ATfalse otherwise
 */
inline ATbool ASF_isASFTestEquationSimple(ASF_ASFTestEquation arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: ASF-Tag */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun44) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: cf */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
                            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                            /* checking for: ASF-Condition */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun28) {
                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                /* checking for: cf */
                                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                  /* checking for: sort */
                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                    /* checking for: ASF-TestEquation */
                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun55) {
                                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                      /* checking for: attrs */
                                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                          ATerm arg_arg0_arg2_arg0_head;
                                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                          /* checking for: term */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                            /* checking for: cons */
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                              /* checking for: simple */
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun46) {
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                          return ATtrue;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquation is a implies by checking against the following ATerm pattern: appl(prod([cf(sort("ASF-Tag")),cf(opt(layout)),cf(sort("ASF-Conditions")),cf(opt(layout)),cf(sort("ASF-Implies")),cf(opt(layout)),cf(sort("ASF-Condition"))],cf(sort("ASF-TestEquation")),attrs([term(cons("implies"))])),[<"ASF-Tag"("ASF-Tag")>,<"ws-after-ASF-Tag"("OptLayout")>,<"ASF-Conditions"("ASF-Conditions")>,<"ws-after-ASF-Conditions"("OptLayout")>,<"ASF-Implies"("ASF-Implies")>,<"ws-after-ASF-Implies"("OptLayout")>,<"ASF-Condition"("ASF-Condition")>]). May not be used to assert correctness of the ASF_ASFTestEquation
 * \param[in] arg input ASF_ASFTestEquation
 * \return ATtrue if #arg corresponds to the signature of a implies, or ATfalse otherwise
 */
inline ATbool ASF_isASFTestEquationImplies(ASF_ASFTestEquation arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: ASF-Tag */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun44) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: cf */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
                            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                            /* checking for: ASF-Conditions */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun37) {
                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                /* checking for: cf */
                                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                  /* checking for: opt */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                    /* checking for: layout */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                        /* checking for: cf */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                          /* checking for: sort */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
                                            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                            /* checking for: ASF-Implies */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun42) {
                                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                /* checking for: cf */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                  /* checking for: opt */
                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                                                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                    /* checking for: layout */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                        /* checking for: cf */
                                                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                          /* checking for: sort */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
                                                            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                            /* checking for: ASF-Condition */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun28) {
                                                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                /* checking for: cf */
                                                                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                                                                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                  /* checking for: sort */
                                                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                                                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                    /* checking for: ASF-TestEquation */
                                                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun55) {
                                                                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                      /* checking for: attrs */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                                                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                          ATerm arg_arg0_arg2_arg0_head;
                                                                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                          /* checking for: term */
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                            /* checking for: cons */
                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                              /* checking for: implies */
                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun47) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                  return ATtrue;
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquation is a when by checking against the following ATerm pattern: appl(prod([cf(sort("ASF-Tag")),cf(opt(layout)),cf(sort("ASF-Condition")),cf(opt(layout)),lit("when"),cf(opt(layout)),cf(sort("ASF-Conditions"))],cf(sort("ASF-TestEquation")),attrs([term(cons("when"))])),[<"ASF-Tag"("ASF-Tag")>,<"ws-after-ASF-Tag"("OptLayout")>,<"ASF-Condition"("ASF-Condition")>,<"ws-after-ASF-Condition"("OptLayout")>,appl(prod([char-class([119]),char-class([104]),char-class([101]),char-class([110])],lit("when"),no-attrs),[119,104,101,110]),<"ws-after-when"("OptLayout")>,<"ASF-Conditions"("ASF-Conditions")>]). May not be used to assert correctness of the ASF_ASFTestEquation
 * \param[in] arg input ASF_ASFTestEquation
 * \return ATtrue if #arg corresponds to the signature of a when, or ATfalse otherwise
 */
inline ATbool ASF_isASFTestEquationWhen(ASF_ASFTestEquation arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: ASF-Tag */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun44) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: cf */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
                            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                            /* checking for: ASF-Condition */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun28) {
                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                /* checking for: cf */
                                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                  /* checking for: opt */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                    /* checking for: layout */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                        /* checking for: lit */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
                                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                          /* checking for: when */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun48) {
                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                              /* checking for: cf */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                /* checking for: opt */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun3) {
                                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                  /* checking for: layout */
                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun4) {
                                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                      /* checking for: cf */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
                                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                        /* checking for: sort */
                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
                                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                          /* checking for: ASF-Conditions */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun37) {
                                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                              /* checking for: cf */
                                                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                                                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                /* checking for: sort */
                                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                  /* checking for: ASF-TestEquation */
                                                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun55) {
                                                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                    /* checking for: attrs */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                        ATerm arg_arg0_arg2_arg0_head;
                                                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                        /* checking for: term */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                          /* checking for: cons */
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                            /* checking for: when */
                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun48) {
                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                  ATerm arg_arg1_head;
                                                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                          /* checking for: appl */
                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                            /* checking for: prod */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                /* checking for: char-class */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 119) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                          /* checking for: char-class */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 104) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                    /* checking for: char-class */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                              /* checking for: char-class */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 110) {

                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                        /* checking for: lit */
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                          /* checking for: when */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun48) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 119) {

                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 104) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 110) {

                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                      return ATtrue;
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquation has a ASF-Tag. 
 * \param[in] arg input ASF_ASFTestEquation
 * \return ATtrue if the ASF_ASFTestEquation had a ASF-Tag, or ATfalse otherwise
 */
ATbool ASF_hasASFTestEquationASFTag(ASF_ASFTestEquation arg) {
  if (ASF_isASFTestEquationSimple(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFTestEquationImplies(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFTestEquationWhen(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquation has a ws-after-ASF-Tag. 
 * \param[in] arg input ASF_ASFTestEquation
 * \return ATtrue if the ASF_ASFTestEquation had a ws-after-ASF-Tag, or ATfalse otherwise
 */
ATbool ASF_hasASFTestEquationWsAfterASFTag(ASF_ASFTestEquation arg) {
  if (ASF_isASFTestEquationSimple(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFTestEquationImplies(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFTestEquationWhen(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquation has a ASF-Condition. 
 * \param[in] arg input ASF_ASFTestEquation
 * \return ATtrue if the ASF_ASFTestEquation had a ASF-Condition, or ATfalse otherwise
 */
ATbool ASF_hasASFTestEquationASFCondition(ASF_ASFTestEquation arg) {
  if (ASF_isASFTestEquationSimple(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFTestEquationImplies(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFTestEquationWhen(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquation has a ASF-Conditions. 
 * \param[in] arg input ASF_ASFTestEquation
 * \return ATtrue if the ASF_ASFTestEquation had a ASF-Conditions, or ATfalse otherwise
 */
ATbool ASF_hasASFTestEquationASFConditions(ASF_ASFTestEquation arg) {
  if (ASF_isASFTestEquationImplies(arg)) {
    return ATtrue;
  }
  else if (ASF_isASFTestEquationWhen(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquation has a ws-after-ASF-Conditions. 
 * \param[in] arg input ASF_ASFTestEquation
 * \return ATtrue if the ASF_ASFTestEquation had a ws-after-ASF-Conditions, or ATfalse otherwise
 */
ATbool ASF_hasASFTestEquationWsAfterASFConditions(ASF_ASFTestEquation arg) {
  if (ASF_isASFTestEquationImplies(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquation has a ASF-Implies. 
 * \param[in] arg input ASF_ASFTestEquation
 * \return ATtrue if the ASF_ASFTestEquation had a ASF-Implies, or ATfalse otherwise
 */
ATbool ASF_hasASFTestEquationASFImplies(ASF_ASFTestEquation arg) {
  if (ASF_isASFTestEquationImplies(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquation has a ws-after-ASF-Implies. 
 * \param[in] arg input ASF_ASFTestEquation
 * \return ATtrue if the ASF_ASFTestEquation had a ws-after-ASF-Implies, or ATfalse otherwise
 */
ATbool ASF_hasASFTestEquationWsAfterASFImplies(ASF_ASFTestEquation arg) {
  if (ASF_isASFTestEquationImplies(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquation has a ws-after-ASF-Condition. 
 * \param[in] arg input ASF_ASFTestEquation
 * \return ATtrue if the ASF_ASFTestEquation had a ws-after-ASF-Condition, or ATfalse otherwise
 */
ATbool ASF_hasASFTestEquationWsAfterASFCondition(ASF_ASFTestEquation arg) {
  if (ASF_isASFTestEquationWhen(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ASFTestEquation has a ws-after-when. 
 * \param[in] arg input ASF_ASFTestEquation
 * \return ATtrue if the ASF_ASFTestEquation had a ws-after-when, or ATfalse otherwise
 */
ATbool ASF_hasASFTestEquationWsAfterWhen(ASF_ASFTestEquation arg) {
  if (ASF_isASFTestEquationWhen(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ASF-Tag ASF_ASFTag of a ASF_ASFTestEquation. Note that the precondition is that this ASF_ASFTestEquation actually has a ASF-Tag
 * \param[in] arg input ASF_ASFTestEquation
 * \return the ASF-Tag of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFTag ASF_getASFTestEquationASFTag(ASF_ASFTestEquation arg) {
  if (ASF_isASFTestEquationSimple(arg)) {
    return (ASF_ASFTag)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else if (ASF_isASFTestEquationImplies(arg)) {
    return (ASF_ASFTag)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else 
    return (ASF_ASFTag)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the ws-after-ASF-Tag ASF_OptLayout of a ASF_ASFTestEquation. Note that the precondition is that this ASF_ASFTestEquation actually has a ws-after-ASF-Tag
 * \param[in] arg input ASF_ASFTestEquation
 * \return the ws-after-ASF-Tag of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFTestEquationWsAfterASFTag(ASF_ASFTestEquation arg) {
  if (ASF_isASFTestEquationSimple(arg)) {
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else if (ASF_isASFTestEquationImplies(arg)) {
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else 
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ASF-Condition ASF_ASFCondition of a ASF_ASFTestEquation. Note that the precondition is that this ASF_ASFTestEquation actually has a ASF-Condition
 * \param[in] arg input ASF_ASFTestEquation
 * \return the ASF-Condition of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFCondition ASF_getASFTestEquationASFCondition(ASF_ASFTestEquation arg) {
  if (ASF_isASFTestEquationSimple(arg)) {
    return (ASF_ASFCondition)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
  }
  else if (ASF_isASFTestEquationImplies(arg)) {
    return (ASF_ASFCondition)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 6);
  }
  else 
    return (ASF_ASFCondition)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
}

/**
 * Get the ASF-Conditions ASF_ASFConditions of a ASF_ASFTestEquation. Note that the precondition is that this ASF_ASFTestEquation actually has a ASF-Conditions
 * \param[in] arg input ASF_ASFTestEquation
 * \return the ASF-Conditions of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFConditions ASF_getASFTestEquationASFConditions(ASF_ASFTestEquation arg) {
  if (ASF_isASFTestEquationImplies(arg)) {
    return (ASF_ASFConditions)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
  }
  else 
    return (ASF_ASFConditions)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 6);
}

/**
 * Get the ws-after-ASF-Conditions ASF_OptLayout of a ASF_ASFTestEquation. Note that the precondition is that this ASF_ASFTestEquation actually has a ws-after-ASF-Conditions
 * \param[in] arg input ASF_ASFTestEquation
 * \return the ws-after-ASF-Conditions of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFTestEquationWsAfterASFConditions(ASF_ASFTestEquation arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the ASF-Implies ASF_ASFImplies of a ASF_ASFTestEquation. Note that the precondition is that this ASF_ASFTestEquation actually has a ASF-Implies
 * \param[in] arg input ASF_ASFTestEquation
 * \return the ASF-Implies of #arg, if it exist or an undefined value if it does not
 */
ASF_ASFImplies ASF_getASFTestEquationASFImplies(ASF_ASFTestEquation arg) {
  
    return (ASF_ASFImplies)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-ASF-Implies ASF_OptLayout of a ASF_ASFTestEquation. Note that the precondition is that this ASF_ASFTestEquation actually has a ws-after-ASF-Implies
 * \param[in] arg input ASF_ASFTestEquation
 * \return the ws-after-ASF-Implies of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFTestEquationWsAfterASFImplies(ASF_ASFTestEquation arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-ASF-Condition ASF_OptLayout of a ASF_ASFTestEquation. Note that the precondition is that this ASF_ASFTestEquation actually has a ws-after-ASF-Condition
 * \param[in] arg input ASF_ASFTestEquation
 * \return the ws-after-ASF-Condition of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFTestEquationWsAfterASFCondition(ASF_ASFTestEquation arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the ws-after-when ASF_OptLayout of a ASF_ASFTestEquation. Note that the precondition is that this ASF_ASFTestEquation actually has a ws-after-when
 * \param[in] arg input ASF_ASFTestEquation
 * \return the ws-after-when of #arg, if it exist or an undefined value if it does not
 */
ASF_OptLayout ASF_getASFTestEquationWsAfterWhen(ASF_ASFTestEquation arg) {
  
    return (ASF_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Set the ASF-Tag of a ASF_ASFTestEquation. The precondition being that this ASF_ASFTestEquation actually has a ASF-Tag
 * \param[in] arg input ASF_ASFTestEquation
 * \param[in] ASFTag new ASF_ASFTag to set in #arg
 * \return A new ASF_ASFTestEquation with ASFTag at the right place, or a core dump if #arg did not have a ASFTag
 */
ASF_ASFTestEquation ASF_setASFTestEquationASFTag(ASF_ASFTestEquation arg, ASF_ASFTag ASFTag) {
  if (ASF_isASFTestEquationSimple(arg)) {
    return (ASF_ASFTestEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFTag), 0), 1);
  }
  else if (ASF_isASFTestEquationImplies(arg)) {
    return (ASF_ASFTestEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFTag), 0), 1);
  }
  else if (ASF_isASFTestEquationWhen(arg)) {
    return (ASF_ASFTestEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFTag), 0), 1);
  }

  ATabort("ASFTestEquation has no ASFTag: %t\n", arg);
  return (ASF_ASFTestEquation)NULL;
}

/**
 * Set the ws-after-ASF-Tag of a ASF_ASFTestEquation. The precondition being that this ASF_ASFTestEquation actually has a ws-after-ASF-Tag
 * \param[in] arg input ASF_ASFTestEquation
 * \param[in] wsAfterASFTag new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFTestEquation with wsAfterASFTag at the right place, or a core dump if #arg did not have a wsAfterASFTag
 */
ASF_ASFTestEquation ASF_setASFTestEquationWsAfterASFTag(ASF_ASFTestEquation arg, ASF_OptLayout wsAfterASFTag) {
  if (ASF_isASFTestEquationSimple(arg)) {
    return (ASF_ASFTestEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterASFTag), 1), 1);
  }
  else if (ASF_isASFTestEquationImplies(arg)) {
    return (ASF_ASFTestEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterASFTag), 1), 1);
  }
  else if (ASF_isASFTestEquationWhen(arg)) {
    return (ASF_ASFTestEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterASFTag), 1), 1);
  }

  ATabort("ASFTestEquation has no WsAfterASFTag: %t\n", arg);
  return (ASF_ASFTestEquation)NULL;
}

/**
 * Set the ASF-Condition of a ASF_ASFTestEquation. The precondition being that this ASF_ASFTestEquation actually has a ASF-Condition
 * \param[in] arg input ASF_ASFTestEquation
 * \param[in] ASFCondition new ASF_ASFCondition to set in #arg
 * \return A new ASF_ASFTestEquation with ASFCondition at the right place, or a core dump if #arg did not have a ASFCondition
 */
ASF_ASFTestEquation ASF_setASFTestEquationASFCondition(ASF_ASFTestEquation arg, ASF_ASFCondition ASFCondition) {
  if (ASF_isASFTestEquationSimple(arg)) {
    return (ASF_ASFTestEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFCondition), 2), 1);
  }
  else if (ASF_isASFTestEquationImplies(arg)) {
    return (ASF_ASFTestEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFCondition), 6), 1);
  }
  else if (ASF_isASFTestEquationWhen(arg)) {
    return (ASF_ASFTestEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFCondition), 2), 1);
  }

  ATabort("ASFTestEquation has no ASFCondition: %t\n", arg);
  return (ASF_ASFTestEquation)NULL;
}

/**
 * Set the ASF-Conditions of a ASF_ASFTestEquation. The precondition being that this ASF_ASFTestEquation actually has a ASF-Conditions
 * \param[in] arg input ASF_ASFTestEquation
 * \param[in] ASFConditions new ASF_ASFConditions to set in #arg
 * \return A new ASF_ASFTestEquation with ASFConditions at the right place, or a core dump if #arg did not have a ASFConditions
 */
ASF_ASFTestEquation ASF_setASFTestEquationASFConditions(ASF_ASFTestEquation arg, ASF_ASFConditions ASFConditions) {
  if (ASF_isASFTestEquationImplies(arg)) {
    return (ASF_ASFTestEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFConditions), 2), 1);
  }
  else if (ASF_isASFTestEquationWhen(arg)) {
    return (ASF_ASFTestEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFConditions), 6), 1);
  }

  ATabort("ASFTestEquation has no ASFConditions: %t\n", arg);
  return (ASF_ASFTestEquation)NULL;
}

/**
 * Set the ws-after-ASF-Conditions of a ASF_ASFTestEquation. The precondition being that this ASF_ASFTestEquation actually has a ws-after-ASF-Conditions
 * \param[in] arg input ASF_ASFTestEquation
 * \param[in] wsAfterASFConditions new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFTestEquation with wsAfterASFConditions at the right place, or a core dump if #arg did not have a wsAfterASFConditions
 */
ASF_ASFTestEquation ASF_setASFTestEquationWsAfterASFConditions(ASF_ASFTestEquation arg, ASF_OptLayout wsAfterASFConditions) {
  if (ASF_isASFTestEquationImplies(arg)) {
    return (ASF_ASFTestEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterASFConditions), 3), 1);
  }

  ATabort("ASFTestEquation has no WsAfterASFConditions: %t\n", arg);
  return (ASF_ASFTestEquation)NULL;
}

/**
 * Set the ASF-Implies of a ASF_ASFTestEquation. The precondition being that this ASF_ASFTestEquation actually has a ASF-Implies
 * \param[in] arg input ASF_ASFTestEquation
 * \param[in] ASFImplies new ASF_ASFImplies to set in #arg
 * \return A new ASF_ASFTestEquation with ASFImplies at the right place, or a core dump if #arg did not have a ASFImplies
 */
ASF_ASFTestEquation ASF_setASFTestEquationASFImplies(ASF_ASFTestEquation arg, ASF_ASFImplies ASFImplies) {
  if (ASF_isASFTestEquationImplies(arg)) {
    return (ASF_ASFTestEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ASFImplies), 4), 1);
  }

  ATabort("ASFTestEquation has no ASFImplies: %t\n", arg);
  return (ASF_ASFTestEquation)NULL;
}

/**
 * Set the ws-after-ASF-Implies of a ASF_ASFTestEquation. The precondition being that this ASF_ASFTestEquation actually has a ws-after-ASF-Implies
 * \param[in] arg input ASF_ASFTestEquation
 * \param[in] wsAfterASFImplies new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFTestEquation with wsAfterASFImplies at the right place, or a core dump if #arg did not have a wsAfterASFImplies
 */
ASF_ASFTestEquation ASF_setASFTestEquationWsAfterASFImplies(ASF_ASFTestEquation arg, ASF_OptLayout wsAfterASFImplies) {
  if (ASF_isASFTestEquationImplies(arg)) {
    return (ASF_ASFTestEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterASFImplies), 5), 1);
  }

  ATabort("ASFTestEquation has no WsAfterASFImplies: %t\n", arg);
  return (ASF_ASFTestEquation)NULL;
}

/**
 * Set the ws-after-ASF-Condition of a ASF_ASFTestEquation. The precondition being that this ASF_ASFTestEquation actually has a ws-after-ASF-Condition
 * \param[in] arg input ASF_ASFTestEquation
 * \param[in] wsAfterASFCondition new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFTestEquation with wsAfterASFCondition at the right place, or a core dump if #arg did not have a wsAfterASFCondition
 */
ASF_ASFTestEquation ASF_setASFTestEquationWsAfterASFCondition(ASF_ASFTestEquation arg, ASF_OptLayout wsAfterASFCondition) {
  if (ASF_isASFTestEquationWhen(arg)) {
    return (ASF_ASFTestEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterASFCondition), 3), 1);
  }

  ATabort("ASFTestEquation has no WsAfterASFCondition: %t\n", arg);
  return (ASF_ASFTestEquation)NULL;
}

/**
 * Set the ws-after-when of a ASF_ASFTestEquation. The precondition being that this ASF_ASFTestEquation actually has a ws-after-when
 * \param[in] arg input ASF_ASFTestEquation
 * \param[in] wsAfterWhen new ASF_OptLayout to set in #arg
 * \return A new ASF_ASFTestEquation with wsAfterWhen at the right place, or a core dump if #arg did not have a wsAfterWhen
 */
ASF_ASFTestEquation ASF_setASFTestEquationWsAfterWhen(ASF_ASFTestEquation arg, ASF_OptLayout wsAfterWhen) {
  if (ASF_isASFTestEquationWhen(arg)) {
    return (ASF_ASFTestEquation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterWhen), 5), 1);
  }

  ATabort("ASFTestEquation has no WsAfterWhen: %t\n", arg);
  return (ASF_ASFTestEquation)NULL;
}

/**
 * Assert whether a ASF_LexLayout is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_LexLayout
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidLexLayout(ASF_LexLayout arg) {
  if (ASF_isLexLayoutWhitespace(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexLayout is a whitespace by checking against the following ATerm pattern: appl(prod([char-class([range(9,10),13,32])],lex(layout),attrs([term(cons("whitespace"))])),[<"ch"(char)>]). Always returns ATtrue
 * \param[in] arg input ASF_LexLayout
 * \return ATtrue if #arg corresponds to the signature of a whitespace, or ATfalse otherwise
 */
inline ATbool ASF_isLexLayoutWhitespace(ASF_LexLayout arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: char-class */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun21) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
            ATerm arg_arg0_arg0_head_arg0_head;
            ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
            /* checking for: range */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
              ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 9) {

                ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 10) {

                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                    arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                    arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                    if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 13) {

                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                        arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                        if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 32) {

                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                              /* checking for: lex */
                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun6) {
                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun4) {
                                  ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                  /* checking for: attrs */
                                  if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                    ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                      ATerm arg_arg0_arg2_arg0_head;
                                      ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                      arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                      arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                      /* checking for: term */
                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                        ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                        /* checking for: cons */
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                          ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                          /* checking for: whitespace */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun65) {
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                ATerm arg_arg1_head;
                                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                    return ATtrue;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexLayout has a ch. 
 * \param[in] arg input ASF_LexLayout
 * \return ATtrue if the ASF_LexLayout had a ch, or ATfalse otherwise
 */
ATbool ASF_hasLexLayoutCh(ASF_LexLayout arg) {
  if (ASF_isLexLayoutWhitespace(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ch char of a ASF_LexLayout. Note that the precondition is that this ASF_LexLayout actually has a ch
 * \param[in] arg input ASF_LexLayout
 * \return the ch of #arg, if it exist or an undefined value if it does not
 */
char ASF_getLexLayoutCh(ASF_LexLayout arg) {
  
    return (char)ASF_charToByte((ATerm)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)));
}

/**
 * Set the ch of a ASF_LexLayout. The precondition being that this ASF_LexLayout actually has a ch
 * \param[in] arg input ASF_LexLayout
 * \param[in] ch new char to set in #arg
 * \return A new ASF_LexLayout with ch at the right place, or a core dump if #arg did not have a ch
 */
ASF_LexLayout ASF_setLexLayoutCh(ASF_LexLayout arg, char ch) {
  if (ASF_isLexLayoutWhitespace(arg)) {
    return (ASF_LexLayout)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) ASF_byteToChar(ch))), 0), 1);
  }

  ATabort("LexLayout has no Ch: %t\n", arg);
  return (ASF_LexLayout)NULL;
}

/**
 * Assert whether a ASF_LexNumChar is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_LexNumChar
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidLexNumChar(ASF_LexNumChar arg) {
  if (ASF_isLexNumCharDigits(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexNumChar is a digits by checking against the following ATerm pattern: appl(prod([char-class([92]),lex(iter(char-class([range(48,57)])))],lex(sort("NumChar")),attrs([term(cons("digits"))])),[92,appl(list(lex(iter(char-class([range(48,57)])))),<"number"(chars)>)]). Always returns ATtrue
 * \param[in] arg input ASF_LexNumChar
 * \return ATtrue if #arg corresponds to the signature of a digits, or ATfalse otherwise
 */
inline ATbool ASF_isLexNumCharDigits(ASF_LexNumChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: char-class */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun21) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
            ATerm arg_arg0_arg0_head_arg0_head;
            ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
            if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 92) {

              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                  /* checking for: lex */
                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun6) {
                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                    /* checking for: iter */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun7) {
                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                      /* checking for: char-class */
                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun21) {
                        ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0) == ATfalse) {
                          ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head;
                          ATermList arg_arg0_arg0_head_arg0_arg0_arg0_list = (ATermList)arg_arg0_arg0_head_arg0_arg0_arg0;
                          arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                          arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                          /* checking for: range */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0_head) == ASF_afun25) {
                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 0);
                            if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0) == 48) {

                              ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 1);
                              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1) == 57) {

                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATtrue) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                    ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                    /* checking for: lex */
                                    if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun6) {
                                      ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                        ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                        /* checking for: NumChar */
                                        if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun66) {
                                          ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                          /* checking for: attrs */
                                          if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                            ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                              ATerm arg_arg0_arg2_arg0_head;
                                              ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                              arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                              arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                              /* checking for: term */
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                /* checking for: cons */
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                  ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                  /* checking for: digits */
                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun67) {
                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                      ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                      if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                        ATerm arg_arg1_head;
                                                        ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                        if (ATgetInt((ATermInt)arg_arg1_head) == 92) {

                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                            /* checking for: appl */
                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                              /* checking for: list */
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun8) {
                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                /* checking for: lex */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == ASF_afun6) {
                                                                  ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                  /* checking for: iter */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == ASF_afun7) {
                                                                    ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                    /* checking for: char-class */
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == ASF_afun21) {
                                                                      ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == ATfalse) {
                                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head;
                                                                        ATermList arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0;
                                                                        arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                        arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                        /* checking for: range */
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == ASF_afun25) {
                                                                          ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 0);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0) == 48) {

                                                                            ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 1);
                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1) == 57) {

                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATtrue) {
                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST) {
                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                    return ATtrue;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexNumChar has a number. 
 * \param[in] arg input ASF_LexNumChar
 * \return ATtrue if the ASF_LexNumChar had a number, or ATfalse otherwise
 */
ATbool ASF_hasLexNumCharNumber(ASF_LexNumChar arg) {
  if (ASF_isLexNumCharDigits(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the number char* of a ASF_LexNumChar. Note that the precondition is that this ASF_LexNumChar actually has a number
 * \param[in] arg input ASF_LexNumChar
 * \return the number of #arg, if it exist or an undefined value if it does not
 */
char* ASF_getLexNumCharNumber(ASF_LexNumChar arg) {
  
    return (char*)ASF_charsToString((ATerm)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1), 1));
}

/**
 * Set the number of a ASF_LexNumChar. The precondition being that this ASF_LexNumChar actually has a number
 * \param[in] arg input ASF_LexNumChar
 * \param[in] number new const char* to set in #arg
 * \return A new ASF_LexNumChar with number at the right place, or a core dump if #arg did not have a number
 */
ASF_LexNumChar ASF_setLexNumCharNumber(ASF_LexNumChar arg, const char* number) {
  if (ASF_isLexNumCharDigits(arg)) {
    return (ASF_LexNumChar)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1), (ATerm)((ATerm) ((ATerm) ASF_stringToChars(number))), 1), 1), 1);
  }

  ATabort("LexNumChar has no Number: %t\n", arg);
  return (ASF_LexNumChar)NULL;
}

/**
 * Assert whether a ASF_NumChar is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_NumChar
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidNumChar(ASF_NumChar arg) {
  if (ASF_isNumCharLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_NumChar is a Lex-to-cf by checking against the following ATerm pattern: appl(prod([lex(sort("NumChar"))],cf(sort("NumChar")),no-attrs),[<"NumChar"("Lex-NumChar")>]). Always returns ATtrue
 * \param[in] arg input ASF_NumChar
 * \return ATtrue if #arg corresponds to the signature of a Lex-to-cf, or ATfalse otherwise
 */
inline ATbool ASF_isNumCharLexToCf(ASF_NumChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: NumChar */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun66) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: NumChar */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun66) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: no-attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun5) {
                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                          arg_arg1_list = ATgetNext(arg_arg1_list);
                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_NumChar has a NumChar. 
 * \param[in] arg input ASF_NumChar
 * \return ATtrue if the ASF_NumChar had a NumChar, or ATfalse otherwise
 */
ATbool ASF_hasNumCharNumChar(ASF_NumChar arg) {
  if (ASF_isNumCharLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the NumChar ASF_LexNumChar of a ASF_NumChar. Note that the precondition is that this ASF_NumChar actually has a NumChar
 * \param[in] arg input ASF_NumChar
 * \return the NumChar of #arg, if it exist or an undefined value if it does not
 */
ASF_LexNumChar ASF_getNumCharNumChar(ASF_NumChar arg) {
  
    return (ASF_LexNumChar)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the NumChar of a ASF_NumChar. The precondition being that this ASF_NumChar actually has a NumChar
 * \param[in] arg input ASF_NumChar
 * \param[in] NumChar new ASF_LexNumChar to set in #arg
 * \return A new ASF_NumChar with NumChar at the right place, or a core dump if #arg did not have a NumChar
 */
ASF_NumChar ASF_setNumCharNumChar(ASF_NumChar arg, ASF_LexNumChar NumChar) {
  if (ASF_isNumCharLexToCf(arg)) {
    return (ASF_NumChar)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) NumChar), 0), 1);
  }

  ATabort("NumChar has no NumChar: %t\n", arg);
  return (ASF_NumChar)NULL;
}

/**
 * Assert whether a ASF_LexShortChar is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_LexShortChar
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidLexShortChar(ASF_LexShortChar arg) {
  if (ASF_isLexShortCharRegular(arg)) {
    return ATtrue;
  }
  else if (ASF_isLexShortCharEscaped(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexShortChar is a regular by checking against the following ATerm pattern: appl(prod([char-class([range(48,57),range(65,90),range(97,122)])],lex(sort("ShortChar")),attrs([term(cons("regular"))])),[<"character"(char)>]). May not be used to assert correctness of the ASF_LexShortChar
 * \param[in] arg input ASF_LexShortChar
 * \return ATtrue if #arg corresponds to the signature of a regular, or ATfalse otherwise
 */
inline ATbool ASF_isLexShortCharRegular(ASF_LexShortChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: char-class */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun21) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
            ATerm arg_arg0_arg0_head_arg0_head;
            ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
            /* checking for: range */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
              ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 48) {

                ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 57) {

                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                    arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                    arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                    /* checking for: range */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
                      ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 65) {

                        ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                        if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 90) {

                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                            /* checking for: range */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
                              ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 97) {

                                ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 122) {

                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                      /* checking for: lex */
                                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun6) {
                                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                          /* checking for: ShortChar */
                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun68) {
                                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                            /* checking for: attrs */
                                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                              ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                ATerm arg_arg0_arg2_arg0_head;
                                                ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                /* checking for: term */
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                  ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                  /* checking for: cons */
                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                    ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                    /* checking for: regular */
                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun69) {
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                          ATerm arg_arg1_head;
                                                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                              return ATtrue;
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexShortChar is a escaped by checking against the following ATerm pattern: appl(prod([char-class([92]),char-class([range(32,47),range(58,64),range(91,96),110,114,116,range(123,255)])],lex(sort("ShortChar")),attrs([term(cons("escaped"))])),[92,<"escape"(char)>]). May not be used to assert correctness of the ASF_LexShortChar
 * \param[in] arg input ASF_LexShortChar
 * \return ATtrue if #arg corresponds to the signature of a escaped, or ATfalse otherwise
 */
inline ATbool ASF_isLexShortCharEscaped(ASF_LexShortChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: char-class */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun21) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
            ATerm arg_arg0_arg0_head_arg0_head;
            ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
            if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 92) {

              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                  /* checking for: char-class */
                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun21) {
                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
                      ATerm arg_arg0_arg0_head_arg0_head;
                      ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
                      arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                      arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                      /* checking for: range */
                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
                        ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                        if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 32) {

                          ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                          if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 47) {

                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                              arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                              /* checking for: range */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
                                ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 58) {

                                  ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                                  if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 64) {

                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                      arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                      /* checking for: range */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
                                        ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                                        if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 91) {

                                          ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                                          if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 96) {

                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                                              arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                              arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 110) {

                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                                                  arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                                  arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                                  if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 114) {

                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                                                      arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                                      arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 116) {

                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                                          arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                                          /* checking for: range */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == ASF_afun25) {
                                                            ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                                                            if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 123) {

                                                              ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                                                              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 255) {

                                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                    ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                    /* checking for: lex */
                                                                    if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun6) {
                                                                      ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                      /* checking for: sort */
                                                                      if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                                                                        ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                        /* checking for: ShortChar */
                                                                        if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun68) {
                                                                          ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                          /* checking for: attrs */
                                                                          if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                                                                            ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                              ATerm arg_arg0_arg2_arg0_head;
                                                                              ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                              arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                              arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                              /* checking for: term */
                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                                                                                ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                /* checking for: cons */
                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                                                                                  ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                  /* checking for: escaped */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun70) {
                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                      ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                      if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                        ATerm arg_arg1_head;
                                                                                        ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head) == 92) {

                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                return ATtrue;
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexShortChar has a character. 
 * \param[in] arg input ASF_LexShortChar
 * \return ATtrue if the ASF_LexShortChar had a character, or ATfalse otherwise
 */
ATbool ASF_hasLexShortCharCharacter(ASF_LexShortChar arg) {
  if (ASF_isLexShortCharRegular(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_LexShortChar has a escape. 
 * \param[in] arg input ASF_LexShortChar
 * \return ATtrue if the ASF_LexShortChar had a escape, or ATfalse otherwise
 */
ATbool ASF_hasLexShortCharEscape(ASF_LexShortChar arg) {
  if (ASF_isLexShortCharEscaped(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the character char of a ASF_LexShortChar. Note that the precondition is that this ASF_LexShortChar actually has a character
 * \param[in] arg input ASF_LexShortChar
 * \return the character of #arg, if it exist or an undefined value if it does not
 */
char ASF_getLexShortCharCharacter(ASF_LexShortChar arg) {
  
    return (char)ASF_charToByte((ATerm)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)));
}

/**
 * Get the escape char of a ASF_LexShortChar. Note that the precondition is that this ASF_LexShortChar actually has a escape
 * \param[in] arg input ASF_LexShortChar
 * \return the escape of #arg, if it exist or an undefined value if it does not
 */
char ASF_getLexShortCharEscape(ASF_LexShortChar arg) {
  
    return (char)ASF_charToByte((ATerm)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1));
}

/**
 * Set the character of a ASF_LexShortChar. The precondition being that this ASF_LexShortChar actually has a character
 * \param[in] arg input ASF_LexShortChar
 * \param[in] character new char to set in #arg
 * \return A new ASF_LexShortChar with character at the right place, or a core dump if #arg did not have a character
 */
ASF_LexShortChar ASF_setLexShortCharCharacter(ASF_LexShortChar arg, char character) {
  if (ASF_isLexShortCharRegular(arg)) {
    return (ASF_LexShortChar)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) ASF_byteToChar(character))), 0), 1);
  }

  ATabort("LexShortChar has no Character: %t\n", arg);
  return (ASF_LexShortChar)NULL;
}

/**
 * Set the escape of a ASF_LexShortChar. The precondition being that this ASF_LexShortChar actually has a escape
 * \param[in] arg input ASF_LexShortChar
 * \param[in] escape new char to set in #arg
 * \return A new ASF_LexShortChar with escape at the right place, or a core dump if #arg did not have a escape
 */
ASF_LexShortChar ASF_setLexShortCharEscape(ASF_LexShortChar arg, char escape) {
  if (ASF_isLexShortCharEscaped(arg)) {
    return (ASF_LexShortChar)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) ASF_byteToChar(escape))), 1), 1);
  }

  ATabort("LexShortChar has no Escape: %t\n", arg);
  return (ASF_LexShortChar)NULL;
}

/**
 * Assert whether a ASF_ShortChar is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_ShortChar
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidShortChar(ASF_ShortChar arg) {
  if (ASF_isShortCharLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ShortChar is a Lex-to-cf by checking against the following ATerm pattern: appl(prod([lex(sort("ShortChar"))],cf(sort("ShortChar")),no-attrs),[<"ShortChar"("Lex-ShortChar")>]). Always returns ATtrue
 * \param[in] arg input ASF_ShortChar
 * \return ATtrue if #arg corresponds to the signature of a Lex-to-cf, or ATfalse otherwise
 */
inline ATbool ASF_isShortCharLexToCf(ASF_ShortChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: ShortChar */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun68) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: ShortChar */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun68) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: no-attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun5) {
                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                          arg_arg1_list = ATgetNext(arg_arg1_list);
                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_ShortChar has a ShortChar. 
 * \param[in] arg input ASF_ShortChar
 * \return ATtrue if the ASF_ShortChar had a ShortChar, or ATfalse otherwise
 */
ATbool ASF_hasShortCharShortChar(ASF_ShortChar arg) {
  if (ASF_isShortCharLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ShortChar ASF_LexShortChar of a ASF_ShortChar. Note that the precondition is that this ASF_ShortChar actually has a ShortChar
 * \param[in] arg input ASF_ShortChar
 * \return the ShortChar of #arg, if it exist or an undefined value if it does not
 */
ASF_LexShortChar ASF_getShortCharShortChar(ASF_ShortChar arg) {
  
    return (ASF_LexShortChar)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the ShortChar of a ASF_ShortChar. The precondition being that this ASF_ShortChar actually has a ShortChar
 * \param[in] arg input ASF_ShortChar
 * \param[in] ShortChar new ASF_LexShortChar to set in #arg
 * \return A new ASF_ShortChar with ShortChar at the right place, or a core dump if #arg did not have a ShortChar
 */
ASF_ShortChar ASF_setShortCharShortChar(ASF_ShortChar arg, ASF_LexShortChar ShortChar) {
  if (ASF_isShortCharLexToCf(arg)) {
    return (ASF_ShortChar)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ShortChar), 0), 1);
  }

  ATabort("ShortChar has no ShortChar: %t\n", arg);
  return (ASF_ShortChar)NULL;
}

/**
 * Assert whether a ASF_Character is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input ASF_Character
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool ASF_isValidCharacter(ASF_Character arg) {
  if (ASF_isCharacterNumeric(arg)) {
    return ATtrue;
  }
  else if (ASF_isCharacterShort(arg)) {
    return ATtrue;
  }
  else if (ASF_isCharacterTop(arg)) {
    return ATtrue;
  }
  else if (ASF_isCharacterEof(arg)) {
    return ATtrue;
  }
  else if (ASF_isCharacterBot(arg)) {
    return ATtrue;
  }
  else if (ASF_isCharacterLabelUnderscoreStart(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Character is a numeric by checking against the following ATerm pattern: appl(prod([cf(sort("NumChar"))],cf(sort("Character")),attrs([term(cons("numeric"))])),[<"NumChar"("NumChar")>]). May not be used to assert correctness of the ASF_Character
 * \param[in] arg input ASF_Character
 * \return ATtrue if #arg corresponds to the signature of a numeric, or ATfalse otherwise
 */
inline ATbool ASF_isCharacterNumeric(ASF_Character arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: NumChar */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun66) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: Character */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun71) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                          ATerm arg_arg0_arg2_arg0_head;
                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                          /* checking for: term */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                            /* checking for: cons */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                              /* checking for: numeric */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun72) {
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Character is a short by checking against the following ATerm pattern: appl(prod([cf(sort("ShortChar"))],cf(sort("Character")),attrs([term(cons("short"))])),[<"ShortChar"("ShortChar")>]). May not be used to assert correctness of the ASF_Character
 * \param[in] arg input ASF_Character
 * \return ATtrue if #arg corresponds to the signature of a short, or ATfalse otherwise
 */
inline ATbool ASF_isCharacterShort(ASF_Character arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun12) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: ShortChar */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == ASF_afun68) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: Character */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun71) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                          ATerm arg_arg0_arg2_arg0_head;
                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                          /* checking for: term */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                            /* checking for: cons */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                              /* checking for: short */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun73) {
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Character is a top by checking against the following ATerm pattern: appl(prod([lit("\\TOP")],cf(sort("Character")),attrs([term(cons("top"))])),[appl(prod([char-class([92]),char-class([84]),char-class([79]),char-class([80])],lit("\\TOP"),no-attrs),[92,84,79,80])]). May not be used to assert correctness of the ASF_Character
 * \param[in] arg input ASF_Character
 * \return ATtrue if #arg corresponds to the signature of a top, or ATfalse otherwise
 */
inline ATbool ASF_isCharacterTop(ASF_Character arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: \TOP */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun74) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: Character */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun71) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: top */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun75) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 92) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 84) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 79) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 80) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                /* checking for: lit */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                  /* checking for: \TOP */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun74) {
                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                    /* checking for: no-attrs */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 92) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 84) {

                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 79) {

                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 80) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                          return ATtrue;
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Character is a eof by checking against the following ATerm pattern: appl(prod([lit("\\EOF")],cf(sort("Character")),attrs([term(cons("eof"))])),[appl(prod([char-class([92]),char-class([69]),char-class([79]),char-class([70])],lit("\\EOF"),no-attrs),[92,69,79,70])]). May not be used to assert correctness of the ASF_Character
 * \param[in] arg input ASF_Character
 * \return ATtrue if #arg corresponds to the signature of a eof, or ATfalse otherwise
 */
inline ATbool ASF_isCharacterEof(ASF_Character arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: \EOF */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun76) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: Character */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun71) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: eof */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun77) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 92) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 69) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 79) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 70) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                /* checking for: lit */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                  /* checking for: \EOF */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun76) {
                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                    /* checking for: no-attrs */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 92) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 69) {

                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 79) {

                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 70) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                          return ATtrue;
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Character is a bot by checking against the following ATerm pattern: appl(prod([lit("\\BOT")],cf(sort("Character")),attrs([term(cons("bot"))])),[appl(prod([char-class([92]),char-class([66]),char-class([79]),char-class([84])],lit("\\BOT"),no-attrs),[92,66,79,84])]). May not be used to assert correctness of the ASF_Character
 * \param[in] arg input ASF_Character
 * \return ATtrue if #arg corresponds to the signature of a bot, or ATfalse otherwise
 */
inline ATbool ASF_isCharacterBot(ASF_Character arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: \BOT */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun78) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: Character */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun71) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: bot */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun79) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 92) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 66) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 79) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 84) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                /* checking for: lit */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                  /* checking for: \BOT */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun78) {
                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                    /* checking for: no-attrs */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 92) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 66) {

                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 79) {

                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 84) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                          return ATtrue;
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Character is a label_start by checking against the following ATerm pattern: appl(prod([lit("\\LABEL_START")],cf(sort("Character")),attrs([term(cons("label_start"))])),[appl(prod([char-class([92]),char-class([76]),char-class([65]),char-class([66]),char-class([69]),char-class([76]),char-class([95]),char-class([83]),char-class([84]),char-class([65]),char-class([82]),char-class([84])],lit("\\LABEL_START"),no-attrs),[92,76,65,66,69,76,95,83,84,65,82,84])]). May not be used to assert correctness of the ASF_Character
 * \param[in] arg input ASF_Character
 * \return ATtrue if #arg corresponds to the signature of a label_start, or ATfalse otherwise
 */
inline ATbool ASF_isCharacterLabelUnderscoreStart(ASF_Character arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == ASF_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == ASF_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == ASF_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: \LABEL_START */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == ASF_afun80) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == ASF_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == ASF_afun12) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: Character */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == ASF_afun71) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == ASF_afun17) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == ASF_afun18) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == ASF_afun19) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: label_start */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == ASF_afun81) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == ASF_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == ASF_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 92) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 76) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 65) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 66) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                /* checking for: char-class */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 69) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                          /* checking for: char-class */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 76) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                    /* checking for: char-class */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 95) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                              /* checking for: char-class */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 83) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                        /* checking for: char-class */
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 84) {

                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                  /* checking for: char-class */
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 65) {

                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                            /* checking for: char-class */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 82) {

                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                      /* checking for: char-class */
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == ASF_afun21) {
                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 84) {

                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                /* checking for: lit */
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == ASF_afun9) {
                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                  /* checking for: \LABEL_START */
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == ASF_afun80) {
                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                    /* checking for: no-attrs */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == ASF_afun5) {
                                                                                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 92) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 76) {

                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 65) {

                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 66) {

                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 69) {

                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 76) {

                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 95) {

                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 83) {

                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 84) {

                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 65) {

                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 82) {

                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 84) {

                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                          return ATtrue;
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Character has a NumChar. 
 * \param[in] arg input ASF_Character
 * \return ATtrue if the ASF_Character had a NumChar, or ATfalse otherwise
 */
ATbool ASF_hasCharacterNumChar(ASF_Character arg) {
  if (ASF_isCharacterNumeric(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a ASF_Character has a ShortChar. 
 * \param[in] arg input ASF_Character
 * \return ATtrue if the ASF_Character had a ShortChar, or ATfalse otherwise
 */
ATbool ASF_hasCharacterShortChar(ASF_Character arg) {
  if (ASF_isCharacterShort(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the NumChar ASF_NumChar of a ASF_Character. Note that the precondition is that this ASF_Character actually has a NumChar
 * \param[in] arg input ASF_Character
 * \return the NumChar of #arg, if it exist or an undefined value if it does not
 */
ASF_NumChar ASF_getCharacterNumChar(ASF_Character arg) {
  
    return (ASF_NumChar)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the ShortChar ASF_ShortChar of a ASF_Character. Note that the precondition is that this ASF_Character actually has a ShortChar
 * \param[in] arg input ASF_Character
 * \return the ShortChar of #arg, if it exist or an undefined value if it does not
 */
ASF_ShortChar ASF_getCharacterShortChar(ASF_Character arg) {
  
    return (ASF_ShortChar)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the NumChar of a ASF_Character. The precondition being that this ASF_Character actually has a NumChar
 * \param[in] arg input ASF_Character
 * \param[in] NumChar new ASF_NumChar to set in #arg
 * \return A new ASF_Character with NumChar at the right place, or a core dump if #arg did not have a NumChar
 */
ASF_Character ASF_setCharacterNumChar(ASF_Character arg, ASF_NumChar NumChar) {
  if (ASF_isCharacterNumeric(arg)) {
    return (ASF_Character)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) NumChar), 0), 1);
  }

  ATabort("Character has no NumChar: %t\n", arg);
  return (ASF_Character)NULL;
}

/**
 * Set the ShortChar of a ASF_Character. The precondition being that this ASF_Character actually has a ShortChar
 * \param[in] arg input ASF_Character
 * \param[in] ShortChar new ASF_ShortChar to set in #arg
 * \return A new ASF_Character with ShortChar at the right place, or a core dump if #arg did not have a ShortChar
 */
ASF_Character ASF_setCharacterShortChar(ASF_Character arg, ASF_ShortChar ShortChar) {
  if (ASF_isCharacterShort(arg)) {
    return (ASF_Character)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ShortChar), 0), 1);
  }

  ATabort("Character has no ShortChar: %t\n", arg);
  return (ASF_Character)NULL;
}

/**
 * Apply functions to the children of a ASF_OptLayout. 
 * \return A new ASF_OptLayout with new children where the argument functions might have applied
 */
ASF_OptLayout ASF_visitOptLayout(ASF_OptLayout arg, ASF_Layout (*acceptLayout)(ASF_Layout)) {
  if (ASF_isOptLayoutAbsent(arg)) {
    return ASF_makeOptLayoutAbsent();
  }
  if (ASF_isOptLayoutPresent(arg)) {
    return ASF_makeOptLayoutPresent(
        acceptLayout ? acceptLayout(ASF_getOptLayoutLayout(arg)) : ASF_getOptLayoutLayout(arg));
  }
  ATabort("not a OptLayout: %t\n", arg);
  return (ASF_OptLayout)NULL;
}
/**
 * Apply functions to the children of a ASF_Layout. 
 * \return A new ASF_Layout with new children where the argument functions might have applied
 */
ASF_Layout ASF_visitLayout(ASF_Layout arg, ASF_LexLayoutList (*acceptList)(ASF_LexLayoutList)) {
  if (ASF_isLayoutLexToCf(arg)) {
    return ASF_makeLayoutLexToCf(
        acceptList ? acceptList(ASF_getLayoutList(arg)) : ASF_getLayoutList(arg));
  }
  ATabort("not a Layout: %t\n", arg);
  return (ASF_Layout)NULL;
}
/**
 * Apply functions to the children of a ASF_LexLayoutList. 
 * \return A new ASF_LexLayoutList with new children where the argument functions might have applied
 */
ASF_LexLayoutList ASF_visitLexLayoutList(ASF_LexLayoutList arg, ASF_LexLayout (*acceptHead)(ASF_LexLayout)) {
  if (ASF_isLexLayoutListEmpty(arg)) {
    return ASF_makeLexLayoutListEmpty();
  }
  if (ASF_isLexLayoutListSingle(arg)) {
    return ASF_makeLexLayoutListSingle(
        acceptHead ? acceptHead(ASF_getLexLayoutListHead(arg)) : ASF_getLexLayoutListHead(arg));
  }
  if (ASF_isLexLayoutListMany(arg)) {
    return ASF_makeLexLayoutListMany(
        acceptHead ? acceptHead(ASF_getLexLayoutListHead(arg)) : ASF_getLexLayoutListHead(arg),
        ASF_visitLexLayoutList(ASF_getLexLayoutListTail(arg), acceptHead));
  }
  ATabort("not a LexLayoutList: %t\n", arg);
  return (ASF_LexLayoutList)NULL;
}
/**
 * Apply functions to the children of a ASF_Tree. 
 * \return A new ASF_Tree with new children where the argument functions might have applied
 */
ASF_Tree ASF_visitTree(ASF_Tree arg, ATerm (*acceptTree)(ATerm), ASF_OptLayout (*acceptWsAfterAmb)(ASF_OptLayout), ASF_OptLayout (*acceptWsAfterParenOpen)(ASF_OptLayout), ASF_TreeAmbs (*acceptAmbs)(ASF_TreeAmbs), ASF_OptLayout (*acceptWsAfterAmbs)(ASF_OptLayout), ASF_OptLayout (*acceptWsAfterName)(ASF_OptLayout), ASF_CHARList (*acceptList)(ASF_CHARList), ASF_OptLayout (*acceptWsAfterList)(ASF_OptLayout)) {
  if (ASF_isTreeCast(arg)) {
    return ASF_makeTreeCast(
        acceptTree ? acceptTree(ASF_getTreeTree(arg)) : ASF_getTreeTree(arg));
  }
  if (ASF_isTreeAmbiguityConstructor(arg)) {
    return ASF_makeTreeAmbiguityConstructor(
        acceptWsAfterAmb ? acceptWsAfterAmb(ASF_getTreeWsAfterAmb(arg)) : ASF_getTreeWsAfterAmb(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(ASF_getTreeWsAfterParenOpen(arg)) : ASF_getTreeWsAfterParenOpen(arg),
        acceptAmbs ? acceptAmbs(ASF_getTreeAmbs(arg)) : ASF_getTreeAmbs(arg),
        acceptWsAfterAmbs ? acceptWsAfterAmbs(ASF_getTreeWsAfterAmbs(arg)) : ASF_getTreeWsAfterAmbs(arg));
  }
  if (ASF_isTreeLexicalConstructor(arg)) {
    return ASF_makeTreeLexicalConstructor(
        ASF_visitTree(ASF_getTreeName(arg), acceptTree, acceptWsAfterAmb, acceptWsAfterParenOpen, acceptAmbs, acceptWsAfterAmbs, acceptWsAfterName, acceptList, acceptWsAfterList),
        acceptWsAfterName ? acceptWsAfterName(ASF_getTreeWsAfterName(arg)) : ASF_getTreeWsAfterName(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(ASF_getTreeWsAfterParenOpen(arg)) : ASF_getTreeWsAfterParenOpen(arg),
        acceptList ? acceptList(ASF_getTreeList(arg)) : ASF_getTreeList(arg),
        acceptWsAfterList ? acceptWsAfterList(ASF_getTreeWsAfterList(arg)) : ASF_getTreeWsAfterList(arg));
  }
  ATabort("not a Tree: %t\n", arg);
  return (ASF_Tree)NULL;
}
/**
 * Apply functions to the children of a ASF_LexCHAR. 
 * \return A new ASF_LexCHAR with new children where the argument functions might have applied
 */
ASF_LexCHAR ASF_visitLexCHAR(ASF_LexCHAR arg, char (*acceptValue)(char)) {
  if (ASF_isLexCHARDefault(arg)) {
    return ASF_makeLexCHARDefault(
        acceptValue ? acceptValue(ASF_getLexCHARValue(arg)) : ASF_getLexCHARValue(arg));
  }
  ATabort("not a LexCHAR: %t\n", arg);
  return (ASF_LexCHAR)NULL;
}
/**
 * Apply functions to the children of a ASF_CHAR. 
 * \return A new ASF_CHAR with new children where the argument functions might have applied
 */
ASF_CHAR ASF_visitCHAR(ASF_CHAR arg, ASF_LexCHAR (*acceptCHAR)(ASF_LexCHAR)) {
  if (ASF_isCHARLexToCf(arg)) {
    return ASF_makeCHARLexToCf(
        acceptCHAR ? acceptCHAR(ASF_getCHARCHAR(arg)) : ASF_getCHARCHAR(arg));
  }
  ATabort("not a CHAR: %t\n", arg);
  return (ASF_CHAR)NULL;
}
/**
 * Apply functions to the children of a ASF_ASFCondition. 
 * \return A new ASF_ASFCondition with new children where the argument functions might have applied
 */
ASF_ASFCondition ASF_visitASFCondition(ASF_ASFCondition arg, ATerm (*acceptTypeOfLhs)(ATerm), ATerm (*acceptTypeOfRhs)(ATerm), ASF_Tree (*acceptLhs)(ASF_Tree), ASF_OptLayout (*acceptWsAfterLhs)(ASF_OptLayout), ASF_OptLayout (*acceptWsAfterUnequal)(ASF_OptLayout), ASF_Tree (*acceptRhs)(ASF_Tree), ASF_OptLayout (*acceptWsAfterEquality)(ASF_OptLayout), ASF_OptLayout (*acceptWsAfterMatch)(ASF_OptLayout)) {
  if (ASF_isASFConditionNegative(arg)) {
    return ASF_makeASFConditionNegative(
        acceptTypeOfLhs ? acceptTypeOfLhs(ASF_getASFConditionTypeOfLhs(arg)) : ASF_getASFConditionTypeOfLhs(arg),
        acceptTypeOfRhs ? acceptTypeOfRhs(ASF_getASFConditionTypeOfRhs(arg)) : ASF_getASFConditionTypeOfRhs(arg),
        acceptLhs ? acceptLhs(ASF_getASFConditionLhs(arg)) : ASF_getASFConditionLhs(arg),
        acceptWsAfterLhs ? acceptWsAfterLhs(ASF_getASFConditionWsAfterLhs(arg)) : ASF_getASFConditionWsAfterLhs(arg),
        acceptWsAfterUnequal ? acceptWsAfterUnequal(ASF_getASFConditionWsAfterUnequal(arg)) : ASF_getASFConditionWsAfterUnequal(arg),
        acceptRhs ? acceptRhs(ASF_getASFConditionRhs(arg)) : ASF_getASFConditionRhs(arg));
  }
  if (ASF_isASFConditionEquality(arg)) {
    return ASF_makeASFConditionEquality(
        acceptTypeOfLhs ? acceptTypeOfLhs(ASF_getASFConditionTypeOfLhs(arg)) : ASF_getASFConditionTypeOfLhs(arg),
        acceptTypeOfRhs ? acceptTypeOfRhs(ASF_getASFConditionTypeOfRhs(arg)) : ASF_getASFConditionTypeOfRhs(arg),
        acceptLhs ? acceptLhs(ASF_getASFConditionLhs(arg)) : ASF_getASFConditionLhs(arg),
        acceptWsAfterLhs ? acceptWsAfterLhs(ASF_getASFConditionWsAfterLhs(arg)) : ASF_getASFConditionWsAfterLhs(arg),
        acceptWsAfterEquality ? acceptWsAfterEquality(ASF_getASFConditionWsAfterEquality(arg)) : ASF_getASFConditionWsAfterEquality(arg),
        acceptRhs ? acceptRhs(ASF_getASFConditionRhs(arg)) : ASF_getASFConditionRhs(arg));
  }
  if (ASF_isASFConditionMatch(arg)) {
    return ASF_makeASFConditionMatch(
        acceptTypeOfLhs ? acceptTypeOfLhs(ASF_getASFConditionTypeOfLhs(arg)) : ASF_getASFConditionTypeOfLhs(arg),
        acceptTypeOfRhs ? acceptTypeOfRhs(ASF_getASFConditionTypeOfRhs(arg)) : ASF_getASFConditionTypeOfRhs(arg),
        acceptLhs ? acceptLhs(ASF_getASFConditionLhs(arg)) : ASF_getASFConditionLhs(arg),
        acceptWsAfterLhs ? acceptWsAfterLhs(ASF_getASFConditionWsAfterLhs(arg)) : ASF_getASFConditionWsAfterLhs(arg),
        acceptWsAfterMatch ? acceptWsAfterMatch(ASF_getASFConditionWsAfterMatch(arg)) : ASF_getASFConditionWsAfterMatch(arg),
        acceptRhs ? acceptRhs(ASF_getASFConditionRhs(arg)) : ASF_getASFConditionRhs(arg));
  }
  if (ASF_isASFConditionNoMatch(arg)) {
    return ASF_makeASFConditionNoMatch(
        acceptTypeOfLhs ? acceptTypeOfLhs(ASF_getASFConditionTypeOfLhs(arg)) : ASF_getASFConditionTypeOfLhs(arg),
        acceptTypeOfRhs ? acceptTypeOfRhs(ASF_getASFConditionTypeOfRhs(arg)) : ASF_getASFConditionTypeOfRhs(arg),
        acceptLhs ? acceptLhs(ASF_getASFConditionLhs(arg)) : ASF_getASFConditionLhs(arg),
        acceptWsAfterLhs ? acceptWsAfterLhs(ASF_getASFConditionWsAfterLhs(arg)) : ASF_getASFConditionWsAfterLhs(arg),
        acceptWsAfterMatch ? acceptWsAfterMatch(ASF_getASFConditionWsAfterMatch(arg)) : ASF_getASFConditionWsAfterMatch(arg),
        acceptRhs ? acceptRhs(ASF_getASFConditionRhs(arg)) : ASF_getASFConditionRhs(arg));
  }
  ATabort("not a ASFCondition: %t\n", arg);
  return (ASF_ASFCondition)NULL;
}
/**
 * Apply functions to the children of a ASF_ASFConditions. 
 * \return A new ASF_ASFConditions with new children where the argument functions might have applied
 */
ASF_ASFConditions ASF_visitASFConditions(ASF_ASFConditions arg, ASF_ASFConditionList (*acceptList)(ASF_ASFConditionList)) {
  if (ASF_isASFConditionsDefault(arg)) {
    return ASF_makeASFConditionsDefault(
        acceptList ? acceptList(ASF_getASFConditionsList(arg)) : ASF_getASFConditionsList(arg));
  }
  ATabort("not a ASFConditions: %t\n", arg);
  return (ASF_ASFConditions)NULL;
}
/**
 * Apply functions to the children of a ASF_ASFConditionList. 
 * \return A new ASF_ASFConditionList with new children where the argument functions might have applied
 */
ASF_ASFConditionList ASF_visitASFConditionList(ASF_ASFConditionList arg, ASF_ASFCondition (*acceptHead)(ASF_ASFCondition), ASF_OptLayout (*acceptWsAfterHead)(ASF_OptLayout), ASF_OptLayout (*acceptWsAfterSep)(ASF_OptLayout)) {
  if (ASF_isASFConditionListEmpty(arg)) {
    return ASF_makeASFConditionListEmpty();
  }
  if (ASF_isASFConditionListSingle(arg)) {
    return ASF_makeASFConditionListSingle(
        acceptHead ? acceptHead(ASF_getASFConditionListHead(arg)) : ASF_getASFConditionListHead(arg));
  }
  if (ASF_isASFConditionListMany(arg)) {
    return ASF_makeASFConditionListMany(
        acceptHead ? acceptHead(ASF_getASFConditionListHead(arg)) : ASF_getASFConditionListHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(ASF_getASFConditionListWsAfterHead(arg)) : ASF_getASFConditionListWsAfterHead(arg),
        acceptWsAfterSep ? acceptWsAfterSep(ASF_getASFConditionListWsAfterSep(arg)) : ASF_getASFConditionListWsAfterSep(arg),
        ASF_visitASFConditionList(ASF_getASFConditionListTail(arg), acceptHead, acceptWsAfterHead, acceptWsAfterSep));
  }
  ATabort("not a ASFConditionList: %t\n", arg);
  return (ASF_ASFConditionList)NULL;
}
/**
 * Apply functions to the children of a ASF_TreeAmbs. 
 * \return A new ASF_TreeAmbs with new children where the argument functions might have applied
 */
ASF_TreeAmbs ASF_visitTreeAmbs(ASF_TreeAmbs arg, ASF_Tree (*acceptHead)(ASF_Tree), ASF_OptLayout (*acceptWsAfterHead)(ASF_OptLayout), ASF_OptLayout (*acceptWsAfterSep)(ASF_OptLayout)) {
  if (ASF_isTreeAmbsEmpty(arg)) {
    return ASF_makeTreeAmbsEmpty();
  }
  if (ASF_isTreeAmbsSingle(arg)) {
    return ASF_makeTreeAmbsSingle(
        acceptHead ? acceptHead(ASF_getTreeAmbsHead(arg)) : ASF_getTreeAmbsHead(arg));
  }
  if (ASF_isTreeAmbsMany(arg)) {
    return ASF_makeTreeAmbsMany(
        acceptHead ? acceptHead(ASF_getTreeAmbsHead(arg)) : ASF_getTreeAmbsHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(ASF_getTreeAmbsWsAfterHead(arg)) : ASF_getTreeAmbsWsAfterHead(arg),
        acceptWsAfterSep ? acceptWsAfterSep(ASF_getTreeAmbsWsAfterSep(arg)) : ASF_getTreeAmbsWsAfterSep(arg),
        ASF_visitTreeAmbs(ASF_getTreeAmbsTail(arg), acceptHead, acceptWsAfterHead, acceptWsAfterSep));
  }
  ATabort("not a TreeAmbs: %t\n", arg);
  return (ASF_TreeAmbs)NULL;
}
/**
 * Apply functions to the children of a ASF_CHARList. 
 * \return A new ASF_CHARList with new children where the argument functions might have applied
 */
ASF_CHARList ASF_visitCHARList(ASF_CHARList arg, ASF_CHAR (*acceptHead)(ASF_CHAR), ASF_OptLayout (*acceptWsAfterHead)(ASF_OptLayout)) {
  if (ASF_isCHARListEmpty(arg)) {
    return ASF_makeCHARListEmpty();
  }
  if (ASF_isCHARListSingle(arg)) {
    return ASF_makeCHARListSingle(
        acceptHead ? acceptHead(ASF_getCHARListHead(arg)) : ASF_getCHARListHead(arg));
  }
  if (ASF_isCHARListMany(arg)) {
    return ASF_makeCHARListMany(
        acceptHead ? acceptHead(ASF_getCHARListHead(arg)) : ASF_getCHARListHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(ASF_getCHARListWsAfterHead(arg)) : ASF_getCHARListWsAfterHead(arg),
        ASF_visitCHARList(ASF_getCHARListTail(arg), acceptHead, acceptWsAfterHead));
  }
  ATabort("not a CHARList: %t\n", arg);
  return (ASF_CHARList)NULL;
}
/**
 * Apply functions to the children of a ASF_LexASFBarEnd. 
 * \return A new ASF_LexASFBarEnd with new children where the argument functions might have applied
 */
ASF_LexASFBarEnd ASF_visitLexASFBarEnd(ASF_LexASFBarEnd arg) {
  if (ASF_isLexASFBarEndAbsent(arg)) {
    return ASF_makeLexASFBarEndAbsent();
  }
  if (ASF_isLexASFBarEndPresent(arg)) {
    return ASF_makeLexASFBarEndPresent();
  }
  ATabort("not a LexASFBarEnd: %t\n", arg);
  return (ASF_LexASFBarEnd)NULL;
}
/**
 * Apply functions to the children of a ASF_ASFBarEnd. 
 * \return A new ASF_ASFBarEnd with new children where the argument functions might have applied
 */
ASF_ASFBarEnd ASF_visitASFBarEnd(ASF_ASFBarEnd arg, ASF_LexASFBarEnd (*acceptASFBarEnd)(ASF_LexASFBarEnd)) {
  if (ASF_isASFBarEndLexToCf(arg)) {
    return ASF_makeASFBarEndLexToCf(
        acceptASFBarEnd ? acceptASFBarEnd(ASF_getASFBarEndASFBarEnd(arg)) : ASF_getASFBarEndASFBarEnd(arg));
  }
  ATabort("not a ASFBarEnd: %t\n", arg);
  return (ASF_ASFBarEnd)NULL;
}
/**
 * Apply functions to the children of a ASF_LexASFImplies. 
 * \return A new ASF_LexASFImplies with new children where the argument functions might have applied
 */
ASF_LexASFImplies ASF_visitLexASFImplies(ASF_LexASFImplies arg, char* (*acceptBar)(char*), ASF_LexASFBarEnd (*acceptEnd)(ASF_LexASFBarEnd)) {
  if (ASF_isLexASFImpliesDefault(arg)) {
    return ASF_makeLexASFImpliesDefault(
        acceptBar ? acceptBar(ASF_getLexASFImpliesBar(arg)) : ASF_getLexASFImpliesBar(arg),
        acceptEnd ? acceptEnd(ASF_getLexASFImpliesEnd(arg)) : ASF_getLexASFImpliesEnd(arg));
  }
  ATabort("not a LexASFImplies: %t\n", arg);
  return (ASF_LexASFImplies)NULL;
}
/**
 * Apply functions to the children of a ASF_ASFImplies. 
 * \return A new ASF_ASFImplies with new children where the argument functions might have applied
 */
ASF_ASFImplies ASF_visitASFImplies(ASF_ASFImplies arg, ASF_LexASFImplies (*acceptASFImplies)(ASF_LexASFImplies)) {
  if (ASF_isASFImpliesLexToCf(arg)) {
    return ASF_makeASFImpliesLexToCf(
        acceptASFImplies ? acceptASFImplies(ASF_getASFImpliesASFImplies(arg)) : ASF_getASFImpliesASFImplies(arg));
  }
  ATabort("not a ASFImplies: %t\n", arg);
  return (ASF_ASFImplies)NULL;
}
/**
 * Apply functions to the children of a ASF_ASFConditionalEquation. 
 * \return A new ASF_ASFConditionalEquation with new children where the argument functions might have applied
 */
ASF_ASFConditionalEquation ASF_visitASFConditionalEquation(ASF_ASFConditionalEquation arg, ASF_ASFTag (*acceptASFTag)(ASF_ASFTag), ASF_OptLayout (*acceptWsAfterASFTag)(ASF_OptLayout), ASF_ASFEquation (*acceptASFEquation)(ASF_ASFEquation), ASF_ASFConditions (*acceptASFConditions)(ASF_ASFConditions), ASF_OptLayout (*acceptWsAfterASFConditions)(ASF_OptLayout), ASF_ASFImplies (*acceptASFImplies)(ASF_ASFImplies), ASF_OptLayout (*acceptWsAfterASFImplies)(ASF_OptLayout), ASF_OptLayout (*acceptWsAfterASFEquation)(ASF_OptLayout), ASF_OptLayout (*acceptWsAfterWhen)(ASF_OptLayout)) {
  if (ASF_isASFConditionalEquationSimple(arg)) {
    return ASF_makeASFConditionalEquationSimple(
        acceptASFTag ? acceptASFTag(ASF_getASFConditionalEquationASFTag(arg)) : ASF_getASFConditionalEquationASFTag(arg),
        acceptWsAfterASFTag ? acceptWsAfterASFTag(ASF_getASFConditionalEquationWsAfterASFTag(arg)) : ASF_getASFConditionalEquationWsAfterASFTag(arg),
        acceptASFEquation ? acceptASFEquation(ASF_getASFConditionalEquationASFEquation(arg)) : ASF_getASFConditionalEquationASFEquation(arg));
  }
  if (ASF_isASFConditionalEquationImplies(arg)) {
    return ASF_makeASFConditionalEquationImplies(
        acceptASFTag ? acceptASFTag(ASF_getASFConditionalEquationASFTag(arg)) : ASF_getASFConditionalEquationASFTag(arg),
        acceptWsAfterASFTag ? acceptWsAfterASFTag(ASF_getASFConditionalEquationWsAfterASFTag(arg)) : ASF_getASFConditionalEquationWsAfterASFTag(arg),
        acceptASFConditions ? acceptASFConditions(ASF_getASFConditionalEquationASFConditions(arg)) : ASF_getASFConditionalEquationASFConditions(arg),
        acceptWsAfterASFConditions ? acceptWsAfterASFConditions(ASF_getASFConditionalEquationWsAfterASFConditions(arg)) : ASF_getASFConditionalEquationWsAfterASFConditions(arg),
        acceptASFImplies ? acceptASFImplies(ASF_getASFConditionalEquationASFImplies(arg)) : ASF_getASFConditionalEquationASFImplies(arg),
        acceptWsAfterASFImplies ? acceptWsAfterASFImplies(ASF_getASFConditionalEquationWsAfterASFImplies(arg)) : ASF_getASFConditionalEquationWsAfterASFImplies(arg),
        acceptASFEquation ? acceptASFEquation(ASF_getASFConditionalEquationASFEquation(arg)) : ASF_getASFConditionalEquationASFEquation(arg));
  }
  if (ASF_isASFConditionalEquationWhen(arg)) {
    return ASF_makeASFConditionalEquationWhen(
        acceptASFTag ? acceptASFTag(ASF_getASFConditionalEquationASFTag(arg)) : ASF_getASFConditionalEquationASFTag(arg),
        acceptWsAfterASFTag ? acceptWsAfterASFTag(ASF_getASFConditionalEquationWsAfterASFTag(arg)) : ASF_getASFConditionalEquationWsAfterASFTag(arg),
        acceptASFEquation ? acceptASFEquation(ASF_getASFConditionalEquationASFEquation(arg)) : ASF_getASFConditionalEquationASFEquation(arg),
        acceptWsAfterASFEquation ? acceptWsAfterASFEquation(ASF_getASFConditionalEquationWsAfterASFEquation(arg)) : ASF_getASFConditionalEquationWsAfterASFEquation(arg),
        acceptWsAfterWhen ? acceptWsAfterWhen(ASF_getASFConditionalEquationWsAfterWhen(arg)) : ASF_getASFConditionalEquationWsAfterWhen(arg),
        acceptASFConditions ? acceptASFConditions(ASF_getASFConditionalEquationASFConditions(arg)) : ASF_getASFConditionalEquationASFConditions(arg));
  }
  ATabort("not a ASFConditionalEquation: %t\n", arg);
  return (ASF_ASFConditionalEquation)NULL;
}
/**
 * Apply functions to the children of a ASF_ASFEquation. 
 * \return A new ASF_ASFEquation with new children where the argument functions might have applied
 */
ASF_ASFEquation ASF_visitASFEquation(ASF_ASFEquation arg, ATerm (*acceptTypeOfLhs)(ATerm), ATerm (*acceptTypeOfRhs)(ATerm), ASF_Tree (*acceptLhs)(ASF_Tree), ASF_OptLayout (*acceptWsAfterLhs)(ASF_OptLayout), ASF_OptLayout (*acceptWsAfterEquals)(ASF_OptLayout), ASF_Tree (*acceptRhs)(ASF_Tree)) {
  if (ASF_isASFEquationDefault(arg)) {
    return ASF_makeASFEquationDefault(
        acceptTypeOfLhs ? acceptTypeOfLhs(ASF_getASFEquationTypeOfLhs(arg)) : ASF_getASFEquationTypeOfLhs(arg),
        acceptTypeOfRhs ? acceptTypeOfRhs(ASF_getASFEquationTypeOfRhs(arg)) : ASF_getASFEquationTypeOfRhs(arg),
        acceptLhs ? acceptLhs(ASF_getASFEquationLhs(arg)) : ASF_getASFEquationLhs(arg),
        acceptWsAfterLhs ? acceptWsAfterLhs(ASF_getASFEquationWsAfterLhs(arg)) : ASF_getASFEquationWsAfterLhs(arg),
        acceptWsAfterEquals ? acceptWsAfterEquals(ASF_getASFEquationWsAfterEquals(arg)) : ASF_getASFEquationWsAfterEquals(arg),
        acceptRhs ? acceptRhs(ASF_getASFEquationRhs(arg)) : ASF_getASFEquationRhs(arg));
  }
  ATabort("not a ASFEquation: %t\n", arg);
  return (ASF_ASFEquation)NULL;
}
/**
 * Apply functions to the children of a ASF_Start. 
 * \return A new ASF_Start with new children where the argument functions might have applied
 */
ASF_Start ASF_visitStart(ASF_Start arg, ASF_OptLayout (*acceptWsBefore)(ASF_OptLayout), ASF_ASFModule (*acceptTopASFModule)(ASF_ASFModule), ASF_OptLayout (*acceptWsAfter)(ASF_OptLayout), int (*acceptAmbCnt)(int), ASF_ASFSection (*acceptTopASFSection)(ASF_ASFSection)) {
  if (ASF_isStartASFModule(arg)) {
    return ASF_makeStartASFModule(
        acceptWsBefore ? acceptWsBefore(ASF_getStartWsBefore(arg)) : ASF_getStartWsBefore(arg),
        acceptTopASFModule ? acceptTopASFModule(ASF_getStartTopASFModule(arg)) : ASF_getStartTopASFModule(arg),
        acceptWsAfter ? acceptWsAfter(ASF_getStartWsAfter(arg)) : ASF_getStartWsAfter(arg),
        acceptAmbCnt ? acceptAmbCnt(ASF_getStartAmbCnt(arg)) : ASF_getStartAmbCnt(arg));
  }
  if (ASF_isStartASFSection(arg)) {
    return ASF_makeStartASFSection(
        acceptWsBefore ? acceptWsBefore(ASF_getStartWsBefore(arg)) : ASF_getStartWsBefore(arg),
        acceptTopASFSection ? acceptTopASFSection(ASF_getStartTopASFSection(arg)) : ASF_getStartTopASFSection(arg),
        acceptWsAfter ? acceptWsAfter(ASF_getStartWsAfter(arg)) : ASF_getStartWsAfter(arg),
        acceptAmbCnt ? acceptAmbCnt(ASF_getStartAmbCnt(arg)) : ASF_getStartAmbCnt(arg));
  }
  ATabort("not a Start: %t\n", arg);
  return (ASF_Start)NULL;
}
/**
 * Apply functions to the children of a ASF_ASFModule. 
 * \return A new ASF_ASFModule with new children where the argument functions might have applied
 */
ASF_ASFModule ASF_visitASFModule(ASF_ASFModule arg, ASF_ASFSectionList (*acceptList)(ASF_ASFSectionList)) {
  if (ASF_isASFModuleDefault(arg)) {
    return ASF_makeASFModuleDefault(
        acceptList ? acceptList(ASF_getASFModuleList(arg)) : ASF_getASFModuleList(arg));
  }
  ATabort("not a ASFModule: %t\n", arg);
  return (ASF_ASFModule)NULL;
}
/**
 * Apply functions to the children of a ASF_ASFSection. 
 * \return A new ASF_ASFSection with new children where the argument functions might have applied
 */
ASF_ASFSection ASF_visitASFSection(ASF_ASFSection arg, ASF_OptLayout (*acceptWsAfterEquations)(ASF_OptLayout), ASF_ASFConditionalEquationList (*acceptList)(ASF_ASFConditionalEquationList), ASF_OptLayout (*acceptWsAfterTests)(ASF_OptLayout), ASF_ASFTestEquationTestList (*acceptTestList)(ASF_ASFTestEquationTestList)) {
  if (ASF_isASFSectionEquations(arg)) {
    return ASF_makeASFSectionEquations(
        acceptWsAfterEquations ? acceptWsAfterEquations(ASF_getASFSectionWsAfterEquations(arg)) : ASF_getASFSectionWsAfterEquations(arg),
        acceptList ? acceptList(ASF_getASFSectionList(arg)) : ASF_getASFSectionList(arg));
  }
  if (ASF_isASFSectionTests(arg)) {
    return ASF_makeASFSectionTests(
        acceptWsAfterTests ? acceptWsAfterTests(ASF_getASFSectionWsAfterTests(arg)) : ASF_getASFSectionWsAfterTests(arg),
        acceptTestList ? acceptTestList(ASF_getASFSectionTestList(arg)) : ASF_getASFSectionTestList(arg));
  }
  ATabort("not a ASFSection: %t\n", arg);
  return (ASF_ASFSection)NULL;
}
/**
 * Apply functions to the children of a ASF_ASFSectionList. 
 * \return A new ASF_ASFSectionList with new children where the argument functions might have applied
 */
ASF_ASFSectionList ASF_visitASFSectionList(ASF_ASFSectionList arg, ASF_ASFSection (*acceptHead)(ASF_ASFSection), ASF_OptLayout (*acceptWsAfterHead)(ASF_OptLayout)) {
  if (ASF_isASFSectionListEmpty(arg)) {
    return ASF_makeASFSectionListEmpty();
  }
  if (ASF_isASFSectionListSingle(arg)) {
    return ASF_makeASFSectionListSingle(
        acceptHead ? acceptHead(ASF_getASFSectionListHead(arg)) : ASF_getASFSectionListHead(arg));
  }
  if (ASF_isASFSectionListMany(arg)) {
    return ASF_makeASFSectionListMany(
        acceptHead ? acceptHead(ASF_getASFSectionListHead(arg)) : ASF_getASFSectionListHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(ASF_getASFSectionListWsAfterHead(arg)) : ASF_getASFSectionListWsAfterHead(arg),
        ASF_visitASFSectionList(ASF_getASFSectionListTail(arg), acceptHead, acceptWsAfterHead));
  }
  ATabort("not a ASFSectionList: %t\n", arg);
  return (ASF_ASFSectionList)NULL;
}
/**
 * Apply functions to the children of a ASF_ASFConditionalEquationList. 
 * \return A new ASF_ASFConditionalEquationList with new children where the argument functions might have applied
 */
ASF_ASFConditionalEquationList ASF_visitASFConditionalEquationList(ASF_ASFConditionalEquationList arg, ASF_ASFConditionalEquation (*acceptHead)(ASF_ASFConditionalEquation), ASF_OptLayout (*acceptWsAfterHead)(ASF_OptLayout)) {
  if (ASF_isASFConditionalEquationListEmpty(arg)) {
    return ASF_makeASFConditionalEquationListEmpty();
  }
  if (ASF_isASFConditionalEquationListSingle(arg)) {
    return ASF_makeASFConditionalEquationListSingle(
        acceptHead ? acceptHead(ASF_getASFConditionalEquationListHead(arg)) : ASF_getASFConditionalEquationListHead(arg));
  }
  if (ASF_isASFConditionalEquationListMany(arg)) {
    return ASF_makeASFConditionalEquationListMany(
        acceptHead ? acceptHead(ASF_getASFConditionalEquationListHead(arg)) : ASF_getASFConditionalEquationListHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(ASF_getASFConditionalEquationListWsAfterHead(arg)) : ASF_getASFConditionalEquationListWsAfterHead(arg),
        ASF_visitASFConditionalEquationList(ASF_getASFConditionalEquationListTail(arg), acceptHead, acceptWsAfterHead));
  }
  ATabort("not a ASFConditionalEquationList: %t\n", arg);
  return (ASF_ASFConditionalEquationList)NULL;
}
/**
 * Apply functions to the children of a ASF_ASFTestEquationTestList. 
 * \return A new ASF_ASFTestEquationTestList with new children where the argument functions might have applied
 */
ASF_ASFTestEquationTestList ASF_visitASFTestEquationTestList(ASF_ASFTestEquationTestList arg, ASF_ASFTestEquation (*acceptHead)(ASF_ASFTestEquation), ASF_OptLayout (*acceptWsAfterHead)(ASF_OptLayout)) {
  if (ASF_isASFTestEquationTestListEmpty(arg)) {
    return ASF_makeASFTestEquationTestListEmpty();
  }
  if (ASF_isASFTestEquationTestListSingle(arg)) {
    return ASF_makeASFTestEquationTestListSingle(
        acceptHead ? acceptHead(ASF_getASFTestEquationTestListHead(arg)) : ASF_getASFTestEquationTestListHead(arg));
  }
  if (ASF_isASFTestEquationTestListMany(arg)) {
    return ASF_makeASFTestEquationTestListMany(
        acceptHead ? acceptHead(ASF_getASFTestEquationTestListHead(arg)) : ASF_getASFTestEquationTestListHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(ASF_getASFTestEquationTestListWsAfterHead(arg)) : ASF_getASFTestEquationTestListWsAfterHead(arg),
        ASF_visitASFTestEquationTestList(ASF_getASFTestEquationTestListTail(arg), acceptHead, acceptWsAfterHead));
  }
  ATabort("not a ASFTestEquationTestList: %t\n", arg);
  return (ASF_ASFTestEquationTestList)NULL;
}
/**
 * Apply functions to the children of a ASF_LexASFTagId. 
 * \return A new ASF_LexASFTagId with new children where the argument functions might have applied
 */
ASF_LexASFTagId ASF_visitLexASFTagId(ASF_LexASFTagId arg, char (*acceptHead)(char), char* (*acceptMiddle)(char*), char (*acceptLast)(char)) {
  if (ASF_isLexASFTagIdOneChar(arg)) {
    return ASF_makeLexASFTagIdOneChar(
        acceptHead ? acceptHead(ASF_getLexASFTagIdHead(arg)) : ASF_getLexASFTagIdHead(arg));
  }
  if (ASF_isLexASFTagIdManyChars(arg)) {
    return ASF_makeLexASFTagIdManyChars(
        acceptHead ? acceptHead(ASF_getLexASFTagIdHead(arg)) : ASF_getLexASFTagIdHead(arg),
        acceptMiddle ? acceptMiddle(ASF_getLexASFTagIdMiddle(arg)) : ASF_getLexASFTagIdMiddle(arg),
        acceptLast ? acceptLast(ASF_getLexASFTagIdLast(arg)) : ASF_getLexASFTagIdLast(arg));
  }
  ATabort("not a LexASFTagId: %t\n", arg);
  return (ASF_LexASFTagId)NULL;
}
/**
 * Apply functions to the children of a ASF_ASFTagId. 
 * \return A new ASF_ASFTagId with new children where the argument functions might have applied
 */
ASF_ASFTagId ASF_visitASFTagId(ASF_ASFTagId arg, ASF_LexASFTagId (*acceptASFTagId)(ASF_LexASFTagId)) {
  if (ASF_isASFTagIdLexToCf(arg)) {
    return ASF_makeASFTagIdLexToCf(
        acceptASFTagId ? acceptASFTagId(ASF_getASFTagIdASFTagId(arg)) : ASF_getASFTagIdASFTagId(arg));
  }
  ATabort("not a ASFTagId: %t\n", arg);
  return (ASF_ASFTagId)NULL;
}
/**
 * Apply functions to the children of a ASF_ASFTag. 
 * \return A new ASF_ASFTag with new children where the argument functions might have applied
 */
ASF_ASFTag ASF_visitASFTag(ASF_ASFTag arg, ASF_OptLayout (*acceptWsAfterBracketOpen)(ASF_OptLayout), ASF_ASFTagId (*acceptASFTagId)(ASF_ASFTagId), ASF_OptLayout (*acceptWsAfterASFTagId)(ASF_OptLayout)) {
  if (ASF_isASFTagEmpty(arg)) {
    return ASF_makeASFTagEmpty(
        acceptWsAfterBracketOpen ? acceptWsAfterBracketOpen(ASF_getASFTagWsAfterBracketOpen(arg)) : ASF_getASFTagWsAfterBracketOpen(arg));
  }
  if (ASF_isASFTagNotEmpty(arg)) {
    return ASF_makeASFTagNotEmpty(
        acceptWsAfterBracketOpen ? acceptWsAfterBracketOpen(ASF_getASFTagWsAfterBracketOpen(arg)) : ASF_getASFTagWsAfterBracketOpen(arg),
        acceptASFTagId ? acceptASFTagId(ASF_getASFTagASFTagId(arg)) : ASF_getASFTagASFTagId(arg),
        acceptWsAfterASFTagId ? acceptWsAfterASFTagId(ASF_getASFTagWsAfterASFTagId(arg)) : ASF_getASFTagWsAfterASFTagId(arg));
  }
  ATabort("not a ASFTag: %t\n", arg);
  return (ASF_ASFTag)NULL;
}
/**
 * Apply functions to the children of a ASF_ASFTestEquation. 
 * \return A new ASF_ASFTestEquation with new children where the argument functions might have applied
 */
ASF_ASFTestEquation ASF_visitASFTestEquation(ASF_ASFTestEquation arg, ASF_ASFTag (*acceptASFTag)(ASF_ASFTag), ASF_OptLayout (*acceptWsAfterASFTag)(ASF_OptLayout), ASF_ASFCondition (*acceptASFCondition)(ASF_ASFCondition), ASF_ASFConditions (*acceptASFConditions)(ASF_ASFConditions), ASF_OptLayout (*acceptWsAfterASFConditions)(ASF_OptLayout), ASF_ASFImplies (*acceptASFImplies)(ASF_ASFImplies), ASF_OptLayout (*acceptWsAfterASFImplies)(ASF_OptLayout), ASF_OptLayout (*acceptWsAfterASFCondition)(ASF_OptLayout), ASF_OptLayout (*acceptWsAfterWhen)(ASF_OptLayout)) {
  if (ASF_isASFTestEquationSimple(arg)) {
    return ASF_makeASFTestEquationSimple(
        acceptASFTag ? acceptASFTag(ASF_getASFTestEquationASFTag(arg)) : ASF_getASFTestEquationASFTag(arg),
        acceptWsAfterASFTag ? acceptWsAfterASFTag(ASF_getASFTestEquationWsAfterASFTag(arg)) : ASF_getASFTestEquationWsAfterASFTag(arg),
        acceptASFCondition ? acceptASFCondition(ASF_getASFTestEquationASFCondition(arg)) : ASF_getASFTestEquationASFCondition(arg));
  }
  if (ASF_isASFTestEquationImplies(arg)) {
    return ASF_makeASFTestEquationImplies(
        acceptASFTag ? acceptASFTag(ASF_getASFTestEquationASFTag(arg)) : ASF_getASFTestEquationASFTag(arg),
        acceptWsAfterASFTag ? acceptWsAfterASFTag(ASF_getASFTestEquationWsAfterASFTag(arg)) : ASF_getASFTestEquationWsAfterASFTag(arg),
        acceptASFConditions ? acceptASFConditions(ASF_getASFTestEquationASFConditions(arg)) : ASF_getASFTestEquationASFConditions(arg),
        acceptWsAfterASFConditions ? acceptWsAfterASFConditions(ASF_getASFTestEquationWsAfterASFConditions(arg)) : ASF_getASFTestEquationWsAfterASFConditions(arg),
        acceptASFImplies ? acceptASFImplies(ASF_getASFTestEquationASFImplies(arg)) : ASF_getASFTestEquationASFImplies(arg),
        acceptWsAfterASFImplies ? acceptWsAfterASFImplies(ASF_getASFTestEquationWsAfterASFImplies(arg)) : ASF_getASFTestEquationWsAfterASFImplies(arg),
        acceptASFCondition ? acceptASFCondition(ASF_getASFTestEquationASFCondition(arg)) : ASF_getASFTestEquationASFCondition(arg));
  }
  if (ASF_isASFTestEquationWhen(arg)) {
    return ASF_makeASFTestEquationWhen(
        acceptASFTag ? acceptASFTag(ASF_getASFTestEquationASFTag(arg)) : ASF_getASFTestEquationASFTag(arg),
        acceptWsAfterASFTag ? acceptWsAfterASFTag(ASF_getASFTestEquationWsAfterASFTag(arg)) : ASF_getASFTestEquationWsAfterASFTag(arg),
        acceptASFCondition ? acceptASFCondition(ASF_getASFTestEquationASFCondition(arg)) : ASF_getASFTestEquationASFCondition(arg),
        acceptWsAfterASFCondition ? acceptWsAfterASFCondition(ASF_getASFTestEquationWsAfterASFCondition(arg)) : ASF_getASFTestEquationWsAfterASFCondition(arg),
        acceptWsAfterWhen ? acceptWsAfterWhen(ASF_getASFTestEquationWsAfterWhen(arg)) : ASF_getASFTestEquationWsAfterWhen(arg),
        acceptASFConditions ? acceptASFConditions(ASF_getASFTestEquationASFConditions(arg)) : ASF_getASFTestEquationASFConditions(arg));
  }
  ATabort("not a ASFTestEquation: %t\n", arg);
  return (ASF_ASFTestEquation)NULL;
}
/**
 * Apply functions to the children of a ASF_LexLayout. 
 * \return A new ASF_LexLayout with new children where the argument functions might have applied
 */
ASF_LexLayout ASF_visitLexLayout(ASF_LexLayout arg, char (*acceptCh)(char)) {
  if (ASF_isLexLayoutWhitespace(arg)) {
    return ASF_makeLexLayoutWhitespace(
        acceptCh ? acceptCh(ASF_getLexLayoutCh(arg)) : ASF_getLexLayoutCh(arg));
  }
  ATabort("not a LexLayout: %t\n", arg);
  return (ASF_LexLayout)NULL;
}
/**
 * Apply functions to the children of a ASF_LexNumChar. 
 * \return A new ASF_LexNumChar with new children where the argument functions might have applied
 */
ASF_LexNumChar ASF_visitLexNumChar(ASF_LexNumChar arg, char* (*acceptNumber)(char*)) {
  if (ASF_isLexNumCharDigits(arg)) {
    return ASF_makeLexNumCharDigits(
        acceptNumber ? acceptNumber(ASF_getLexNumCharNumber(arg)) : ASF_getLexNumCharNumber(arg));
  }
  ATabort("not a LexNumChar: %t\n", arg);
  return (ASF_LexNumChar)NULL;
}
/**
 * Apply functions to the children of a ASF_NumChar. 
 * \return A new ASF_NumChar with new children where the argument functions might have applied
 */
ASF_NumChar ASF_visitNumChar(ASF_NumChar arg, ASF_LexNumChar (*acceptNumChar)(ASF_LexNumChar)) {
  if (ASF_isNumCharLexToCf(arg)) {
    return ASF_makeNumCharLexToCf(
        acceptNumChar ? acceptNumChar(ASF_getNumCharNumChar(arg)) : ASF_getNumCharNumChar(arg));
  }
  ATabort("not a NumChar: %t\n", arg);
  return (ASF_NumChar)NULL;
}
/**
 * Apply functions to the children of a ASF_LexShortChar. 
 * \return A new ASF_LexShortChar with new children where the argument functions might have applied
 */
ASF_LexShortChar ASF_visitLexShortChar(ASF_LexShortChar arg, char (*acceptCharacter)(char), char (*acceptEscape)(char)) {
  if (ASF_isLexShortCharRegular(arg)) {
    return ASF_makeLexShortCharRegular(
        acceptCharacter ? acceptCharacter(ASF_getLexShortCharCharacter(arg)) : ASF_getLexShortCharCharacter(arg));
  }
  if (ASF_isLexShortCharEscaped(arg)) {
    return ASF_makeLexShortCharEscaped(
        acceptEscape ? acceptEscape(ASF_getLexShortCharEscape(arg)) : ASF_getLexShortCharEscape(arg));
  }
  ATabort("not a LexShortChar: %t\n", arg);
  return (ASF_LexShortChar)NULL;
}
/**
 * Apply functions to the children of a ASF_ShortChar. 
 * \return A new ASF_ShortChar with new children where the argument functions might have applied
 */
ASF_ShortChar ASF_visitShortChar(ASF_ShortChar arg, ASF_LexShortChar (*acceptShortChar)(ASF_LexShortChar)) {
  if (ASF_isShortCharLexToCf(arg)) {
    return ASF_makeShortCharLexToCf(
        acceptShortChar ? acceptShortChar(ASF_getShortCharShortChar(arg)) : ASF_getShortCharShortChar(arg));
  }
  ATabort("not a ShortChar: %t\n", arg);
  return (ASF_ShortChar)NULL;
}
/**
 * Apply functions to the children of a ASF_Character. 
 * \return A new ASF_Character with new children where the argument functions might have applied
 */
ASF_Character ASF_visitCharacter(ASF_Character arg, ASF_NumChar (*acceptNumChar)(ASF_NumChar), ASF_ShortChar (*acceptShortChar)(ASF_ShortChar)) {
  if (ASF_isCharacterNumeric(arg)) {
    return ASF_makeCharacterNumeric(
        acceptNumChar ? acceptNumChar(ASF_getCharacterNumChar(arg)) : ASF_getCharacterNumChar(arg));
  }
  if (ASF_isCharacterShort(arg)) {
    return ASF_makeCharacterShort(
        acceptShortChar ? acceptShortChar(ASF_getCharacterShortChar(arg)) : ASF_getCharacterShortChar(arg));
  }
  if (ASF_isCharacterTop(arg)) {
    return ASF_makeCharacterTop();
  }
  if (ASF_isCharacterEof(arg)) {
    return ASF_makeCharacterEof();
  }
  if (ASF_isCharacterBot(arg)) {
    return ASF_makeCharacterBot();
  }
  if (ASF_isCharacterLabelUnderscoreStart(arg)) {
    return ASF_makeCharacterLabelUnderscoreStart();
  }
  ATabort("not a Character: %t\n", arg);
  return (ASF_Character)NULL;
}

